@@ -1,4 +1,3 @@
-# -*-python-*-
 # GemRB - Infinity Engine Emulator
 # Copyright (C) 2003 The GemRB Project
 #
@@ -24,6 +23,7 @@ import GameCheck
 import GUIClasses
 import collections
 import CommonTables
+import Spellbook
 from ie_restype import RES_CHU, RES_2DA, RES_BAM, RES_WAV
 from ie_spells import LS_MEMO
 from GUIDefines import *
@@ -32,19 +32,13 @@ from ie_stats import *
 CommonTables.Load ()
 
 def GetWindowPack():
-	width = GemRB.GetSystemVariable (SV_WIDTH)
 	height = GemRB.GetSystemVariable (SV_HEIGHT)
 
-	if GemRB.GameType == "pst":
+	if GameCheck.IsPST ():
 		default = "GUIWORLD"
 	else:
 		default = "GUIW"
 
-	# use a custom gui if there is one
-	gui = "CGUI" + str(width)[:2] + str(height)[:2]
-	if GemRB.HasResource (gui, RES_CHU, 1):
-		return gui
-
 	# select this based on height
 	# we do this because:
 	# 1. windows are never the entire width,
@@ -52,12 +46,19 @@ def GetWindowPack():
 	# 2. the originals were for 4:3 screens,
 	#    but modern screens are usually a wider aspect
 	# 3. not all games have all the window packs
-	if height >= 960 and GemRB.HasResource ("GUIW12", RES_CHU, 1):
-		return "GUIW12"
-	elif height >= 768 and GemRB.HasResource ("GUIW10", RES_CHU, 1):
+	# ... but the widescreen mod only modifies guiw08 or guiw10, not touching others
+	# luckily internally its guiw08 is in the end produced as a copy of guiw10
+	if GameCheck.HasWideScreenMod ():
+		if GameCheck.IsBG1 () or GameCheck.IsPST ():
+			return default
 		return "GUIW10"
-	elif height >= 600 and GemRB.HasResource ("GUIW08", RES_CHU, 1):
-		return "GUIW08"
+	else:
+		if height >= 960 and GemRB.HasResource ("GUIW12", RES_CHU, 1):
+			return "GUIW12"
+		elif height >= 768 and GemRB.HasResource ("GUIW10", RES_CHU, 1):
+			return "GUIW10"
+		elif height >= 600 and GemRB.HasResource ("GUIW08", RES_CHU, 1):
+			return "GUIW08"
 
 	# fallback to the smallest resolution
 	return default
@@ -74,14 +75,10 @@ def LocationPressed ():
 
 	return
 
-def SelectFormation (btn, val):
-	GemRB.GameSetFormation (val)
-	return
-
-def OpenFloatMenuWindow (x, y):
+def OpenFloatMenuWindow (point):
 	if GameCheck.IsPST():
 		import FloatMenuWindow
-		FloatMenuWindow.OpenFloatMenuWindow(x, y)
+		FloatMenuWindow.OpenFloatMenuWindow(**point)
 	else:
 		GemRB.GameControlSetTargetMode (TARGET_MODE_NONE)
 
@@ -102,10 +99,6 @@ def GetActorPaperDoll (actor):
 def SelectAllOnPress ():
 	GemRB.GameSelectPC (0, 1)
 
-def GearsClicked ():
-	#GemRB.SetPlayerStat(GemRB.GameGetFirstSelectedPC (),44,249990)
-	GemRB.GamePause (2, 0)
-
 def GetAbilityBonus (Actor, Stat):
 	Ability = GemRB.GetPlayerStat (Actor, Stat)
 	return Ability//2-5
@@ -132,7 +125,7 @@ def CheckStat20 (Actor, Stat, Diff):
 	return False
 
 def GetGUISpellButtonCount ():
-	if GameCheck.HasHOW() or GameCheck.IsBG2():
+	if GameCheck.HasHOW() or GameCheck.IsBG2OrEE ():
 		return 24
 	else:
 		return 20
@@ -174,7 +167,6 @@ def ResolveClassAbilities (pc, ClassName):
 # Adds class/kit abilities
 def AddClassAbilities (pc, table, Level=1, LevelDiff=1, align=-1):
 	TmpTable = GemRB.LoadTable (table)
-	import Spellbook
 
 	# gotta stay positive
 	if Level-LevelDiff < 0:
@@ -199,37 +191,32 @@ def AddClassAbilities (pc, table, Level=1, LevelDiff=1, align=-1):
 		# apply each spell from each new class
 		for j in range (jMin, jMax):
 			ab = TmpTable.GetValue (i, j, GTV_STR)
-			if ab and ab != "****":
-				# seems all SPINs act like GA_*
-				if ab[:4] == "SPIN":
-					ab = "GA_" + ab
+			AddClassAbility(pc, ab)
 
-				# apply spell (AP_) or gain spell (GA_)
-				if ab[:3] == "AP_":
-					GemRB.ApplySpell (pc, ab[3:])
-				elif ab[:3] == "GA_":
-					Spellbook.LearnSpell (pc, ab[3:], IE_SPELL_TYPE_INNATE, 0, 1, LS_MEMO)
-				elif ab[:3] == "FS_":
-					Gain(26320, ab[3:])
-				elif ab[:3] == "FA_":
-					Gain(10514, ab[3:])
-				else:
-					GemRB.Log (LOG_ERROR, "AddClassAbilities", "Unknown class ability (type): " + ab)
-
-def MakeSpellCount (pc, spell, count):
-	have = GemRB.CountSpells (pc, spell, 1)
-	if count<=have:
+def AddClassAbility (pc, ab):
+	if not ab or ab == "****":
 		return
-	# only used for innates, which are all level 1
-	import Spellbook
-	Spellbook.LearnSpell (pc, spell, IE_IWD2_SPELL_INNATE, 0, count-have, LS_MEMO)
-	return
+
+	# seems all SPINs act like GA_*
+	if ab[:4] == "SPIN":
+		ab = "GA_" + ab
+
+	# apply spell (AP_) or gain spell (GA_)
+	if ab[:3] == "AP_":
+		GemRB.ApplySpell (pc, ab[3:])
+	elif ab[:3] == "GA_":
+		Spellbook.LearnSpell (pc, ab[3:], IE_SPELL_TYPE_INNATE, 0, 1, LS_MEMO)
+	elif ab[:3] == "FS_":
+		Gain(26320, ab[3:])
+	elif ab[:3] == "FA_":
+		Gain(10514, ab[3:])
+	else:
+		GemRB.Log (LOG_ERROR, "AddClassAbilities", "Unknown class ability (type): " + ab)
 
 # remove all class abilities up to the given level
 # for dual-classing mainly
 def RemoveClassAbilities (pc, table, Level):
 	TmpTable = GemRB.LoadTable (table)
-	import Spellbook
 
 	# gotta stay positive
 	if Level < 0:
@@ -243,25 +230,30 @@ def RemoveClassAbilities (pc, table, Level):
 	for i in range(TmpTable.GetRowCount ()):
 		for j in range (jMax):
 			ab = TmpTable.GetValue (i, j, GTV_STR)
-			if ab and ab != "****":
-				# get the index
-				SpellIndex = Spellbook.HasSpell (pc, IE_SPELL_TYPE_INNATE, 0, ab[3:])
+			RemoveClassAbility (pc, ab)
 
-				# seems all SPINs act like GA_*
-				if ab[:4] == "SPIN":
-					ab = "GA_" + ab
+def RemoveClassAbility (pc, ab):
+	if not ab or ab == "****":
+		return
 
-				# apply spell (AP_) or gain spell (GA_)?
-				if ab[:3] == "AP_":
-					GemRB.RemoveEffects (pc, ab[3:])
-				elif ab[:3] == "GA_":
-					if SpellIndex >= 0:
-						# TODO: get the correct counts to avoid removing an innate ability
-						# given by more than one thing?
-						# RemoveSpell will unmemorize them all too
-						GemRB.RemoveSpell (pc, IE_SPELL_TYPE_INNATE, 0, SpellIndex)
-				elif ab[:3] != "FA_" and ab[:3] != "FS_":
-					GemRB.Log (LOG_ERROR, "RemoveClassAbilities", "Unknown class ability (type): " + ab)
+	# get the index
+	SpellIndex = Spellbook.HasSpell (pc, IE_SPELL_TYPE_INNATE, 0, ab[3:])
+
+	# seems all SPINs act like GA_*
+	if ab[:4] == "SPIN":
+		ab = "GA_" + ab
+
+	# apply spell (AP_) or gain spell (GA_)?
+	if ab[:3] == "AP_":
+		GemRB.RemoveEffects (pc, ab[3:])
+	elif ab[:3] == "GA_":
+		if SpellIndex >= 0:
+			# TODO: get the correct counts to avoid removing an innate ability
+			# given by more than one thing?
+			# RemoveSpell will unmemorize them all too
+			GemRB.RemoveSpell (pc, IE_SPELL_TYPE_INNATE, 0, SpellIndex)
+	elif ab[:3] != "FA_" and ab[:3] != "FS_":
+		GemRB.Log (LOG_ERROR, "RemoveClassAbilities", "Unknown class ability (type): " + ab)
 
 # PST uses a button, IWD2 two types, the rest are the same with two labels
 def SetEncumbranceLabels (Window, ControlID, Control2ID, pc):
@@ -288,14 +280,14 @@ def SetEncumbranceLabels (Window, ControlID, Control2ID, pc):
 	ratio = encumbrance / max_encumb
 	if GameCheck.IsIWD2 () or GameCheck.IsPST ():
 		if ratio > 1.0:
-			Control.SetTextColor ({'r' : 255, 'g' : 0, 'b' : 0})
+			Control.SetColor ({'r' : 255, 'g' : 0, 'b' : 0})
 		elif ratio > 0.8:
-			Control.SetTextColor ({'r' : 255, 'g' : 255, 'b' : 0})
+			Control.SetColor ({'r' : 255, 'g' : 255, 'b' : 0})
 		else:
-			Control.SetTextColor ({'r' : 255, 'g' : 255, 'b' : 255})
+			Control.SetColor ({'r' : 255, 'g' : 255, 'b' : 255})
 
 		if Control2ID:
-			Control2.SetTextColor ({'r' : 255, 'g' : 0, 'b' : 0})
+			Control2.SetColor ({'r' : 255, 'g' : 0, 'b' : 0})
 
 	else:
 		if ratio > 1.0:
@@ -311,52 +303,43 @@ def GetActorClassTitle (actor):
 	"""Returns the string representation of the actors class."""
 
 	ClassTitle = GemRB.GetPlayerStat (actor, IE_TITLE1)
-
-	if ClassTitle == 0:
-		ClassName = GetClassRowName (actor)
-		KitIndex = GetKitIndex (actor)
-		Multi = HasMultiClassBits (actor)
-		Dual = IsDualClassed (actor, 1)
-		MCFlags = GemRB.GetPlayerStat (actor, IE_MC_FLAGS)
-
-		if Multi and Dual[0] == 0: # true multi class
-			ClassTitle = CommonTables.Classes.GetValue (ClassName, "CAP_REF", GTV_REF)
-		else:
-			if Dual[0]: # dual class
-				# first (previous) kit or class of the dual class
-				if Dual[0] == 1:
-					ClassTitle = CommonTables.KitList.GetValue (Dual[1], 2)
-				else:
-					ClassTitle = CommonTables.Classes.GetValue (GetClassRowName(Dual[1], "index"), "CAP_REF")
-				if ClassTitle != "*":
-					ClassTitle = GemRB.GetString (ClassTitle)
-				ClassTitle += " / "
-				if Dual[0] == 3:
-					ClassTitle += CommonTables.KitList.GetValue (Dual[2], 2, GTV_REF)
-				else:
-					ClassTitle += CommonTables.Classes.GetValue (GetClassRowName(Dual[2], "index"), "CAP_REF", GTV_REF)
-			elif MCFlags & (MC_FALLEN_PALADIN|MC_FALLEN_RANGER): # fallen
-				ClassTitle = 10369
-				if MCFlags & MC_FALLEN_PALADIN:
-					ClassTitle = 10371
-				ClassTitle = GemRB.GetString (ClassTitle)
-			else: # ordinary class or kit
-				if KitIndex:
-					ClassTitle = CommonTables.KitList.GetValue (KitIndex, 2)
-				else:
-					ClassTitle = CommonTables.Classes.GetValue (ClassName, "CAP_REF")
-				if ClassTitle != "*":
-					ClassTitle = GemRB.GetString (ClassTitle)
-	else:
+	if ClassTitle != 0:
 		ClassTitle = GemRB.GetString (ClassTitle)
+		return ClassTitle
 
-	#GetActorClassTitle returns string now...
-	#if ClassTitle == "*":
-	#	return 0
+	ClassName = GetClassRowName (actor)
+	KitIndex = GetKitIndex (actor)
+	Multi = HasMultiClassBits (actor)
+	Dual = IsDualClassed (actor, 1)
+	MCFlags = GemRB.GetPlayerStat (actor, IE_MC_FLAGS)
+
+	if Multi and Dual[0] == 0: # true multi class
+		ClassTitle = CommonTables.Classes.GetValue (ClassName, "CAP_REF", GTV_REF)
+		return ClassTitle
+
+	if Dual[0]: # dual class
+		# first (previous) kit or class of the dual class
+		if Dual[0] == 1:
+			ClassTitle = CommonTables.KitList.GetValue (Dual[1], 2, GTV_REF)
+		else:
+			ClassTitle = CommonTables.Classes.GetValue (GetClassRowName(Dual[1], "index"), "CAP_REF", GTV_REF)
+		ClassTitle += " / "
+		if Dual[0] == 3:
+			ClassTitle += CommonTables.KitList.GetValue (Dual[2], 2, GTV_REF)
+		else:
+			ClassTitle += CommonTables.Classes.GetValue (GetClassRowName(Dual[2], "index"), "CAP_REF", GTV_REF)
+	elif MCFlags & (MC_FALLEN_PALADIN | MC_FALLEN_RANGER): # fallen
+		ClassTitle = 10369
+		if MCFlags & MC_FALLEN_PALADIN:
+			ClassTitle = 10371
+		ClassTitle = GemRB.GetString (ClassTitle)
+	elif KitIndex: # ordinary kit
+		ClassTitle = CommonTables.KitList.GetValue (KitIndex, 2, GTV_REF)
+	else: # ordinary class
+		ClassTitle = CommonTables.Classes.GetValue (ClassName, "CAP_REF", GTV_REF)
 
 	return ClassTitle
 
-
 def GetKitIndex (actor):
 	"""Return the index of the actors kit from KITLIST.2da.
 
@@ -365,14 +348,11 @@ def GetKitIndex (actor):
 	Kit = GemRB.GetPlayerStat (actor, IE_KIT)
 	KitIndex = 0
 
-	if Kit & 0xc000 == 0x4000:
-		KitIndex = Kit & 0xfff
-
 	# carefully looking for kit by the usability flag
 	# since the barbarian kit id clashes with the no-kit value
 	if KitIndex == 0 and Kit != 0x4000:
 		KitIndex = CommonTables.KitList.FindValue (6, Kit)
-		if KitIndex == -1:
+		if KitIndex is None:
 			KitIndex = 0
 
 	return KitIndex
@@ -391,18 +371,20 @@ def GetClassRowName(value, which=-1):
 		else:
 			raise RuntimeError("Bad type parameter for GetClassRowName: " + str(which))
 		ClassIndex = CommonTables.Classes.FindValue ("ID", Class)
+	if ClassIndex is None:
+		return ""
 	ClassRowName = CommonTables.Classes.GetRowName (ClassIndex)
 	return ClassRowName
 
 # checks the classes.2da table if the class is multiclass/dualclass capable (bits define the class combination)
 def HasMultiClassBits(actor):
-	MultiBits = CommonTables.Classes.GetValue (GetClassRowName(actor), "MULTI")
+	MultiBits = CommonTables.Classes.GetValue (GetClassRowName(actor), "MULTI", GTV_STR)
 
 	# we have no entries for npc creature classes, so treat them as single-classed
 	if MultiBits == "*":
-		MultiBits = 0
+		return 0
 
-	return MultiBits
+	return int(MultiBits)
 
 def IsDualClassed(actor, verbose):
 	"""Returns an array containing the dual class information.
@@ -412,57 +394,50 @@ def IsDualClassed(actor, verbose):
 	Return[2] contains the class index of the new class.
 	If verbose is false, only Return[0] contains useable data."""
 
-	if GameCheck.IsIWD2():
-		return (0,-1,-1)
-
 	Multi = HasMultiClassBits (actor)
-
-	if Multi == 0:
+	if Multi == 0: # also catches iwd2
 		return (0, -1, -1)
 
 	DualedFrom = GemRB.GetPlayerStat (actor, IE_MC_FLAGS) & MC_WAS_ANY_CLASS
+	if DualedFrom == 0:
+		return (0, -1, -1)
 
-	if verbose:
-		KitIndex = GetKitIndex (actor)
-		if KitIndex:
-			KittedClass = CommonTables.KitList.GetValue (KitIndex, 7)
-			KittedClassIndex = CommonTables.Classes.FindValue ("ID", KittedClass)
-		else:
-			KittedClassIndex = 0
+	if not verbose:
+		return (1, -1, -1)
 
-		if DualedFrom > 0: # first (previous) class of the dual class
-			FirstClassIndex = CommonTables.Classes.FindValue ("MC_WAS_ID", DualedFrom)
-
-			# use the first class of the multiclass bunch that isn't the same as the first class
-			for i in range (1,16):
-				Mask = 1 << (i - 1)
-				if Multi & Mask:
-					ClassIndex = CommonTables.Classes.FindValue ("ID", i)
-					if ClassIndex == FirstClassIndex:
-						continue
-					SecondClassIndex = ClassIndex
-					break
-			else:
-				GemRB.Log (LOG_WARNING, "IsDualClassed", "Invalid dualclass combination, treating as a single class!")
-				print(DualedFrom, Multi, KitIndex, FirstClassIndex)
-				return (0,-1,-1)
-
-			if KittedClassIndex == FirstClassIndex and KitIndex:
-				return (1, KitIndex, SecondClassIndex)
-			elif KittedClassIndex == SecondClassIndex:
-				return (3, FirstClassIndex, KitIndex)
-			else:
-				return (2, FirstClassIndex, SecondClassIndex)
-		else:
-			return (0,-1,-1)
+	KitIndex = GetKitIndex (actor)
+	if KitIndex:
+		KittedClass = CommonTables.KitList.GetValue (KitIndex, 7)
+		KittedClassIndex = CommonTables.Classes.FindValue ("ID", KittedClass)
 	else:
-		if DualedFrom > 0:
-			return (1,-1,-1)
-		else:
-			return (0,-1,-1)
+		KittedClassIndex = 0
+
+	# first (previous) class of the dual class
+	FirstClassIndex = CommonTables.Classes.FindValue ("MC_WAS_ID", DualedFrom)
+
+	# use the first class of the multiclass bunch that isn't the same as the first class
+	for i in range (1,16):
+		Mask = 1 << (i - 1)
+		if Multi & Mask:
+			ClassIndex = CommonTables.Classes.FindValue ("ID", i)
+			if ClassIndex == FirstClassIndex:
+				continue
+			SecondClassIndex = ClassIndex
+			break
+	else:
+		GemRB.Log (LOG_WARNING, "IsDualClassed", "Invalid dualclass combination, treating as a single class!")
+		print(DualedFrom, Multi, KitIndex, FirstClassIndex)
+		return (0, -1, -1)
+
+	if KittedClassIndex == FirstClassIndex and KitIndex:
+		return (1, KitIndex, SecondClassIndex)
+	elif KittedClassIndex == SecondClassIndex:
+		return (3, FirstClassIndex, KitIndex)
+	else:
+		return (2, FirstClassIndex, SecondClassIndex)
 
 def IsDualSwap (actor, override=None):
-	"""Returns true if the dualed classes are reverse of expection.
+	"""Returns true if the dualed classes are reverse of expectation.
 
 	This can happen, because the engine gives dualclass characters the same ID as
 	their multiclass counterpart (eg. FIGHTER_MAGE = 3). Logic would dictate that
@@ -490,11 +465,11 @@ def IsDualSwap (actor, override=None):
 	if Dual[0] > 1:
 		BaseClass = GetClassRowName(Dual[1], "index")
 	else:
-		BaseClass = CommonTables.KitList.GetValue (Dual[1], 7)
+		BaseClass = CommonTables.KitList.GetValue (Dual[1], 7, GTV_STR)
 		if BaseClass == "*":
 			# mod boilerplate
 			return 0
-		BaseClass = GetClassRowName(BaseClass, "class")
+		BaseClass = GetClassRowName(int(BaseClass), "class")
 
 	# if our old class is the first class, we need to swap
 	if Class[0] == BaseClass:
@@ -532,18 +507,21 @@ def IsMultiClassed (actor, verbose):
 	# loop through each class and test it as a mask
 	ClassCount = CommonTables.Classes.GetRowCount()
 	for i in range (1, ClassCount):
-		if IsMulti&Mask: # it's part of this class
-			#we need to place the classes in the array based on their order in the name,
-			#NOT the order they are detected in
-			CurrentName = GetClassRowName (i, "class")
-			if CurrentName == "*":
-				# we read too far, as the upper range limit is greater than the number of "single" classes
-				break
-			for j in range(len(ClassNames)):
-				if ClassNames[j] == CurrentName:
-					Classes[j] = i # mask is (i-1)^2 where i is class id
-			NumClasses = NumClasses+1
-		Mask = 1 << i # shift to the next multiple of 2 for testing
+		if IsMulti & Mask == 0:
+			Mask = 1 << i
+			continue
+
+		# we need to place the classes in the array based on their order in the name,
+		# NOT the order they are detected in
+		CurrentName = GetClassRowName (i, "class")
+		if CurrentName == "*":
+			# we read too far, as the upper range limit is greater than the number of "single" classes
+			break
+		for j in range(len(ClassNames)):
+			if ClassNames[j] == CurrentName:
+				Classes[j] = i # mask is (i-1)^2 where i is class id
+		NumClasses = NumClasses + 1
+		Mask = 1 << i
 
 	# in case we couldn't figure out to which classes the multi belonged
 	if NumClasses < 2:
@@ -576,25 +554,33 @@ def NamelessOneClass (actor):
 def CanDualClass(actor):
 	# race restriction (human)
 	RaceName = CommonTables.Races.FindValue ("ID", GemRB.GetPlayerStat (actor, IE_RACE, 1))
+	if RaceName == None:
+		return 0
 	RaceName = CommonTables.Races.GetRowName (RaceName)
-	RaceDual = CommonTables.Races.GetValue (RaceName, "CANDUAL")
-	if int(RaceDual) != 1:
-		return 1
+	RaceDual = CommonTables.Races.GetValue (RaceName, "CANDUAL", GTV_STR)
+	if RaceDual != "1":
+		return 0
 
 	# already dualclassed
 	Dual = IsDualClassed (actor,0)
 	if Dual[0] > 0:
-		return 1
+		return 0
 
 	DualClassTable = GemRB.LoadTable ("dualclas")
-	CurrentStatTable = GemRB.LoadTable ("abdcscrq")
 	ClassName = GetClassRowName(actor)
 	KitIndex = GetKitIndex (actor)
 	if KitIndex == 0:
 		ClassTitle = ClassName
 	else:
-		ClassTitle = CommonTables.KitList.GetValue (KitIndex, 0)
+		ClassTitle = CommonTables.KitList.GetValue (KitIndex, 0, GTV_STR)
 	Row = DualClassTable.GetRowIndex (ClassTitle)
+	if Row == None and KitIndex > 0:
+		# retry with the baseclass in case the kit/school is missing (eg. wildmages)
+		Row = DualClassTable.GetRowIndex (ClassName)
+
+	if Row == None:
+		print("CannotDualClass: inappropriate starting class")
+		return 0
 
 	# create a lookup table for the DualClassTable columns
 	classes = []
@@ -612,12 +598,12 @@ def CanDualClass(actor):
 	# cannot dc if all the columns of the DualClassTable are 0
 	if Sum == 0:
 		print("CannotDualClass: all the columns of the DualClassTable are 0")
-		return 1
+		return 0
 
 	# if the only choice for dc is already the same as the actors base class
 	if Sum == 1 and ClassName in matches and KitIndex == 0:
 		print("CannotDualClass: the only choice for dc is already the same as the actors base class")
-		return 1
+		return 0
 
 	AlignmentTable = GemRB.LoadTable ("alignmnt")
 	Alignment = GemRB.GetPlayerStat (actor, IE_ALIGNMENT)
@@ -625,24 +611,28 @@ def CanDualClass(actor):
 	AlignmentColName = CommonTables.Aligns.GetValue (AlignmentColName, 4)
 	if AlignmentColName == -1:
 		print("CannotDualClass: extraordinary character alignment")
-		return 1
+		return 0
 	Sum = 0
 	for classy in matches:
-		Sum += AlignmentTable.GetValue (classy, AlignmentColName)
+		Sum += AlignmentTable.GetValue (classy, AlignmentColName, GTV_INT)
 
 	# cannot dc if all the available classes forbid the chars alignment
 	if Sum == 0:
 		print("CannotDualClass: all the available classes forbid the chars alignment")
-		return 1
+		return 0
 
 	# check current class' stat limitations
+	CurrentStatTable = GemRB.LoadTable ("abdcscrq")
 	ClassStatIndex = CurrentStatTable.GetRowIndex (ClassTitle)
+	if ClassStatIndex == None and KitIndex > 0:
+		# retry with the baseclass in case the kit/school is missing (eg. wildmages)
+		ClassStatIndex = CurrentStatTable.GetRowIndex (ClassName)
 	for stat in range (6):
 		minimum = CurrentStatTable.GetValue (ClassStatIndex, stat)
 		name = CurrentStatTable.GetColumnName (stat)
 		if GemRB.GetPlayerStat (actor, SafeStatEval ("IE_" + name[4:]), 1) < minimum:
 			print("CannotDualClass: current class' stat limitations are too big")
-			return 1
+			return 0
 
 	# check new class' stat limitations - make sure there are any good class choices
 	TargetStatTable = GemRB.LoadTable ("abdcdsrq")
@@ -657,16 +647,16 @@ def CanDualClass(actor):
 				break
 	if len(matches) == bad:
 		print("CannotDualClass: no good new class choices")
-		return 1
+		return 0
 
 	# must be at least level 2
 	if GemRB.GetPlayerStat (actor, IE_LEVEL) == 1:
 		print("CannotDualClass: level 1")
-		return 1
-	return 0
+		return 0
+	return 1
 
 def IsWarrior (actor):
-	IsWarrior = CommonTables.ClassSkills.GetValue (GetClassRowName(actor), "NO_PROF")
+	IsWarrior = CommonTables.ClassSkills.GetValue (GetClassRowName(actor), "NO_PROF", GTV_INT)
 
 	# warriors get only a -2 penalty for wielding weapons they are not proficient with
 	# FIXME: make the check more robust, someone may change the value!
@@ -677,7 +667,7 @@ def IsWarrior (actor):
 		DualedFrom = GemRB.GetPlayerStat (actor, IE_MC_FLAGS) & MC_WAS_ANY_CLASS
 		FirstClassIndex = CommonTables.Classes.FindValue ("MC_WAS_ID", DualedFrom)
 		FirstClassName = CommonTables.Classes.GetRowName (FirstClassIndex)
-		OldIsWarrior = CommonTables.ClassSkills.GetValue (FirstClassName, "NO_PROF")
+		OldIsWarrior = CommonTables.ClassSkills.GetValue (FirstClassName, "NO_PROF", GTV_INT)
 		# there are no warrior to warrior dualclasses, so if the previous class was one, the current one certainly isn't
 		if OldIsWarrior == -2:
 			return 0
@@ -685,57 +675,13 @@ def IsWarrior (actor):
 
 	return IsWarrior
 
-def SetupDamageInfo (pc, Button, Window):
-	hp = GemRB.GetPlayerStat (pc, IE_HITPOINTS)
-	hp_max = GemRB.GetPlayerStat (pc, IE_MAXHITPOINTS)
-	state = GemRB.GetPlayerStat (pc, IE_STATE_ID)
-
-	if hp_max < 1 or hp == "?":
-		ratio = 0.0
-	else:
-		ratio = hp / float(hp_max)
-
-	if hp < 1 or (state & STATE_DEAD):
-		c = {'r' : 64, 'g' : 64, 'b' : 64, 'a' : 255}
-		Button.SetOverlay (0, c, c)
-
-	if ratio == 1.0:
-		band = 0
-		color = {'r' : 255, 'g' : 255, 'b' : 255}  # white
-	elif ratio >= 0.75:
-		band = 1
-		color = {'r' : 0, 'g' : 255, 'b' : 0}  # green
-	elif ratio >= 0.50:
-		band = 2
-		color = {'r' : 255, 'g' : 255, 'b' : 0}  # yellow
-	elif ratio >= 0.25:
-		band = 3
-		color = {'r' : 255, 'g' : 128, 'b' : 0}  # orange
-	else:
-		band = 4
-		color = {'r' : 255, 'g' : 0, 'b' : 0}  # red
-
-	if GemRB.GetVar("Old Portrait Health") or not GameCheck.IsIWD2():
-		# draw the blood overlay
-		if hp >= 1 and not (state & STATE_DEAD):
-			c1 = {'r' : 0x70, 'g' : 0, 'b' : 0, 'a' : 0xff}
-			c2 = {'r' : 0xf7, 'g' : 0, 'b' : 0, 'a' : 0xff}
-			Button.SetOverlay (ratio, c1, c2)
-	else:
-		# scale the hp bar under the portraits and recolor it
-		# GUIHITPT has 5 frames with different severity colors
-		# luckily their ids follow a nice pattern
-		hpBar = Window.GetControl (pc-1 + 50)
-		hpBar.SetBAM ("GUIHITPT", band, 0)
-		hpBar.SetPictureClipping (ratio)
-		hpBar.SetFlags (IE_GUI_BUTTON_NO_IMAGE, OP_OR)
-
-	ratio_str = ""
-	if hp != "?":
-		ratio_str = "\n%d/%d" %(hp, hp_max)
-	Button.SetTooltip (GemRB.GetPlayerName (pc, 1) + ratio_str)
-
-	return ratio_str, color
+# set MAGESCHOOL to mage school (kit) index
+def UpdateMageSchool(pc):
+	GemRB.SetVar ("MAGESCHOOL", 0)
+	Kit = GetKitIndex (pc)
+	if Kit and CommonTables.KitList.GetValue (Kit, 7) == 1:
+		MageTable = GemRB.LoadTable ("magesch")
+		GemRB.SetVar ("MAGESCHOOL", MageTable.GetRowIndex (CommonTables.KitList.GetValue (Kit, 0, GTV_STR)))
 
 def SetCurrentDateTokens (stat, plural=False):
 	# NOTE: currentTime is in seconds, joinTime is in seconds * 15
@@ -839,10 +785,10 @@ def GetACStyleBonus (pc):
 	cdet = GemRB.GetCombatDetails (pc, 0)
 	if cdet["Style"] % 1000 != IE_PROFICIENCYSINGLEWEAPON:
 		return 0
-	return WStyleTable.GetValue (str(stars), "AC")
+	return WStyleTable.GetValue (str(stars), "AC", GTV_INT)
 
 def AddDefaultVoiceSet (VoiceList, Voices):
-	if GameCheck.IsBG1 () or GameCheck.IsBG2 ():
+	if GameCheck.IsBG1 () or GameCheck.IsBG2OrEE ():
 		Options = collections.OrderedDict(enumerate(Voices))
 		Options[-1] = "default"
 		Options = collections.OrderedDict(sorted(Options.items()))
@@ -856,28 +802,10 @@ def OverrideDefaultVoiceSet (Gender, CharSound):
 		if GameCheck.IsBG1 ():
 			Gender2Sound = [ "", "mainm", "mainf" ]
 			CharSound = Gender2Sound[Gender]
-		elif GameCheck.IsBG2 ():
+		elif GameCheck.IsBG2OrEE ():
 			Gender2Sound = [ "", "male005", "female4" ]
 			CharSound = Gender2Sound[Gender]
 	return CharSound
 
-class _stdioWrapper(object):
-	def __init__(self, log_level):
-		self.log_level = log_level
-		self.buffer = ""
-	def write(self, message):
-		self.buffer += str(message)
-		if self.buffer.endswith("\n"):
-			out = self.buffer.rstrip("\n")
-			if out:
-				GemRB.Log(self.log_level, "Python", out)
-			self.buffer = ""
-	def flush(self):
-		pass
-
-def _wrapStdio():
-	import sys
-	sys.stdout = _stdioWrapper(LOG_MESSAGE)
-	sys.stderr = _stdioWrapper(LOG_ERROR)
-
-_wrapStdio()
+def BindControlCallbackParams(fn, *args):
+	return lambda ctl: fn(*args)
