@@ -33,7 +33,6 @@ def MoveToNewArea ():
 	GUICommonWindows.CloseTopWindow ()
 	if GemRB.GetView ("WIN_PSTWMAP"):
 		GemRB.GetView ("WIN_PSTWMAP").Close ()
-		GemRB.SetVar ("Travel", -1)
 		GemRB.GamePause (0, 0)
 
 	if travel["Destination"].lower() == GemRB.GetGameString(STR_AREANAME).lower():
@@ -42,7 +41,11 @@ def MoveToNewArea ():
 		print ("Invalid target", travel)
 		return
 
-	GemRB.CreateMovement (travel["Destination"], travel["Entrance"], travel["Direction"])
+	# pst drops you off in the center
+	entrance = travel["Entrance"]
+	if not entrance:
+		entrance = "FROMMAP"
+	GemRB.CreateMovement (travel["Destination"], entrance, travel["Direction"])
 
 	if hours == 0:
 		return
