@@ -24,6 +24,7 @@ import Portrait
 from GUIDefines import *
 from ie_stats import IE_SEX, IE_RACE, IE_MC_FLAGS, MC_EXPORTABLE
 from ie_restype import RES_WAV
+from ie_sounds import SND_SPEECH
 
 CustomizeWindow = None
 ExportWindow = None
@@ -31,12 +32,12 @@ NameField = ExportDoneButton = None
 ScriptsTable = None
 RevertButton = None
 
-if GameCheck.IsBG2() or GameCheck.IsBG1():
+if GameCheck.IsBG2OrEE () or GameCheck.IsBG1():
 	BioStrRefSlot = 74
 else:
 	BioStrRefSlot = 63
 
-if GameCheck.IsBG2() or GameCheck.IsIWD2():
+if GameCheck.IsBG2OrEE () or GameCheck.IsIWD2():
 	PortraitNameSuffix = "L"
 else:
 	PortraitNameSuffix = "G"
@@ -73,7 +74,7 @@ def OpenCustomizeWindow ():
 	ScriptsTable = GemRB.LoadTable ("SCRPDESC")
 	GUIREC.ColorTable = GemRB.LoadTable ("CLOWNCOL")
 	Gender = GemRB.GetPlayerStat (pc, IE_SEX)
-	CustomizeWindow = GemRB.LoadWindow (17)
+	CustomizeWindow = GemRB.LoadWindow (17, "GUIREC")
 
 	PortraitSelectButton = CustomizeWindow.GetControl (0)
 	PortraitSelectButton.SetText (11961)
@@ -126,7 +127,7 @@ def OpenCustomizeWindow ():
 def OpenPortraitSelectWindow ():
 	global PortraitPictureButton
 
-	SubCustomizeWindow = GemRB.LoadWindow (18)
+	SubCustomizeWindow = GemRB.LoadWindow (18, "GUIREC")
 	SubCustomizeWindow.AddAlias("SUB_WIN", 0)
 
 	PortraitPictureButton = SubCustomizeWindow.GetControl (0)
@@ -173,7 +174,7 @@ def OpenPortraitSelectWindow ():
 def PortraitDonePress ():
 	pc = GemRB.GameGetSelectedPCSingle ()
 	# eh, different sizes
-	if GameCheck.IsBG2():
+	if GameCheck.IsBG2OrEE ():
 		GemRB.FillPlayerInfo (pc, Portrait.Name () + "M", Portrait.Name () + "S")
 	else:
 		GemRB.FillPlayerInfo (pc, Portrait.Name () + "L", Portrait.Name () + "S")
@@ -194,7 +195,7 @@ def OpenCustomPortraitWindow ():
 	global PortraitList1, PortraitList2
 	global RowCount1, RowCount2
 
-	Window = GemRB.LoadWindow (19)
+	Window = GemRB.LoadWindow (19, "GUIREC")
 	Window.AddAlias("SUB_WIN", 1)
 
 	CustomPortraitDoneButton = Window.GetControl (10)
@@ -296,7 +297,7 @@ def OpenSoundWindow ():
 
 	pc = GemRB.GameGetSelectedPCSingle ()
 	OldVoiceSet = GemRB.GetPlayerSound (pc)
-	SubCustomizeWindow = GemRB.LoadWindow (20)
+	SubCustomizeWindow = GemRB.LoadWindow (20, "GUIREC")
 	SubCustomizeWindow.AddAlias("SUB_WIN", 0)
 
 	VoiceList = SubCustomizeWindow.GetControl (5)
@@ -372,7 +373,7 @@ def PlaySoundPressed():
 			break
 	else:
 		NextSound()
-	GemRB.PlaySound (VoiceSet + SoundSeq[SoundIndex], "CHARACT" + str(pc - 1), 0, 0, 5)
+	GemRB.PlaySound (VoiceSet + SoundSeq[SoundIndex], "CHARACT" + str(pc - 1), 0, 0, SND_SPEECH)
 	return
 
 def NextSound():
@@ -395,7 +396,7 @@ def OpenScriptWindow ():
 	global ScriptTextArea, SelectedTextArea
 	global options
 
-	SubCustomizeWindow = GemRB.LoadWindow (11)
+	SubCustomizeWindow = GemRB.LoadWindow (11, "GUIREC")
 	SubCustomizeWindow.AddAlias("SUB_WIN", 0)
 
 	ScriptTextArea = SubCustomizeWindow.GetControl (2)
@@ -507,14 +508,17 @@ def OpenBiographyEditWindow ():
 
 	# 23 and 24 were deleted and replaced in iwd
 	if GameCheck.IsIWD1() or GameCheck.IsIWD2():
-		SubCustomizeWindow = GemRB.LoadWindow (51)
+		SubCustomizeWindow = GemRB.LoadWindow (51, "GUIREC")
+		SubCustomizeWindow.DeleteControl (3)
 	else:
-		SubCustomizeWindow = GemRB.LoadWindow (23)
-		
+		SubCustomizeWindow = GemRB.LoadWindow (23, "GUIREC")
+		if GameCheck.IsBG2OrEE ():
+			SubCustomizeWindow.DeleteControl (6)
+
 	SubCustomizeWindow.AddAlias("SUB_WIN", 0)
 
 	ClearButton = SubCustomizeWindow.GetControl (5)
-	if GameCheck.IsBG2():
+	if GameCheck.IsBG2OrEE ():
 		ClearButton.SetText (34881)
 	else:
 		ClearButton.SetText (18622)
@@ -571,7 +575,7 @@ def DoneBiographyWindow (ta):
 	return
 
 def OpenBiographyWindow ():
-	BiographyWindow = GemRB.LoadWindow (12)
+	BiographyWindow = GemRB.LoadWindow (12, "GUIREC")
 
 	TextArea = BiographyWindow.GetControl (0)
 	pc = GemRB.GameGetSelectedPCSingle ()
@@ -602,7 +606,7 @@ def GetProtagonistBiography (pc):
 def OpenExportWindow ():
 	global ExportWindow, NameField, ExportDoneButton
 
-	ExportWindow = GemRB.LoadWindow (13)
+	ExportWindow = GemRB.LoadWindow (13, "GUIREC")
 
 	TextArea = ExportWindow.GetControl (2)
 	TextArea.SetText (10962)
