@@ -23,6 +23,7 @@
 
 import GemRB
 
+import ActionsWindow
 import CommonWindow
 import Container
 import GameCheck
@@ -65,16 +66,12 @@ def DialogStarted ():
 	CommonWindow.SetGameGUIHidden(False)
 	GemRB.GameSetScreenFlags(GS_DIALOG, OP_OR)
 
-	# disable the 1-6 hotkeys, so they'll work for choosing answers
-	if GemRB.GetView ("PORTWIN"):
-		GUICommonWindows.UpdatePortraitWindow ()
-
 	ContinueWindow = OpenDialogButton(9)
 
 def DialogEnded ():
 	global ContinueWindow
 
-	GUICommonWindows.UpdateActionsWindow()
+	ActionsWindow.UpdateActionsWindow ()
 	if not ContinueWindow:
 		return
 
