@@ -30,18 +30,25 @@ from ie_spells import *
 from ie_sounds import DEF_IDENTIFY
 
 UsedSlot = None
-ItemInfoWindow = None
 ItemAmountWindow = None
-ItemIdentifyWindow = None
-ItemAbilitiesWindow = None
-ErrorWindow = None
 ColorPicker = None
 StackAmount = 0
 
  # A map that defines which inventory slots are used per character (PST)
 SlotMap = None
 
-UpdateInventoryWindow = None
+def InventoryClosed(win):
+	GemRB.LeaveContainer()
+	if GemRB.IsDraggingItem () == 1:
+		pc = GemRB.GameGetSelectedPCSingle ()
+		#store the item in the inventory before window is closed
+		GemRB.DropDraggedItem (pc, -3)
+		#dropping on ground if cannot store in inventory
+		if GemRB.IsDraggingItem () == 1:
+			GemRB.DropDraggedItem (pc, -2)
+	
+	import GUICommonWindows
+	GUICommonWindows.TopWindowClosed(win)
 
 def OnDragItemGround (btn):
 	"""Drops and item to the ground."""
@@ -60,7 +67,6 @@ def OnDragItemGround (btn):
 	else:
 		GemRB.DropDraggedItem (pc, -2) #dropping on ground
 
-	UpdateInventoryWindow ()
 	return
 
 def OnAutoEquip ():
@@ -77,7 +83,6 @@ def OnAutoEquip ():
 	if GemRB.IsDraggingItem ()==1:
 		GemRB.PlaySound("GAM_47") #failed equip
 
-	UpdateInventoryWindow ()
 	return
 
 def OnDragItem (btn):
@@ -143,7 +148,6 @@ def OnDragItem (btn):
 			if GemRB.GetPlayerStat (pc, IE_STATE_ID) & (STATE_BERSERK) and GemRB.IsDraggingItem ():
 				GemRB.DropDraggedItem (pc, -3)
 
-	UpdateInventoryWindow ()
 	return
 
 def OnDropItemToPC (pc):
@@ -156,7 +160,6 @@ def OnDropItemToPC (pc):
 
 	#-3 : drop stuff in inventory (but not equippable slots)
 	GemRB.DropDraggedItem (pc, -3)
-	UpdateInventoryWindow ()
 	return
 
 def DecreaseStackAmount ():
@@ -230,12 +233,6 @@ def MouseLeaveGround (Button):
 		Button.SetState (IE_GUI_BUTTON_FAKEPRESSED)
 	return
 
-def CloseItemInfoWindow ():
-	if ItemInfoWindow:
-		ItemInfoWindow.Close ()
-	UpdateInventoryWindow ()
-	return
-
 def GetItemDescription (item, itemtype):
 	text = item["ItemDescIdentified"]
 	if (itemtype & 2):
@@ -252,21 +249,28 @@ def GetItemDescription (item, itemtype):
 	text = searchRE.sub(replacement, text)
 	return text
 
-def DisplayItem (slotItem, itemtype):
-	global ItemInfoWindow
+def ItemPress(func, slotItem, *args):
+	def Pressed(btn):
+		func(slotItem, *args)
+		btn.Window.Close()
+	return Pressed
 
+def DisplayItem (slotItem, ground = False):
+	Window = GemRB.LoadWindow (5, "GUIINV")
+
+	# the ground items are only displayable
+	if slotItem["Flags"] & IE_INV_ITEM_IDENTIFIED:
+		value = 0
+	else:
+		value = 2
+
+	if not ground:
+		value += 1
+
+	UpdateItemDisplay(Window, slotItem, value)
+
+def UpdateItemDisplay(Window, slotItem, itemtype):
 	item = GemRB.GetItem (slotItem["ItemResRef"])
-	
-	#window can be refreshed by cycling to next/prev item, so it may still exist
-	if not ItemInfoWindow:
-		ItemInfoWindow = GemRB.LoadWindow (5)
-
-	Window = ItemInfoWindow
-	def OnClose():
-		global ItemInfoWindow
-		ItemInfoWindow = None
-	Window.SetAction (OnClose, ACTION_WINDOW_CLOSED)
-
 	if GameCheck.IsPST():
 		strrefs = [ 1403, 4256, 4255, 4251, 4252, 4254, 4279 ]
 	elif GameCheck.IsGemRBDemo ():
@@ -295,12 +299,12 @@ def DisplayItem (slotItem, itemtype):
 	#middle button
 	Button = Window.GetControl (4)
 	Button.SetText (strrefs[0])
-	Button.OnPress (CloseItemInfoWindow)
+	Button.OnPress (lambda: Window.Close())
 	Button.MakeDefault()
 
 	#textarea
 	Text = Window.GetControl (5)
-	if GameCheck.IsBG2(): # I believe only BG2 has special initials
+	if GameCheck.IsBG2OrEE (): # I believe only BG2 has special initials
 		Text.SetColor (ColorWhitish, TA_COLOR_INITIALS)
 	text = GetItemDescription (item, itemtype)
 	Text.SetText (text)
@@ -310,14 +314,15 @@ def DisplayItem (slotItem, itemtype):
 	#left button
 	Button = Window.GetControl(8)
 	select = (itemtype & 1) and (item["Function"]&ITM_F_ABILITIES)
+	pc = GemRB.GameGetSelectedPCSingle ()
 
 	if itemtype & 2:
 		Button.SetText (strrefs[1])
-		Button.OnPress (IdentifyItemWindow)
+		Button.OnPress (lambda: IdentifyItemWindow(slotItem, pc))
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_SET)
 	elif select and not GameCheck.IsPST():
 		Button.SetText (strrefs[2])
-		Button.OnPress (AbilitiesItemWindow)
+		Button.OnPress (lambda: AbilitiesItemWindow(slotItem, pc))
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_SET)
 	else:
 		Button.SetText ("")
@@ -328,7 +333,7 @@ def DisplayItem (slotItem, itemtype):
 	# description icon (not present in iwds)
 	if not GameCheck.IsIWD1() and not GameCheck.IsIWD2():
 		Button = Window.GetControl (7)
-		Button.SetFlags (IE_GUI_BUTTON_PICTURE | IE_GUI_BUTTON_CENTER_PICTURES | IE_GUI_BUTTON_NO_IMAGE, OP_OR)
+		Button.SetFlags (IE_GUI_BUTTON_PICTURE | (0 if GameCheck.IsBG2EE() else IE_GUI_BUTTON_CENTER_PICTURES) | IE_GUI_BUTTON_NO_IMAGE, OP_OR)
 		if GameCheck.IsPST():
 			Button.SetItemIcon (slotItem["ItemResRef"], 1) # no DescIcon
 		else:
@@ -340,23 +345,25 @@ def DisplayItem (slotItem, itemtype):
 	Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_SET)
 	drink = (itemtype & 1) and (item["Function"]&ITM_F_DRINK)
 	read = (itemtype & 1) and (item["Function"]&ITM_F_READ)
-	# only mages and bards can learn spells
-	pc = GemRB.GameGetSelectedPCSingle ()
+	# only mages and some bards can learn spells (externalize this to clskills.2da?)
 	ClassName = GUICommon.GetClassRowName (pc)
-	SpellBookType = CommonTables.ClassSkills.GetValue (ClassName, "MAGESPELL", GTV_STR)
-	if SpellBookType == "*" or SpellBookType == "MXSPLSRC":
-		read = 0
+	if GameCheck.IsIWD2 ():
+		if GemRB.GetPlayerStat (pc, IE_LEVELMAGE) == 0:
+			read = 0
+	else:
+		if "MAGE" not in ClassName and "BARD" not in ClassName:
+			read = 0
 	# furthermore there might be school exclusions present
 	if read:
 		read = GemRB.CanUseItemType (SLOT_ALL, slotItem['ItemResRef'], pc, False)
 	container = (itemtype & 1) and (item["Function"]&ITM_F_CONTAINER)
 	dialog = (itemtype & 1) and (item["Dialog"]!="" and item["Dialog"]!="*")
-	familiar = (itemtype & 1) and (item["Type"] == 38) and (item["Flags"] & IE_INV_ITEM_UNDROPPABLE)
+	familiar = (itemtype & 1) and (item["Type"] == 38) and (slotItem["Flags"] & IE_INV_ITEM_UNDROPPABLE)
 
 	# The "conversable" bit in PST actually means "usable", eg clot charm
 	# unlike BG2 (which only has the bit set on SW2H14 Lilarcor)
 	# Meanwhile IWD series has the bit set on important quest items
-	# So the widely accepted name of this bit is misleading
+	# So the widely accepted name of this bit is misleading (see use of GFFlags::SELLABLE_CRITS_NO_CONV)
 
 	# There are also items in PST, cube.itm and doll.itm 
 	# that are not flagged usable but still have dialog attached.
@@ -373,23 +380,24 @@ def DisplayItem (slotItem, itemtype):
 	if drink and not dialog:
 		# Standard consumable item
 		Button.SetText (strrefs[3])
-		Button.OnPress (ConsumeItem)
+		Button.OnPress (ItemPress(ConsumeItem, slotItem, pc))
 	elif read:
 		Button.SetText (strrefs[4])
-		Button.OnPress (ReadItemWindow)
+		Button.OnPress (ItemPress(ReadItemWindow, slotItem, pc))
 	elif container:
 		# Just skip the redundant info page and go directly to the container
 		if GemRB.GetVar("GUIEnhancements")&GE_ALWAYS_OPEN_CONTAINER_ITEMS:
-			OpenItemWindow()
+			OpenItemWindow(slotItem)
+			Window.Close()
 			return
 		if GameCheck.IsIWD2() or GameCheck.IsHOW():
 			Button.SetText (24891) # Open Container
-		elif GameCheck.IsBG2():
+		elif GameCheck.IsBG2OrEE ():
 			Button.SetText (44002) # open container
 		else:
 			# a fallback, since the originals have nothing appropriate from not having any bags
 			Button.SetText ("Open container")
-		Button.OnPress (OpenItemWindow)
+		Button.OnPress (ItemPress(OpenItemWindow, slotItem))
 	elif dialog:
 		if drink:
 			# Dialog item that is 'used'
@@ -397,12 +405,12 @@ def DisplayItem (slotItem, itemtype):
 		else:
 			# Dialog item that is 'talked to'
 			Button.SetText (strrefs[5])
-		Button.OnPress (DialogItemWindow)
+		Button.OnPress (ItemPress(DialogItemWindow, slotItem, pc))
 	elif familiar and not GameCheck.IsPST():
 		# PST earings share a type with familiars, so no
 		# mods that allow familiars would be possible in PST
 		Button.SetText (4373)
-		Button.OnPress (ReleaseFamiliar)
+		Button.OnPress (ItemPress(ReleaseFamiliar, slotItem, pc))
 	else:
 		Button.SetState (IE_GUI_BUTTON_LOCKED)
 		Button.SetFlags (IE_GUI_BUTTON_NO_IMAGE, OP_SET)
@@ -419,27 +427,20 @@ def DisplayItem (slotItem, itemtype):
 
 	# in pst one can cycle through all the items from the description window
 	if GameCheck.IsPST():
-
 		#left scroll
 		Button = Window.GetControl (13)
-		Button.OnPress (lambda: CycleDisplayItem(-1))
+		Button.OnPress (lambda: CycleDisplayItem(slotItem["Slot"], pc, -1))
 
 		#right scroll
 		Button = Window.GetControl (14)
-		Button.OnPress (lambda: CycleDisplayItem(1))
+		Button.OnPress (lambda: CycleDisplayItem(slotItem["Slot"], pc, 1))
 
-	ItemInfoWindow.ShowModal(MODAL_SHADOW_GRAY)
+	Window.ShowModal(MODAL_SHADOW_GRAY)
 	return
 
-def CycleDisplayItem(direction):
-
-	slot = int(GemRB.GetVar('ItemButton'))
-
-	pc = GemRB.GameGetSelectedPCSingle ()
-
-	slot_item = None
-	
+def CycleDisplayItem(slot, pc, direction):
 	#try the next slot for an item. if the slot is empty, loop until one is found.
+	slot_item = None
 	while not slot_item:
 		slot += direction
 
@@ -450,55 +451,91 @@ def CycleDisplayItem(direction):
 			slot = 53
 
 		slot_item = GemRB.GetSlotItem (pc, slot)
-		GemRB.SetVar('ItemButton', slot)
 
 	if slot_item:
-		OpenItemInfoWindow (slot)
+		OpenItemInfoWindow(slot_item, pc)
 
-def OpenItemInfoWindow (slot):
-	pc = GemRB.GameGetSelectedPCSingle ()
-
-	slotItem = GemRB.GetSlotItem (pc, slot)
-	slotType = GemRB.GetSlotType (slot, pc)
+def OpenItemInfoWindow (slotItem, pc):
+	slotType = GemRB.GetSlotType (slotItem["Slot"], pc)
 
 	# PST: if the slot is empty but is also the first quick weapon slot, display the info for the "default" weapon
 	if GameCheck.IsPST() and slotItem is None and slotType["ID"] == 10 and GemRB.GetEquippedQuickSlot(pc) == 10:
-		DisplayItem (GemRB.GetSlotItem (pc, 0), 1)
+		DisplayItem (GemRB.GetSlotItem (pc, 0))
 		return
 
 	item = GemRB.GetItem (slotItem["ItemResRef"])
 
-	if TryAutoIdentification(pc, item, slot, slotItem, True):
-		UpdateInventoryWindow ()
-
-	if slotItem["Flags"] & IE_INV_ITEM_IDENTIFIED:
-		value = 1
-	else:
-		value = 3
-	DisplayItem (slotItem, value)
+	TryAutoIdentification(pc, item, slotItem["Slot"], slotItem, True, True)
+	DisplayItem (slotItem)
 	return
 
-#auto identify when lore is high enough
-def TryAutoIdentification(pc, item, slot, slot_item, enabled=0):
-	if enabled and item["LoreToID"]<=GemRB.GetPlayerStat (pc, IE_LORE):
+# auto identify when lore is high enough
+def TryAutoIdentification(pc, item, slot, slot_item, enabled, feedback = False):
+	if not enabled or slot_item["Flags"] & IE_INV_ITEM_IDENTIFIED:
+		return False
+
+	if not GameCheck.IsIWD2 ():
+		# simple logic for other games
+		if item["LoreToID"] <= GemRB.GetPlayerStat (pc, IE_LORE):
+			GemRB.ChangeItemFlag (pc, slot, IE_INV_ITEM_IDENTIFIED, OP_OR)
+			slot_item["Flags"] |= IE_INV_ITEM_IDENTIFIED
+			return True
+		return False
+
+	# iwd2 has extra hidden feedback strings
+	# they're directly usable by the old-style python formatter, however our tokenizer
+	# replaces the specifiers with fmt-compatible {}
+	feedback = feedback and GemRB.GetVar ("EnableRollFeedback")
+	# 1. try general knowledge arcana
+	lore = GemRB.GetPlayerStat (pc, IE_LORE)
+	intBon = GUICommon.GetAbilityBonus(pc, IE_INT) # already included in lore
+	itemIdDC = item["LoreToID"]
+	success = lore >= itemIdDC
+	msgArea = GemRB.GetView ("MsgSys")
+	if success:
 		GemRB.ChangeItemFlag (pc, slot, IE_INV_ITEM_IDENTIFIED, OP_OR)
 		slot_item["Flags"] |= IE_INV_ITEM_IDENTIFIED
-		return True
-	return False
+	# @39263 = ~Failed identify item check! (Knowledge Arcana + Int mod) %d + %d vs. (item's lore) %d~
+	# @39264 = ~Successful identify item check! (Knowledge Arcana + Int mod) %d + %d vs. (item's lore) %d~
+	if feedback:
+		msgArea.Append (GemRB.GetString(39263 + success).format(lore, intBon, itemIdDC) + "\n")
+	if success:
+		return
+
+	# 2. try alchemy for potions
+	if item["Type"] == 9:
+		alchemy = GemRB.GetPlayerStat (pc, IE_ALCHEMY)
+		success = alchemy >= itemIdDC
+		if success:
+			GemRB.ChangeItemFlag (pc, slot, IE_INV_ITEM_IDENTIFIED, OP_OR)
+			slot_item["Flags"] |= IE_INV_ITEM_IDENTIFIED
+		# @39261 = ~Successful identify potion check! (Alchemy + Int mod) %d + %d vs. (potion's lore) %d~
+		# @39262 = ~Failed identify potion check! (Alchemy + Int mod) %d + %d vs. (potion's lore) %d~
+		if feedback:
+			msgArea.Append (GemRB.GetString(39262 - success).format(alchemy, intBon, itemIdDC) + "\n")
+		if success:
+			return
+
+	# 3. try bardic lore
+	bardLevel = GemRB.GetPlayerStat (pc, IE_LEVELBARD)
+	if bardLevel > 0:
+		success = (bardLevel + intBon) >= itemIdDC
+		if success:
+			GemRB.ChangeItemFlag (pc, slot, IE_INV_ITEM_IDENTIFIED, OP_OR)
+			slot_item["Flags"] |= IE_INV_ITEM_IDENTIFIED
+		# @39259 = ~Failed identify item check! Check Bardic Lore %d vs. item's lore %d (%d Intelligence Ability Mod)~
+		# @39260 = ~Successful identify item check! Check Bardic Lore %d vs. item's lore %d (%d Intelligence Ability Mod)~
+		if feedback:
+			msgArea.Append (GemRB.GetString(39259 + success).format(bardLevel, itemIdDC, intBon) + "\n")
+
+	return success
 
 def OpenGroundItemInfoWindow (btn):
-	global ItemInfoWindow
-
 	pc = GemRB.GameGetSelectedPCSingle ()
 	slot = btn.Value
 	slot_item = GemRB.GetContainerItem (pc, slot)
 
-	#the ground items are only displayable
-	if slot_item["Flags"] & IE_INV_ITEM_IDENTIFIED:
-		value = 0
-	else:
-		value = 2
-	DisplayItem(slot_item, value)
+	DisplayItem(slot_item, True)
 	return
 
 def OpenGroundItemAmountWindow (btn):
@@ -509,7 +546,6 @@ def ItemAmountWindowClosed(win):
 
 	ItemAmountWindow = None
 	UsedSlot = None
-	UpdateInventoryWindow()
 
 def OpenItemAmountWindow (btn, location = "inventory"):
 	"""Open the split window."""
@@ -541,7 +577,7 @@ def OpenItemAmountWindow (btn, location = "inventory"):
 		UpdateSlot (pc, UsedSlot-1)
 		return
 
-	ItemAmountWindow = Window = GemRB.LoadWindow (4)
+	ItemAmountWindow = Window = GemRB.LoadWindow (4, "GUIINV")
 	Window.SetFlags(WF_ALPHA_CHANNEL, OP_OR)
 	Window.SetAction(ItemAmountWindowClosed, ACTION_WINDOW_CLOSED)
 
@@ -639,7 +675,7 @@ def UpdateSlot (pc, slot):
 	Button.SetAction (OnDragItem, IE_ACT_DRAG_DROP_DST)
 	Button.SetFlags (IE_GUI_BUTTON_NO_IMAGE, OP_NAND)
 
-	# characters should auto-identify any item they recieve
+	# characters should auto-identify any item they receive
 	if slot_item:
 		item = GemRB.GetItem (slot_item["ItemResRef"])
 		TryAutoIdentification(pc, item, slot+1, slot_item, GemRB.GetVar("GUIEnhancements")&GE_TRY_IDENTIFY_ON_TRANSFER)
@@ -649,12 +685,15 @@ def UpdateSlot (pc, slot):
 	if slot_item:
 		Button.SetAction(OnDragItem, IE_ACT_DRAG_DROP_CRT)
 		Button.OnPress (OnDragItem)
-		Button.OnRightPress (lambda: OpenItemInfoWindow (slot + 1))
+		Button.OnRightPress (lambda: OpenItemInfoWindow (slot_item, pc))
 		Button.OnShiftPress (OpenItemAmountWindow)
 		#If the slot is being used to display the 'default' weapon, disable dragging.
 		if SlotType["ID"] == 10 and using_fists:
 			Button.OnPress (None)
 			#dropping is ok, because it will drop in the quick weapon slot and not the default weapon slot.
+		# pst shows the inventory-bag icon bg behind items
+		if GameCheck.IsPST ():
+			Button.SetSprites ("IVSLOT", 0, 0, 0, 0, 0)
 	else:
 		if SlotType["ResRef"]=="*":
 			Button.SetBAM ("",0,0)
@@ -719,7 +758,6 @@ def ColorDonePress():
 		GUICommon.SetColorStat (pc, IE_MAJOR_COLOR, PickedColor)
 	else:
 		GUICommon.SetColorStat (pc, IE_MINOR_COLOR, PickedColor)
-	UpdateInventoryWindow ()
 	return
 
 def HairPress():
@@ -768,8 +806,8 @@ def GetColor():
 	ColorTable = GemRB.LoadTable ("clowncol")
 	InventoryWindow = GemRB.GetView ("WIN_INV")
 	InventoryWindow.SetDisabled (True) #darken it
-	ColorPicker = GemRB.LoadWindow (3)
-	GemRB.SetVar ("Selected",-1)
+	ColorPicker = GemRB.LoadWindow (3, "GUIINV")
+	GemRB.SetVar ("Selected", None)
 	if GameCheck.IsIWD2 () or GameCheck.IsGemRBDemo ():
 		Button = ColorPicker.GetControl (35)
 		Button.OnPress (CancelColor)
@@ -796,39 +834,31 @@ def GetColor():
 	ColorPicker.Focus()
 	return
 
-def ReleaseFamiliar ():
+def ReleaseFamiliar (item, pc):
 	"""Simple Use Item"""
 
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
 	# the header is always the first, target is always self
-	GemRB.UseItem (pc, slot, 0, 5)
-	CloseItemInfoWindow ()
+	GemRB.UseItem (pc, item["Slot"], 0, 5)
 	return
 
-def ConsumeItem ():
+def ConsumeItem (item, pc):
 	"""Drink the potion"""
 
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
 	# the drink item header is always the first
 	# pst also requires forcing the target (eg. clot charms), which doesn't hurt elsewhere
-	GemRB.UseItem (pc, slot, 0, 5)
-	CloseItemInfoWindow ()
+	GemRB.UseItem (pc, item["Slot"], 0, 5)
 	return
 
 def OpenErrorWindow (strref):
 	"""Opens the error window and displays the string."""
 
-	global ErrorWindow
-
-	ErrorWindow = Window = GemRB.LoadWindow (7)
+	Window = GemRB.LoadWindow (7, "GUIINV")
 	Button = Window.GetControl (0)
 	if GameCheck.IsPST():
 		Button.SetText (1403)
 	else:
 		Button.SetText (11973)
-	Button.OnPress (CloseErrorWindow)
+	Button.OnPress (lambda: Window.Close())
 	Button.MakeDefault()
 
 	TextArea = Window.GetControl (3)
@@ -836,19 +866,10 @@ def OpenErrorWindow (strref):
 	Window.ShowModal (MODAL_SHADOW_GRAY)
 	return
 
-def CloseErrorWindow ():
-	if ErrorWindow:
-		ErrorWindow.Close ()
-	UpdateInventoryWindow ()
-	return
-
-def ReadItemWindow ():
+def ReadItemWindow (item, pc):
 	"""Tries to learn the mage scroll."""
 
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
-	ret = Spellbook.CannotLearnSlotSpell()
-
+	ret = Spellbook.CannotLearnSlotSpell(item, pc)
 	if ret:
 		# these failures are soft - the scroll is not destroyed
 		if ret == LSR_KNOWN and GameCheck.HasTOB():
@@ -860,7 +881,7 @@ def ReadItemWindow ():
 			strref = 72874 # your spell school does not permit you to learn
 		elif ret == LSR_LEVEL and GameCheck.HasTOB():
 			strref = 48806 # inadequate intelligence (good enough approximation)
-		elif ret == LSR_FULL and GameCheck.IsBG2():
+		elif ret == LSR_FULL and GameCheck.IsBG2OrEE ():
 			strref = 32097
 		elif ret == LSR_FULL and GameCheck.IsPST():
 			strref = 50395
@@ -869,13 +890,12 @@ def ReadItemWindow ():
 		else:
 			strref = 10831
 
-		CloseItemInfoWindow ()
 		GemRB.PlaySound ("EFF_M10") # failure!
 		OpenErrorWindow (strref)
 		return
 
 	# we already checked for most failures, but we can still fail with bad % rolls vs intelligence
-	ret = Spellbook.LearnFromScroll (pc, slot)
+	ret = Spellbook.LearnFromScroll (pc, item["Slot"])
 	if ret == LSR_OK:
 		GemRB.PlaySound ("GAM_44") # success!
 		if GameCheck.IsPST():
@@ -891,7 +911,6 @@ def ReadItemWindow ():
 		else:
 			strref = 10831
 
-	CloseItemInfoWindow ()
 	OpenErrorWindow (strref)
 
 def GetPSTPersonalizedRef(pc, baseRef):
@@ -903,103 +922,59 @@ def GetPSTPersonalizedRef(pc, baseRef):
 	pcOffset = spec2offset[GemRB.GetPlayerStat (pc, IE_SPECIFIC) - 2]
 	return baseRef + pcOffset
 
-def OpenItemWindow ():
+def OpenItemWindow (slot_item):
 	"""Displays information about the item."""
 
-	#close inventory
-	GemRB.SetVar ("Inventory", 1)
-	slot = GemRB.GetVar ("ItemButton") #get this before closing win
-	if ItemInfoWindow:
-		ItemInfoWindow.Close ()
-
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot_item = GemRB.GetSlotItem (pc, slot)
 	ResRef = slot_item['ItemResRef']
-	#the store will have to reopen the inventory
 	GemRB.EnterStore (ResRef)
 	return
 
-def DialogItemWindow ():
+def DialogItemWindow (slot_item, pc):
 	"""Converse with an item."""
 
-	pc = GemRB.GameGetSelectedPCSingle ()
-
-	slot = GemRB.GetVar ("ItemButton")
-	slot_item = GemRB.GetSlotItem (pc, slot)
-
 	ResRef = slot_item['ItemResRef']
 	item = GemRB.GetItem (ResRef)
 	dialog=item["Dialog"]
-	if ItemInfoWindow:
-		ItemInfoWindow.Close ()
 
 	GemRB.ExecuteString ("StartDialogOverride(\""+dialog+"\",Myself,0,0,1)", pc)
 	return
 
-def IdentifyUseSpell ():
+def IdentifyUseSpell (slotItem, pc):
 	"""Identifies the item with a memorized spell."""
 
-	global ItemIdentifyWindow
-
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
-	if ItemIdentifyWindow:
-		ItemIdentifyWindow.Close ()
 	GemRB.HasSpecialSpell (pc, SP_IDENTIFY, 1)
-	if ItemInfoWindow:
-		ItemInfoWindow.Close ()
-	GemRB.ChangeItemFlag (pc, slot, IE_INV_ITEM_IDENTIFIED, OP_OR)
+	GemRB.ChangeItemFlag (pc, slotItem["Slot"], IE_INV_ITEM_IDENTIFIED, OP_OR)
+	slotItem["Flags"] |= IE_INV_ITEM_IDENTIFIED
 	if GameCheck.IsPST ():
 		strRef = GetPSTPersonalizedRef (pc, 35685)
 		GemRB.GetString (strRef, 2) # play the attached sound
 	else:
 		GemRB.PlaySound (DEF_IDENTIFY)
-	OpenItemInfoWindow(slot)
+	OpenItemInfoWindow(slotItem, pc)
 	return
 
-def IdentifyUseScroll ():
+def IdentifyUseScroll (slotItem, pc):
 	"""Identifies the item with a scroll or other item."""
 
-	global ItemIdentifyWindow
-
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
-	if ItemIdentifyWindow:
-		ItemIdentifyWindow.Close ()
-	if ItemInfoWindow:
-		ItemInfoWindow.Close ()
 	if GemRB.HasSpecialItem (pc, 1, 1):
-		GemRB.ChangeItemFlag (pc, slot, IE_INV_ITEM_IDENTIFIED, OP_OR)
+		GemRB.ChangeItemFlag (pc, slotItem["Slot"], IE_INV_ITEM_IDENTIFIED, OP_OR)
+		slotItem["Flags"] |= IE_INV_ITEM_IDENTIFIED
 	if GameCheck.IsPST ():
 		strRef = GetPSTPersonalizedRef (pc, 35685)
 		GemRB.GetString (strRef, 2) # play the attached sound
 	else:
 		GemRB.PlaySound (DEF_IDENTIFY)
-	OpenItemInfoWindow(slot)
+	OpenItemInfoWindow(slotItem, pc)
 	return
 
-def CloseIdentifyItemWindow ():
-	global ItemIdentifyWindow, ItemInfoWindow
-
-	if ItemIdentifyWindow:
-		ItemIdentifyWindow.Close ()
-		ItemIdentifyWindow = None
-	if ItemInfoWindow:
-		ItemInfoWindow.ShowModal (MODAL_SHADOW_GRAY)
-	return
-
-def IdentifyItemWindow ():
-	global ItemIdentifyWindow
-
-	pc = GemRB.GameGetSelectedPCSingle ()
-
-	ItemIdentifyWindow = Window = GemRB.LoadWindow (9)
+def IdentifyItemWindow (slotItem, pc):
+	Window = GemRB.LoadWindow (9, "GUIINV")
 	Button = Window.GetControl (0)
 	if GameCheck.IsPST():
 		Button.SetText (4259)
 	else:
 		Button.SetText (17105)
-	Button.OnPress (IdentifyUseSpell)
+	Button.OnPress (ItemPress(IdentifyUseSpell, slotItem, pc))
 	if not GemRB.HasSpecialSpell (pc, SP_IDENTIFY, 0):
 		Button.SetState (IE_GUI_BUTTON_DISABLED)
 
@@ -1008,7 +983,7 @@ def IdentifyItemWindow ():
 		Button.SetText (4260)
 	else:
 		Button.SetText (17106)
-	Button.OnPress (IdentifyUseScroll)
+	Button.OnPress (ItemPress(IdentifyUseScroll, slotItem, pc))
 	if not GemRB.HasSpecialItem (pc, 1, 0):
 		Button.SetState (IE_GUI_BUTTON_DISABLED)
 
@@ -1017,7 +992,7 @@ def IdentifyItemWindow ():
 		Button.SetText (4196)
 	else:
 		Button.SetText (13727)
-	Button.OnPress (CloseIdentifyItemWindow)
+	Button.OnPress (lambda: Window.Close())
 	Button.MakeEscape()
 
 	TextArea = Window.GetControl (3)
@@ -1028,38 +1003,20 @@ def IdentifyItemWindow ():
 	Window.ShowModal (MODAL_SHADOW_GRAY)
 	return
 
-def DoneAbilitiesItemWindow ():
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
-	GemRB.SetupQuickSlot (pc, 0, slot, GemRB.GetVar ("Ability") )
-	CloseAbilitiesItemWindow ()
+def DoneAbilitiesItemWindow (slot_item, pc):
+	GemRB.SetupQuickSlot (pc, 0, slot_item["Slot"], GemRB.GetVar ("Ability"))
 	return
 
-def CloseAbilitiesItemWindow ():
-	global ItemAbilitiesWindow, ItemInfoWindow
+def AbilitiesItemWindow (slot_item, pc):
+	Window = GemRB.LoadWindow (6, "GUIINV")
 
-	if ItemAbilitiesWindow:
-		ItemAbilitiesWindow.Close ()
-		ItemAbilitiesWindow = None
-	if ItemInfoWindow:
-		ItemInfoWindow.ShowModal (MODAL_SHADOW_GRAY)
-	return
-
-def AbilitiesItemWindow ():
-	global ItemAbilitiesWindow
-
-	ItemAbilitiesWindow = Window = GemRB.LoadWindow (6)
-
-	pc = GemRB.GameGetSelectedPCSingle ()
-	slot = GemRB.GetVar ("ItemButton")
-	slot_item = GemRB.GetSlotItem (pc, slot)
 	item = GemRB.GetItem (slot_item["ItemResRef"])
 	Tips = item["Tooltips"]
 
 	GemRB.SetVar ("Ability", slot_item["Header"])
 	for i in range(3):
 		Button = Window.GetControl (i+1)
-		if GameCheck.IsBG2():
+		if GameCheck.IsBG2OrEE ():
 			Button.SetSprites ("GUIBTBUT",i,0,1,2,0)
 		Button.SetFlags (IE_GUI_BUTTON_RADIOBUTTON, OP_OR)
 		Button.SetVarAssoc ("Ability",i)
@@ -1078,12 +1035,12 @@ def AbilitiesItemWindow ():
 
 	Button = Window.GetControl (7)
 	Button.SetText (11973)
-	Button.OnPress (DoneAbilitiesItemWindow)
+	Button.OnPress (ItemPress(DoneAbilitiesItemWindow, slot_item, pc))
 	Button.MakeDefault()
 
 	Button = Window.GetControl (10)
 	Button.SetText (13727)
-	Button.OnPress (CloseAbilitiesItemWindow)
+	Button.OnPress (lambda: Window.Close())
 	Button.MakeEscape()
 	Window.ShowModal (MODAL_SHADOW_GRAY)
 	return
@@ -1096,6 +1053,7 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 	colorUnusable = {'r' : 255, 'g' : 128, 'b' : 128, 'a' : 64}
 	Button.SetBorder (2, colorUnusable, 0, 1)
 	colorUMD = {'r' : 255, 'g' : 255, 'b' : 0, 'a' : 64}
+	colorGreen =  {'r' : 0, 'g' : 255, 'b' : 0, 'a' : 64}
 
 	Button.SetText ("")
 	Button.SetFlags (IE_GUI_BUTTON_ALIGN_RIGHT | IE_GUI_BUTTON_ALIGN_BOTTOM | IE_GUI_BUTTON_PICTURE, OP_OR)
@@ -1107,6 +1065,7 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 			tooltips = { "inventory": 82, "ground": 83, "container": "" }
 		Button.SetTooltip (tooltips[Type])
 		Button.EnableBorder (0, 0)
+		Button.EnableBorder (1, 0)
 		Button.EnableBorder (2, 0)
 		return
 
@@ -1114,11 +1073,19 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 	identified = Slot["Flags"] & IE_INV_ITEM_IDENTIFIED
 	magical = item["Enchantment"] > 0
 
+	# gemrb extension based on ImprovedGUI - mark scrolls that the pc hasn't learned yet
+	scroll = False
+	knowsScroll = False
+	if Slot["Flags"] & IE_INV_ITEM_IDENTIFIED and GemRB.GetVar ("GUIEnhancements") & GE_MARK_SCROLLS:
+		scroll = item["Function"] & ITM_F_READ
+	if scroll and not Spellbook.HasSorcererBook (pc):
+		knowsScroll = Spellbook.CannotLearnSlotSpell (Slot, pc) == LSR_KNOWN
+
 	# MaxStackAmount holds the *maximum* item count in the stack while Usages0 holds the actual
 	if item["MaxStackAmount"] > 1:
 		Button.SetText (str (Slot["Usages0"]))
 
-	# auto-identify mundane items; the actual indentification will happen on transfer
+	# auto-identify mundane items; the actual identification will happen on transfer
 	if not identified and item["LoreToID"] == 0:
 		identified = True
 
@@ -1134,10 +1101,18 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 		# enable yellow overlay for "use magical device"
 		if usable & 0x100000:
 			Button.SetBorder (2, colorUMD, 1, 1)
+			# unset green border
+			Button.EnableBorder (1, 0)
+		elif scroll and not knowsScroll:
+			# set green border
+			Button.SetBorder (1, colorGreen, 1)
 		else:
 			Button.EnableBorder (2, 0)
+			# unset green border
+			Button.EnableBorder (1, 0)
 	else:
 		Button.SetBorder (2, colorUnusable, 1, 1)
+		Button.EnableBorder (1, 0)
 
 	if magical and GameCheck.IsIWD2 ():
 		Button.SetFlags (IE_GUI_BUTTON_HORIZONTAL, OP_OR)
