@@ -1,3 +1,4 @@
+import BGCommon
 import GemRB
 from GUIDefines import *
 from ie_stats import *
@@ -97,7 +98,7 @@ def getAlignment(area):
 	area.Append(AlignCap)
 	area.Append("\n")
 
-#Abilties
+# Abilities
 def unsetAbilities():
 	MyChar = GemRB.GetVar ("Slot")
 	AbilityTable = GemRB.LoadTable ("ability")
@@ -242,9 +243,7 @@ def getProfi(TextAreaControl):
 		Weapon = TmpTable.GetValue (i, 1, GTV_REF)
 		Value = GemRB.GetPlayerStat (MyChar, stat)
 		if Value:
-			pluses = " "
-			for plus in range(0, Value):
-				pluses += "+"
+			pluses = " " + "+" * Value
 			TextAreaControl.Append (Weapon + pluses + "\n")
 
 #Appearance
@@ -315,6 +314,9 @@ def setAccept():
 	#set my character up
 	MyChar = GemRB.GetVar ("Slot")
 
+	#reputation
+	BGCommon.SetReputation ()
+
 	# don't reset most stats of imported chars
 	if GemRB.GetVar ("ImportedChar"):
 		CustomizeChar (MyChar)
@@ -322,14 +324,6 @@ def setAccept():
 		return
 
 	ClassName = GUICommon.GetClassRowName (MyChar)
-	
-	#reputation
-	AlignID = GemRB.GetPlayerStat (MyChar, IE_ALIGNMENT)
-	TmpTable=GemRB.LoadTable ("repstart")
-	t = TmpTable.GetValue (AlignID, 0) * 10
-	GemRB.SetPlayerStat (MyChar, IE_REPUTATION, t)
-	if MyChar == 1: # only do it once
-		GemRB.GameSetReputation( t )
 
 	#lore, thac0, hp, and saves
 	GemRB.SetPlayerStat (MyChar, IE_MAXHITPOINTS, 0)
@@ -374,7 +368,7 @@ def RunGame(MyChar):
 	playmode = GemRB.GetVar ("PlayMode")
 	GemRB.SetVar ("ImportedChar", 0)
 		
-	if playmode >=0:
+	if playmode is not None:
 		CharGenCommon.close()
 		GemRB.SaveCharacter (MyChar, "gembak")
 		GemRB.EnterGame()
