@@ -16,6 +16,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
 # character generation end
+import BGCommon
 import GemRB
 import GameCheck
 import GUICommon
@@ -32,6 +33,9 @@ def OnLoad():
 	# set my character up
 	MyChar = GemRB.GetVar ("Slot")
 
+	#reputation
+	BGCommon.SetReputation ()
+
 	# don't reset most stats of imported chars
 	if GemRB.GetVar ("ImportedChar"):
 		CustomizeChar (MyChar)
@@ -98,7 +102,7 @@ def RunGame(MyChar):
 		GemRB.ChargeSpells (MyChar)
 
 	playmode = GemRB.GetVar ("PlayMode")
-	if playmode >=0:
+	if playmode is not None:
 		GemRB.SaveCharacter (MyChar, "gembak")
 		#LETS PLAY!!
 		import CharGenCommon, CommonWindow
