@@ -50,10 +50,10 @@ def RefreshPDoll():
 	global ColorWindow, PDollButton
 	global Color1, Color2, Color3, Color4, PDollResRef
 
-	PDollButton.SetFlags(IE_GUI_BUTTON_PLAYALWAYS|IE_GUI_BUTTON_CENTER_PICTURES, OP_OR)
+	PDollButton.SetFlags(IE_GUI_BUTTON_CENTER_PICTURES, OP_OR)
 	PDollButton.SetBAM("", 0, 0, 0) # just hide or there is a tiny artifact
 	PDollButton.SetAnimation (None) # force reset
-	PDollButton.SetAnimation (PDollResRef, 1, 8, [0, Color4, Color3, Color2, 0, 0, Color1, 0])
+	PDollButton.SetAnimation (PDollResRef, 1, A_ANI_ACTIVE, [0, Color4, Color3, Color2, 0, 0, Color1, 0])
 	return
 
 def OnLoad():
@@ -191,8 +191,8 @@ def CancelPress():
 def GetColor():
 	global ColorPicker, ColorIndex, PickedColor
 
-	ColorPicker=GemRB.LoadWindow(14)
-	GemRB.SetVar("Selected",-1)
+	ColorPicker=GemRB.LoadWindow(14, "GUICG")
+	GemRB.SetVar("Selected", None)
 	for i in range(33):
 		Button = ColorPicker.GetControl(i)
 		Button.SetState(IE_GUI_BUTTON_DISABLED)
@@ -231,6 +231,7 @@ def GetColor():
 	CancelButton.OnPress (CancelPress)
 	CancelButton.MakeEscape()
 
+	ColorPicker.ShowModal (MODAL_SHADOW_GRAY)
 	ColorPicker.Focus()
 	return
 
