@@ -1,4 +1,3 @@
-# -*-python-*-
 # GemRB - Infinity Engine Emulator
 # Copyright (C) 2003-2017 The GemRB Project
 #
@@ -21,6 +20,17 @@ import GemRB
 import GUICommon
 from GUIDefines import *
 
+def CreateClockButton(Button):
+	Button.SetAnimation ("WMTIME", 0, A_ANI_GAMEANIM)
+	Button.SetState (IE_GUI_BUTTON_LOCKED)
+	Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_SET)
+	Button.OnPress (lambda: GemRB.GamePause (2, 0))
+	Button.OnMouseEnter (UpdateClock)
+	SetPSTGamedaysAndHourToken ()
+	Button.SetTooltip (GemRB.GetString(65027))
+	
+	UpdateClock()
+
 def SetPSTGamedaysAndHourToken ():
 	currentTime = GemRB.GetGameTime()
 	hours = (currentTime % 7200) / 300
