@@ -36,7 +36,7 @@ def InitMapWindow (Window):
 	# World Map
 	Button = Window.GetControl (0)
 	Button.SetText (20429)
-	Button.OnPress (OpenTravelWindow)
+	Button.OnPress (lambda: OpenTravelWindow(None))
 
 	# Add Note
 	Button = Window.GetControl (1)
@@ -81,11 +81,9 @@ def InitMapWindow (Window):
 
 	return
 
-def OpenTravelWindow ():
+def OpenTravelWindow (Travel):
 	global WorldMapControl
 
-	Travel = GemRB.GetVar ("Travel")
-
 	Window = GemRB.LoadWindow (0, "GUIWMAP")
 	Window.AddAlias ("WIN_PSTWMAP")
 
@@ -95,7 +93,7 @@ def OpenTravelWindow ():
 	#center on current area
 	WMap.Scroll (0,0)
 	WMap.Focus()
-	if Travel != -1:
+	if Travel is not None:
 		WMap.OnPress (GUIMACommon.MoveToNewArea)
 
 	# Done
@@ -103,13 +101,14 @@ def OpenTravelWindow ():
 	Button.SetText (1403)
 	Button.OnPress (Window.Close)
 
-ToggleMapWindow = GUICommonWindows.CreateTopWinLoader(3, "GUIMA", GUICommonWindows.ToggleWindow, InitMapWindow, None, WINDOW_TOP|WINDOW_HCENTER)
-OpenMapWindow = GUICommonWindows.CreateTopWinLoader(3, "GUIMA", GUICommonWindows.OpenWindowOnce, InitMapWindow, None, WINDOW_TOP|WINDOW_HCENTER)
+ToggleMapWindow = GUICommonWindows.CreateTopWinLoader(3, "GUIMA", GUICommonWindows.ToggleWindow, InitMapWindow)
+OpenMapWindow = GUICommonWindows.CreateTopWinLoader(3, "GUIMA", GUICommonWindows.OpenWindowOnce, InitMapWindow)
 
 def NoteChanged (Edit):
 	Edit.SetFlags(IE_GUI_VIEW_IGNORE_EVENTS, OP_OR)
 	Text = Edit.QueryText ()
 	Edit.SetText ("")
+	Edit.SetBackground ("MAMOSED1")
 	PosX = GemRB.GetVar("MapControlX")
 	PosY = GemRB.GetVar("MapControlY")
 	GemRB.SetMapnote (PosX, PosY, 1, Text)
