@@ -22,12 +22,14 @@
 ###################################################
 
 import GemRB
+import ActionsWindow as ActionsWindowModule
 import GUIClasses
 import GUICommon
 import GUICommonWindows
 import CommonWindow
 import GUIWORLD
 import Clock
+import PortraitWindow
 from GameCheck import MAX_PARTY_SIZE
 from GUIDefines import *
 
@@ -59,23 +61,22 @@ def OnLoad():
 	MWindow.AddAlias("HIDE_CUT", 0)
 	MWindow.SetFlags(WF_BORDERLESS|IE_GUI_VIEW_IGNORE_EVENTS, OP_OR)
 
-	PortraitWindow = GUICommonWindows.OpenPortraitWindow (1, WINDOW_BOTTOM|WINDOW_HCENTER)
-	#PortraitWindow.AddAlias("HIDE_CUT", 3)
-	PortraitWindow.AddAlias("NOT_DLG", 2)
-	PortraitWindow.SetFlags(WF_BORDERLESS|IE_GUI_VIEW_IGNORE_EVENTS, OP_OR)
+	PortraitWin = PortraitWindow.OpenPortraitWindow (WINDOW_BOTTOM|WINDOW_HCENTER)
+	PortraitWin.AddAlias("NOT_DLG", 2)
+	PortraitWin.SetFlags(WF_BORDERLESS|IE_GUI_VIEW_IGNORE_EVENTS, OP_OR)
 
-	pframe = PortraitWindow.GetFrame()
+	pframe = PortraitWin.GetFrame()
 	pframe['x'] -= 16
-	PortraitWindow.SetFrame(pframe)
+	PortraitWin.SetFrame(pframe)
 
 	MessageTA = MWindow.GetControl (1)
 	MessageTA.SetFlags (IE_GUI_TEXTAREA_AUTOSCROLL|IE_GUI_TEXTAREA_HISTORY)
 	MessageTA.SetResizeFlags(IE_GUI_VIEW_RESIZE_ALL)
 	MessageTA.AddAlias("MsgSys", 0)
-	MessageTA.SetColor({'r' : 255, 'g' : 0, 'b' : 0}, TA_COLOR_OPTIONS)
-	MessageTA.SetColor({'r' : 255, 'g' : 255, 'b' : 255}, TA_COLOR_HOVER)
+	MessageTA.SetColor(ColorRed, TA_COLOR_OPTIONS)
+	MessageTA.SetColor(ColorWhite, TA_COLOR_HOVER)
 
-	CloseButton= MWindow.GetControl (0)
+	CloseButton = MWindow.GetControl (0)
 	CloseButton.SetText(28082)
 	CloseButton.OnPress (MWindow.Close)
 	CloseButton.MakeDefault()
@@ -106,7 +107,7 @@ def SetupClockWindowControls (Window):
 	# Abort current action
 	Button = Window.GetControl (3)
 	Button.SetTooltip (41655)
-	Button.OnPress (GUICommonWindows.ActionStopPressed)
+	Button.OnPress (ActionsWindowModule.ActionStopPressed)
 
 	# Formations
 	import GUIWORLD
