@@ -25,18 +25,19 @@
 
 namespace GemRB {
 
-AnimationFactory::AnimationFactory(const ResRef &resref,
-								   std::vector<Holder<Sprite2D>> f,
-								   std::vector<CycleEntry> c,
-								   std::vector<index_t> flt)
-: FactoryObject(resref, IE_BAM_CLASS_ID),
-frames(std::move(f)),
-cycles(std::move(c)),
-FLTable(std::move(flt))
+AnimationFactory::AnimationFactory(const ResRef& resref,
+				   std::vector<Holder<Sprite2D>> f,
+				   std::vector<CycleEntry> c,
+				   std::vector<index_t> flt)
+	: FactoryObject(resref, IE_BAM_CLASS_ID),
+	  frames(std::move(f)),
+	  cycles(std::move(c)),
+	  FLTable(std::move(flt))
 {
 	assert(frames.size() < InvalidIndex);
 	assert(cycles.size() < InvalidIndex);
 	assert(FLTable.size() < InvalidIndex);
+	fps = core->GetAnimationFPS(resRef);
 }
 
 Animation* AnimationFactory::GetCycle(index_t cycle) const noexcept
@@ -52,7 +53,7 @@ Animation* AnimationFactory::GetCycle(index_t cycle) const noexcept
 		animframes.push_back(frames[FLTable[i]]);
 	}
 	assert(cycles[cycle].FramesCount == animframes.size());
-	return new Animation(std::move(animframes));
+	return new Animation(std::move(animframes), fps);
 }
 
 /* returns the required frame of the named cycle, cycle defaults to 0 */
@@ -63,60 +64,18 @@ Holder<Sprite2D> AnimationFactory::GetFrame(index_t index, index_t cycle) const
 	}
 	index_t ff = cycles[cycle].FirstFrame;
 	index_t fc = cycles[cycle].FramesCount;
-	if(index >= fc) {
+	if (index >= fc) {
 		return nullptr;
 	}
-	return frames[FLTable[ff+index]];
+	return frames[FLTable[ff + index]];
 }
 
 Holder<Sprite2D> AnimationFactory::GetFrameWithoutCycle(index_t index) const
 {
-	if(index >= frames.size()) {
-		return NULL;
-	}
-	return frames[index];
-}
-
-Holder<Sprite2D> AnimationFactory::GetPaperdollImage(const ieDword *Colors,
-		Holder<Sprite2D> &Picture2, unsigned int type) const
-{
-	if (frames.size()<2) {
+	if (index >= frames.size()) {
 		return nullptr;
 	}
-
-	// mod paperdolls can be unsorted (Longer Road Irenicus cycle: 1 1 0)
-	index_t first = InvalidIndex; // top half
-	index_t second = InvalidIndex; // bottom half
-	index_t ff = cycles[0].FirstFrame;
-	for (index_t f = 0; f < cycles[0].FramesCount; f++) {
-		index_t idx = FLTable[ff + f];
-		if (first == InvalidIndex) {
-			first = idx;
-		} else if (second == InvalidIndex && idx != first) {
-			second = idx;
-			break;
-		}
-	}
-	if (second == InvalidIndex) {
-		return NULL;
-	}
-
-	Picture2 = frames[second]->copy();
-	Picture2->Frame.x = frames[second]->Frame.x;
-	Picture2->Frame.y = frames[second]->Frame.y - 80;
-
-	Holder<Sprite2D> spr = frames[first]->copy();
-	spr->Frame.x = frames[first]->Frame.x;
-	spr->Frame.y = frames[first]->Frame.y;
-	
-	if (Colors) {
-		PaletteHolder pal = spr->GetPalette()->Copy();
-		pal->SetupPaperdollColours(Colors, type);
-		spr->SetPalette(pal);
-		Picture2->SetPalette(pal);
-	}
-	
-	return spr;
+	return frames[index];
 }
 
 AnimationFactory::index_t AnimationFactory::GetCycleSize(index_t idx) const
