@@ -23,77 +23,93 @@
 
 #include <type_traits>
 
-template <typename ENUM>
-using under_t = typename std::underlying_type<ENUM>::type;
+#ifdef __has_attribute
+	#define HAS_ATTRIBUTE(x) __has_attribute(x)
+#else
+	#define HAS_ATTRIBUTE(x) 0
+#endif
+
+#if HAS_ATTRIBUTE(flag_enum)
+	#define FLAG_ENUM enum class __attribute__((flag_enum))
+#else
+	#define FLAG_ENUM enum class
+#endif
+
+template<typename ENUM>
+using under_t = std::underlying_type_t<ENUM>;
+
+template<typename T, bool = std::is_enum<T>::value>
+struct under_sfinae {
+	using type = typename std::underlying_type_t<T>;
+};
+
+template<typename T>
+struct under_sfinae<T, false> {
+	using type = T;
+};
+
+template<typename ENUM>
+using under_sfinae_t = typename under_sfinae<ENUM>::type;
 
 template<typename ENUM_FLAGS>
-constexpr
-under_t<ENUM_FLAGS>
-UnderType(ENUM_FLAGS a) noexcept
+constexpr under_sfinae_t<ENUM_FLAGS>
+	UnderType(ENUM_FLAGS a) noexcept
 {
 	return static_cast<under_t<ENUM_FLAGS>>(a);
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>::type
-operator |(ENUM_FLAGS a, ENUM_FLAGS b) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>
+	operator|(ENUM_FLAGS a, ENUM_FLAGS b) noexcept
 {
 	return static_cast<ENUM_FLAGS>(UnderType(a) | UnderType(b));
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS&>::type
-operator |=(ENUM_FLAGS& a, ENUM_FLAGS b) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS&>
+	operator|=(ENUM_FLAGS& a, ENUM_FLAGS b) noexcept
 {
 	return a = a | b;
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>::type
-operator &(ENUM_FLAGS a, ENUM_FLAGS b) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>
+	operator&(ENUM_FLAGS a, ENUM_FLAGS b) noexcept
 {
 	return static_cast<ENUM_FLAGS>(UnderType(a) & UnderType(b));
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS&>::type
-operator &=(ENUM_FLAGS& a, ENUM_FLAGS b) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS&>
+	operator&=(ENUM_FLAGS& a, ENUM_FLAGS b) noexcept
 {
 	return a = a & b;
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>::type
-operator ^(ENUM_FLAGS a, ENUM_FLAGS b) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>
+	operator^(ENUM_FLAGS a, ENUM_FLAGS b) noexcept
 {
 	return static_cast<ENUM_FLAGS>(UnderType(a) ^ UnderType(b));
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS&>::type
-operator ^=(ENUM_FLAGS& a, ENUM_FLAGS b) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS&>
+	operator^=(ENUM_FLAGS& a, ENUM_FLAGS b) noexcept
 {
 	return a = a ^ b;
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>::type
-operator ~(ENUM_FLAGS a) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, ENUM_FLAGS>
+	operator~(ENUM_FLAGS a) noexcept
 {
 	return static_cast<ENUM_FLAGS>(~UnderType(a));
 }
 
 template<typename ENUM_FLAGS>
-constexpr
-typename std::enable_if<std::is_enum<ENUM_FLAGS>::value, bool>::type
-operator !(ENUM_FLAGS a) noexcept
+constexpr std::enable_if_t<std::is_enum<ENUM_FLAGS>::value, bool>
+	operator!(ENUM_FLAGS a) noexcept
 {
 	return !UnderType(a);
 }
