@@ -21,10 +21,10 @@
 #ifndef FACTORYOBJECT_H
 #define FACTORYOBJECT_H
 
+#include "SClassID.h"
 #include "exports.h"
 #include "globals.h"
 
-#include "SClassID.h"
 #include "Resource.h"
 
 namespace GemRB {
@@ -33,7 +33,8 @@ class GEM_EXPORT FactoryObject {
 public:
 	SClass_ID SuperClassID;
 	ResRef resRef;
-	FactoryObject(const ResRef &name, SClass_ID superClassID) : SuperClassID(superClassID), resRef(name) {};
+	FactoryObject(const ResRef& name, SClass_ID superClassID)
+		: SuperClassID(superClassID), resRef(name) {};
 	virtual ~FactoryObject() noexcept = default;
 };
 
