@@ -21,9 +21,11 @@
 #ifndef GemRB_FontManager_h
 #define GemRB_FontManager_h
 
-#include "TypeID.h"
-#include "Resource.h"
 #include "exports.h"
+
+#include "Resource.h"
+#include "TypeID.h"
+
 #include "GUI/TextSystem/Font.h"
 
 namespace GemRB {
@@ -32,8 +34,9 @@ class GEM_EXPORT FontManager : public Resource {
 public:
 	// Public data members
 	static const TypeID ID;
+
 public:
-	virtual Font* GetFont(ieWord pxSize, FontStyle style, bool background)=0;
+	virtual Holder<Font> GetFont(ieWord pxSize, FontStyle style, bool background) = 0;
 };
 
 }
