@@ -20,22 +20,21 @@
 
 #include "GUI/Button.h"
 
-#include "GUI/GameControl.h"
-#include "GUI/EventMgr.h"
-#include "GUI/ScrollBar.h"
-#include "GUI/Window.h"
-
 #include "defsounds.h"
 #include "ie_cursors.h"
 
+#include "Audio.h"
 #include "Game.h"
 #include "GameData.h"
-#include "Logging/Logging.h"
+#include "Interface.h"
 #include "Palette.h"
 
-#include <utility>
+#include "GUI/EventMgr.h"
+#include "GUI/ScrollBar.h"
+#include "GUI/Window.h"
+#include "Logging/Logging.h"
 
-#define IS_PORTRAIT (Picture && ((flags&IE_GUI_BUTTON_PORTRAIT) == IE_GUI_BUTTON_PORTRAIT))
+#include <utility>
 
 namespace GemRB {
 
@@ -51,8 +50,8 @@ Button::Button(const Region& frame)
 
 Button::~Button()
 {
-	delete animation;
-	SetImage(BUTTON_IMAGE_NONE, NULL);
+	SetAnimation(nullptr);
+	SetImage(ButtonImage::None, nullptr);
 	ClearPictureList();
 
 	if (hotKey.global) {
@@ -73,14 +72,9 @@ void Button::UnregisterHotKey()
 
 /** Sets the 'type' Image of the Button to 'img'.
  see 'BUTTON_IMAGE_TYPE' */
-void Button::SetImage(BUTTON_IMAGE_TYPE type, Holder<Sprite2D> img)
+void Button::SetImage(ButtonImage type, Holder<Sprite2D> img)
 {
-	if (type >= BUTTON_IMAGE_TYPE_COUNT) {
-		Log(ERROR, "Button", "Trying to set a button image index out of range: {}", type);
-		return;
-	}
-
-	if (type <= BUTTON_IMAGE_NONE) {
+	if (type == ButtonImage::None) {
 		for (auto& buttonImage : buttonImages) {
 			buttonImage = nullptr;
 		}
@@ -88,7 +82,7 @@ void Button::SetImage(BUTTON_IMAGE_TYPE type, Holder<Sprite2D> img)
 	} else {
 		buttonImages[type] = std::move(img);
 		/*
-		 currently IE_GUI_BUTTON_NO_IMAGE cannot be infered from the presence or lack of images
+		 currently IE_GUI_BUTTON_NO_IMAGE cannot be inferred from the presence or lack of images
 		 leaving this here commented out in case it may be useful in the future.
 
 		if (img) {
@@ -97,12 +91,12 @@ void Button::SetImage(BUTTON_IMAGE_TYPE type, Holder<Sprite2D> img)
 			// check if we should set IE_GUI_BUTTON_NO_IMAGE
 
 			int i=0;
-			for (; i < BUTTON_IMAGE_TYPE_COUNT; i++) {
+			for (; i < BUTTON_IMAGE_TYPE::None; i++) {
 				if (buttonImages[i] != NULL) {
 					break;
 				}
 			}
-			if (i == BUTTON_IMAGE_TYPE_COUNT) {
+			if (i == BUTTON_IMAGE_TYPE::None) {
 				// we made it to the end of the list without breaking so we have no images
 				Flags &= IE_GUI_BUTTON_NO_IMAGE;
 			}
@@ -114,7 +108,10 @@ void Button::SetImage(BUTTON_IMAGE_TYPE type, Holder<Sprite2D> img)
 void Button::WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 {
 	if (animation && animation->HasEnded()) {
+		auto sprite = animation->Current();
 		SetAnimation(nullptr);
+		SetPicture(std::move(sprite));
+		PerformAction(Action::EndReached);
 	}
 }
 
@@ -132,32 +129,28 @@ void Button::DidDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 /** Draws the Control on the Output Display */
 void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 {
-	Video * video = core->GetVideoDriver();
-
 	// Button image
-	if (!( flags & IE_GUI_BUTTON_NO_IMAGE )) {
+	if (!(flags & IE_GUI_BUTTON_NO_IMAGE)) {
 		Holder<Sprite2D> Image;
 
 		switch (ButtonState) {
 			case FAKEPRESSED:
 			case PRESSED:
-				Image = buttonImages[BUTTON_IMAGE_PRESSED];
+				Image = buttonImages[ButtonImage::Pressed];
 				break;
 			case SELECTED:
-				Image = buttonImages[BUTTON_IMAGE_SELECTED];
+				Image = buttonImages[ButtonImage::Selected];
 				break;
 			case DISABLED:
 			case FAKEDISABLED:
-				Image = buttonImages[BUTTON_IMAGE_DISABLED];
+				Image = buttonImages[ButtonImage::Disabled];
 				break;
 			default:
-				Image = buttonImages[BUTTON_IMAGE_UNPRESSED];
+				Image = buttonImages[ButtonImage::Unpressed];
 				break;
 		}
 		if (Image) {
-			// FIXME: maybe it's useless...
-			Point offset((frame.w / 2) - (Image->Frame.w / 2), (frame.h / 2) - (Image->Frame.h / 2));
-			video->BlitSprite(Image, rgn.origin + offset);
+			VideoDriver->BlitSprite(Image, rgn.origin);
 		}
 	}
 
@@ -169,7 +162,7 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 
 	// Button picture
 	Point picPos;
-	if (Picture && (flags & IE_GUI_BUTTON_PICTURE) ) {
+	if (Picture && (flags & IE_GUI_BUTTON_PICTURE)) {
 		// Picture is drawn centered
 		picPos.x = (rgn.w / 2) - (Picture->Frame.w / 2) + rgn.x;
 		picPos.y = (rgn.h / 2) - (Picture->Frame.h / 2) + rgn.y;
@@ -187,33 +180,35 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 			if (overlayHeight) {
 				// TODO: Add an option to add BlitFlags::GREY to the flags
 				const Color& col = overlayAnim.Current();
-				video->BlitGameSprite(Picture, picPos, BlitFlags::COLOR_MOD, col);
+				VideoDriver->BlitGameSprite(Picture, picPos, BlitFlags::COLOR_MOD, col);
 			}
 
 			Region rb = Region(picPos.x, picPos.y, Picture->Frame.w, buttonHeight);
-			video->BlitSprite( Picture, rb.origin, &rb );
+			VideoDriver->BlitSprite(Picture, rb.origin, &rb);
 		} else {
 			Region r(picPos.x, picPos.y, (Picture->Frame.w * Clipping), Picture->Frame.h);
-			video->BlitSprite(Picture, Picture->Frame.origin + r.origin, &r);
+			BlitFlags bf = IsDisabled() ? BlitFlags::SEPIA : BlitFlags::NONE;
+			VideoDriver->BlitSprite(Picture, Picture->Frame.origin + r.origin, &r, bf);
 		}
 	}
 
 	// Button animation
-	if (animation && animation->Current()) {
+	if (animation) {
 		auto AnimPicture = animation->Current();
-		int xOffs = ( frame.w / 2 ) - ( AnimPicture->Frame.w / 2 );
-		int yOffs = ( frame.h / 2 ) - ( AnimPicture->Frame.h / 2 );
-		Region r( rgn.x + xOffs, rgn.y + yOffs, int(AnimPicture->Frame.w * Clipping), AnimPicture->Frame.h );
+		int xOffs = (frame.w / 2) - (AnimPicture->Frame.w / 2);
+		int yOffs = (frame.h / 2) - (AnimPicture->Frame.h / 2);
+		Region r(rgn.x + xOffs, rgn.y + yOffs, int(AnimPicture->Frame.w * Clipping), AnimPicture->Frame.h);
 
+		BlitFlags bf = bool(animation->flags & Animation::Flags::BlendBlack) ? BlitFlags::ONE_MINUS_DST : BlitFlags::BLENDED;
 		if (flags & IE_GUI_BUTTON_CENTER_PICTURES) {
-			video->BlitSprite( AnimPicture, r.origin + AnimPicture->Frame.origin, &r );
+			VideoDriver->BlitSprite(AnimPicture, r.origin + AnimPicture->Frame.origin, &r, bf);
 		} else {
-			video->BlitSprite( AnimPicture, r.origin, &r );
+			VideoDriver->BlitSprite(AnimPicture, r.origin, &r, bf);
 		}
 	}
 
 	// Composite pictures (paperdolls/description icons)
-	if (!PictureList.empty() && (flags & IE_GUI_BUTTON_PICTURE) ) {
+	if (!PictureList.empty() && (flags & IE_GUI_BUTTON_PICTURE)) {
 		auto iter = PictureList.begin();
 		Point offset;
 		if (flags & IE_GUI_BUTTON_CENTER_PICTURES) {
@@ -224,8 +219,8 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 			// Display as-is
 		} else {
 			// Center the first picture, and align the rest to that
-			offset.x = frame.w / 2 - (*iter)->Frame.w/2 + (*iter)->Frame.x;
-			offset.y = frame.h / 2 - (*iter)->Frame.h/2 + (*iter)->Frame.y;
+			offset.x = frame.w / 2 - (*iter)->Frame.w / 2 + (*iter)->Frame.x;
+			offset.y = frame.h / 2 - (*iter)->Frame.h / 2 + (*iter)->Frame.y;
 		}
 
 		BlitFlags blitFlags = BlitFlags::NONE;
@@ -233,12 +228,12 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 			blitFlags = BlitFlags::HALFTRANS;
 		}
 		for (; iter != PictureList.end(); ++iter) {
-			video->BlitSprite(*iter, rgn.origin + offset, nullptr, blitFlags);
+			VideoDriver->BlitSprite(*iter, rgn.origin + offset, nullptr, blitFlags);
 		}
 	}
 
 	// Button label
-	if (hasText && ! ( flags & IE_GUI_BUTTON_NO_TEXT )) {
+	if (hasText) {
 		// FIXME: hopefully there's no button which sinks when selected
 		//   AND has text label
 		//else if (State == IE_GUI_BUTTON_PRESSED || State == IE_GUI_BUTTON_SELECTED) {
@@ -259,17 +254,17 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 			align |= IE_FONT_ALIGN_MIDDLE;
 
 		Region r = rgn;
-		if (IS_PORTRAIT) {
+		if (Picture && flags & IE_GUI_BUTTON_PICTURE) {
 			// constrain the label (status icons) to the picture bounds
 			// FIXME: we have to do +1 because the images are 1 px too small to fit 3 icons...
 			r = Region(picPos.x, picPos.y, Picture->Frame.w + 1, Picture->Frame.h);
-		} else if (flags&IE_GUI_BUTTON_ANCHOR) {
+		} else if (flags & IE_GUI_BUTTON_ANCHOR) {
 			r.x += Anchor.x;
 			r.y += Anchor.y;
 			r.w -= Anchor.x;
 			r.h -= Anchor.y;
 		} else {
-			Font::StringSizeMetrics metrics {r.size, 0, 0, false};
+			Font::StringSizeMetrics metrics { r.size, 0, 0, false };
 			font->StringSize(Text, &metrics);
 
 			if (metrics.numLines == 1 && (IE_GUI_BUTTON_ALIGNMENT_FLAGS & flags)) {
@@ -280,7 +275,7 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 				r.ExpandAllSides(-5);
 			}
 		}
-		
+
 		Color c = textColor;
 		if (ButtonState == DISABLED || IsDisabled()) {
 			c.r *= 0.66;
@@ -288,47 +283,30 @@ void Button::DrawSelf(const Region& rgn, const Region& /*clip*/)
 			c.b *= 0.66;
 		}
 
-		Font::PrintColors colors {c, ColorBlack};
+		Font::PrintColors colors { c, textBGColor };
 		font->Print(r, Text, align, colors);
 	}
 
-	if (! (flags&IE_GUI_BUTTON_NO_IMAGE)) {
-		for (const auto& border : borders) {
-			const ButtonBorder *fr = &border;
-			if (! fr->enabled) continue;
+	if (!(flags & IE_GUI_BUTTON_NO_IMAGE)) {
+		for (const ButtonBorder& border : borders) {
+			if (!border.enabled) continue;
 
-			const Region& frRect = fr->rect;
-			Region r = Region( rgn.origin + frRect.origin, frRect.size );
-			if (pulseBorder && !fr->filled) {
-				Color mix = GlobalColorCycle.Blend(ColorWhite, fr->color);
-				video->DrawRect( r, mix, fr->filled, BlitFlags::BLENDED );
+			const Region& frRect = border.rect;
+			Region r = Region(rgn.origin + frRect.origin, frRect.size);
+			if (pulseBorder && !border.filled) {
+				Color mix = GlobalColorCycle.Blend(ColorWhite, border.color);
+				VideoDriver->DrawRect(r, mix, border.filled, BlitFlags::BLENDED);
 			} else {
-				video->DrawRect( r, fr->color, fr->filled, BlitFlags::BLENDED );
+				VideoDriver->DrawRect(r, border.color, border.filled, BlitFlags::BLENDED);
 			}
 		}
 	}
 }
 
-void Button::FlagsChanged(unsigned int /*oldflags*/)
-{
-	if (animation) {
-		animation->flags = SpriteAnimation::PLAY_NORMAL;
-		if (flags & IE_GUI_BUTTON_PLAYRANDOM) {
-			animation->flags |= SpriteAnimation::PLAY_RANDOM;
-		}
-		if (flags & IE_GUI_BUTTON_PLAYONCE) {
-			animation->flags |= SpriteAnimation::PLAY_ONCE;
-		}
-		if (flags & IE_GUI_BUTTON_PLAYALWAYS) {
-			animation->flags |= SpriteAnimation::PLAY_ALWAYS;
-		}
-	}
-}
-
 /** Sets the Button State */
-void Button::SetState(State state)
+void Button::SetState(State state, bool setval)
 {
-	if (state > LOCKED_PRESSED) {// If wrong value inserted
+	if (state > LOCKED_PRESSED) { // If wrong value inserted
 		return;
 	}
 
@@ -338,9 +316,17 @@ void Button::SetState(State state)
 	if (ButtonState != state) {
 		MarkDirty();
 		ButtonState = state;
+		if (setval && ButtonState == SELECTED) {
+			UpdateDictValue();
+		}
 	}
 }
 
+void Button::SetState(State state)
+{
+	return SetState(state, true);
+}
+
 bool Button::IsAnimated() const
 {
 	if (animation) {
@@ -360,22 +346,19 @@ bool Button::IsAnimated() const
 
 bool Button::IsOpaque() const
 {
-	if (animation) {
-		// we are dirty every frame anyway
-		// so no need to get fancy
-		// just redraw everything
-		return false;
+	bool opaque = Control::IsOpaque();
+	if (!opaque && animation && animation->Current()) {
+		auto AnimPicture = animation->Current();
+		opaque = !AnimPicture->HasTransparency();
+	}
+	if (!opaque && Picture && !(flags & IE_GUI_BUTTON_NO_IMAGE)) {
+		opaque = !Picture->HasTransparency();
 	}
 
-	bool opaque = View::IsOpaque();
-	if (!opaque && Picture) {
-		opaque = !(flags&IE_GUI_BUTTON_NO_IMAGE) && !Picture->HasTransparency();
-	}
-	
 	return opaque;
 }
 
-void Button::SetBorder(int index, const Region& rgn, const Color &color, bool enabled, bool filled)
+void Button::SetBorder(int index, const Region& rgn, const Color& color, bool enabled, bool filled)
 {
 	if (index >= MAX_NUM_BORDERS)
 		return;
@@ -397,108 +380,82 @@ void Button::EnableBorder(int index, bool enabled)
 	}
 }
 
-void Button::SetFont(Font* newfont)
+void Button::SetFont(Holder<Font> newfont)
 {
-	font = newfont;
+	font = std::move(newfont);
 }
 
 String Button::TooltipText() const
 {
 	if (IsDisabled() || flags & IE_GUI_BUTTON_NO_TOOLTIP) {
-		return L"";
+		return u"";
 	}
 
-	ieDword showHotkeys = core->GetVariable("Hotkeys On Tooltips", 0);
+	ieDword showHotkeys = core->GetDictionary().Get("Hotkeys On Tooltips", 0);
 	if (showHotkeys && hotKey) {
 		String s;
 		switch (hotKey.key) {
 			// FIXME: these arent localized...
 			case GEM_ESCAPE:
-				s += L"Esc";
+				s += u"Esc";
 				break;
 			case GEM_RETURN:
-				s += L"Enter";
+				s += u"Enter";
 				break;
 			case GEM_PGUP:
-				s += L"PgUp";
+				s += u"PgUp";
 				break;
 			case GEM_PGDOWN:
-				s += L"PgDn";
+				s += u"PgDn";
 				break;
 			default:
 				if (hotKey.key >= GEM_FUNCTIONX(1) && hotKey.key <= GEM_FUNCTIONX(16)) {
-					s.push_back(L'F');
+					s.push_back(u'F');
 					int offset = hotKey.key - GEM_FUNCTIONX(0);
 					if (hotKey.key > GEM_FUNCTIONX(9)) {
-						s.push_back(L'1');
+						s.push_back(u'1');
 						offset -= 10;
 					}
-					s.push_back(L'0' + offset);
+					s.push_back(u'0' + offset);
 				} else {
 					s.push_back(towupper(hotKey.key));
 				}
 				break;
 		}
 		String tt = ((tooltip.length()) ? tooltip : QueryText());
-		tt = (tt.length()) ? s + L": " + tt : s;
+		tt = (tt.length()) ? std::move(s) + u": " + tt : std::move(s);
 		return tt;
 	}
 	return Control::TooltipText();
 }
 
-Holder<Sprite2D> Button::Cursor() const
-{
-	if (IS_PORTRAIT) {
-		const GameControl* gc = core->GetGameControl();
-		if (gc) {
-			Holder<Sprite2D> cur = gc->GetTargetActionCursor();
-			if (cur) return cur;
-		}
-	}
-	return Control::Cursor();
-}
-
-bool Button::AcceptsDragOperation(const DragOp& dop) const
-{
-	// FIXME: this implementation is obviously not future proof
-	// portrait buttons accept other portraits and dropped items
-	if (IS_PORTRAIT) {
-		return true;
-	}
-	
-	return Control::AcceptsDragOperation(dop);
-}
-
 void Button::CompleteDragOperation(const DragOp& dop)
 {
 	if (dop.dragView == this) {
 		// this was the dragged view
 		EnableBorder(1, false);
 	}
-	
+
 	Control::CompleteDragOperation(dop);
 }
 
 Holder<Sprite2D> Button::DragCursor() const
 {
-	if (IS_PORTRAIT) {
-		// TODO: would it be an enhancement to actually use the portrait for the drag icon?
-		return core->Cursors[IE_CURSOR_SWAP];
-	} else if (Picture) {
+	if (Picture) {
 		return Picture;
 	}
-	
+
 	return Control::DragCursor();
 }
 
 /** Mouse Button Down */
 bool Button::OnMouseDown(const MouseEvent& me, unsigned short mod)
 {
-	ActionKey key(Action::DragDropDest);
+	ActionKey key(Control::Action::DragDropDest);
 	if (core->GetDraggedItem() && !SupportsAction(key)) {
 		return true;
 	}
-    
+
 	if (me.button == GEM_MB_ACTION) {
 		if (ButtonState == LOCKED) {
 			SetState(LOCKED_PRESSED);
@@ -506,7 +463,7 @@ bool Button::OnMouseDown(const MouseEvent& me, unsigned short mod)
 		}
 		SetState(PRESSED);
 		if (flags & IE_GUI_BUTTON_SOUND) {
-			core->PlaySound(DS_BUTTON_PRESSED, SFX_CHAN_GUI);
+			core->PlaySound(DS_BUTTON_PRESSED, SFXChannel::GUI);
 		}
 	}
 	return Control::OnMouseDown(me, mod);
@@ -515,10 +472,10 @@ bool Button::OnMouseDown(const MouseEvent& me, unsigned short mod)
 /** Mouse Button Up */
 bool Button::OnMouseUp(const MouseEvent& me, unsigned short mod)
 {
-	bool drag = core->GetDraggedItem () != NULL;
+	bool drag = core->GetDraggedItem() != NULL;
 
 	if (drag && me.repeats == 1) {
-		ActionKey key(Action::DragDropDest);
+		ActionKey key(Control::Action::DragDropDest);
 		if (SupportsAction(key)) {
 			return PerformAction(key);
 		} else {
@@ -529,11 +486,13 @@ bool Button::OnMouseUp(const MouseEvent& me, unsigned short mod)
 
 	if (ButtonState == LOCKED_PRESSED) {
 		SetState(LOCKED);
-	} else {
+	} else if (ButtonState != LOCKED) {
 		SetState(UNPRESSED);
 	}
 
-	DoToggle();
+	if (me.button == GEM_MB_ACTION) {
+		DoToggle();
+	}
 	return Control::OnMouseUp(me, mod);
 }
 
@@ -554,10 +513,9 @@ void Button::OnMouseEnter(const MouseEvent& me, const DragOp* dop)
 		SetState(PRESSED);
 	}
 
-	for (const auto& border : borders) {
-		const ButtonBorder *fr = &border;
-		if (fr->enabled) {
-			pulseBorder = !fr->filled;
+	for (const ButtonBorder& border : borders) {
+		if (border.enabled) {
+			pulseBorder = !border.filled;
 			MarkDirty();
 			break;
 		}
@@ -583,10 +541,10 @@ void Button::SetText(String string)
 {
 	Text = std::move(string);
 	if (Text.length()) {
-		if (flags&IE_GUI_BUTTON_LOWERCASE)
-			StringToLower( Text );
-		else if (flags&IE_GUI_BUTTON_CAPS)
-			StringToUpper( Text );
+		if (flags & IE_GUI_BUTTON_LOWERCASE)
+			StringToLower(Text);
+		else if (flags & IE_GUI_BUTTON_CAPS)
+			StringToUpper(Text);
 		hasText = true;
 	} else {
 		hasText = false;
@@ -599,7 +557,7 @@ BitOp Button::GetDictOp() const noexcept
 	if (flags & IE_GUI_BUTTON_CHECKBOX) {
 		return BitOp::XOR;
 	}
-	
+
 	return BitOp::SET;
 }
 
@@ -610,20 +568,16 @@ void Button::UpdateState(value_t Sum)
 		// FIXME: buttons should be able to both be disabled and reflect their state
 		return;
 	}
-	
-	State state = UNPRESSED;
+
 	if (flags & IE_GUI_BUTTON_RADIOBUTTON) {
 		//radio button, exact value
-		state = Sum == GetValue() ? SELECTED : UNPRESSED;
+		State state = Sum == GetValue() ? SELECTED : UNPRESSED;
+		SetState(state);
 	} else if (flags & IE_GUI_BUTTON_CHECKBOX) {
 		//checkbox, bitvalue
-		state = bool(Sum & GetValue()) ? SELECTED : UNPRESSED;
-	} else {
-		//other buttons, nothing to redraw
-		return;
+		State state = bool(Sum & GetValue()) ? SELECTED : UNPRESSED;
+		SetState(state, false);
 	}
-
-	SetState(state);
 }
 
 void Button::DoToggle()
@@ -640,7 +594,7 @@ void Button::SetPicture(Holder<Sprite2D> newpic)
 		// try fitting to width if rescaling is possible, otherwise we automatically crop
 		unsigned int ratio = CeilDiv(Picture->Frame.w, frame.w);
 		if (ratio > 1) {
-			Holder<Sprite2D> img = core->GetVideoDriver()->SpriteScaleDown(Picture, ratio);
+			Holder<Sprite2D> img = VideoDriver->SpriteScaleDown(Picture, ratio);
 			Picture = std::move(img);
 		}
 		flags |= IE_GUI_BUTTON_PICTURE;
@@ -652,18 +606,16 @@ void Button::SetPicture(Holder<Sprite2D> newpic)
 
 void Button::SetAnimation(SpriteAnimation* anim)
 {
-	// if this button says the resource is the same
-	// we wanted to set, we don't reset it
-	// but we must reinitialize it, if it was play once
-	if (animation && animation->SameResource(anim) && !(animation->flags & SpriteAnimation::PLAY_ONCE)) {
-		delete anim;
-		return;
+	delete animation;
+	animation = anim;
+
+	const auto& key = fmt::format("{}_ANIM", ControlID);
+	if (animation) {
+		core->GetDictionary().Set(key, true);
 	} else {
-		delete animation;
-		animation = anim;
-		FlagsChanged(flags); // sync animation flags
+		core->GetDictionary().Erase(key);
 	}
-	
+
 	MarkDirty();
 }
 
@@ -688,27 +640,27 @@ bool Button::HitTest(const Point& p) const
 	if (hit) {
 		// some buttons have hollow Image frame filled w/ Picture
 		// some buttons in BG2 are text only (if BAM == 'GUICTRL')
-		Holder<Sprite2D> Unpressed = buttonImages[BUTTON_IMAGE_UNPRESSED];
+		Holder<Sprite2D> Unpressed = buttonImages[ButtonImage::Unpressed];
 		if (Picture || !PictureList.empty() || !Unpressed) return true;
-
-		Point off;
-		off.x = (frame.w / 2) - (Unpressed->Frame.w / 2) + Unpressed->Frame.x;
-		off.y = (frame.h / 2) - (Unpressed->Frame.h / 2) + Unpressed->Frame.y;
-		hit = !Unpressed->IsPixelTransparent(p - off);
+		hit = !Unpressed->IsPixelTransparent(p);
 	}
 	return hit;
 }
 
 // Set palette used for drawing button label in normal state
-void Button::SetTextColor(const Color &color)
+void Button::SetTextColor(const Color& color, bool bg)
 {
-	textColor = color;
+	if (bg) {
+		textBGColor = color;
+	} else {
+		textColor = color;
+	}
 	MarkDirty();
 }
 
-void Button::SetHorizontalOverlay(double clip, const Color& src, const Color &dest)
+void Button::SetHorizontalOverlay(double clip, const Color& src, const Color& dest)
 {
-	if ((Clipping>clip) || !(flags&IE_GUI_BUTTON_HORIZONTAL) ) {
+	if ((Clipping > clip) || !(flags & IE_GUI_BUTTON_HORIZONTAL)) {
 		flags |= IE_GUI_BUTTON_HORIZONTAL;
 
 		overlayAnim = ColorAnimation(src, dest, false);
@@ -719,18 +671,18 @@ void Button::SetHorizontalOverlay(double clip, const Color& src, const Color &de
 
 void Button::SetAnchor(int x, int y)
 {
-	Anchor = Point(x,y);
+	Anchor = Point(x, y);
 }
 
 void Button::SetPushOffset(int x, int y)
 {
-	PushOffset = Point(x,y);
+	PushOffset = Point(x, y);
 }
 
 bool Button::SetHotKey(KeyboardKey key, short mod, bool global)
 {
 	UnregisterHotKey();
-	
+
 	if (key == 0) {
 		return true;
 	}
