@@ -21,12 +21,13 @@
 #include "GUI/Console.h"
 
 #include "Interface.h"
+
 #include "Streams/FileStream.h"
 
 namespace GemRB {
 
 Console::Console(const Region& frame, TextArea* ta)
-: TextEdit(frame, -1, Point(3, 3))
+	: TextEdit(frame, -1, Point(3, 3))
 {
 	ControlEventHandler onReturn = [this](const Control*) {
 		Execute(QueryText());
@@ -35,7 +36,7 @@ Console::Console(const Region& frame, TextArea* ta)
 
 	if (ta) {
 		textArea = ta;
-		ControlEventHandler handler = [this](const Control* c) {
+		textArea->SetAction([this](const Control* c) {
 			auto val = c->GetValue();
 			size_t histSize = History.Size();
 			size_t selected = histSize - val;
@@ -47,8 +48,8 @@ Console::Console(const Region& frame, TextArea* ta)
 				SetText(c->QueryText());
 			}
 			SetFocus();
-		};
-		textArea->SetAction(std::move(handler), TextArea::Action::Select);
+		},
+				    TextArea::Action::Select);
 	}
 
 	LoadHistory();
@@ -67,26 +68,24 @@ void Console::UpdateTextArea()
 			options.push_back(History.Retrieve(i));
 			options.back().first = int(i) + 1;
 		}
-		
+
 		textArea->SetValue(INVALID_VALUE);
 		textArea->SetSelectOptions(options, false);
 		// TODO: if we add a method to TextArea to return the TextContainer for a given select option
-		// then we can change the color to red for failed commands and green for successfull ones
+		// then we can change the color to red for failed commands and green for successful ones
 		// and the highlight can be just a darker shade of those
 	}
 }
 
 bool Console::Execute(const String& text)
 {
-	bool ret = false;
+	bool success = false;
 	if (text.length()) {
-		std::string mbstr = MBStringFromString(text);
-		ScriptEngine::FunctionParameters params;
-		params.push_back(ScriptEngine::Parameter(mbstr.c_str()));
-		ret = core->GetGUIScriptEngine()->RunFunction("Console", "Exec", params);
+		auto ret = core->GetGUIScriptEngine()->RunFunction("Console", "Exec", text);
+		success = !ret.IsNull();
 		HistoryAdd();
 	}
-	return ret;
+	return success;
 }
 
 /** Key Press Event */
@@ -110,7 +109,7 @@ void Console::HistorySetPos(size_t pos)
 	HistPos = Clamp<size_t>(pos, 0, History.Size());
 
 	if (HistPos == History.Size()) {
-		SetText(L"");
+		SetText(u"");
 		if (textArea) {
 			textArea->SelectAvailableOption(-1);
 		}
@@ -153,12 +152,11 @@ void Console::SaveHistory() const noexcept
 	size_t histSize = std::min(History.Size(), HistoryMaxSize);
 	for (size_t i = histSize - 1; signed(i) >= 0; i--) {
 		const String& cmd = History.Retrieve(i).second;
-		commands += fmt::format("{}\n", fmt::WideToChar{cmd});
+		commands += fmt::format("{}\n", fmt::WideToChar { cmd });
 	}
 
-	char filePath[_MAX_PATH + 20];
-	PathJoin(filePath, core->config.GamePath, "gemrb_console.txt", nullptr);
-	FileStream *histFile = new FileStream();
+	path_t filePath = PathJoin<false>(core->config.GamePath, "gemrb_console.txt");
+	FileStream* histFile = new FileStream();
 	if (histFile->Create(filePath)) {
 		histFile->Write(commands.c_str(), commands.size());
 		histFile->Close();
@@ -168,15 +166,12 @@ void Console::SaveHistory() const noexcept
 
 void Console::LoadHistory()
 {
-	char filePath[_MAX_PATH + 20];
-	PathJoin(filePath, core->config.GamePath, "gemrb_console.txt", nullptr);
-	FileStream *histFile = FileStream::OpenFile(filePath);
+	path_t filePath = PathJoin(core->config.GamePath, "gemrb_console.txt");
+	FileStream* histFile = FileStream::OpenFile(filePath);
 	if (histFile) {
 		std::string line;
 		while (histFile->ReadLine(line) != DataStream::Error) {
-			String* tmp = StringFromCString(line.c_str());
-			History.Append(std::make_pair(-1, std::move(*tmp)));
-			delete tmp;
+			History.Append(std::make_pair(-1, StringFromUtf8(line)));
 		}
 	}
 	delete histFile;
