@@ -28,6 +28,7 @@
 #define CONSOLE_H
 
 #include "CircularBuffer.h"
+
 #include "GUI/TextArea.h"
 #include "GUI/TextEdit.h"
 
@@ -44,10 +45,10 @@ namespace GemRB {
 
 constexpr size_t HistoryMaxSize = 10;
 
-class GEM_EXPORT Console : public TextEdit {
+class GEM_EXPORT Console final : public TextEdit {
 private:
 	/** History Buffer */
-	CircularBuffer<SelectOption> History{HistoryMaxSize};
+	CircularBuffer<SelectOption> History { HistoryMaxSize };
 	/** History Position and size */
 	TextArea* textArea = nullptr;
 	// an index into Hiostory, except when > History.size() which indicates a new entry
@@ -55,8 +56,8 @@ private:
 
 public:
 	Console(const Region& frame, TextArea* ta);
-	~Console() noexcept;
-	
+	~Console() noexcept override;
+
 	bool Execute(const String&);
 
 private:
