@@ -19,25 +19,28 @@
  */
 
 #include "GUI/Control.h"
-#include "GUI/GUIScriptInterface.h"
-#include "GUI/Window.h"
 
 #include "ie_cursors.h"
+
+#include "Debug.h"
 #include "Interface.h"
-#include "Logging/Logging.h"
 #include "Sprite2D.h"
 
+#include "GUI/GUIScriptInterface.h"
+#include "GUI/Window.h"
+#include "Logging/Logging.h"
+
 #include <cstdio>
 #include <cstring>
 
 namespace GemRB {
 
-unsigned int Control::ActionRepeatDelay = 250;
+tick_t Control::ActionRepeatDelay = 250;
 
 const Control::ValueRange Control::MaxValueRange = std::make_pair(0, std::numeric_limits<value_t>::max());
 
 Control::Control(const Region& frame)
-: View(frame) // dont pass superview to View constructor
+	: View(frame) // dont pass superview to View constructor
 {
 	SetValueRange(MaxValueRange);
 }
@@ -48,7 +51,7 @@ Control::~Control()
 }
 
 void Control::SetAction(ControlEventHandler handler, Control::Action type, EventButton button,
-						Event::EventMods mod, short count)
+			Event::EventMods mod, short count)
 {
 	ControlActionKey key(type, mod, button, count);
 	return SetAction(std::move(handler), key);
@@ -57,7 +60,7 @@ void Control::SetAction(ControlEventHandler handler, Control::Action type, Event
 void Control::SetAction(Responder handler, const ActionKey& key)
 {
 	if (handler) {
-		actions[key] = handler;
+		actions[key] = std::move(handler);
 	} else {
 		// delete the entry if there is one instead of setting it to NULL
 		const auto& it = actions.find(key);
@@ -67,11 +70,11 @@ void Control::SetAction(Responder handler, const ActionKey& key)
 	}
 }
 
-void Control::SetActionInterval(unsigned int interval)
+void Control::SetActionInterval(tick_t interval)
 {
 	repeatDelay = interval;
 	if (actionTimer) {
-		actionTimer->SetInverval(repeatDelay);
+		actionTimer->SetInterval(repeatDelay);
 	}
 }
 
@@ -90,7 +93,7 @@ bool Control::PerformAction(const ActionKey& key)
 	if (IsDisabled()) {
 		return false;
 	}
-	
+
 	const auto& it = actions.find(key);
 	if (it != actions.end()) {
 		if (!window) {
@@ -105,7 +108,7 @@ bool Control::PerformAction(const ActionKey& key)
 
 void Control::FlagsChanged(unsigned int /*oldflags*/)
 {
-	if (actionTimer && (flags&Disabled)) {
+	if (actionTimer && (flags & Disabled)) {
 		ClearActionTimer();
 	}
 }
@@ -132,7 +135,7 @@ Control::value_t Control::SetValue(value_t val)
 {
 	value_t oldVal = Value;
 	Value = Clamp(val, range.first, range.second);
-	
+
 	if (oldVal != Value) {
 		if (IsDictBound()) {
 			UpdateDictValue();
@@ -162,23 +165,23 @@ void Control::UpdateDictValue() noexcept
 	if (!IsDictBound()) {
 		return;
 	}
-	
+
 	// set this even when the value doesn't change
 	// if a radio is clicked, then one of its siblings, the siblings value won't change
 	// but we expect the dictionary to reflect the selected value
 	auto& vars = core->GetDictionary();
 	BitOp op = GetDictOp();
 	value_t curVal = op == BitOp::SET ? INVALID_VALUE : 0;
-	std::string key{VarName.c_str()};
+	std::string key { VarName.c_str() };
 
-	auto lookup = vars.find(key);
-	if (lookup != vars.cend()) {
-		curVal = lookup->second;
+	auto lookup = vars.Get(key);
+	if (lookup != nullptr) {
+		curVal = *lookup;
 	}
 
 	value_t newVal = curVal;
 	SetBits(newVal, Value, op);
-	vars[key] = newVal;
+	vars.Set(key, newVal);
 
 	const Window* win = GetWindow();
 	if (win) {
@@ -204,9 +207,9 @@ void Control::BindDictVariable(const varname_t& var, value_t val, ValueRange val
 		UpdateDictValue();
 	} else {
 		auto& vars = core->GetDictionary();
-		auto lookup = vars.find(VarName.c_str());
-		if (lookup != vars.cend()) {
-			UpdateState(VarName, lookup->second);
+		auto lookup = vars.Get(VarName);
+		if (lookup != nullptr) {
+			UpdateState(VarName, *lookup);
 		}
 	}
 }
@@ -224,9 +227,9 @@ void Control::ClearActionTimer()
 	}
 }
 
-Timer* Control::StartActionTimer(const ControlEventHandler& action, unsigned int delay)
+void Control::StartActionTimer(const ControlEventHandler& action, tick_t delay)
 {
-	EventHandler h = [this, action] () {
+	EventHandler h = [this, action]() {
 		// update the timer to use the actual repeatDelay
 		SetActionInterval(repeatDelay);
 
@@ -238,7 +241,7 @@ Timer* Control::StartActionTimer(const ControlEventHandler& action, unsigned int
 	};
 	// always start the timer with ActionRepeatDelay
 	// this way we have consistent behavior for the initial delay prior to switching to a faster delay
-	return &core->SetTimer(h, delay ? delay : ActionRepeatDelay);
+	actionTimer = &core->SetTimer(h, delay ? delay : ActionRepeatDelay);
 }
 
 View::UniqueDragOp Control::DragOperation()
@@ -246,18 +249,18 @@ View::UniqueDragOp Control::DragOperation()
 	if (actionTimer) {
 		return nullptr;
 	}
-	
+
 	ActionKey key(Action::DragDropCreate);
-	
+
 	if (SupportsAction(key)) {
 		// we have to use a timer so that the dragop is set before the callback is called
-		EventHandler h = [this, key] () {
+		EventHandler h = [this, key]() {
 			return actions[key](this);
 		};
 
 		actionTimer = &core->SetTimer(h, 0, 0);
 	}
-	return GemRB::make_unique<ControlDragOp>(this);
+	return std::make_unique<ControlDragOp>(this);
 }
 
 bool Control::AcceptsDragOperation(const DragOp& dop) const
@@ -268,13 +271,13 @@ bool Control::AcceptsDragOperation(const DragOp& dop) const
 		// if 2 controls share the same VarName we assume they are swappable...
 		return (VarName == cdop->Source()->VarName);
 	}
-	
+
 	return View::AcceptsDragOperation(dop);
 }
 
 Holder<Sprite2D> Control::DragCursor() const
 {
-	if (core->InDebugMode(ID_VIEWS)) {
+	if (InDebugMode(DebugMode::VIEWS)) {
 		return core->Cursors[IE_CURSOR_SWAP];
 	}
 	return nullptr;
@@ -300,7 +303,7 @@ bool Control::OnMouseDown(const MouseEvent& me, unsigned short mod)
 {
 	ControlActionKey key(Click, mod, me.button, me.repeats);
 	if (repeatDelay && SupportsAction(key)) {
-		actionTimer = StartActionTimer(actions[key]);
+		StartActionTimer(actions[key]);
 	}
 	return true; // always handled
 }
@@ -317,8 +320,8 @@ void Control::OnMouseLeave(const MouseEvent& /*me*/, const DragOp*)
 
 bool Control::OnTouchDown(const TouchEvent& /*te*/, unsigned short /*mod*/)
 {
-	ControlEventHandler cb = METHOD_CALLBACK(&Control::HandleTouchActionTimer, this);
-	actionTimer = StartActionTimer(cb, 500); // TODO: this time value should be configurable
+	ControlEventHandler cb = &Control::HandleTouchActionTimer;
+	StartActionTimer(cb, 500); // TODO: this time value should be configurable
 	return true; // always handled
 }
 
@@ -340,13 +343,12 @@ bool Control::OnKeyPress(const KeyboardEvent& key, unsigned short mod)
 	if (key.keycode == GEM_RETURN) {
 		return PerformAction();
 	}
-	
+
 	return View::OnKeyPress(key, mod);
 }
 
-void Control::HandleTouchActionTimer(const Control* ctrl)
+void Control::HandleTouchActionTimer()
 {
-	assert(ctrl == this);
 	assert(actionTimer);
 
 	ClearActionTimer();
