@@ -19,12 +19,12 @@
  */
 
 #include "GUI/EventMgr.h"
-#include "Interface.h"
-#include "Logging/Logging.h"
-#include "Video/Video.h"
 
 #include "globals.h"
 
+#include "Logging/Logging.h"
+#include "Video/Video.h"
+
 namespace GemRB {
 
 tick_t EventMgr::DCDelay = 250;
@@ -92,7 +92,7 @@ MouseEvent MouseEventFromController(const ControllerEvent& ce, bool down)
 
 KeyboardEvent KeyEventFromController(const ControllerEvent& ce)
 {
-	KeyboardEvent ke{};
+	KeyboardEvent ke {};
 
 	// TODO: probably want more than the DPad
 	switch (ce.button) {
@@ -143,19 +143,17 @@ bool EventMgr::ControllerButtonState(EventButton btn)
 
 void EventMgr::DispatchEvent(Event&& e) const
 {
-	if (TouchInputEnabled == false && e.EventMaskFromType(e.type) & Event::AllTouchMask) {
+	if (TouchInputEnabled == false && Event::EventMaskFromType(e.type) & Event::AllTouchMask) {
 		return;
 	}
 
-	Video* video = core->GetVideoDriver();
-
 	e.time = GetMilliseconds();
 
 	if (e.type == Event::TextInput) {
 		if (e.text.text.length() == 0) {
 			return;
 		}
-	} else if (e.EventMaskFromType(e.type) & Event::AllKeyMask) {
+	} else if (Event::EventMaskFromType(e.type) & Event::AllKeyMask) {
 		// first check for hot key listeners
 		static tick_t lastKeyDown = 0;
 		static unsigned char repeatCount = 0;
@@ -177,28 +175,23 @@ void EventMgr::DispatchEvent(Event&& e) const
 		flags |= e.keyboard.keycode;
 		modKeys = e.mod;
 
-		KeyMap::const_iterator hit = HotKeys.find(flags);
-		if (hit != HotKeys.end()) {
-			assert(!hit->second.empty());
-			KeyMap::value_type::second_type list = hit->second;
-			EventCallback cb = hit->second.front();
-			if (cb(e)) {
+		const auto& range = HotKeys.equal_range(flags);
+		for (auto it = range.first; it != range.second; ++it) {
+			if (it->second(e)) {
 				return;
 			}
 		}
-	} else if (e.EventMaskFromType(e.type) & Event::ControllerAxisMask) {
+	} else if (Event::EventMaskFromType(e.type) & Event::ControllerAxisMask) {
 		// only the left stick moves the cursor
 		if (e.controller.axis == AXIS_LEFT_X) {
 			mousePos.x += e.controller.axisDelta;
 		} else if (e.controller.axis == AXIS_LEFT_Y) {
 			mousePos.y += e.controller.axisDelta;
 		}
-	} else if (e.EventMaskFromType(e.type) & (Event::ControllerButtonUpMask | Event::ControllerButtonDownMask)) {
+	} else if (Event::EventMaskFromType(e.type) & (Event::ControllerButtonUpMask | Event::ControllerButtonDownMask)) {
 		controllerButtonStates = e.controller.buttonStates;
 	} else if (e.isScreen) {
-		if (e.EventMaskFromType(e.type) & (Event::MouseUpMask | Event::MouseDownMask
-									    | Event::TouchUpMask | Event::TouchDownMask)
-		) {
+		if (Event::EventMaskFromType(e.type) & (Event::MouseUpMask | Event::MouseDownMask | Event::TouchUpMask | Event::TouchDownMask)) {
 			// WARNING: these are shared between mouse and touch
 			// it is assumed we won't be using both simultaneously
 			static tick_t lastMouseDown = 0;
@@ -210,14 +203,11 @@ void EventMgr::DispatchEvent(Event&& e) const
 			EventButton btn = (e.type == Event::MouseDown) ? e.mouse.button : 0;
 
 			if (e.type == Event::MouseDown || e.type == Event::TouchDown) {
-				core->GetVideoDriver()->CaptureMouse(true);
-				if (video->InTextInput())
-					video->StopTextInput();
+				VideoDriver->CaptureMouse(true);
+				if (VideoDriver->InTextInput())
+					VideoDriver->StopTextInput();
 
-				if (btn == repeatButton
-					&& e.time <= lastMouseDown + DCDelay
-					&& repeatPos.isWithinRadius(mouseClickRadius, se.Pos())
-				) {
+				if (btn == repeatButton && e.time <= lastMouseDown + DCDelay && repeatPos.IsWithinRadius(mouseClickRadius, se.Pos())) {
 					repeatCount++;
 				} else {
 					repeatCount = 1;
@@ -226,13 +216,13 @@ void EventMgr::DispatchEvent(Event&& e) const
 				repeatButton = btn;
 				lastMouseDown = GetMilliseconds();
 			} else if (e.type == Event::MouseUp && e.mouse.buttonStates == 0) {
-				core->GetVideoDriver()->CaptureMouse(false);
+				VideoDriver->CaptureMouse(false);
 			}
 
 			se.repeats = repeatCount;
 		}
 
-		if (e.EventMaskFromType(e.type) & Event::AllMouseMask) {
+		if (Event::EventMaskFromType(e.type) & Event::AllMouseMask) {
 			// set/clear the appropriate buttons
 			mouseButtonFlags = e.mouse.buttonStates;
 			mousePos = e.mouse.Pos();
@@ -266,8 +256,8 @@ void EventMgr::DispatchEvent(Event&& e) const
 			}
 		}
 	} else {
-		if (video->InTextInput())
-			video->StopTextInput();
+		if (VideoDriver->InTextInput())
+			VideoDriver->StopTextInput();
 	}
 
 	// no hot keys or their listeners refused the event...
@@ -275,7 +265,7 @@ void EventMgr::DispatchEvent(Event&& e) const
 	EventTaps::iterator it = tapsCopy.begin();
 	for (; it != tapsCopy.end(); ++it) {
 		const std::pair<Event::EventTypeMask, EventCallback>& pair = it->second;
-		if (pair.first & e.EventMaskFromType(e.type)) {
+		if (pair.first & Event::EventMaskFromType(e.type)) {
 			// all matching taps get a copy of the event
 			pair.second(e);
 		}
@@ -291,13 +281,7 @@ bool EventMgr::RegisterHotKeyCallback(const EventCallback& cb, KeyboardKey key,
 	int flags = mod << 16;
 	flags |= key;
 
-	KeyMap::iterator it = HotKeys.find(flags);
-	if (it != HotKeys.end()) {
-		it->second.push_front(cb);
-	} else {
-		HotKeys.emplace(flags, std::list<EventCallback>(1, cb));
-	}
-
+	HotKeys.emplace(flags, cb);
 	return true;
 }
 
@@ -306,17 +290,12 @@ void EventMgr::UnRegisterHotKeyCallback(const EventCallback& cb, KeyboardKey key
 	int flags = mod << 16;
 	flags |= key;
 
-	KeyMap::iterator it = HotKeys.find(flags);
-	if (it != HotKeys.end()) {
-		KeyMap::value_type::second_type::iterator cbit;
-		cbit = std::find_if(it->second.begin(), it->second.end(), [&cb](decltype(cb)& item) {
-			return FunctionTargetsEqual(cb, item);
-		});
-		if (cbit != it->second.end()) {
-			it->second.erase(cbit);
-			if (it->second.empty()) {
-				HotKeys.erase(it);
-			}
+	const auto& range = HotKeys.equal_range(flags);
+	for (auto item = range.first; item != range.second;) {
+		if (FunctionTargetsEqual(cb, item->second)) {
+			item = HotKeys.erase(item);
+		} else {
+			++item;
 		}
 	}
 }
@@ -417,10 +396,10 @@ Event EventMgr::CreateTouchEvent(const TouchEvent::Finger fingers[], int numFing
 		for (int i = 0; i < numFingers; ++i) {
 			e.touch.x += fingers[i].x;
 			e.touch.y += fingers[i].y;
-			if (abs(fingers[i].deltaX) > abs(e.touch.deltaX)) {
+			if (std::abs(fingers[i].deltaX) > std::abs(e.touch.deltaX)) {
 				e.touch.deltaX = fingers[i].deltaX;
 			}
-			if (abs(fingers[i].deltaY) > abs(e.touch.deltaY)) {
+			if (std::abs(fingers[i].deltaY) > std::abs(e.touch.deltaY)) {
 				e.touch.deltaY = fingers[i].deltaY;
 			}
 			e.touch.fingers[i] = fingers[i];
@@ -451,13 +430,7 @@ Event EventMgr::CreateTouchGesture(const TouchEvent& touch, float rotation, floa
 
 Event EventMgr::CreateTextEvent(const char* text)
 {
-	Event e = {};
-	String* string = StringFromUtf8(text);
-	if (string) {
-		e = EventMgr::CreateTextEvent(*string);
-		delete string;
-	}
-	return e;
+	return EventMgr::CreateTextEvent(StringFromUtf8(text));
 }
 
 Event EventMgr::CreateTextEvent(const String& text)
@@ -497,7 +470,8 @@ Event EventMgr::CreateControllerButtonEvent(EventButton btn, bool down)
 	return e;
 }
 
-Event EventMgr::CreateRedrawRequestEvent() {
+Event EventMgr::CreateRedrawRequestEvent()
+{
 	Event e = {};
 	e.type = Event::RedrawRequest;
 
