@@ -20,58 +20,65 @@
 #ifndef Animations_h
 #define Animations_h
 
+#include "globals.h"
+
+#include "Animation.h"
 #include "Holder.h"
 #include "Region.h"
 #include "Sprite2D.h"
 
-#include "globals.h"
-
 namespace GemRB {
 
-template <class T>
-class GEM_EXPORT GUIAnimation {
+template<class T>
+class GUIAnimation {
 protected:
-	tick_t begintime;
+	tick_t begintime = 0;
 	T current;
-	
+
 public:
-	GUIAnimation() {
-		begintime = GetMilliseconds();
-	}
-	
+	explicit GUIAnimation(tick_t begin) noexcept
+		: begintime(begin) {}
+
+	GUIAnimation() noexcept
+		: GUIAnimation(GetMilliseconds()) {}
+
 	virtual ~GUIAnimation() noexcept = default;
-	
-	explicit operator bool() const {
+
+	explicit operator bool() const
+	{
 		return !HasEnded();
 	}
 
-	T Next(tick_t time) {
+	T Next(tick_t time)
+	{
 		if (HasEnded() == false) {
 			current = GenerateNext(time);
 		}
 		return current;
 	}
 
-	T Current() {
+	T Current()
+	{
 		return current;
 	}
 
 private:
-	virtual T GenerateNext(tick_t time)=0;
-	virtual bool HasEnded() const=0;
+	virtual T GenerateNext(tick_t time) = 0;
+	virtual bool HasEnded() const = 0;
 };
 
 class GEM_EXPORT PointAnimation : public GUIAnimation<Point> {
 public:
 	Point begin;
 	Point end;
-	tick_t endtime;
-	
+	tick_t endtime = 0;
+
 public:
-	PointAnimation() : GUIAnimation(), endtime(0) {}
-	
+	PointAnimation() = default;
+
 	PointAnimation(const Point& begin, const Point& end, tick_t duration)
-	: GUIAnimation(), begin(begin), end(end), endtime(begintime + duration) {
+		: GUIAnimation(), begin(begin), end(end), endtime(begintime + duration)
+	{
 		Next(begintime);
 	}
 
@@ -82,37 +89,40 @@ private:
 
 class GEM_EXPORT ColorCycle {
 	uint8_t step = 0;
-	uint8_t speed;
+	uint8_t speed = 0;
 
 public:
-	explicit ColorCycle(uint8_t speed) : speed(speed) {}
+	explicit ColorCycle(uint8_t speed)
+		: speed(speed) {}
 
 	void AdvanceTime(tick_t time);
 	Color Blend(const Color& c1, const Color& c2) const;
 
-	uint8_t Step() const {
+	uint8_t Step() const
+	{
 		return step;
 	}
 };
 
-// this is used to syncronize the various "selected" Actor color animations
+// this is used to synchronize the various "selected" Actor color animations
 extern ColorCycle GlobalColorCycle;
 
 // This is supposed to be a fast optionally infinitely repeating transition
-// between 2 colors. We will create a global instance to syncronize many elements with the same animation.
-class GEM_EXPORT ColorAnimation : public GUIAnimation<Color> {
+// between 2 colors. We will create a global instance to synchronize many elements with the same animation.
+class ColorAnimation : public GUIAnimation<Color> {
 public:
 	Color begin;
 	Color end;
 	bool repeat = false;
-	ColorCycle cycle{0};
+	ColorCycle cycle { 0 };
 	int timeOffset = 0;
 
 public:
-	ColorAnimation() : GUIAnimation() {}
+	ColorAnimation() = default;
 
 	ColorAnimation(const Color& begin, const Color& end, bool repeat)
-	: GUIAnimation(), begin(begin), end(end), repeat(repeat), cycle(7) {
+		: GUIAnimation(), begin(begin), end(end), repeat(repeat), cycle(7)
+	{
 		// we don't handle alpha, if we need it revisit this.
 		this->begin.a = 0xff;
 		this->end.a = 0xff;
@@ -126,39 +136,21 @@ private:
 	bool HasEnded() const override;
 };
 
-class AnimationFactory;
-
 class GEM_EXPORT SpriteAnimation : public GUIAnimation<Holder<Sprite2D>> {
 private:
-	std::shared_ptr<const AnimationFactory> bam;
-	uint8_t cycle = 0;
-	uint8_t frame = 0;
-	unsigned int anim_phase = 0;
-	bool has_palette = false;
-	ieDword colors[8] {};
-	tick_t nextFrameTime = 0;
+	std::shared_ptr<Animation> anim;
 
-	tick_t CalculateNextFrameDelta();
 	Holder<Sprite2D> GenerateNext(tick_t time) override;
+
 public:
-	explicit SpriteAnimation(std::shared_ptr<const AnimationFactory> af, int Cycle = 0);
-	//report if the current resource is the same as descripted by the params
-	void SetPaletteGradients(const ieDword *col);
-	bool SameResource(const SpriteAnimation*) const;
+	explicit SpriteAnimation(std::shared_ptr<Animation> anim);
+
 	bool HasEnded() const override;
 
-	tick_t Time() const { return nextFrameTime; }
-	
-	enum RepeatFlags : uint8_t {
-		PLAY_NORMAL		= 0,  // play in a loop
-		PLAY_RANDOM		= 1,
-		PLAY_ONCE		= 2,  // play and stop at end
-		PLAY_ALWAYS		= 4   // play even when game is paused
-	} flags = PLAY_NORMAL;
-	
-	BlitFlags blitFlags = BlitFlags::BLENDED;
+	Animation::Flags& flags;
+	bool& gameAnimation;
 };
 
 }
-	
+
 #endif /* Animations_h */
