@@ -23,18 +23,21 @@
 
 #include "Game.h"
 #include "GlobalTimer.h"
+#include "Interface.h"
 #include "Map.h"
 #include "Sprite2D.h"
+
 #include "GUI/GameControl.h"
+#include "GUI/TextEdit.h"
 #include "Scriptable/Actor.h"
 
 namespace GemRB {
 
 MapControl::MapControl(const Region& frame, std::shared_ptr<const AnimationFactory> af)
-: Control(frame), mapFlags(std::move(af))
+	: Control(frame), mapFlags(std::move(af))
 {
 	ControlType = IE_GUI_MAP;
-	SetValueRange({NO_NOTES, EDIT_NOTE});
+	SetValueRange({ NO_NOTES, EDIT_NOTE });
 	UpdateMap();
 }
 
@@ -56,12 +59,11 @@ void MapControl::UpdateMap()
 // Draw fog on the small bitmap
 void MapControl::DrawFog(const Region& rgn) const
 {
-	Video *video = core->GetVideoDriver();
 	const Size mapsize = MyMap->GetSize();
 	Point p;
 	Point gameP = p;
 
-	std::vector<Point> points;
+	std::vector<BasePoint> points;
 	points.reserve(rgn.w * rgn.h);
 
 	for (; p.y < rgn.h; ++p.y) {
@@ -69,7 +71,7 @@ void MapControl::DrawFog(const Region& rgn) const
 
 		for (p.x = 0; p.x < rgn.w; ++p.x) {
 			gameP.x = int(p.x * double(mapsize.w) / mosRgn.w);
-			
+
 			bool visible = MyMap->IsExplored(gameP);
 			if (!visible) {
 				points.push_back(p + rgn.origin);
@@ -77,30 +79,30 @@ void MapControl::DrawFog(const Region& rgn) const
 		}
 	}
 
-	video->DrawPoints(points, ColorBlack);
+	VideoDriver->DrawPoints(points, ColorBlack);
 }
-	
+
 Point MapControl::ConvertPointToGame(Point p) const
 {
 	const Size mapsize = MyMap->GetSize();
-	
+
 	// mos is centered... first convert p to mos coordinates
 	// mos is in win coordinates (to make things easy elsewhere)
 	p = ConvertPointToSuper(p) - mosRgn.origin;
-	
+
 	p.x = int(p.x * double(mapsize.w) / mosRgn.w);
 	p.y = int(p.y * double(mapsize.h) / mosRgn.h);
-	
+
 	return p;
 }
-	
+
 Point MapControl::ConvertPointFromGame(Point p) const
 {
 	const Size mapsize = MyMap->GetSize();
-	
+
 	p.x = int(p.x * double(mosRgn.w) / mapsize.w);
 	p.y = int(p.y * double(mosRgn.h) / mapsize.h);
-	
+
 	// mos is centered... convert p from mos coordinates
 	return p + mosRgn.origin;
 }
@@ -109,14 +111,13 @@ void MapControl::UpdateState(value_t val)
 {
 	SetValue(val);
 }
-	
+
 void MapControl::WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 {
 	UpdateMap();
 
 	if (LinkedLabel) {
-		if (GetValue() == EDIT_NOTE)
-		{
+		if (GetValue() == EDIT_NOTE) {
 			LinkedLabel->SetFlags(IgnoreEvents, BitOp::NAND);
 			LinkedLabel->SetFocus();
 		} else {
@@ -126,7 +127,7 @@ void MapControl::WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 
 	if (MapMOS) {
 		const Size& mosSize = MapMOS->Frame.size;
-		const Point center(frame.w/2 - mosSize.w/2, frame.h/2 - mosSize.h/2);
+		const Point center(frame.w / 2 - mosSize.w / 2, frame.h / 2 - mosSize.h / 2);
 		mosRgn = Region(Origin() + center, mosSize);
 	} else {
 		mosRgn = Region(Point(), Dimensions());
@@ -152,59 +153,59 @@ Region MapControl::GetViewport() const
 /** Draws the Control on the Output Display */
 void MapControl::DrawSelf(const Region& rgn, const Region& /*clip*/)
 {
-	Video* video = core->GetVideoDriver();
-	video->DrawRect(rgn, ColorBlack, true);
-		
+	VideoDriver->DrawRect(rgn, ColorBlack, true);
+
 	if (MyMap == nullptr) {
 		return;
 	}
 
 	if (MapMOS) {
-		video->BlitSprite(MapMOS, mosRgn.origin);
+		VideoDriver->BlitSprite(MapMOS, mosRgn.origin);
 	}
 
-	if ((core->GetGameControl()->DebugFlags & DEBUG_SHOW_FOG_UNEXPLORED) == 0)
+	if ((GameControl::DebugFlags & DEBUG_SHOW_FOG_UNEXPLORED) == 0)
 		DrawFog(mosRgn);
 
 	Region vp = GetViewport();
-	video->DrawRect(vp, ColorGreen, false );
-	
+	VideoDriver->DrawRect(vp, ColorGreen, false);
+
 	// Draw PCs' ellipses
-	const Game *game = core->GetGame();
+	const Game* game = core->GetGame();
 	int i = game->GetPartySize(true);
 	while (i--) {
-		const Actor *actor = game->GetPC(i, true);
-		if (MyMap->HasActor(actor) ) {
+		const Actor* actor = game->GetPC(i, true);
+		if (MyMap->HasActor(actor)) {
 			const Point pos = ConvertPointFromGame(actor->Pos);
 			const Size s(6, 4);
 			const Region r(pos - s.Center(), s);
-			video->DrawEllipse(r, actor->Selected ? ColorGreen : ColorGreenDark );
+			VideoDriver->DrawEllipse(r, actor->Selected ? ColorGreen : ColorGreenDark);
 		}
 	}
 	// Draw Map notes, could be turned off in bg2
 	// we use the common control value to handle it, because then we
 	// don't need another interface
 	if (GetValue() != NO_NOTES) {
-		i = MyMap -> GetMapNoteCount();
+		i = MyMap->GetMapNoteCount();
 		while (i--) {
-			const MapNote& mn = MyMap -> GetMapNote(i);
-			
+			const MapNote& mn = MyMap->GetMapNote(i);
+
 			// Skip unexplored map notes unless they are player added
-			// FIXME: PST should include user notes regardless (!mn.readonly)
+			// PST draws user notes regardless of visibility
 			bool visible = MyMap->IsExplored(mn.Pos);
-			if (!visible)
+			if (!visible && (!core->HasFeature(GFFlags::PST_STATE_FLAGS) || mn.readonly)) {
 				continue;
+			}
 
 			Point pos = ConvertPointFromGame(mn.Pos);
 
 			Holder<Sprite2D> anim = mapFlags ? mapFlags->GetFrame(0, mn.color) : nullptr;
 			if (anim) {
 				Point p(anim->Frame.w / 2, anim->Frame.h / 2);
-				video->BlitSprite(anim, pos - p);
+				VideoDriver->BlitSprite(anim, pos - p);
 			} else {
 				const Size s(12, 10);
 				const Region r(pos - s.Center(), s);
-				video->DrawEllipse(r, mn.GetColor());
+				VideoDriver->DrawEllipse(r, mn.GetColor());
 			}
 		}
 	}
@@ -213,19 +214,23 @@ void MapControl::DrawSelf(const Region& rgn, const Region& /*clip*/)
 void MapControl::ClickHandle(const MouseEvent&) const
 {
 	auto& vars = core->GetDictionary();
-	vars["MapControlX"] = notePos.x;
-	vars["MapControlY"] = notePos.y;
+	vars.Set("MapControlX", notePos.x);
+	vars.Set("MapControlY", notePos.y);
+
+	if (LinkedLabel && LinkedLabel->ControlType == IE_GUI_EDIT && GetValue() == EDIT_NOTE) {
+		static_cast<TextEdit*>(LinkedLabel)->SetBackground(TextEditBG::Editing);
+	}
 }
 
 void MapControl::UpdateViewport(Point vp)
 {
 	Region vp2 = GetViewport();
-	vp.x -= vp2.w/2;
-	vp.y -= vp2.h/2;
+	vp.x -= vp2.w / 2;
+	vp.y -= vp2.h / 2;
 	vp = ConvertPointToGame(vp);
-	
+
 	// clear any previously scheduled moves and then do it asap, so it works while paused
-	core->timer.SetMoveViewPort( vp, 0, false );
+	core->timer.SetMoveViewPort(vp, 0, false);
 
 	MarkDirty();
 }
@@ -279,13 +284,18 @@ bool MapControl::OnMouseDown(const MouseEvent& me, unsigned short /*Mod*/)
 	UpdateCursor();
 	return true;
 }
-	
+
 /** Mouse Over Event */
 bool MapControl::OnMouseOver(const MouseEvent& me)
 {
 	if (MyMap == NULL)
 		return false;
 
+	TextEdit* edit = nullptr;
+	if (LinkedLabel && LinkedLabel->ControlType == IE_GUI_EDIT) {
+		edit = static_cast<TextEdit*>(LinkedLabel);
+	}
+
 	value_t val = GetValue();
 	if (val == VIEW_NOTES) {
 		Point p = ConvertPointFromScreen(me.Pos());
@@ -293,19 +303,25 @@ bool MapControl::OnMouseOver(const MouseEvent& me)
 		const MapNote* mn = MapNoteAtPoint(p);
 		if (mn) {
 			notePos = mn->Pos;
-			
+
 			if (LinkedLabel) {
 				LinkedLabel->SetText(mn->text);
 			}
+			if (edit) {
+				edit->SetBackground(TextEditBG::Over);
+			}
 		} else if (LinkedLabel) {
-			LinkedLabel->SetText(L"");
+			LinkedLabel->SetText(u"");
+			if (edit) {
+				edit->SetBackground(TextEditBG::Normal);
+			}
 		}
 	}
 
 	UpdateCursor();
 	return true;
 }
-	
+
 bool MapControl::OnMouseDrag(const MouseEvent& me)
 {
 	if (GetValue() == VIEW_NOTES) {
@@ -321,7 +337,7 @@ bool MapControl::OnMouseUp(const MouseEvent& me, unsigned short mod)
 {
 	Point p = ConvertPointFromScreen(me.Pos());
 
-	switch(GetValue()) {
+	switch (GetValue()) {
 		case EDIT_NOTE:
 			SetValue(VIEW_NOTES);
 			break;
