@@ -20,8 +20,6 @@
 
 #include "GUI/Progressbar.h"
 
-#include "Interface.h"
-
 #include "GUI/Window.h"
 
 #include <cstring>
@@ -31,7 +29,7 @@
 namespace GemRB {
 
 Progressbar::Progressbar(const Region& frame, unsigned short KnobStepsCount)
-: Control(frame), KnobStepsCount(KnobStepsCount)
+	: Control(frame), KnobStepsCount(KnobStepsCount)
 {
 	ControlType = IE_GUI_PROGRESSBAR;
 
@@ -57,33 +55,33 @@ void Progressbar::DrawSelf(const Region& rgn, const Region& /*clip*/)
 {
 	ieDword val = GetValue();
 
-	if((val >= 100) && KnobStepsCount && BackGround2) {
+	if ((val >= 100) && KnobStepsCount && BackGround2) {
 		//animated progbar end stage
-		core->GetVideoDriver()->BlitSprite(BackGround2, rgn.origin);
+		VideoDriver->BlitSprite(BackGround2, rgn.origin);
 		return; //done for animated progbar
 	}
 
 	unsigned int Count;
 
-	if(!KnobStepsCount) {
+	if (!KnobStepsCount) {
 		//linear progressbar (pst, iwd)
 		const Size& size = BackGround2->Frame.size;
 		//this is the PST/IWD specific part
 		Count = val * size.w / 100;
 		Region r(rgn.origin + KnobPos, Size(Count, size.h));
-		core->GetVideoDriver()->BlitSprite(BackGround2, r.origin, &r);
+		VideoDriver->BlitSprite(BackGround2, r.origin, &r);
 
 		Point p = rgn.origin + CapPos;
 		p.x += Count - PBarCap->Frame.w;
-		core->GetVideoDriver()->BlitSprite(PBarCap, p);
+		VideoDriver->BlitSprite(PBarCap, p);
 		return;
 	}
 
 	//animated progressbar (bg2)
-	Count=val*KnobStepsCount/100;
+	Count = val * KnobStepsCount / 100;
 	for (unsigned int i = 0; i < Count && PBarAnim; i++) {
 		Holder<Sprite2D> Knob = PBarAnim->GetFrame(i);
-		core->GetVideoDriver()->BlitSprite(Knob, Point());
+		VideoDriver->BlitSprite(Knob, Point());
 	}
 }
 
@@ -104,7 +102,7 @@ void Progressbar::SetImages(Holder<Sprite2D> bg, Holder<Sprite2D> cap)
 	MarkDirty();
 }
 
-void Progressbar::SetAnimation(Animation *arg)
+void Progressbar::SetAnimation(Animation* arg)
 {
 	delete PBarAnim;
 	PBarAnim = arg;
