@@ -19,11 +19,11 @@
 
 #include "ScrollView.h"
 
-#include "GUI/ScrollBar.h"
-
 #include "GUIScriptInterface.h"
-#include "Interface.h"
+
+#include "GUI/ScrollBar.h"
 #include "Logging/Logging.h"
+#include "Video/Video.h"
 
 namespace GemRB {
 
@@ -40,17 +40,17 @@ void ScrollView::ContentView::SizeChanged(const Size& oldsize)
 	ResizeToSubviews();
 	sv->ScrollDelta(Point(dx, dy));
 }
-	
+
 void ScrollView::ContentView::SubviewAdded(View* /*view*/, View* /*parent*/)
 {
 	ResizeToSubviews();
 }
-	
+
 void ScrollView::ContentView::SubviewRemoved(View* /*view*/, View* /*parent*/)
 {
 	ResizeToSubviews();
 }
-	
+
 void ScrollView::ContentView::ResizeToSubviews()
 {
 	assert(superView);
@@ -81,35 +81,34 @@ void ScrollView::ContentView::ResizeToSubviews()
 		sv->UpdateScrollbars();
 	}
 }
-	
+
 void ScrollView::ContentView::WillDraw(const Region& /*drawFrame*/, const Region& clip)
 {
 	const ScrollView* parent = static_cast<const ScrollView*>(superView);
-	
+
 	Region clipArea = parent->ContentRegion();
 	Point origin = parent->ConvertPointToWindow(clipArea.origin);
 	clipArea.x = origin.x;
 	clipArea.y = origin.y;
-	
+
 	const Region intersect = clip.Intersect(clipArea);
 	if (intersect.size.IsInvalid()) return; // outside the window/screen
-	
+
 	// clip drawing to the ContentRegion, then restore after drawing
-	Video* video = core->GetVideoDriver();
-	video->SetScreenClip(&intersect);
+	VideoDriver->SetScreenClip(&intersect);
 }
 
 void ScrollView::ContentView::DidDraw(const Region& /*drawFrame*/, const Region& clip)
 {
-	core->GetVideoDriver()->SetScreenClip(&clip);
+	VideoDriver->SetScreenClip(&clip);
 }
 
 ScrollView::ScrollView(const Region& frame)
-: View(frame), contentView(Region())
+	: View(frame), contentView(Region())
 {
 	View::AddSubviewInFrontOfView(&contentView);
 	contentView.SetFrame(Region(Point(), frame.size));
-	contentView.SetFlags(RESIZE_WIDTH|RESIZE_HEIGHT, BitOp::OR);
+	contentView.SetFlags(RESIZE_WIDTH | RESIZE_HEIGHT, BitOp::OR);
 	contentView.SetAutoResizeFlags(ResizeAll, BitOp::SET);
 
 	SetVScroll(nullptr);
@@ -119,7 +118,7 @@ ScrollView::ScrollView(const Region& frame)
 ScrollView::~ScrollView()
 {
 	View::RemoveSubview(&contentView); // no delete
-	
+
 	delete hscroll;
 	delete vscroll;
 }
@@ -134,30 +133,30 @@ void ScrollView::SetVScroll(ScrollBar* sbar)
 			Log(ERROR, "ScrollView", "Unable to add scrollbars: missing default scrollbar template.");
 		} else {
 			sbar = new ScrollBar(*sbar);
-			
+
 			Region sbFrame = sbar->Frame();
 			sbFrame.x = frame.w - sbFrame.w;
 			sbFrame.y = 0;
 			sbFrame.h = frame.h;
-			
+
 			sbar->SetFrame(sbFrame);
-			sbar->SetAutoResizeFlags(ResizeRight|ResizeTop|ResizeBottom, BitOp::SET);
+			sbar->SetAutoResizeFlags(ResizeRight | ResizeTop | ResizeBottom, BitOp::SET);
+			savedSBSize.w = sbFrame.w;
 		}
 	}
-	
+
 	// this update must be done before binding an action
 	vscroll = sbar;
 	UpdateScrollbars();
-	
+
 	if (sbar) {
 		// ensure scrollbars are on top
 		View::AddSubviewInFrontOfView(sbar, &contentView);
 
-		ControlEventHandler handler = [this](Control* sb) {
+		sbar->SetAction([this](Control* sb) {
 			ScrollbarValueChange(static_cast<ScrollBar*>(sb));
-		};
-		
-		sbar->SetAction(std::move(handler), Control::ValueChange);
+		},
+				Control::ValueChange);
 	}
 }
 
@@ -167,6 +166,30 @@ void ScrollView::SetHScroll(ScrollBar*)
 	// this is currently a limitation in the Scrollbar class
 }
 
+void ScrollView::ToggleScrollbar(ScrollBar* sb, bool visible)
+{
+	assert(sb);
+	if (sb->IsVisible() == visible) return;
+
+	sb->SetVisible(visible);
+	Size dims = sb->Dimensions();
+	// We have to change the frame size because we dont support overlapping views
+	if (visible) {
+		if (sb == vscroll) {
+			dims.w = savedSBSize.w;
+		} else { // hscroll visible
+			dims.h = savedSBSize.h;
+		}
+	} else if (sb == vscroll) {
+		savedSBSize.w = dims.w;
+		dims.w = 0;
+	} else { // hscroll hidden
+		savedSBSize.h = dims.h;
+		dims.h = 0;
+	}
+	sb->SetFrameSize(dims);
+}
+
 void ScrollView::UpdateScrollbars()
 {
 	// FIXME: this is assuming an origin of 0,0
@@ -180,23 +203,23 @@ void ScrollView::UpdateScrollbars()
 		hscroll->SetValue(-contentFrame.origin.x);
 	}
 	if (vscroll) {
+		bool show = false;
 		if (contentFrame.h > mySize.h) {
-			vscroll->SetVisible((Flags()&View::IgnoreEvents) ? false : true);
+			show = !(Flags() & View::IgnoreEvents);
 
 			int maxVal = contentFrame.h - mySize.h;
 			Control::ValueRange range(0, maxVal);
 			vscroll->SetValueRange(range);
-		} else {
-			vscroll->SetVisible(false);
 		}
+		ToggleScrollbar(vscroll, show);
 		vscroll->SetValue(-contentFrame.origin.y);
 	}
 }
-	
+
 void ScrollView::ScrollbarValueChange(const ScrollBar* sb)
 {
 	const Point& origin = contentView.Origin();
-	
+
 	if (sb == hscroll) {
 		Point p(-int(sb->GetValue()), origin.y);
 		ScrollTo(p);
@@ -207,7 +230,7 @@ void ScrollView::ScrollbarValueChange(const ScrollBar* sb)
 		Log(ERROR, "ScrollView", "ScrollbarValueChange for unknown scrollbar");
 	}
 }
-	
+
 void ScrollView::WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 {
 	if (animation) {
@@ -215,7 +238,7 @@ void ScrollView::WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 		contentView.SetFrameOrigin(animation.Next(GetMilliseconds()));
 	}
 }
-	
+
 void ScrollView::DidDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 {
 	if (animation) {
@@ -223,16 +246,16 @@ void ScrollView::DidDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 		contentView.SetFrameOrigin(animation.end);
 	}
 }
-	
+
 Region ScrollView::ContentRegion() const
 {
-	Region cr = Region(Point(0,0), Dimensions());
+	Region cr = Region(Point(0, 0), Dimensions());
 	if (hscroll && hscroll->IsVisible()) {
 		cr.h -= hscroll->Frame().h;
 	}
 	if (vscroll && vscroll->IsVisible()) {
 		const Region& sframe = vscroll->Frame();
-		
+
 		if (sframe.x == 0) {
 			// scrollbar is the leftmost view
 			cr.x += sframe.w;
@@ -248,16 +271,16 @@ Region ScrollView::ContentRegion() const
 	}
 	return cr;
 }
-	
+
 void ScrollView::FlagsChanged(unsigned int /*oldflags*/)
 {
-	if (Flags()&IgnoreEvents) {
+	if (Flags() & IgnoreEvents) {
 		if (hscroll) {
-			hscroll->SetVisible(false);
+			ToggleScrollbar(hscroll, false);
 		}
-		
+
 		if (vscroll) {
-			vscroll->SetVisible(false);
+			ToggleScrollbar(vscroll, false);
 		}
 	}
 }
@@ -335,7 +358,7 @@ void ScrollView::ScrollTo(Point newP, ieDword duration)
 	UpdateScrollbars();
 
 	// set up animation if required
-	if  (duration) {
+	if (duration) {
 		animation = PointAnimation(current, newP, duration);
 	} else {
 		// cancel the existing animation (if any)
@@ -382,7 +405,7 @@ bool ScrollView::OnMouseDrag(const MouseEvent& me)
 		ScrollDelta(me.Delta());
 		return true;
 	}
-	
+
 	return false;
 }
 
