@@ -24,18 +24,18 @@
 #include "GameData.h"
 #include "Interface.h"
 #include "Sprite2D.h"
+
 #include "GUI/EventMgr.h"
 #include "GUI/Window.h"
 
 namespace GemRB {
 
 TextEdit::TextEdit(const Region& frame, unsigned short maxLength, Point p)
-: Control(frame), textContainer(Region(Point(), Dimensions()), core->GetTextFont())
+	: Control(frame), textContainer(Region(Point(), Dimensions()), core->GetTextFont())
 {
 	ControlType = IE_GUI_EDIT;
 
-	// FIXME: should we set IE_FONT_SINGLE_LINE?
-	textContainer.SetAlignment(IE_FONT_ALIGN_MIDDLE | IE_FONT_ALIGN_LEFT);
+	textContainer.SetAlignment(IE_FONT_ALIGN_MIDDLE | IE_FONT_ALIGN_LEFT | IE_FONT_SINGLE_LINE);
 	textContainer.SetColors(ColorWhite, ColorBlack);
 	AddSubviewInFrontOfView(&textContainer);
 
@@ -44,8 +44,8 @@ TextEdit::TextEdit(const Region& frame, unsigned short maxLength, Point p)
 	max = maxLength;
 	textContainer.SetMargin(p.y, p.x);
 
-	SetFlags(Alpha|Numeric, BitOp::OR);
-	
+	SetFlags(Alpha | Numeric, BitOp::OR);
+
 	textContainer.SetEventProxy(this);
 }
 
@@ -60,9 +60,9 @@ void TextEdit::SetAlignment(unsigned char align)
 }
 
 /** Set Font */
-void TextEdit::SetFont(Font* f)
+void TextEdit::SetFont(Holder<Font> f)
 {
-	textContainer.SetFont(f);
+	textContainer.SetFont(std::move(f));
 }
 
 /** Key Press Event */
@@ -72,7 +72,7 @@ bool TextEdit::OnKeyPress(const KeyboardEvent& key, unsigned short mod)
 		PerformAction(Action::Done);
 		return true;
 	}
-	
+
 	// textContainer.OnKeyPress only handles deletion and navigation
 	// text is handled in TextEdit::OnTextInput
 	if (textContainer.OnKeyPress(key, mod)) {
@@ -100,7 +100,7 @@ void TextEdit::OnTextInput(const TextEvent& te)
 			break;
 		}
 	}
-	
+
 	textContainer.InsertText(te.text.substr(0, i));
 }
 
@@ -140,4 +140,18 @@ String TextEdit::QueryText() const
 	return textContainer.Text();
 }
 
+void TextEdit::SetBackground(const ResRef& bg, TextEditBG type)
+{
+	bgMos[type] = bg;
+}
+
+void TextEdit::SetBackground(TextEditBG type)
+{
+	auto mos = gamedata->GetResourceHolder<ImageMgr>(bgMos[type]);
+	if (mos) {
+		Holder<Sprite2D> img = mos->GetSprite2D();
+		View::SetBackground(std::move(img));
+	}
+}
+
 }
