@@ -20,11 +20,11 @@
 
 #include "Font.h"
 
+#include "Debug.h"
 #include "GameData.h"
-#include "Interface.h"
-#include "Logging/Logging.h"
 #include "Palette.h"
 
+#include "Logging/Logging.h"
 #include "Video/Video.h"
 
 #include <cwctype>
@@ -34,7 +34,7 @@
 namespace GemRB {
 
 static void BlitGlyphToCanvas(const Glyph& glyph, const Point& p,
-							  ieByte* canvas, const Size& size)
+			      ieByte* canvas, const Size& size)
 {
 	const ieByte* src = glyph.pixels;
 	if (canvas == NULL || src == NULL) {
@@ -46,38 +46,39 @@ static void BlitGlyphToCanvas(const Glyph& glyph, const Point& p,
 	Point blitPoint = p + glyph.pos;
 	Size srcSize = glyph.size;
 	if (blitPoint.y < 0) {
-		int offset = (-blitPoint.y * glyph.size.w);
-		src += offset;
+		int offset = -blitPoint.y * glyph.size.w;
+		src += offset * glyph.bytesPerPx;
 		srcSize.h -= offset;
 		blitPoint.y = 0;
 	}
 	if (blitPoint.x < 0) {
 		int offset = -blitPoint.x;
-		src += offset;
+		src += offset * glyph.bytesPerPx;
 		srcSize.w -= offset;
 		blitPoint.x = 0;
 	}
-	ieByte* dest = canvas + (size.w * blitPoint.y) + blitPoint.x;
+	ieByte* dest = canvas + ((size.w * blitPoint.y) + blitPoint.x) * glyph.bytesPerPx;
 	assert(src >= glyph.pixels);
 	assert(dest >= canvas);
 	// copy the glyph to the canvas
-	for(int row = 0; row < srcSize.h; row++ ) {
-		if (dest + srcSize.w > canvas + (size.w * size.h)) {
+	for (int row = 0; row < srcSize.h; row++) {
+		if (dest + srcSize.w * glyph.bytesPerPx > canvas + (size.w * size.h * glyph.bytesPerPx)) {
 			break;
 		}
-		memcpy(dest, src, srcSize.w);
-		dest += size.w;
-		src += glyph.pitch;
+
+		memcpy(dest, src, srcSize.w * glyph.bytesPerPx);
+		dest += size.w * glyph.bytesPerPx;
+		src += glyph.pitch * glyph.bytesPerPx;
 	}
 }
 
 Font::GlyphAtlasPage::GlyphAtlasPage(Size pageSize, Font* font)
-: SpriteSheet<ieWord>(core->GetVideoDriver()), font(font)
+	: SpriteSheet<ieWord>(), font(font)
 {
 	SheetRegion.w = pageSize.w;
 	SheetRegion.h = pageSize.h;
 
-	pageData = (ieByte*)calloc(pageSize.h, pageSize.w);
+	pageData = (ieByte*) calloc(pageSize.h, pageSize.w * (font->palette ? 1 : 4));
 }
 
 bool Font::GlyphAtlasPage::AddGlyph(ieWord chr, const Glyph& g)
@@ -87,21 +88,21 @@ bool Font::GlyphAtlasPage::AddGlyph(ieWord chr, const Glyph& g)
 	if (newX > SheetRegion.w) {
 		return false;
 	}
-	
-	int glyphH = g.size.h + abs(g.pos.y);
+
+	int glyphH = g.size.h + std::abs(g.pos.y);
 	if (glyphH > SheetRegion.h) {
 		// must grow to accommodate this glyph
 		if (Sheet) {
 			// if we already have a sheet we need to destroy it before we can add more glyphs
-			pageData = (ieByte*)calloc(SheetRegion.w, glyphH);
+			pageData = (ieByte*) calloc(SheetRegion.w, glyphH * g.bytesPerPx);
 			const ieByte* pixels = static_cast<const ieByte*>(Sheet->LockSprite());
-			std::copy(pixels, pixels + (Sheet->Frame.w * Sheet->Frame.h), pageData);
+			std::copy(pixels, pixels + (Sheet->Frame.w * Sheet->Frame.h) * g.bytesPerPx, pageData);
 			Sheet->UnlockSprite();
 			Sheet = nullptr;
 		} else {
-			pageData = (ieByte*)realloc(pageData, SheetRegion.w * glyphH);
+			pageData = (ieByte*) realloc(pageData, SheetRegion.w * glyphH * g.bytesPerPx);
 		}
-		
+
 		assert(pageData);
 		SheetRegion.h = glyphH;
 	} else if (Sheet) {
@@ -115,14 +116,14 @@ bool Font::GlyphAtlasPage::AddGlyph(ieWord chr, const Glyph& g)
 	MapSheetSegment(chr, Region(pageXPos, (g.pos.y < 0) ? 0 : g.pos.y, g.size.w, g.size.h));
 	// make the non-temporary glyph from our own data
 	const ieByte* pageLoc = pageData + pageXPos;
-	glyphs.emplace(chr, Glyph(g.size, g.pos, pageLoc, SheetRegion.w));
+	glyphs.emplace(chr, Glyph(g.size, g.pos, pageLoc, SheetRegion.w, g.bytesPerPx));
 
 	pageXPos = newX;
-	
+
 	if (Sheet) {
 		Sheet->UnlockSprite();
 	}
-	
+
 	return true;
 }
 
@@ -132,7 +133,7 @@ const Glyph& Font::GlyphAtlasPage::GlyphForChr(ieWord chr) const
 	if (it != glyphs.end()) {
 		return it->second;
 	}
-	const static Glyph blank(Size(0,0), Point(0, 0), NULL, 0);
+	const static Glyph blank(Size(0, 0), Point(0, 0), NULL, 0, 1);
 	return blank;
 }
 
@@ -140,26 +141,35 @@ void Font::GlyphAtlasPage::Draw(ieWord chr, const Region& dest, const PrintColor
 {
 	// ensure that we have a sprite!
 	if (Sheet == NULL) {
-		//Sheet = core->GetVideoDriver()->CreateSprite8(SheetRegion.w, SheetRegion.h, pageData, pal, true, 0);
-		PixelFormat fmt = PixelFormat::Paletted8Bit(font->palette, true, 0);
-		Sheet = core->GetVideoDriver()->CreateSprite(SheetRegion, pageData, fmt);
-		if (font->background) {
+		PixelFormat fmt = PixelFormat::ARGB32Bit();
+		if (font->palette) {
+			fmt = PixelFormat::Paletted8Bit(font->palette, true, 0);
+		}
+
+		Sheet = VideoDriver->CreateSprite(SheetRegion, pageData, fmt);
+		// FIXME: allow inverting non-paletted fonts (see #2224)
+		if (font->background && font->palette) {
 			invertedSheet = Sheet->copy();
-			auto invertedPalette = font->palette->Copy();
-			for (auto& c : invertedPalette->col) {
+			auto invertedPalette = MakeHolder<Palette>(*font->palette);
+
+			Palette::Colors buffer;
+			for (size_t i = 0; i < buffer.size(); ++i) {
+				auto c = invertedPalette->GetColorAt(i);
 				c.r = 255 - c.r;
 				c.g = 255 - c.g;
 				c.b = 255 - c.b;
+				buffer[i] = c;
 			}
+			invertedPalette->CopyColors(0, buffer.cbegin(), buffer.cend());
 			invertedSheet->SetPalette(invertedPalette);
 		}
 	}
-	
+
 	if (colors) {
 		if (font->background) {
 			SpriteSheet<ieWord>::Draw(chr, dest, BlitFlags::BLENDED | BlitFlags::COLOR_MOD, colors->bg);
 			// no point in BlitFlags::ADD with black so let's optimize away some blits
-			if (colors->fg != ColorBlack) {
+			if (colors->fg != ColorBlack && font->palette) {
 				std::swap(Sheet, invertedSheet);
 				SpriteSheet<ieWord>::Draw(chr, dest, BlitFlags::ADD | BlitFlags::COLOR_MOD, colors->fg);
 				std::swap(Sheet, invertedSheet);
@@ -174,16 +184,15 @@ void Font::GlyphAtlasPage::Draw(ieWord chr, const Region& dest, const PrintColor
 
 void Font::GlyphAtlasPage::DumpToScreen(const Region& r) const
 {
-	Video* video = core->GetVideoDriver();
-	video->SetScreenClip(NULL);
+	VideoDriver->SetScreenClip(NULL);
 	Region drawRgn = Region(0, 0, 1024, Sheet->Frame.h);
-	video->DrawRect(drawRgn, ColorBlack, true);
-	video->DrawRect(Sheet->Frame.Intersect(r), ColorWhite, false);
-	video->BlitSprite(Sheet, Sheet->Frame.Intersect(r), drawRgn, BlitFlags::BLENDED);
+	VideoDriver->DrawRect(drawRgn, ColorBlack, true);
+	VideoDriver->DrawRect(Sheet->Frame.Intersect(r), ColorWhite, false);
+	VideoDriver->BlitSprite(Sheet, Sheet->Frame.Intersect(r), drawRgn, BlitFlags::BLENDED);
 }
 
-Font::Font(PaletteHolder pal, ieWord lineheight, ieWord baseline, bool bg)
-: palette(std::move(pal)), background(bg), LineHeight(lineheight), Baseline(baseline)
+Font::Font(Holder<Palette> pal, ieWord lineheight, ieWord baseline, bool bg)
+	: palette(std::move(pal)), background(bg), LineHeight(lineheight), Baseline(baseline)
 {}
 
 Font::~Font(void)
@@ -197,7 +206,7 @@ void Font::CreateGlyphIndex(ieWord chr, ieWord pageIdx, const Glyph* g)
 {
 	if (chr >= AtlasIndex.size()) {
 		// potentially wasteful I guess, but much faster than a map.
-		AtlasIndex.resize(chr+1);
+		AtlasIndex.resize(chr + 1);
 	} else {
 		assert(AtlasIndex[chr].pageIdx == static_cast<ieWord>(-1));
 	}
@@ -208,12 +217,12 @@ const Glyph& Font::CreateGlyphForCharSprite(ieWord chr, const Holder<Sprite2D>&
 {
 	assert(AtlasIndex.size() <= chr || AtlasIndex[chr].pageIdx == static_cast<ieWord>(-1));
 	assert(spr);
-	
+
 	Size size(spr->Frame.w, spr->Frame.h);
 	// FIXME: should we adjust for spr->Frame.x too?
 	Point pos(0, Baseline - spr->Frame.y);
 
-	Glyph tmp = Glyph(size, pos, (ieByte*)spr->LockSprite(), spr->Frame.w);
+	Glyph tmp = Glyph(size, pos, (ieByte*) spr->LockSprite(), spr->Frame.w, spr->GetPalette() ? 1 : 4);
 	spr->UnlockSprite(); // FIXME: this is assuming it is ok to hang onto to pixel buffer returned from LockSprite()
 	// adjust the location for the glyph
 	if (!CurrentAtlasPage || !CurrentAtlasPage->AddGlyph(chr, tmp)) {
@@ -235,7 +244,7 @@ void Font::CreateAliasForChar(ieWord chr, ieWord alias)
 	assert(AtlasIndex.size() > chr && AtlasIndex[chr].pageIdx != static_cast<ieWord>(-1));
 
 	// we need to now find the page for the existing character and add this new one to that page
-	const GlyphIndexEntry& idx = AtlasIndex[chr]; // this referenece may become invalid after call to CreateGlyphIndex!
+	const GlyphIndexEntry& idx = AtlasIndex[chr]; // this reference may become invalid after call to CreateGlyphIndex!
 	ieWord pageIdx = idx.pageIdx;
 	CreateGlyphIndex(alias, pageIdx, idx.glyph);
 	Atlas[pageIdx]->MapSheetSegment(alias, (*Atlas[pageIdx])[chr]);
@@ -249,19 +258,19 @@ const Glyph& Font::GetGlyph(ieWord chr) const
 			return *g;
 		}
 	}
-	const static Glyph blank(Size(0,0), Point(0, 0), NULL, 0);
+	const static Glyph blank(Size(0, 0), Point(0, 0), NULL, 0, 1);
 	return blank;
 }
 
 size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, const PrintColors* colors,
-						Point* point, ieByte** canvas, bool grow) const
+			Point* point, ieByte** canvas, bool grow) const
 {
 	// NOTE: vertical alignment is not handled here.
 	// it should have been calculated previously and passed in via the "point" parameter
 
-	bool singleLine = (alignment&IE_FONT_SINGLE_LINE);
+	bool singleLine = (alignment & IE_FONT_SINGLE_LINE);
 	Point dp = point ? *point : Point();
-	const Region& sclip = core->GetVideoDriver()->GetScreenClip();
+	const Region& sclip = VideoDriver->GetScreenClip();
 
 	size_t charCount = 0;
 	bool lineBreak = false;
@@ -271,7 +280,7 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 		if (lineBreak) {
 			lineBreak = false;
 		} else {
-			size_t eolpos = string.find_first_of(L'\n', stringPos);
+			size_t eolpos = string.find_first_of(u'\n', stringPos);
 			if (eolpos == String::npos) {
 				eolpos = string.length();
 			} else {
@@ -295,12 +304,12 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 			int vGrow = (numLines * LineHeight);
 			rgn.h += vGrow;
 
-			if (core->InDebugMode(ID_FONTS)) {
+			if (InDebugMode(DebugMode::FONTS)) {
 				Log(MESSAGE, "Font", "Resizing canvas from {}x{} to {}x{}",
-					rgn.w, rgn.h - vGrow, rgn.w, rgn.h);
+				    rgn.w, rgn.h - vGrow, rgn.w, rgn.h);
 			}
 
-			*canvas = (ieByte*)realloc(*canvas, rgn.w * rgn.h);
+			*canvas = (ieByte*) realloc(*canvas, rgn.w * rgn.h);
 			assert(canvas);
 			// fill the buffer with the color key, or the new area or we will get garbage in the areas we dont blit to
 			memset(*canvas + curpos, 0, vGrow * rgn.w);
@@ -310,7 +319,7 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 		size_t lineLen = line.length();
 		if (lineLen) {
 			const Region lineRgn(dp + rgn.origin, Size(rgn.w, LineHeight));
-			StringSizeMetrics metrics = {lineRgn.size, 0, 0, true};
+			StringSizeMetrics metrics = { lineRgn.size, 0, 0, true };
 			const Size lineSize = StringSize(line, &metrics);
 			size_t linePos = metrics.numChars;
 			Point linePoint;
@@ -324,7 +333,7 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 				linePoint.x = lineSize.w;
 			} else {
 				// on screen
-				if (alignment&(IE_FONT_ALIGN_CENTER|IE_FONT_ALIGN_RIGHT)) {
+				if (alignment & (IE_FONT_ALIGN_CENTER | IE_FONT_ALIGN_RIGHT)) {
 					linePoint.x += (rgn.w - lineSize.w); // this is right aligned, but we can adjust for center later on
 					if (linePoint.x < 0) {
 						linePos = String::npos;
@@ -333,10 +342,10 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 						while (linePoint.x < 0) {
 							// yuck, this is not optimal. not sure of a better way.
 							// we have to rewind, word by word, until X >= 0
-							linePos = line.find_last_of(L' ', prevPos);
+							linePos = line.find_last_of(u' ', prevPos);
 							if (linePos == String::npos) {
-								if (core->InDebugMode(ID_FONTS)) {
-									Log(MESSAGE, "Font", "Horizontal alignment invalidated for '{}' due to insufficient width {}", fmt::WideToChar{line}, lineSize.w);
+								if (InDebugMode(DebugMode::FONTS)) {
+									Log(MESSAGE, "Font", "Horizontal alignment invalidated for '{}' due to insufficient width {}", fmt::WideToChar { line }, lineSize.w);
 								}
 								linePoint.x = 0;
 								break;
@@ -347,14 +356,15 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 							prevPos = linePos - 1;
 						}
 					}
-					if (alignment&IE_FONT_ALIGN_CENTER) {
+					if (alignment & IE_FONT_ALIGN_CENTER) {
 						linePoint.x /= 2;
 					}
 				}
-				if (core->InDebugMode(ID_FONTS)) {
-					core->GetVideoDriver()->DrawRect(lineRgn, ColorGreen, false);
-					core->GetVideoDriver()->DrawRect(Region(linePoint + lineRgn.origin,
-												 Size(lineSize.w, LineHeight)), ColorWhite, false);
+				if (InDebugMode(DebugMode::FONTS)) {
+					VideoDriver->DrawRect(lineRgn, ColorGreen, false);
+					VideoDriver->DrawRect(Region(linePoint + lineRgn.origin,
+								     Size(lineSize.w, LineHeight)),
+							      ColorWhite, false);
 				}
 				linePos = RenderLine(line, lineRgn, linePoint, colors, canvas);
 			}
@@ -391,14 +401,14 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 		if (usedh < rgn.h) {
 			// this is more than just saving memory
 			// vertical alignment will be off if we have extra space
-			*canvas = (ieByte*)realloc(*canvas, rgn.w * usedh);
+			*canvas = (ieByte*) realloc(*canvas, rgn.w * usedh);
 			rgn.h = usedh;
 		}
 	}
 
 	if (point) {
 		// deal with possible trailing newline
-		if (charCount > 0 && string[charCount - 1] == L'\n') {
+		if (charCount > 0 && string[charCount - 1] == u'\n') {
 			dp.y += LineHeight;
 		}
 		*point = Point(dp.x, dp.y - LineHeight);
@@ -409,7 +419,7 @@ size_t Font::RenderText(const String& string, Region& rgn, ieByte alignment, con
 }
 
 size_t Font::RenderLine(const String& line, const Region& lineRgn,
-						Point& dp, const PrintColors* colors, ieByte** canvas) const
+			Point& dp, const PrintColors* colors, ieByte** canvas) const
 {
 	assert(lineRgn.h == LineHeight);
 
@@ -427,15 +437,15 @@ size_t Font::RenderLine(const String& line, const Region& lineRgn,
 	// not as simple as adding it to find_first_of
 	bool done = false;
 	do {
-		wordBreak = line.find_first_of(L' ', linePos);
+		wordBreak = line.find_first_of(u' ', linePos);
 		String word;
 		if (wordBreak == linePos) {
-			word = L' ';
+			word = u' ';
 		} else {
 			word = line.substr(linePos, wordBreak - linePos);
 		}
 
-		StringSizeMetrics metrics = {lineRgn.size, 0, 0, true};
+		StringSizeMetrics metrics = { lineRgn.size, 0, 0, true };
 		int wordW = StringSize(word, &metrics).w;
 		if (dp.x == 0 && metrics.forceBreak) {
 			done = true;
@@ -447,24 +457,24 @@ size_t Font::RenderLine(const String& line, const Region& lineRgn,
 		}
 
 		// print the word
-		wchar_t currChar = '\0';
+		char16_t currChar = u'\0';
 		size_t i = 0;
 		for (; i < word.length(); i++) {
 			// process glyphs in word
 			currChar = word[i];
-			if (currChar == '\r' || currChar == '\n') {
+			if (currChar == u'\r' || currChar == u'\n') {
 				continue;
 			}
 			if (i > 0) { // kerning
-				dp.x -= GetKerningOffset(word[i-1], currChar);
+				dp.x -= GetKerningOffset(word[i - 1], currChar);
 			}
 
 			const Glyph& curGlyph = GetGlyph(currChar);
 			Point blitPoint = dp + lineRgn.origin + curGlyph.pos;
 			// use intersection because some rare glyphs can sometimes overlap lines
 			if (!lineRgn.IntersectsRegion(Region(blitPoint, curGlyph.size))) {
-				if (core->InDebugMode(ID_FONTS)) {
-					core->GetVideoDriver()->DrawRect(lineRgn, ColorRed, false);
+				if (InDebugMode(DebugMode::FONTS)) {
+					VideoDriver->DrawRect(lineRgn, ColorRed, false);
 				}
 				assert(metrics.forceBreak == false || dp.x > 0);
 				done = true;
@@ -475,8 +485,10 @@ size_t Font::RenderLine(const String& line, const Region& lineRgn,
 				BlitGlyphToCanvas(curGlyph, blitPoint, *canvas, lineRgn.size);
 			} else {
 				size_t pageIdx = AtlasIndex[currChar].pageIdx;
-				GlyphAtlasPage* page = Atlas[pageIdx];
-				page->Draw(currChar, Region(blitPoint, curGlyph.size), colors);
+				if (pageIdx < Atlas.size()) {
+					GlyphAtlasPage* page = Atlas[pageIdx];
+					page->Draw(currChar, Region(blitPoint, curGlyph.size), colors);
+				}
 			}
 			dp.x += curGlyph.size.w;
 		}
@@ -487,82 +499,6 @@ size_t Font::RenderLine(const String& line, const Region& lineRgn,
 	return linePos;
 }
 
-Holder<Sprite2D> Font::RenderTextAsSprite(const String& string, const Size& size,
-								   ieByte alignment, size_t* numPrinted, Point* endPoint) const
-{
-	Size canvasSize = StringSize(string); // same as size(0, 0)
-	// if the string is larger than the region shrink the canvas
-	// except 0 means we should size to fit in that dimension
-	if (size.w) {
-		// potentially resize
-		if (size.w < canvasSize.w) {
-			if (!(alignment&IE_FONT_SINGLE_LINE)) {
-				// we need to resize horizontally which creates new lines
-				ieWord trimmedArea = ((canvasSize.w - size.w) * canvasSize.h);
-				// this automatically becomes multiline, therefore use LineHeight
-				ieWord lineArea = size.w * LineHeight;
-				// round up
-				ieWord numLines = 1 + ((trimmedArea - 1) / lineArea);
-				if (!size.h) {
-					// grow as much as needed vertically.
-					canvasSize.h += (numLines * LineHeight);
-					// there is a chance we didn't grow enough vertically...
-					// we can't possibly know how lines will break ahead of time,
-					// over a long enough paragraph we can overflow the canvas
-					// this is handled in RenderText() by reallocing the canvas based on
-					// the same estimation algorithim (total area of text) used here
-				} else if (size.h > canvasSize.h) {
-					// grow by line increments until we hit the limit
-					// round up, because even a partial line should be blitted (and clipped)
-					ieWord maxLines = 1 + (((size.h - canvasSize.h) - 1) / LineHeight);
-					if (maxLines < numLines) {
-						numLines = maxLines;
-					}
-					canvasSize.h += (numLines * LineHeight);
-					// if the new canvas size is taller than size.h it will be dealt with later
-				}
-			}
-			canvasSize.w = size.w;
-		} else if (alignment&(IE_FONT_ALIGN_CENTER|IE_FONT_ALIGN_RIGHT)) {
-			// the size width is how we center or right align so we cant trim the canvas
-			canvasSize.w = size.w;
-		}
-		// else: we already fit in the designated area (horizontally). No need to resize.
-	}
-	if (canvasSize.h < LineHeight) {
-		// should be at least LineHeight
-		canvasSize.h = LineHeight;
-	}
-	if (size.h && size.h < canvasSize.h) {
-		// we can't unbreak lines ("\n") so at best we can clip the text.
-		canvasSize.h = size.h;
-	}
-	assert(size.h || canvasSize.h >= LineHeight);
-
-	// we must calloc because not all glyphs are equal height. set remainder to the color key
-	ieByte* canvasPx = (ieByte*)calloc(canvasSize.w, canvasSize.h);
-
-	Region rgn = Region(Point(0,0), canvasSize);
-	size_t ret = RenderText(string, rgn, alignment, nullptr, endPoint, &canvasPx, (size.h) ? false : true);
-	if (numPrinted) {
-		*numPrinted = ret;
-	}
-
-	// must ue rgn! the canvas height might be changed in RenderText()
-	if (alignment&IE_FONT_ALIGN_CENTER) {
-		rgn.x = (size.w - rgn.w) / 2;
-	} else if (alignment&IE_FONT_ALIGN_RIGHT) {
-		rgn.x = size.w - rgn.w;
-	}
-	if (alignment&IE_FONT_ALIGN_MIDDLE) {
-		rgn.y = -(size.h - rgn.h) / 2;
-	} else if (alignment&IE_FONT_ALIGN_BOTTOM) {
-		rgn.y = -(size.h - rgn.h);
-	}
-	PixelFormat fmt = PixelFormat::Paletted8Bit(palette, true, 0);
-	return core->GetVideoDriver()->CreateSprite(rgn, canvasPx, fmt);
-}
-
 size_t Font::Print(const Region& rgn, const String& string, ieByte alignment, Point* point) const
 {
 	return Print(rgn, string, alignment, nullptr, point);
@@ -578,17 +514,17 @@ size_t Font::Print(Region rgn, const String& string, ieByte alignment, const Pri
 	if (rgn.size.IsInvalid()) return 0;
 
 	Point p = point ? *point : Point();
-	if (alignment&(IE_FONT_ALIGN_MIDDLE|IE_FONT_ALIGN_BOTTOM)) {
+	if (alignment & (IE_FONT_ALIGN_MIDDLE | IE_FONT_ALIGN_BOTTOM)) {
 		// we assume that point will be an offset from midde/bottom position
 		Size stringSize;
-		if (alignment&IE_FONT_SINGLE_LINE) {
+		if (alignment & IE_FONT_SINGLE_LINE) {
 			// we can optimize single lines without StringSize()
 			stringSize.h = LineHeight;
 		} else {
 			stringSize = rgn.size;
-			StringSizeMetrics metrics = {stringSize, 0, 0, true};
+			StringSizeMetrics metrics = { stringSize, 0, 0, true };
 			stringSize = StringSize(string, &metrics);
-			if (alignment&IE_FONT_NO_CALC && metrics.numChars < string.length()) {
+			if (alignment & IE_FONT_NO_CALC && metrics.numChars < string.length()) {
 				// PST GUISTORE, not sure what else
 				stringSize.h = rgn.h;
 			}
@@ -596,7 +532,7 @@ size_t Font::Print(Region rgn, const String& string, ieByte alignment, const Pri
 
 		// important: we must do this adjustment even if it leads to -p.y!
 		// some labels depend on this behavior (BG2 GUIINV) :/
-		if (alignment&IE_FONT_ALIGN_MIDDLE) {
+		if (alignment & IE_FONT_ALIGN_MIDDLE) {
 			p.y += (rgn.h - stringSize.h) / 2;
 		} else { // bottom alignment
 			p.y += rgn.h - stringSize.h;
@@ -618,14 +554,14 @@ size_t Font::StringSizeWidth(const String& string, size_t width, size_t* numChar
 	size_t length = string.length();
 	for (; i < length; ++i) {
 		wchar_t c = string[i];
-		if (c == L'\n') {
+		if (c == u'\n') {
 			break;
 		}
 
 		const Glyph& curGlyph = GetGlyph(c);
 		ieWord chrW = curGlyph.size.w;
 		if (i > 0) {
-			chrW -= GetKerningOffset(string[i-1], string[i]);
+			chrW -= GetKerningOffset(string[i - 1], string[i]);
 		}
 
 		if (width > 0 && size + chrW >= width) {
@@ -645,11 +581,13 @@ Size Font::StringSize(const String& string, StringSizeMetrics* metrics) const
 {
 	if (!string.length()) return Size();
 #define WILL_WRAP(val) \
-	(stop && stop->w && lineW + val > stop->w)
+	(stop && stop->w && lineW + (val) > stop->w)
 
 #define APPEND_TO_LINE(val) \
-	lineW += val; charCount = i + 1; val = 0
-	
+	lineW += val; \
+	charCount = i + 1; \
+	val = 0
+
 	ieWord w = 0, lines = 1;
 	ieWord lineW = 0, wordW = 0, spaceW = 0;
 	bool newline = false, eos = false, ws = false, forceBreak = false;
@@ -662,7 +600,7 @@ Size Font::StringSize(const String& string, StringSizeMetrics* metrics) const
 		if (!ws) {
 			ieWord chrW = curGlyph.size.w;
 			if (lineW > 0) { // kerning
-				chrW -= GetKerningOffset(string[i-1], string[i]);
+				chrW -= GetKerningOffset(string[i - 1], string[i]);
 			}
 			if (lineW == 0 && wordW > 0 && WILL_WRAP(wordW + chrW) && metrics->forceBreak && wordW <= stop->w) {
 				// the word is longer than the line allows, but we allow a break mid-word
@@ -679,11 +617,11 @@ Size Font::StringSize(const String& string, StringSizeMetrics* metrics) const
 			if (WILL_WRAP(spaceW + wordW)) {
 				newline = true;
 			} else {
-				if (string[i] == L'\n') {
+				if (string[i] == u'\n') {
 					// always append *everything* if there is \n
 					lineW += spaceW; // everything else appended later
 					newline = true;
-				} else if (ws && string[i] != L'\r') {
+				} else if (ws && string[i] != u'\r') {
 					spaceW += curGlyph.size.w;
 				}
 				APPEND_TO_LINE(wordW);
@@ -693,10 +631,10 @@ Size Font::StringSize(const String& string, StringSizeMetrics* metrics) const
 		if (newline || eos) {
 			w = std::max(w, lineW);
 			if (stop) {
-				if (stop->h && (LineHeight * (lines + 1)) > stop->h ) {
+				if (stop->h && (LineHeight * (lines + 1)) > stop->h) {
 					break;
 				}
-				if (eos && stop->w && wordW < stop->w ) {
+				if (eos && stop->w && wordW < stop->w) {
 					// its possible the last word of string is longer than any of the previous lines
 					w = std::max(w, wordW);
 				}
@@ -727,7 +665,7 @@ Size Font::StringSize(const String& string, StringSizeMetrics* metrics) const
 		metrics->numChars = charCount;
 		metrics->size = Size(w, (LineHeight * lines));
 		metrics->numLines = lines;
-		if (core->InDebugMode(ID_FONTS)) {
+		if (InDebugMode(DebugMode::FONTS)) {
 			assert(metrics->numChars <= string.length());
 			assert(w <= stop->w);
 		}
