@@ -32,10 +32,11 @@
 #ifndef FONT_H
 #define FONT_H
 
-#include "globals.h"
 #include "exports.h"
+#include "globals.h"
 
 #include "SpriteSheet.h"
+
 #include "Strings/String.h"
 
 #include <deque>
@@ -50,9 +51,6 @@ enum FontStyle {
 	UNDERLINE = 0x04
 };
 
-class Palette;
-using PaletteHolder = Holder<Palette>;
-
 #define IE_FONT_ALIGN_LEFT   0x00
 #define IE_FONT_ALIGN_CENTER 0x01
 #define IE_FONT_ALIGN_RIGHT  0x02
@@ -60,9 +58,9 @@ using PaletteHolder = Holder<Palette>;
 #define IE_FONT_ALIGN_TOP    0x10
 #define IE_FONT_ALIGN_MIDDLE 0x20
 // optimization to make printing faster when text should be on a single line
-#define IE_FONT_SINGLE_LINE  0x40
+#define IE_FONT_SINGLE_LINE 0x40
 // work around to use the region passed to Font::Print as if it were the actual print size when the text cant actually fit the region
-#define IE_FONT_NO_CALC		 0x80
+#define IE_FONT_NO_CALC 0x80
 
 struct Glyph {
 	const Size size;
@@ -70,9 +68,10 @@ struct Glyph {
 
 	const ieWord pitch;
 	const ieByte* pixels;
+	const uint8_t bytesPerPx;
 
-	Glyph(const Size& size, Point pos, const ieByte* pixels, ieWord pitch)
-	: size(size), pos(pos), pitch(pitch), pixels(pixels) {};
+	Glyph(const Size& size, Point pos, const ieByte* pixels, ieWord pitch, uint8_t bpp)
+		: size(size), pos(pos), pitch(pitch), pixels(pixels), bytesPerPx(bpp) {};
 };
 
 /**
@@ -89,45 +88,48 @@ class GEM_EXPORT Font {
 	 Furthermore, a single page may grow too large to be used as a texture in OpenGL (esp for mobile devices).
 	 Therefore we generate pages of glyphs (1024 x LineHeight + descent) as sprites suitable for segmented blitting to the screen.
 	 The pixel data will be safely shared between the Sprite2D objects and the Glyph objects when the video driver is using software rendering
-	 so this isn't horribly wasteful useage of memory. Hardware acceleration will force the font to keep its own copy of pixel data.
+	 so this isn't horribly wasteful usage of memory. Hardware acceleration will force the font to keep its own copy of pixel data.
 	 
 	 One odd quirk in this implementation is that, since TTF fonts cannot be pregenerated (efficiently), we must defer creation of a page sprite 
 	 until either the page is full, or until a call to a print method is made.
 	 To avoid generating more than one partial page, subsequent calls to add new glyphs will destroy the partial Sprite (not the source pixels of course)
 	*/
+
 public:
 	struct PrintColors {
 		Color fg;
 		Color bg;
 	};
-	
+
 	struct StringSizeMetrics {
-		// specifiy behavior of StringSize based on values of struct
+		// specify behavior of StringSize based on values of struct
 		// StringSize will modify the struct with the results
-		Size size;		// maximum size allowed; updated with actual size <= initial value
+		Size size; // maximum size allowed; updated with actual size <= initial value
 		size_t numChars; // maximum characters to size (0 implies no limit); updated with the count of characters that fit within size <= initial value
 		uint32_t numLines; // maximum number of lines to allow (use 0 for unlimited); updated with the actual number of lines that were used
-		bool forceBreak;// whether or not a break can occur without whitespace; updated to false if initially true and no force break occured
+		bool forceBreak; // whether or not a break can occur without whitespace; updated to false if initially true and no force break occurred
 	};
 
 private:
 	class GlyphAtlasPage : public SpriteSheet<ieWord> {
-		private:
-			using GlyphMap = std::map<ieWord, Glyph>;
-			GlyphMap glyphs;
-			ieByte* pageData; // current raw page being built
-			int pageXPos = 0; // current position on building page
-			Font* font;
-			Holder<Sprite2D> invertedSheet;
-		public:
-			GlyphAtlasPage(Size pageSize, Font* font);
-			GlyphAtlasPage(const GlyphAtlasPage&) = delete;
-			GlyphAtlasPage& operator=(const GlyphAtlasPage&) = delete;
-			~GlyphAtlasPage() override {
-				if (Sheet == NULL) {
-					free(pageData);
-				}
+	private:
+		using GlyphMap = std::map<ieWord, Glyph>;
+		GlyphMap glyphs;
+		ieByte* pageData; // current raw page being built
+		int pageXPos = 0; // current position on building page
+		Font* font;
+		Holder<Sprite2D> invertedSheet;
+
+	public:
+		GlyphAtlasPage(Size pageSize, Font* font);
+		GlyphAtlasPage(const GlyphAtlasPage&) = delete;
+		GlyphAtlasPage& operator=(const GlyphAtlasPage&) = delete;
+		~GlyphAtlasPage() override
+		{
+			if (Sheet == NULL) {
+				free(pageData);
 			}
+		}
 		bool AddGlyph(ieWord chr, const Glyph& g);
 		const Glyph& GlyphForChr(ieWord chr) const;
 
@@ -143,7 +145,8 @@ private:
 		const Glyph* glyph = nullptr;
 
 		GlyphIndexEntry() noexcept = default;
-		GlyphIndexEntry(ieWord c, ieWord p, const Glyph* g) : chr(c), pageIdx(p), glyph(g) {}
+		GlyphIndexEntry(ieWord c, ieWord p, const Glyph* g)
+			: chr(c), pageIdx(p), glyph(g) {}
 	};
 
 	using GlyphIndex = std::vector<GlyphIndexEntry>;
@@ -156,7 +159,7 @@ private:
 	GlyphAtlas Atlas;
 
 protected:
-	PaletteHolder palette;
+	Holder<Palette> palette;
 	bool background = false;
 
 public:
@@ -167,15 +170,15 @@ private:
 	void CreateGlyphIndex(ieWord chr, ieWord pageIdx, const Glyph*);
 	// Blit to the sprite or screen if canvas is NULL
 	size_t RenderText(const String&, Region&, ieByte alignment, const PrintColors*,
-					  Point* = NULL, ieByte** canvas = NULL, bool grow = false) const;
+			  Point* = NULL, ieByte** canvas = NULL, bool grow = false) const;
 	// render a single line of text. called by RenderText()
 	size_t RenderLine(const String& string, const Region& rgn,
-					  Point& dp, const PrintColors*, ieByte** canvas = NULL) const;
-	
+			  Point& dp, const PrintColors*, ieByte** canvas = NULL) const;
+
 	size_t Print(Region rgn, const String& string, ieByte Alignment, const PrintColors* colors, Point* point = nullptr) const;
 
 public:
-	Font(PaletteHolder pal, ieWord lineheight, ieWord baseline, bool bg);
+	Font(Holder<Palette> pal, ieWord lineheight, ieWord baseline, bool bg);
 	Font(const Font&) = delete;
 	virtual ~Font();
 	Font& operator=(const Font&) = delete;
@@ -188,25 +191,22 @@ public:
 	//allow reading but not setting glyphs
 	virtual const Glyph& GetGlyph(ieWord chr) const;
 
-	virtual int GetKerningOffset(ieWord /*leftChr*/, ieWord /*rightChr*/) const {return 0;};
-
-	Holder<Sprite2D> RenderTextAsSprite(const String& string, const Size& size, ieByte alignment,
-								 size_t* numPrinted = NULL, Point* = NULL) const;
+	virtual int GetKerningOffset(ieWord /*leftChr*/, ieWord /*rightChr*/) const { return 0; };
 
 	// return the number of glyphs printed
 	// the "point" parameter can be passed with a start point for rendering
 	// it will be filled with the point inside 'rgn' where the string ends upon return
-	
+
 	size_t Print(const Region& rgn, const String& string, ieByte Alignment, Point* point = nullptr) const;
 	size_t Print(const Region& rgn, const String& string, ieByte Alignment, const PrintColors& colors, Point* point = nullptr) const;
-	
+
 	size_t Print(Region rgn, const String& string,
-				 PaletteHolder hicolor, ieByte Alignment, Point* point = nullptr) const;
+		     Holder<Palette> hicolor, ieByte Alignment, Point* point = nullptr) const;
 
 	/** Returns size of the string rendered in this font in pixels */
 	Size StringSize(const String&, StringSizeMetrics* metrics = NULL) const;
 
-	// like StringSize, but single line and doens't take whitespace into consideration
+	// like StringSize, but single line and doesn't take whitespace into consideration
 	size_t StringSizeWidth(const String&, size_t width, size_t* numChars = NULL) const;
 };
 
