@@ -20,6 +20,7 @@
 #define GEMMARKUP_H
 
 #include "TextContainer.h"
+
 #include "Strings/String.h"
 
 #include <map>
@@ -38,12 +39,12 @@ public:
 	};
 
 	GemMarkupParser();
-	GemMarkupParser(const Font* ftext, Font::PrintColors textCols,
-					const Font* finit, Font::PrintColors initCols);
+	GemMarkupParser(const Holder<Font> ftext, Font::PrintColors textCols,
+			const Holder<Font> finit, Font::PrintColors initCols);
 	~GemMarkupParser() noexcept = default;
 
-	void ResetAttributes(const Font *ftext, Font::PrintColors textCols,
-						 const Font *finit, Font::PrintColors initCols);
+	void ResetAttributes(const Holder<Font> ftext, Font::PrintColors textCols,
+			     const Holder<Font> finit, Font::PrintColors initCols);
 
 	void Reset();
 
@@ -52,37 +53,38 @@ public:
 
 private:
 	class TextAttributes {
-		private:
+	private:
 		Font::PrintColors textColor;
 		Font::PrintColors swapColor;
 
-		public:
-		const Font* TextFont;
-		const Font* SwapFont;
+	public:
+		Holder<Font> TextFont;
+		Holder<Font> SwapFont;
 
-		public:
-		TextAttributes(const Font *text, Font::PrintColors textColor,
-					   const Font *init, Font::PrintColors initColor)
-		: textColor(textColor), swapColor(initColor)
+	public:
+		TextAttributes(const Holder<Font> text, Font::PrintColors textColor,
+			       const Holder<Font> init, Font::PrintColors initColor)
+			: textColor(textColor), swapColor(initColor), TextFont(text), SwapFont(init)
 		{
-			TextFont = text;
-			SwapFont = init;
 			assert(TextFont && SwapFont);
 		}
 
 		TextAttributes(const TextAttributes& ta) = default;
 		TextAttributes& operator=(const TextAttributes& ta) = default;
 
-		void SwapFonts() {
+		void SwapFonts()
+		{
 			std::swap(TextFont, SwapFont);
 			std::swap(textColor, swapColor);
 		}
 
-		void SetTextColor(const Font::PrintColors& c) {
+		void SetTextColor(const Font::PrintColors& c)
+		{
 			textColor = c;
 		}
 
-		const Font::PrintColors& TextColor() const {
+		const Font::PrintColors& TextColor() const
+		{
 			return textColor;
 		}
 	};
