@@ -18,9 +18,11 @@
 
 #include "TextContainer.h"
 
+#include "Debug.h"
 #include "Interface.h"
 #include "Palette.h"
 #include "Sprite2D.h"
+
 #include "Strings/String.h"
 #include "Video/Video.h"
 
@@ -34,12 +36,12 @@ LayoutRegions Content::LayoutForPointInRegion(Point p, const Region& rgn) const
 	return { std::make_shared<LayoutRegion>(Region(rgn.origin + p, frame.size)) };
 }
 
-TextSpan::TextSpan(String string, const Font* fnt, const Size* frame)
+TextSpan::TextSpan(String string, const Holder<Font> fnt, const Size* frame)
 	: Content(frame ? *frame : Size()), text(std::move(string)), font(fnt)
 {
 }
 
-TextSpan::TextSpan(String string, const Font* fnt, Font::PrintColors cols, const Size* frame)
+TextSpan::TextSpan(String string, const Holder<Font> fnt, Font::PrintColors cols, const Size* frame)
 	: Content(frame ? *frame : Size()), text(std::move(string)), font(fnt), colors(new Font::PrintColors(cols))
 {
 }
@@ -57,10 +59,10 @@ void TextSpan::ClearColors()
 void TextSpan::SetColors(const Color& fg, const Color& bg)
 {
 	ClearColors();
-	colors = new Font::PrintColors {fg, bg};
+	colors = new Font::PrintColors { fg, bg };
 }
 
-inline const Font* TextSpan::LayoutFont() const
+inline Holder<const Font> TextSpan::LayoutFont() const
 {
 	if (font) return font;
 
@@ -73,7 +75,7 @@ inline const Font* TextSpan::LayoutFont() const
 
 inline Region TextSpan::LayoutInFrameAtPoint(const Point& p, const Region& rgn) const
 {
-	const Font* layoutFont = LayoutFont();
+	auto layoutFont = LayoutFont();
 	Size maxSize = frame.size;
 	Region drawRegion = Region(p + rgn.origin, maxSize);
 	if (maxSize.w <= 0) {
@@ -83,7 +85,7 @@ inline Region TextSpan::LayoutInFrameAtPoint(const Point& p, const Region& rgn)
 			maxSize.w = drawRegion.w;
 			assert(drawRegion.w);
 		} else {
-			Font::StringSizeMetrics metrics = {maxSize, 0, 0, true};
+			Font::StringSizeMetrics metrics = { maxSize, 0, 0, true };
 			drawRegion.w = layoutFont->StringSize(text, &metrics).w;
 			assert(drawRegion.w);
 		}
@@ -94,7 +96,7 @@ inline Region TextSpan::LayoutInFrameAtPoint(const Point& p, const Region& rgn)
 			drawRegion.h = rgn.w - p.y;
 			assert(drawRegion.h);
 		} else {
-			Font::StringSizeMetrics metrics = {maxSize, 0, 0, true};
+			Font::StringSizeMetrics metrics = { maxSize, 0, 0, true };
 			drawRegion.h = layoutFont->StringSize(text, &metrics).h;
 			assert(drawRegion.h);
 		}
@@ -106,7 +108,7 @@ LayoutRegions TextSpan::LayoutForPointInRegion(Point layoutPoint, const Region&
 {
 	LayoutRegions layoutRegions;
 	const Point& drawOrigin = rgn.origin;
-	const Font* layoutFont = LayoutFont();
+	auto layoutFont = LayoutFont();
 	assert(layoutFont);
 
 	if (frame.size.IsZero()) {
@@ -133,11 +135,11 @@ LayoutRegions TextSpan::LayoutForPointInRegion(Point layoutPoint, const Region&
 
 				lineSegment = lineRgn;
 			}
-			
+
 			size_t begin = 0;
 			size_t end = 0;
 			do {
-				// process all overlaping exclusion zones until we trim down to the leftmost non conflicting region.
+				// process all overlapping exclusion zones until we trim down to the leftmost non conflicting region.
 				// check for intersections with other content
 				excluded = parent->ContentRegionForRect(lineSegment);
 				if (!excluded) {
@@ -175,7 +177,7 @@ LayoutRegions TextSpan::LayoutForPointInRegion(Point layoutPoint, const Region&
 				assert(lineSegment.h == lineheight);
 				size_t numOnLine = 0;
 				// must limit our operation to this single line.
-				size_t nextLine = text.find_first_of(L'\n', numPrinted);
+				size_t nextLine = text.find_first_of(u'\n', numPrinted);
 				if (nextLine == numPrinted) {
 					// this is a new line, we dont have to actually size that
 					// simply occupy the entire area and advance.
@@ -188,11 +190,11 @@ LayoutRegions TextSpan::LayoutForPointInRegion(Point layoutPoint, const Region&
 						subLen = nextLine - numPrinted + 1; // +1 for the \n
 					}
 					const String& substr = text.substr(numPrinted, subLen);
-					Font::StringSizeMetrics metrics = {lineSegment.size, 0, 0, lineSegment.w == lineRgn.w};
+					Font::StringSizeMetrics metrics = { lineSegment.size, 0, 0, lineSegment.w == lineRgn.w };
 					Size printSize = layoutFont->StringSize(substr, &metrics);
 					numOnLine = metrics.numChars;
 					assert(numOnLine || !metrics.forceBreak);
-					
+
 					begin = numPrinted;
 					end = begin + numOnLine;
 
@@ -215,7 +217,7 @@ LayoutRegions TextSpan::LayoutForPointInRegion(Point layoutPoint, const Region&
 			assert(!lineSegment.size.IsInvalid());
 			lineExclusions.push_back(lineSegment);
 
-		newline:
+newline:
 			if (newline || numPrinted == text.length()) {
 				// must claim the lineExclusions as part of the layout
 				// just because we didnt fit doesn't mean something else won't...
@@ -249,7 +251,7 @@ void TextSpan::DrawContentsInRegions(const LayoutRegions& rgns, const Point& off
 		Region drawRect = lrgn->region;
 		drawRect.x += offset.x;
 		drawRect.y += offset.y;
-		const Font* printFont = LayoutFont();
+		auto printFont = LayoutFont();
 		const Font::PrintColors* pc = colors;
 		const TextContainer* container = static_cast<const TextContainer*>(parent);
 		if (!pc && container) {
@@ -259,9 +261,9 @@ void TextSpan::DrawContentsInRegions(const LayoutRegions& rgns, const Point& off
 		// FIXME: this shouldnt happen, but it does (BG2 belt03 unidentified).
 		// for now only assert when ID_TEXT is set
 		// the situation is benign and nothing even looks wrong because all that this means is that there was more space allocated than was actually needed
-		if (core->InDebugMode(ID_TEXT)) {
+		if (InDebugMode(DebugMode::TEXT)) {
 			assert(charsPrinted < text.length());
-			core->GetVideoDriver()->DrawRect(drawRect, ColorRed, true);
+			VideoDriver->DrawRect(drawRect, ColorRed, true);
 		}
 		// FIXME: layout assumes left alignment, so alignment is mostly broken
 		// we only use it for TextEdit tho which is single line and therefore works as long as the text ends in a newline
@@ -271,8 +273,8 @@ void TextSpan::DrawContentsInRegions(const LayoutRegions& rgns, const Point& off
 			charsPrinted += printFont->Print(drawRect, text.substr(charsPrinted), Alignment);
 		}
 
-		if (core->InDebugMode(ID_TEXT)) {
-			core->GetVideoDriver()->DrawRect(drawRect, ColorWhite, false);
+		if (InDebugMode(DebugMode::TEXT)) {
+			VideoDriver->DrawRect(drawRect, ColorWhite, false);
 		}
 	}
 }
@@ -289,11 +291,11 @@ void ImageSpan::DrawContentsInRegions(const LayoutRegions& rgns, const Point& of
 	Region r = rgns.front()->region;
 	r.x += offset.x;
 	r.y += offset.y;
-	core->GetVideoDriver()->BlitSprite(image, r.origin, &r);
+	VideoDriver->BlitSprite(image, r.origin, &r);
 }
 
 ContentContainer::ContentContainer(const Region& frame)
-: View(frame)
+	: View(frame)
 {
 	SizeChanged(Size());
 }
@@ -320,49 +322,48 @@ void ContentContainer::SetMargin(ieByte top, ieByte right, ieByte bottom, ieByte
 void ContentContainer::WillDraw(const Region& drawFrame, const Region& clip)
 {
 	Region sc = clip;
-	
+
 	int diff = clip.x - drawFrame.x;
 	if (diff < margin.left) {
 		sc.x += margin.left - diff;
 		sc.w -= margin.left - diff;
 	}
-	
+
 	diff = (drawFrame.x + drawFrame.w) - (clip.x + clip.w);
 	if (diff < margin.right) {
 		sc.w += margin.right - diff;
 	}
-	
-	// TODO: if we ever support horzontal scrollbars these will need to be fixed
+
+	// TODO: if we ever support horizontal scrollbars these will need to be fixed
 	sc.y += margin.top;
 	sc.h -= margin.top + margin.bottom;
 
-	core->GetVideoDriver()->SetScreenClip(&sc);
+	VideoDriver->SetScreenClip(&sc);
 }
 
 void ContentContainer::DidDraw(const Region& /*drawFrame*/, const Region& clip)
 {
-	core->GetVideoDriver()->SetScreenClip(&clip);
+	VideoDriver->SetScreenClip(&clip);
 }
 
 void ContentContainer::DrawSelf(const Region& drawFrame, const Region& clip)
 {
-	Video* video = core->GetVideoDriver();
-	if (core->InDebugMode(ID_TEXT)) {
+	if (InDebugMode(DebugMode::TEXT)) {
 		Region r = clip;
-		video->DrawRect(r, ColorYellow, true);
-		
+		VideoDriver->DrawRect(r, ColorYellow, true);
+
 		r.x += margin.left;
 		r.y += margin.top;
 		r.w -= margin.left + margin.right;
 		r.h -= margin.bottom + margin.top;
-		
-		video->DrawRect(r, ColorGreen, true);
+
+		VideoDriver->DrawRect(r, ColorGreen, true);
 	}
 
 	// layout shouldn't be empty unless there is no content anyway...
 	if (layout.empty()) return;
 	Point dp = drawFrame.origin + Point(margin.left, margin.top);
-	
+
 	ContentLayout::const_iterator it = layout.begin();
 	for (; it != layout.end(); ++it) {
 		const Layout& l = *it;
@@ -413,7 +414,7 @@ void ContentContainer::SizeChanged(const Size& /*oldSize*/)
 void ContentContainer::SubviewAdded(View* view, View* parent)
 {
 	if (parent == this) {
-		// ContentContainer should grow to the size of its (immidiate) subviews automatically
+		// ContentContainer should grow to the size of its (immediate) subviews automatically
 		const Region& subViewFrame = view->Frame();
 		Size s;
 		s.h = std::max(subViewFrame.y + subViewFrame.h, frame.h);
@@ -449,7 +450,7 @@ Content* ContentContainer::RemoveContent(const Content* span, bool doLayout)
 }
 
 ContentContainer::ContentList::iterator
-ContentContainer::EraseContent(ContentList::iterator it)
+	ContentContainer::EraseContent(ContentList::iterator it)
 {
 	Content* content = *it;
 	content->parent = NULL;
@@ -462,7 +463,7 @@ ContentContainer::EraseContent(ContentList::iterator it)
 }
 
 ContentContainer::ContentList::iterator
-ContentContainer::EraseContent(ContentList::iterator beg, ContentList::iterator end)
+	ContentContainer::EraseContent(ContentList::iterator beg, ContentList::iterator end)
 {
 	while (beg != end) {
 		beg = EraseContent(beg);
@@ -476,7 +477,7 @@ Content* ContentContainer::ContentAtPoint(const Point& p) const
 	if (contentLayout) {
 		// i know we are casting away const.
 		// we could return std::find(contents.begin(), contents.end(), *it) instead, but whats the point?
-		return (Content*)(contentLayout->content);
+		return (Content*) (contentLayout->content);
 	}
 	return NULL;
 }
@@ -502,7 +503,7 @@ const ContentContainer::Layout* ContentContainer::LayoutAtPoint(const Point& p)
 			++it;
 			count -= step + 1;
 		} else {
-			std::advance(it, -std::make_signed<size_t>::type(step));
+			std::advance(it, -std::make_signed_t<size_t>(step));
 			count = step;
 		}
 	}
@@ -524,7 +525,7 @@ Region ContentContainer::BoundingBoxForLayout(const LayoutRegions& layoutRgns) c
 		}
 		return r;
 	}
-	
+
 	return Region();
 }
 
@@ -577,7 +578,7 @@ void ContentContainer::LayoutContentsFrom(ContentList::const_iterator it)
 		ContentLayout::iterator i = std::find(layout.begin(), layout.end(), *clearit);
 		if (i != layout.end()) {
 			layoutPoint.reset(); // reset cached layoutPoint
-			// since 'layout' is sorted alongsize 'contents' we should be able clear everyting following 'i' and bail
+			// since 'layout' is sorted alongsize 'contents' we should be able clear everything following 'i' and bail
 			layout.erase(i, layout.end());
 			break;
 		}
@@ -585,12 +586,12 @@ void ContentContainer::LayoutContentsFrom(ContentList::const_iterator it)
 
 	Size contentBounds = Dimensions();
 	Region layoutFrame = Region(Point(), contentBounds);
-	if (Flags()&RESIZE_WIDTH) {
+	if (Flags() & RESIZE_WIDTH) {
 		layoutFrame.w = SHRT_MAX;
 	} else {
 		layoutFrame.w -= margin.left + margin.right;
 	}
-	if (Flags()&RESIZE_HEIGHT) {
+	if (Flags() & RESIZE_HEIGHT) {
 		layoutFrame.h = SHRT_MAX;
 	} else {
 		layoutFrame.h -= margin.top + margin.bottom;
@@ -626,14 +627,14 @@ void ContentContainer::LayoutContentsFrom(ContentList::const_iterator it)
 		exContent = content;
 
 		ieDword flags = Flags();
-		if (flags&(RESIZE_HEIGHT|RESIZE_WIDTH)) {
+		if (flags & (RESIZE_HEIGHT | RESIZE_WIDTH)) {
 			Region bounds = BoundingBoxForLayout(rgns);
 			bounds.w += margin.left + margin.right;
 			bounds.h += margin.top + margin.bottom;
-			
-			if (flags&RESIZE_HEIGHT)
+
+			if (flags & RESIZE_HEIGHT)
 				contentBounds.h = (bounds.y + bounds.h > contentBounds.h) ? bounds.y + bounds.h : contentBounds.h;
-			if (flags&RESIZE_WIDTH)
+			if (flags & RESIZE_WIDTH)
 				contentBounds.w = (bounds.x + bounds.w > contentBounds.w) ? bounds.x + bounds.w : contentBounds.w;
 		}
 	}
@@ -660,10 +661,10 @@ void ContentContainer::DeleteContentsInRect(const Region& exclusion)
 		delete RemoveContent(content, false);
 	}
 
-	if (Flags()&RESIZE_HEIGHT) {
+	if (Flags() & RESIZE_HEIGHT) {
 		frame.h = 0;
 	}
-	if (Flags()&RESIZE_WIDTH) {
+	if (Flags() & RESIZE_WIDTH) {
 		frame.w = 0;
 	}
 	// TODO: we could optimize this to only layout content after exclusion.y
@@ -671,8 +672,8 @@ void ContentContainer::DeleteContentsInRect(const Region& exclusion)
 }
 
 
-TextContainer::TextContainer(const Region& frame, Font* fnt)
-	: ContentContainer(frame), font(fnt)
+TextContainer::TextContainer(const Region& frame, Holder<Font> fnt)
+	: ContentContainer(frame), font(std::move(fnt))
 {
 }
 
@@ -686,7 +687,7 @@ void TextContainer::AppendText(String text)
 	AppendText(std::move(text), nullptr, colors);
 }
 
-void TextContainer::AppendText(String text, const Font* fnt, const Font::PrintColors* cols)
+void TextContainer::AppendText(String text, const Holder<Font> fnt, const Font::PrintColors* cols)
 {
 	size_t len = text.length();
 	if (len) {
@@ -717,7 +718,7 @@ void TextContainer::ClearColors()
 void TextContainer::SetColors(const Color& fg, const Color& bg)
 {
 	ClearColors();
-	colors = new Font::PrintColors {fg, bg};
+	colors = new Font::PrintColors { fg, bg };
 }
 
 String TextContainer::Text() const
@@ -733,10 +734,10 @@ String TextContainer::TextFrom(const Content* content) const
 String TextContainer::TextFrom(ContentList::const_iterator it) const
 {
 	if (it == contents.end()) {
-		return L""; // must bail or things will get screwed up!
+		return u""; // must bail or things will get screwed up!
 	}
 
-	// iterate all the content and pick out the TextSpans and concatonate them into a single string
+	// iterate all the content and pick out the TextSpans and concatenate them into a single string
 	String text;
 	for (; it != contents.end(); ++it) {
 		if (const TextSpan* textSpan = static_cast<TextSpan*>(*it)) {
@@ -754,17 +755,17 @@ void TextContainer::DrawSelf(const Region& drawFrame, const Region& clip)
 	if (layout.empty() && Editable()) {
 		Holder<Sprite2D> cursor = core->GetCursorSprite();
 		Point p(drawFrame.x + margin.left, drawFrame.y + margin.top + cursor->Frame.y);
-		core->GetVideoDriver()->BlitSprite(cursor, p);
+		VideoDriver->BlitSprite(cursor, p);
 	}
 }
 
 LayoutRegions::const_iterator
-TextContainer::FindCursorRegion(const Layout& layout) const
+	TextContainer::FindCursorRegion(const Layout& layout) const
 {
 	auto end = layout.regions.end();
 	for (auto it = layout.regions.begin(); it != end; ++it) {
 		const TextLayout& tlrgn = static_cast<const TextLayout&>(**it);
-		
+
 		if (tlrgn.beginCharIdx <= cursorPos && tlrgn.endCharIdx >= cursorPos) {
 			return it;
 		}
@@ -773,19 +774,19 @@ TextContainer::FindCursorRegion(const Layout& layout) const
 }
 
 void TextContainer::DrawContents(const Layout& layout, Point dp)
-{	
+{
 	ContentContainer::DrawContents(layout, dp);
 
-	const TextSpan* ts = (const TextSpan*)layout.content;
+	const TextSpan* ts = (const TextSpan*) layout.content;
 	const String& text = ts->Text();
 	size_t textLength = ts->Text().length();
 
 	if (Editable() && printPos <= cursorPos && printPos + textLength >= cursorPos) {
-		const Font* printFont = ts->LayoutFont();
-		
+		auto printFont = ts->LayoutFont();
+
 		auto it = FindCursorRegion(layout);
 		if (it != layout.regions.end()) {
-			auto cursorRegion = static_cast<const TextLayout&>(**it);
+			const auto& cursorRegion = static_cast<const TextLayout&>(**it);
 			size_t begin = cursorRegion.beginCharIdx;
 			const Region& rect = cursorRegion.region;
 			cursorPoint = rect.origin;
@@ -795,7 +796,7 @@ void TextContainer::DrawContents(const Layout& layout, Point dp)
 
 		Holder<Sprite2D> cursor = core->GetCursorSprite();
 		dp.y += cursor->Frame.y;
-		core->GetVideoDriver()->BlitSprite(cursor, cursorPoint + dp);
+		VideoDriver->BlitSprite(cursor, cursorPoint + dp);
 	}
 	printPos += textLength;
 }
@@ -819,8 +820,8 @@ void TextContainer::MoveCursorToPoint(const Point& p)
 	if (layout) {
 		const TextSpan* ts = (const TextSpan*) layout->content;
 		const String& text = ts->Text();
-		const Font* printFont = ts->LayoutFont();
-		Font::StringSizeMetrics metrics = {Size(0,0), 0, 0, true};
+		auto printFont = ts->LayoutFont();
+		Font::StringSizeMetrics metrics = { Size(0, 0), 0, 0, true };
 		size_t numChars = 0;
 
 		for (const auto& lrgn : layout->regions) {
@@ -856,12 +857,12 @@ void TextContainer::MoveCursorToPoint(const Point& p)
 
 void TextContainer::DidFocus()
 {
-	core->GetVideoDriver()->StartTextInput();
+	VideoDriver->StartTextInput();
 }
 
 void TextContainer::DidUnFocus()
 {
-	core->GetVideoDriver()->StopTextInput();
+	VideoDriver->StopTextInput();
 }
 
 bool TextContainer::OnMouseDown(const MouseEvent& me, unsigned short /*Mod*/)
@@ -884,7 +885,7 @@ bool TextContainer::OnKeyPress(const KeyboardEvent& key, unsigned short /*Mod*/)
 	if (Editable() == false)
 		return false;
 
-	core->GetVideoDriver()->StartTextInput();
+	VideoDriver->StartTextInput();
 
 	switch (key.keycode) {
 		case GEM_HOME:
@@ -912,12 +913,12 @@ bool TextContainer::OnKeyPress(const KeyboardEvent& key, unsigned short /*Mod*/)
 				if (layout) {
 					it = FindCursorRegion(*layout);
 					assert(it != layout->regions.end());
-					auto cursorRegion = static_cast<const TextLayout&>(**it);
+					const auto& cursorRegion = static_cast<const TextLayout&>(**it);
 					offset = cursorPos - cursorRegion.beginCharIdx;
 				} else { // cursor is at end of text
 					return true;
 				}
-				
+
 				if (key.keycode == GEM_UP) {
 					if (it == layout->regions.begin()) {
 						return true;
@@ -929,9 +930,9 @@ bool TextContainer::OnKeyPress(const KeyboardEvent& key, unsigned short /*Mod*/)
 					}
 					it++;
 				}
-				
+
 				if (it != layout->regions.end()) {
-					auto cursorRegion = static_cast<const TextLayout&>(**it);
+					const auto& cursorRegion = static_cast<const TextLayout&>(**it);
 					size_t length = cursorRegion.endCharIdx - cursorRegion.beginCharIdx;
 					cursorPos = cursorRegion.beginCharIdx + std::min(offset, length);
 					MarkDirty();
@@ -960,7 +961,7 @@ bool TextContainer::OnKeyPress(const KeyboardEvent& key, unsigned short /*Mod*/)
 void TextContainer::OnTextInput(const TextEvent& te)
 {
 	InsertText(te.text);
-	core->GetVideoDriver()->StartTextInput();
+	VideoDriver->StartTextInput();
 }
 
 // move cursor to beginning of text
