@@ -21,9 +21,9 @@
 #define __GemRB__Tooltip__
 
 #include "Region.h"
-#include "Video/Video.h"
 
 #include "GUI/TextSystem/Font.h"
+#include "Video/Video.h"
 
 namespace GemRB {
 
@@ -51,19 +51,19 @@ public:
 
 class Tooltip {
 	String text;
-	Font* font;
+	Holder<Font> font;
 	std::unique_ptr<TooltipBackground> background;
 	Size textSize;
 	Font::PrintColors colors;
 
 public:
-	Tooltip(const String& s, Font* fnt, const Font::PrintColors& cols, TooltipBackground* bg);
+	Tooltip(const String& s, Holder<Font> fnt, const Font::PrintColors& cols, TooltipBackground* bg);
 
 	void SetText(const String& s);
 	Size TextSize() const;
 
 	void Draw(const Point& p) const;
-	
+
 	// !!! Keep this synchronized with GUIDefines.py !!!
 	// used for calculating the tooltip delay limit and the real tooltip delay
 	static constexpr int DELAY_FACTOR = 250;
