@@ -19,11 +19,13 @@
 
 #include "View.h"
 
+#include "Debug.h"
+#include "Interface.h"
+#include "Sprite2D.h"
+
 #include "GUI/GUIScriptInterface.h"
 #include "GUI/ScrollBar.h"
 #include "GUI/TextSystem/Font.h"
-#include "Interface.h"
-#include "Sprite2D.h"
 #include "Video/Video.h"
 
 #include <typeinfo>
@@ -33,10 +35,11 @@
 namespace GemRB {
 
 View::DragOp::DragOp(View* v, Holder<Sprite2D> cursor)
-: dragView(v), cursor(std::move(cursor))
+	: dragView(v), cursor(std::move(cursor))
 {}
 
-View::DragOp::~DragOp() {
+View::DragOp::~DragOp()
+{
 	dragView->CompleteDragOperation(*this);
 }
 
@@ -47,7 +50,7 @@ View::View(const Region& frame)
 View::~View()
 {
 	ClearScriptingRefs();
-	
+
 	if (superView) {
 		superView->RemoveSubview(this);
 	}
@@ -71,57 +74,40 @@ void View::SetCursor(Holder<Sprite2D> c)
 	cursor = std::move(c);
 }
 
+View* View::GetEventProxy() const
+{
+	return eventProxy;
+}
+
 void View::SetEventProxy(View* proxy)
 {
 	while (proxy && proxy->eventProxy) {
 		proxy = proxy->eventProxy;
 	}
-	
+
 	eventProxy = proxy;
 }
 
 // TODO: while GemRB does support nested subviews, it does not (fully) support overlapping subviews (same superview, intersecting frame)
 // expect weird things to happen with them
 // this method takes the dirty region so the framework exists, but currently this just invalidates any intersecting subviews
-void View::MarkDirty(const Region* rgn)
+void View::MarkDirty(const Region* /*rgn*/)
 {
 	// TODO: we could implement partial redraws by storing the dirty region
 	// not much to gain at the moment, however
 
-	if (dirty) return;
-
 	dirty = true;
-
-	if (superView && !IsOpaque()) {
-		superView->DirtyBGRect(frame);
-	}
-
-	for (const auto& view : subViews) {
-		if (rgn) {
-			Region intersect = view->frame.Intersect(*rgn);
-			const Size& idims = intersect.size;
-			if (!idims.IsInvalid()) {
-				Point p = view->ConvertPointFromSuper(intersect.origin);
-				Region r = Region(p, idims);
-				view->MarkDirty(&r);
-			}
-		} else {
-			Point p = view->ConvertPointFromSuper(Point());
-			Region r = Region(p, Dimensions());
-			view->MarkDirty(&r);
-		}
-	}
 }
 
 void View::MarkDirty()
 {
-	return MarkDirty(NULL);
+	return MarkDirty(nullptr);
 }
 
 bool View::NeedsDraw() const
 {
 	// cull anything that can't be seen
-	if (frame.size.IsInvalid() || (flags&Invisible)) return false;
+	if (frame.size.IsInvalid() || (flags & Invisible)) return false;
 
 	// check ourselves
 	if (dirty || IsAnimated()) {
@@ -132,22 +118,39 @@ bool View::NeedsDraw() const
 	return false;
 }
 
-bool View::NeedsDrawRecursive() const
+void View::InvalidateDirtySubviewRegions()
 {
-	if (NeedsDraw()) {
-		return true;
+	for (const View* subview : subViews) {
+		// FIXME: this is the real code we should be using (if we supported dirty subrects)
+		// for (const Region& rgn : subview->DirtySuperViewRegions()) {
+		//  	MarkDirty(&rgn);
+		// }
+		// since we dont, just MarkDirty() and bail if we have any
+		if (!subview->DirtySuperViewRegions().empty()) {
+			MarkDirty();
+			return;
+		}
 	}
-	
-	if (superView) {
-		return superView->NeedsDrawRecursive();
+}
+
+void View::InvalidateSubviews(const Region& rgn) const
+{
+	if (rgn.size.IsInvalid()) {
+		return;
+	}
+	for (View* subview : subViews) {
+		Region r = rgn.Intersect(subview->frame);
+		if (!r.size.IsInvalid()) {
+			r.origin = subview->ConvertPointFromSuper(r.origin);
+			subview->MarkDirty(&r);
+			subview->InvalidateSubviews(r);
+		}
 	}
-	
-	return false;
 }
 
 bool View::IsVisible() const
 {
-	bool isVisible = !(flags&Invisible);
+	bool isVisible = !(frame.size.IsInvalid() || (flags & Invisible));
 	if (superView && isVisible) {
 		return superView->IsVisible();
 	}
@@ -156,7 +159,7 @@ bool View::IsVisible() const
 
 bool View::IsDisabledCursor() const
 {
-	if (core->InDebugMode(ID_VIEWS)) {
+	if (InDebugMode(DebugMode::VIEWS)) {
 		return IsDisabled();
 	}
 	return false;
@@ -164,156 +167,159 @@ bool View::IsDisabledCursor() const
 
 bool View::IsReceivingEvents() const
 {
-	bool getEvents = !(flags&(IgnoreEvents|Invisible|Disabled));
+	bool getEvents = !(flags & (IgnoreEvents | Invisible | Disabled));
 	if (superView && getEvents) {
 		return superView->IsReceivingEvents();
 	}
 	return getEvents;
 }
 
-void View::DirtyBGRect(const Region& r, bool force) noexcept
+Regions View::DirtySuperViewRegions() const
 {
-	// no need to draw the parent BG for opaque views
-	if (superView && !IsOpaque()) {
-		Region rgn = frame.Intersect(Region(ConvertPointToSuper(r.origin), r.size));
-		superView->DirtyBGRect(rgn, force);
+	// since we dont support overlapping views...
+	// if we are opaque we cover everything and dont care about the superview
+	// if we arent but we need to redraw then we simply report our entire area
+
+	if (IsOpaque() || !IsVisible()) {
+		return {};
 	}
 
-	// if we are going to draw the entire BG, no need to compute and store this
-	if (!force && NeedsDrawRecursive())
-		return;
+	if (NeedsDraw()) {
+		return { frame };
+	}
 
-	// do we want to intersect this too?
-	//Region bgRgn = Region(background->Frame.x, background->Frame.y, background->Frame.w, background->Height);
-	Region clip(Point(), Dimensions());
-	Region dirtyRect = r.Intersect(clip);
-	dirtyBGRects.push_back(dirtyRect);
-	
-	MarkDirty(&dirtyRect);
+	Regions dirtyAreas;
+	for (const View* subview : subViews) {
+		Regions r = subview->DirtySuperViewRegions();
+		dirtyAreas.reserve(dirtyAreas.size() + r.size());
+		std::transform(r.begin(), r.end(), std::back_inserter(dirtyAreas), [this](const Region& rgn) {
+			return ConvertRegionToSuper(rgn).Intersect(frame);
+		});
+	}
+	return dirtyAreas;
 }
 
-void View::DrawSubviews()
+void View::DrawSubviews() const
 {
 	for (View* subview : subViews) {
 		subview->Draw();
-		if (subview->IsAnimated() && !subview->IsOpaque()) {
-			DirtyBGRect(subview->frame, true);
-		}
 	}
 }
 
 Region View::DrawingFrame() const
 {
-	return Region(ConvertPointToWindow(Point(0,0)), Dimensions());
+	return Region(ConvertPointToWindow(Point(0, 0)), Dimensions());
+}
+
+bool View::HasBackground() const
+{
+	return backgroundColor.a > 0 || background;
 }
 
 void View::DrawBackground(const Region* rgn) const
 {
-	Video* video = core->GetVideoDriver();
 	if (backgroundColor.a > 0) {
 		if (rgn) {
-			Point p = ConvertPointToWindow(rgn->origin);
-			video->DrawRect(Region(p, rgn->size), backgroundColor, true);
+			Region r = ConvertRegionToWindow(*rgn);
+			VideoDriver->DrawRect(r, backgroundColor, true);
 		} else if (window) {
 			assert(superView);
-			Point p = superView->ConvertPointToWindow(frame.origin);
-			video->DrawRect(Region(p, Dimensions()), backgroundColor, true);
+			Region r = superView->ConvertRegionToWindow(frame);
+			VideoDriver->DrawRect(r, backgroundColor, true);
 		} else {
-			// FIXME: this is a Window and we need this hack becasue Window::WillDraw() changed the coordinate system
-			video->DrawRect(Region(Point(), Dimensions()), backgroundColor, true);
+			// FIXME: this is a Window and we need this hack because Window::WillDraw() changed the coordinate system
+			VideoDriver->DrawRect(Region(Point(), Dimensions()), backgroundColor, true);
 		}
 	}
-		
+
 	// NOTE: technically it's possible for the BG to be smaller than the view
 	// if this were to happen then the areas outside the BG wouldnt get redrawn
-	// you should make sure the backgound color is set to something suitable in those cases
+	// you should make sure the background color is set to something suitable in those cases
 
 	if (background) {
 		if (rgn) {
 			Region intersect = rgn->Intersect(background->Frame);
 			Point screenPt = ConvertPointToWindow(intersect.origin);
 			Region toClip(screenPt, intersect.size);
-			video->BlitSprite(background, intersect, std::move(toClip), BlitFlags::BLENDED);
+			VideoDriver->BlitSprite(background, intersect, toClip, BlitFlags::BLENDED);
 		} else {
 			Point dp = ConvertPointToWindow(Point(background->Frame.x, background->Frame.y));
-			video->BlitSprite(background, dp);
+			VideoDriver->BlitSprite(background, dp);
 		}
 	}
 }
 
 void View::Draw()
 {
-	if (flags&Invisible) return;
+	TRACY(ZoneScoped);
+	if (flags & Invisible) return;
 
-	Video* video = core->GetVideoDriver();
-	const Region clip = video->GetScreenClip();
+	const Region clip = VideoDriver->GetScreenClip();
 	const Region& drawFrame = DrawingFrame();
 	const Region& intersect = clip.Intersect(drawFrame);
 	if (intersect.size.IsInvalid()) return; // outside the window/screen
 
 	// clip drawing to the view bounds, then restore after drawing
-	video->SetScreenClip(&intersect);
+	VideoDriver->SetScreenClip(&intersect);
 
-	bool needsDraw = NeedsDrawRecursive(); // check this before WillDraw else an animation update might get missed
+	InvalidateDirtySubviewRegions();
+
+	bool needsDraw = NeedsDraw(); // check this before WillDraw else an animation update might get missed
 	// notify subclasses that drawing is about to happen. could pass the rects too, but no need ATM.
 	WillDraw(drawFrame, intersect);
 
 	if (needsDraw) {
-		DrawBackground(NULL);
+		InvalidateSubviews(ConvertRegionFromSuper(frame));
+		DrawBackground(nullptr);
 		DrawSelf(drawFrame, intersect);
-	} else {
-		Regions::iterator it = dirtyBGRects.begin();
-		while (it != dirtyBGRects.end()) {
-			DrawBackground(&(*it++));
-		}
 	}
 
-	dirtyBGRects.clear();
-
 	// always call draw on subviews because they can be dirty without us
 	DrawSubviews();
+	// Overlays like when disabled
+	if (needsDraw) {
+		DrawAfterSubviews(drawFrame, intersect);
+	}
 	DidDraw(drawFrame, intersect); // notify subclasses that drawing finished
 	dirty = false;
 
-	if (core->InDebugMode(ID_VIEWS)) {
+	if (InDebugMode(DebugMode::VIEWS)) {
 		const Window* win = GetWindow();
 		if (win == nullptr) {
-			video->DrawRect(drawFrame, ColorBlue, false);
+			VideoDriver->DrawRect(drawFrame, ColorBlue, false);
 			debuginfo = EventMgr::ModState(GEM_MOD_SHIFT);
 		} else if (NeedsDraw()) {
-			video->DrawRect(drawFrame, ColorRed, false);
+			VideoDriver->DrawRect(drawFrame, ColorRed, false);
 		} else {
-			video->DrawRect(drawFrame, ColorGreen, false);
+			VideoDriver->DrawRect(drawFrame, ColorGreen, false);
 		}
 		debuginfo = debuginfo || EventMgr::ModState(GEM_MOD_CTRL);
 
 		if (debuginfo) {
 			const ViewScriptingRef* ref = GetScriptingRef();
 			if (ref) {
-				const Font* fnt = core->GetTextFont();
+				auto fnt = core->GetTextFont();
 				ScriptingId id = ref->Id;
 				id &= 0x00000000ffffffff; // control id is lower 32bits
 
 				std::string formatted = fmt::format("id: {}  grp: {}  \nflgs: {}\ntype:{}", id, ref->ScriptingGroup(), flags, typeid(*this).name());
-				const String* string = StringFromCString(formatted.c_str());
-				assert(string);
-				
+				const String& string = StringFromASCII(formatted);
+
 				Region r = drawFrame;
 				r.w = win ? win->Frame().w - r.x : Frame().w - r.x;
-				Font::StringSizeMetrics metrics = {r.size, 0, 0, true};
-				fnt->StringSize(*string, &metrics);
+				Font::StringSizeMetrics metrics = { r.size, 0, 0, true };
+				fnt->StringSize(string, &metrics);
 				r.h = metrics.size.h;
 				r.w = metrics.size.w;
-				video->SetScreenClip(nullptr);
-				video->DrawRect(r, ColorBlack, true);
-				fnt->Print(r, *string, IE_FONT_ALIGN_TOP|IE_FONT_ALIGN_LEFT, {ColorWhite, ColorBlack});
-				delete string;
+				VideoDriver->SetScreenClip(nullptr);
+				VideoDriver->DrawRect(r, ColorBlack, true);
+				fnt->Print(r, string, IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_LEFT, { ColorWhite, ColorBlack });
 			}
 		}
 	}
 
 	// restore the screen clip
-	video->SetScreenClip(&clip);
+	VideoDriver->SetScreenClip(&clip);
 }
 
 Point View::ConvertPointToSuper(const Point& p) const
@@ -403,7 +409,7 @@ Region View::ConvertRegionFromScreen(Region r) const
 void View::AddSubviewInFrontOfView(View* front, const View* back)
 {
 	if (front == nullptr) return;
-	
+
 	// remember, being "in front" means coming after in the list
 	auto it = subViews.begin();
 	if (back != nullptr) {
@@ -421,19 +427,19 @@ void View::AddSubviewInFrontOfView(View* front, const View* back)
 		if (super != nullptr) {
 			front->superView->RemoveSubview(front);
 		}
-		
+
 		subViews.insert(it, front);
 	}
 
 	front->superView = this;
 	front->MarkDirty(); // must redraw the control now
-	
+
 	View* ancestor = this;
 	do {
 		ancestor->SubviewAdded(front, this);
 		ancestor = ancestor->superView;
 	} while (ancestor);
-	
+
 	front->AddedToView(this);
 }
 
@@ -450,17 +456,17 @@ View* View::RemoveSubview(const View* view) noexcept
 	View* subView = *it;
 	assert(subView == view);
 	subViews.erase(it);
-	DirtyBGRect(subView->Frame());
+	MarkDirty();
 
 	subView->superView = NULL;
 	subView->RemovedFromView(this);
-	
+
 	View* ancestor = this;
 	do {
 		ancestor->SubviewRemoved(subView, this);
 		ancestor = ancestor->superView;
 	} while (ancestor);
-	
+
 	return subView;
 }
 
@@ -472,7 +478,7 @@ View* View::RemoveFromSuperview()
 	}
 	return super;
 }
-	
+
 void View::AddedToWindow(Window* newwin)
 {
 	window = newwin;
@@ -486,7 +492,7 @@ void View::AddedToView(View* view)
 	Window* newwin = view->GetWindow();
 	if (newwin == NULL)
 		newwin = dynamic_cast<Window*>(view);
-	
+
 	if (newwin != window) {
 		AddedToWindow(newwin);
 	}
@@ -502,7 +508,7 @@ bool View::IsOpaque() const
 	if (backgroundColor.a == 0xff) {
 		return true;
 	}
-	
+
 	return background && background->HasTransparency() == false;
 }
 
@@ -620,10 +626,10 @@ void View::SetFrameOrigin(const Point& p)
 {
 	Point oldP = frame.origin;
 	if (oldP == p) return;
-	
-	MarkDirty(); // refresh the old position in the superview
+
 	frame.origin = p;
-	
+
+	MarkDirty();
 	OriginChanged(oldP);
 }
 
@@ -632,7 +638,6 @@ void View::SetFrameSize(const Size& s)
 	const Size oldSize = frame.size;
 	if (oldSize == s) return;
 
-	MarkDirty(); // refresh the old position in the superview
 	frame.w = std::max(0, s.w);
 	frame.h = std::max(0, s.h);
 
@@ -659,7 +664,7 @@ bool View::SetFlags(unsigned int arg_flags, BitOp opcode)
 
 	return ret;
 }
-	
+
 bool View::SetAutoResizeFlags(unsigned short arg_flags, BitOp opcode)
 {
 	return SetBits(autoresizeFlags, arg_flags, opcode);
@@ -675,23 +680,23 @@ void View::SetTooltip(const String& string)
 // otherwise attempts to handle the event by calling "OnEvent"
 // if the event is unhandled, bubble it up to the superview
 #define HandleEvent1(meth, p1) \
-HandleEvent(meth(p1))
+	HandleEvent(meth(p1))
 
 #define HandleEvent2(meth, p1, p2) \
-HandleEvent(meth(p1, p2))
-	
+	HandleEvent(meth(p1, p2))
+
 #define HandleEvent(meth) \
-if (eventProxy) { \
-	eventProxy->On ## meth; \
-	return; \
-} \
-\
-if ((flags&(Disabled|IgnoreEvents)) == 0) { \
-	bool handled = On ## meth; \
-	if (handled == false && superView) { \
-		superView->meth; \
+	if (eventProxy) { \
+		eventProxy->On##meth; \
+		return; \
 	} \
-}
+\
+	if ((flags & (Disabled | IgnoreEvents)) == 0) { \
+		bool handled = On##meth; \
+		if (handled == false && superView) { \
+			superView->meth; \
+		} \
+	}
 
 bool View::KeyPress(const KeyboardEvent& key, unsigned short mod)
 {
@@ -719,7 +724,7 @@ void View::TextInput(const TextEvent& te)
 
 void View::MouseEnter(const MouseEvent& me, const DragOp* op)
 {
-	if (core->InDebugMode(ID_VIEWS)) {
+	if (InDebugMode(DebugMode::VIEWS)) {
 		debuginfo = true;
 	}
 
@@ -728,7 +733,7 @@ void View::MouseEnter(const MouseEvent& me, const DragOp* op)
 
 void View::MouseLeave(const MouseEvent& me, const DragOp* op)
 {
-	if (core->InDebugMode(ID_VIEWS)) {
+	if (InDebugMode(DebugMode::VIEWS)) {
 		debuginfo = false;
 		MarkDirty();
 	}
@@ -758,8 +763,7 @@ void View::MouseUp(const MouseEvent& me, unsigned short mod)
 
 void View::MouseWheelScroll(const Point& delta)
 {
-	if ((eventProxy && !eventProxy->IsPerPixelScrollable())
-		|| (eventProxy == nullptr && !IsPerPixelScrollable())) {
+	if ((eventProxy && !eventProxy->IsPerPixelScrollable()) || (eventProxy == nullptr && !IsPerPixelScrollable())) {
 		Point scaledDelta;
 		int speed = core->GetMouseScrollSpeed();
 
@@ -768,13 +772,13 @@ void View::MouseWheelScroll(const Point& delta)
 		} else if (delta.x > 0) {
 			scaledDelta.x = std::max<int>(delta.x / speed, 1);
 		}
-		
+
 		if (delta.y < 0) {
 			scaledDelta.y = std::min<int>(delta.y / speed, -1);
 		} else if (delta.y > 0) {
 			scaledDelta.y = std::max<int>(delta.y / speed, 1);
 		}
-		
+
 		HandleEvent1(MouseWheelScroll, scaledDelta);
 	} else {
 		HandleEvent1(MouseWheelScroll, delta);
@@ -856,27 +860,22 @@ bool View::OnControllerAxis(const ControllerEvent& ce)
 
 bool View::OnControllerButtonDown(const ControllerEvent& ce)
 {
-	if (ce.button == CONTROLLER_BUTTON_A
-		|| ce.button == CONTROLLER_BUTTON_B
-		|| ce.button == CONTROLLER_BUTTON_LEFTSTICK)
-	{
+	if (ce.button == CONTROLLER_BUTTON_A || ce.button == CONTROLLER_BUTTON_B || ce.button == CONTROLLER_BUTTON_LEFTSTICK) {
 		MouseEvent me = MouseEventFromController(ce, true);
 		// TODO: we might want to add modifiers for "trigger" buttons
 		return OnMouseDown(me, 0);
 	}
-	
-	if (ce.button == CONTROLLER_BUTTON_START)
-	{
+
+	if (ce.button == CONTROLLER_BUTTON_START) {
 		core->TogglePause();
 		return true;
 	}
-	
-	if (ce.button == CONTROLLER_BUTTON_GUIDE)
-	{
-		core->GetVideoDriver()->StartTextInput();
+
+	if (ce.button == CONTROLLER_BUTTON_GUIDE) {
+		VideoDriver->StartTextInput();
 		return true;
 	}
-	
+
 	// TODO: we might want to add modifiers for "trigger" buttons
 	KeyboardEvent ke = KeyEventFromController(ce);
 	return OnKeyPress(ke, 0);
@@ -884,15 +883,12 @@ bool View::OnControllerButtonDown(const ControllerEvent& ce)
 
 bool View::OnControllerButtonUp(const ControllerEvent& ce)
 {
-	if (ce.button == CONTROLLER_BUTTON_A
-		|| ce.button == CONTROLLER_BUTTON_B
-		|| ce.button == CONTROLLER_BUTTON_LEFTSTICK)
-	{
+	if (ce.button == CONTROLLER_BUTTON_A || ce.button == CONTROLLER_BUTTON_B || ce.button == CONTROLLER_BUTTON_LEFTSTICK) {
 		MouseEvent me = MouseEventFromController(ce, false);
 		// TODO: we might want to add modifiers for "trigger" buttons
 		return OnMouseUp(me, 0);
 	}
-	
+
 	// TODO: we might want to add modifiers for "trigger" buttons
 	KeyboardEvent ke = KeyEventFromController(ce);
 	return OnKeyRelease(ke, 0);
@@ -923,7 +919,7 @@ const ViewScriptingRef* View::RemoveScriptingRef(const ViewScriptingRef* ref)
 	static ScriptingId id = 0;
 	return ReplaceScriptingRef(ref, id++, "__DEL__");
 }
-	
+
 void View::ClearScriptingRefs() noexcept
 {
 	for (auto rit = scriptingRefs.begin(); rit != scriptingRefs.end();) {
@@ -935,12 +931,12 @@ void View::ClearScriptingRefs() noexcept
 		rit = scriptingRefs.erase(rit);
 	}
 }
-	
+
 ViewScriptingRef* View::CreateScriptingRef(ScriptingId id, ScriptingGroup_t group)
 {
 	return new ViewScriptingRef(this, id, group);
 }
-	
+
 const ViewScriptingRef* View::AssignScriptingRef(ScriptingId id, const ScriptingGroup_t& group)
 {
 	ViewScriptingRef* ref = CreateScriptingRef(id, group);
@@ -958,10 +954,10 @@ const ViewScriptingRef* View::GetScriptingRef(ScriptingId id, ScriptingGroup_t g
 	auto it = std::find_if(scriptingRefs.begin(), scriptingRefs.end(), [&](const ViewScriptingRef* ref) {
 		return ref->Id == id && ref->ScriptingGroup() == group;
 	});
-	
+
 	return (it != scriptingRefs.end()) ? *it : nullptr;
 }
-	
+
 const ViewScriptingRef* View::GetScriptingRef() const
 {
 	if (scriptingRefs.empty()) {
