@@ -20,8 +20,10 @@
 
 #include "Window.h"
 
+#include "Debug.h"
 #include "Interface.h"
 #include "ScrollBar.h"
+#include "WindowManager.h"
 
 #include "GUI/GUIScriptInterface.h"
 
@@ -48,8 +50,8 @@ void Window::Close()
 	if (eventHandlers[Closed]) {
 		eventHandlers[Closed](this);
 	}
-	
-	if (flags&DestroyOnClose) {
+
+	if (flags & DestroyOnClose) {
 		ClearScriptingRefs();
 		manager.CloseWindow(this);
 	} else {
@@ -135,23 +137,21 @@ void Window::SizeChanged(const Size& /*oldSize*/)
 
 void Window::FlagsChanged(unsigned int oldflags)
 {
-	if ((flags&AlphaChannel) != (oldflags&AlphaChannel)) {
+	if ((flags & AlphaChannel) != (oldflags & AlphaChannel)) {
 		RecreateBuffer();
 	}
 
-	if ((flags&View::Invisible) && focusView) {
+	if ((flags & View::Invisible) && focusView) {
 		focusView->DidUnFocus();
-	} else if ((oldflags&View::Invisible) && focusView) {
+	} else if ((oldflags & View::Invisible) && focusView) {
 		focusView->DidFocus();
 	}
 }
 
 void Window::RecreateBuffer()
 {
-	Video* video = core->GetVideoDriver();
-
-	Video::BufferFormat fmt = (flags&AlphaChannel) ? Video::BufferFormat::DISPLAY_ALPHA : Video::BufferFormat::DISPLAY;
-	backBuffer = video->CreateBuffer(frame, fmt);
+	Video::BufferFormat fmt = (flags & AlphaChannel) ? Video::BufferFormat::DISPLAY_ALPHA : Video::BufferFormat::DISPLAY;
+	backBuffer = VideoDriver->CreateBuffer(frame, fmt);
 
 	// the entire window must be invalidated, because the new buffer is blank
 	// TODO: we *could* optimize this to instead blit the old buffer to the new one
@@ -162,46 +162,57 @@ const VideoBufferPtr& Window::DrawWithoutComposition()
 {
 	View::Draw();
 
-	core->GetVideoDriver()->PopDrawingBuffer();
+	VideoDriver->PopDrawingBuffer();
 	return backBuffer;
 }
 
+void Window::DrawAfterSubviews(const Region& /*drawFrame*/, const Region& /*clip*/)
+{
+	if (IsDisabled()) {
+		Region winrgn(Point(), Dimensions());
+		VideoDriver->DrawRect(winrgn, ColorBlack, true, BlitFlags::HALFTRANS | BlitFlags::BLENDED);
+	}
+}
+
 void Window::WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 {
 	backBuffer->SetOrigin(frame.origin);
-	core->GetVideoDriver()->PushDrawingBuffer(backBuffer);
+	VideoDriver->PushDrawingBuffer(backBuffer);
 }
 
 void Window::DidDraw(const Region& /*drawFrame*/, const Region& /*clip*/)
 {
-	if (!core->InDebugMode(ID_WINDOWS)) return;
+	if (!InDebugMode(DebugMode::WINDOWS)) return;
+
+	VideoDriver->SetScreenClip(nullptr);
 
-	Video* video = core->GetVideoDriver();
-	video->SetScreenClip(nullptr);
-	
 	auto lock = manager.DrawHUD();
 
 	if (focusView) {
 		Region r = focusView->ConvertRegionToScreen(Region(Point(), focusView->Dimensions()));
-		video->DrawRect(r, ColorWhite, false);
+		VideoDriver->DrawRect(r, ColorWhite, false);
 	}
-	
+
 	if (hoverView) {
 		Region r = hoverView->ConvertRegionToScreen(Region(Point(), hoverView->Dimensions()));
 		r.ExpandAllSides(-5);
-		video->DrawRect(r, ColorBlue, false);
+		VideoDriver->DrawRect(r, ColorBlue, false);
 	}
-	
+
 	if (trackingView) {
 		Region r = trackingView->ConvertRegionToScreen(Region(Point(), trackingView->Dimensions()));
 		r.ExpandAllSides(-10);
-		video->DrawRect(r, ColorRed, false);
+		VideoDriver->DrawRect(r, ColorRed, false);
 	}
 }
 
 void Window::Focus()
 {
-	manager.FocusWindow(this);
+	if (!HasFocus()) {
+		manager.FocusWindow(this);
+	} else if (responderStack.empty()) {
+		FocusGained(); // fire the focus handler anyway
+	}
 }
 
 void Window::SetFocused(View* ctrl)
@@ -222,7 +233,7 @@ Holder<Sprite2D> Window::Cursor() const
 	if (drag) {
 		return drag->cursor;
 	}
-	
+
 	Holder<Sprite2D> cursor = ScrollView::Cursor();
 	if (cursor == NULL && hoverView) {
 		cursor = hoverView->Cursor();
@@ -240,6 +251,11 @@ bool Window::IsDisabledCursor() const
 	return isDisabled;
 }
 
+bool Window::IsReceivingEvents() const
+{
+	return !IsDisabled();
+}
+
 void Window::SetPosition(WindowPosition pos)
 {
 	// start at top left
@@ -247,16 +263,16 @@ void Window::SetPosition(WindowPosition pos)
 	Size screen = manager.ScreenSize();
 
 	// adjust horizontal
-	if ((pos&PosHmid) == PosHmid) {
+	if ((pos & PosHmid) == PosHmid) {
 		newFrame.x = (screen.w / 2) - (newFrame.w) / 2;
-	} else if (pos&PosRight) {
+	} else if (pos & PosRight) {
 		newFrame.x = screen.w - newFrame.w;
 	}
 
 	// adjust vertical
-	if ((pos&PosVmid) == PosVmid) {
+	if ((pos & PosVmid) == PosVmid) {
 		newFrame.y = (screen.h / 2) - (newFrame.h) / 2;
-	} else if (pos&PosBottom) {
+	} else if (pos & PosBottom) {
 		newFrame.y = screen.h - newFrame.h;
 	}
 	SetFrame(newFrame);
@@ -264,7 +280,7 @@ void Window::SetPosition(WindowPosition pos)
 
 void Window::RedrawControls(const Control::varname_t& VarName) const
 {
-	Control::value_t val = core->GetVariable(VarName.c_str(), Control::INVALID_VALUE);
+	Control::value_t val = core->GetDictionary().Get(VarName, Control::INVALID_VALUE);
 
 	for (auto ctrl : Controls) {
 		ctrl->UpdateState(VarName, val);
@@ -292,21 +308,20 @@ View* Window::TrySetFocus(View* target)
 	return newFocus;
 }
 
-bool Window::IsDragable() const
+bool Window::IsDraggable() const
 {
-	if (trackingView != this)
-	{
+	if (trackingView != this) {
 		return false;
 	}
 
-	return (flags&Draggable) ||
-	       (EventMgr::ModState(GEM_MOD_CTRL) && EventMgr::MouseButtonState(GEM_MB_ACTION));
+	return (flags & Draggable) ||
+		(EventMgr::ModState(GEM_MOD_CTRL) && EventMgr::MouseButtonState(GEM_MB_ACTION));
 }
 
 bool Window::HitTest(const Point& p) const
 {
 	bool hit = View::HitTest(p);
-	if (hit == false){
+	if (hit == false) {
 		// check the control list. we could make View::HitTest optionally recursive, but this is cheaper
 		for (const auto& ctrl : Controls) {
 			if (ctrl->IsVisible() && ctrl->View::HitTest(ctrl->ConvertPointFromWindow(p))) {
@@ -341,14 +356,14 @@ bool Window::SupportsAction(const ActionKey& key)
 void Window::DispatchMouseMotion(View* target, const MouseEvent& me)
 {
 	if (hoverView && target != hoverView) {
-			hoverView->MouseLeave(me, drag.get());
+		hoverView->MouseLeave(me, drag.get());
 	}
-	
+
 	if (target && target != hoverView) {
 		// must create the drag event before calling MouseEnter
 		target->MouseEnter(me, drag.get());
 	}
-	
+
 	if (trackingView && Distance(dragOrigin, me.Pos()) > EventMgr::mouseDragRadius) {
 		// tracking will eat this event
 		if (me.buttonStates) {
@@ -368,10 +383,8 @@ void Window::DispatchMouseMotion(View* target, const MouseEvent& me)
 void Window::DispatchMouseDown(View* target, const MouseEvent& me, unsigned short mod)
 {
 	assert(target);
-	
-	if (me.button == GEM_MB_ACTION
-		&& !(Flags() & View::IgnoreEvents)
-	) {
+
+	if (me.button == GEM_MB_ACTION && !(Flags() & View::IgnoreEvents)) {
 		Focus();
 	}
 
@@ -385,10 +398,10 @@ void Window::DispatchMouseDown(View* target, const MouseEvent& me, unsigned shor
 void Window::DispatchMouseUp(View* target, const MouseEvent& me, unsigned short mod)
 {
 	assert(target);
-	
+
 	if (drag && drag->dragView != target && target->AcceptsDragOperation(*drag)) {
-			drag->dropView = target;
-			target->CompleteDragOperation(*drag);
+		drag->dropView = target;
+		target->CompleteDragOperation(*drag);
 	} else if (trackingView) {
 		if (trackingView == target || trackingView->TracksMouseDown()) {
 			trackingView->MouseUp(me, mod);
@@ -404,8 +417,7 @@ void Window::DispatchTouchDown(View* target, const TouchEvent& te, unsigned shor
 {
 	assert(target);
 
-	if (te.numFingers == 1
-		&& !(Flags() & View::IgnoreEvents)) {
+	if (te.numFingers == 1 && !(Flags() & View::IgnoreEvents)) {
 		Focus();
 	}
 
@@ -454,17 +466,13 @@ bool Window::DispatchKey(View* keyView, const Event& event)
 	// try the keyView view first, if it fails have the window itself try
 	bool handled = false;
 	if (keyView) {
-		handled = (event.type == Event::KeyDown)
-		? keyView->KeyPress(event.keyboard, event.mod)
-		: keyView->KeyRelease(event.keyboard, event.mod);
+		handled = (event.type == Event::KeyDown) ? keyView->KeyPress(event.keyboard, event.mod) : keyView->KeyRelease(event.keyboard, event.mod);
 	}
-	
+
 	if (!handled) {
 		// FIXME: using OnKeyPress to avoid eventProxy from eating esc key
 		// would be better if we could delegate proxies for different event classes (keys, mouse, etc)
-		handled = (event.type == Event::KeyDown)
-		? OnKeyPress(event.keyboard, event.mod)
-		: OnKeyRelease(event.keyboard, event.mod);
+		handled = (event.type == Event::KeyDown) ? OnKeyPress(event.keyboard, event.mod) : OnKeyRelease(event.keyboard, event.mod);
 	}
 	return handled;
 }
@@ -491,7 +499,7 @@ bool Window::DispatchEvent(const Event& event)
 
 	Point screenPos = event.mouse.Pos();
 	if (!frame.PointInside(screenPos) && trackingView == nullptr) {
-		// this can hapen if the window is modal since it will absorb all events
+		// this can happen if the window is modal since it will absorb all events
 		// the window manager maybe shouldnt dispatch the events in this case
 		// but this is a public function and its possible to post a phoney event from anywhere anyway
 		return true;
@@ -500,7 +508,7 @@ bool Window::DispatchEvent(const Event& event)
 	target = SubviewAt(ConvertPointFromScreen(screenPos), false, true);
 	assert(target == nullptr || target->IsVisible());
 
-	if (IsDragable() && target == nullptr) {
+	if (IsDraggable() && target == nullptr) {
 		target = this;
 	}
 
@@ -567,7 +575,7 @@ bool Window::DispatchEvent(const Event& event)
 	// absorb other screen events i guess
 	return true;
 }
-	
+
 bool Window::InActionHandler() const
 {
 	for (const auto& ctrl : Controls) {
@@ -575,8 +583,8 @@ bool Window::InActionHandler() const
 			return true;
 		}
 	}
-	
-	return executingResponseHandler;
+
+	return !responderStack.empty();
 }
 
 bool Window::RegisterHotKeyCallback(EventMgr::EventCallback cb, KeyboardKey key)
@@ -610,7 +618,7 @@ bool Window::OnMouseDrag(const MouseEvent& me)
 {
 	assert(me.buttonStates);
 	// dragging the window to a new position. only happens with left mouse.
-	if (IsDragable()) {
+	if (IsDraggable()) {
 		Point newOrigin = frame.origin - me.Delta();
 		SetFrameOrigin(newOrigin);
 	} else {
@@ -618,7 +626,7 @@ bool Window::OnMouseDrag(const MouseEvent& me)
 	}
 	return true;
 }
-	
+
 void Window::OnMouseLeave(const MouseEvent& me, const DragOp*)
 {
 	DispatchMouseMotion(NULL, me);
@@ -629,13 +637,23 @@ bool Window::OnKeyPress(const KeyboardEvent& key, unsigned short mod)
 	if (Flags() & View::IgnoreEvents) {
 		return false;
 	}
-	
+
 	if (key.keycode == GEM_ESCAPE && mod == 0) {
 		Close();
 		return true;
 	}
 
-	return ScrollView::OnKeyPress(key, mod);
+	if (ScrollView::OnKeyPress(key, mod)) {
+		return true;
+	}
+
+	// This way, we can assign GameControl as EP and handle some left-over keys,
+	// e.g. Pause from the Container window.
+	if (GetEventProxy()) {
+		return View::KeyPress(key, mod);
+	}
+
+	return false;
 }
 
 bool Window::OnControllerButtonDown(const ControllerEvent& ce)
@@ -644,10 +662,10 @@ bool Window::OnControllerButtonDown(const ControllerEvent& ce)
 		Close();
 		return true;
 	}
-		
+
 	return View::OnControllerButtonDown(ce);
 }
-	
+
 ViewScriptingRef* Window::CreateScriptingRef(ScriptingId id, ScriptingGroup_t group)
 {
 	return new WindowScriptingRef(this, id, group);
