@@ -18,16 +18,20 @@
 
 #include "WindowManager.h"
 
-#include "GameData.h"
-#include "Interface.h"
-#include "ImageMgr.h"
-#include "Window.h"
-#include "GUI/GameControl.h"
-
 #include "defsounds.h"
 
+#include "Debug.h"
+#include "GameData.h"
+#include "ImageMgr.h"
+#include "Interface.h"
+#include "Tooltip.h"
+#include "Window.h"
+
+#include "GUI/GUIFactory.h"
+#include "GUI/GameControl.h"
+
 #define WIN_IT(w) \
-std::find(windows.begin(), windows.end(), w)
+	std::find(windows.begin(), windows.end(), w)
 
 namespace GemRB {
 
@@ -39,37 +43,40 @@ Holder<Sprite2D> WindowManager::CursorMouseDown;
 
 void WindowManager::SetTooltipDelay(int delay)
 {
-	ToolTipDelay = delay;
+	// Max setting disables tooltips in originals, we just set it to an extremely high value for simplicity.
+	ToolTipDelay = (delay == 10 * Tooltip::DELAY_FACTOR) ? 10000000 : delay;
 }
 
-WindowManager::WindowManager(const std::shared_ptr<Video>& vid)
-: tooltip(core->CreateTooltip())
+WindowManager::WindowManager(PluginHolder<Video> vid, std::shared_ptr<GUIFactory> fact)
+	: guifact(std::move(fact)), video(std::move(vid)), tooltip(core->CreateTooltip())
 {
-	assert(vid);
+	assert(video);
+	assert(guifact);
+
+	guifact->SetWindowManager(*this);
 
 	cursorFeedback = MOUSE_ALL;
 
 	EventMgr::EventCallback cb = METHOD_CALLBACK(&WindowManager::DispatchEvent, this);
-	eventMgr.RegisterEventMonitor(cb);
+	EventMgr::RegisterEventMonitor(cb);
 
 	cb = METHOD_CALLBACK(&WindowManager::HotKey, this);
-	eventMgr.RegisterHotKeyCallback(cb, 'f', GEM_MOD_CTRL);
-	eventMgr.RegisterHotKeyCallback(cb, GEM_GRAB, 0);
+	EventMgr::RegisterHotKeyCallback(cb, 'f', GEM_MOD_CTRL);
+	EventMgr::RegisterHotKeyCallback(cb, GEM_GRAB, 0);
 
-	screen = Region(Point(), vid->GetScreenSize());
+	screen = Region(Point(), video->GetScreenSize());
 	// FIXME: technically we should unset the current video event manager...
-	vid->SetEventMgr(&eventMgr);
+	video->SetEventMgr(&eventMgr);
 
 	gameWin = new Window(screen, *this);
-	gameWin->SetFlags(Window::Borderless|View::Invisible, BitOp::SET);
+	gameWin->SetFlags(Window::Borderless | View::Invisible, BitOp::SET);
 	gameWin->SetFrame(screen);
 
-	HUDBuf = vid->CreateBuffer(screen, Video::BufferFormat::DISPLAY_ALPHA);
+	HUDBuf = video->CreateBuffer(screen, Video::BufferFormat::DISPLAY_ALPHA);
 
 	// set the buffer that always gets cleared just in case anything
 	// tries to draw
-	vid->PushDrawingBuffer(HUDBuf);
-	video = vid;
+	video->PushDrawingBuffer(HUDBuf);
 	// TODO: changing screen size should adjust window positions too
 	// TODO: how do we get notified if the Video driver changes size?
 }
@@ -84,13 +91,36 @@ void WindowManager::MarkAllDirty() const
 WindowManager::~WindowManager()
 {
 	CloseAllWindows();
-	
+
 	DestroyClosedWindows();
 	assert(closedWindows.empty());
 
 	delete gameWin;
 }
 
+Window* WindowManager::LoadWindow(ScriptingId WindowID, const ScriptingGroup_t& ref, Window::WindowPosition pos)
+{
+	guifact->LoadWindowPack(ref);
+
+	Window* win = GetWindow(WindowID, ref);
+	if (!win) {
+		win = guifact->GetWindow(WindowID);
+	}
+	if (win) {
+		assert(win->GetScriptingRef());
+		win->SetPosition(pos);
+		FocusWindow(win);
+	}
+	return win;
+}
+
+Window* WindowManager::CreateWindow(ScriptingId WindowID, const Region& frame)
+{
+	// FIXME: this will create a window under the current "window pack"
+	// obviously its possible the id can conflict with an existing window
+	return guifact->CreateWindow(WindowID, frame);
+}
+
 void WindowManager::DestroyClosedWindows()
 {
 	WindowList::iterator it = closedWindows.begin();
@@ -121,14 +151,14 @@ Window* WindowManager::ModalWindow() const
 /** Show a Window in Modal Mode */
 bool WindowManager::PresentModalWindow(Window* win)
 {
-	if (!IsOpenWindow( win )) return false;
+	if (!IsOpenWindow(win)) return false;
 
 	OrderFront(win);
 	win->SetDisabled(false);
 	win->SetFlags(Window::Modal, BitOp::OR);
 
 	if (win->Flags() & Window::Borderless && !(win->Flags() & Window::NoSounds)) {
-		core->PlaySound(DS_WINDOW_OPEN, SFX_CHAN_GUI);
+		core->PlaySound(DS_WINDOW_OPEN, SFXChannel::GUI);
 	}
 
 	return true;
@@ -152,7 +182,7 @@ bool WindowManager::FocusWindow(Window* win)
 			return false;
 		}
 	}
-	
+
 	if (OrderFront(win)) {
 		if (gameWin == win) {
 			core->SetEventFlag(EF_CONTROL);
@@ -201,7 +231,7 @@ bool WindowManager::OrderRelativeTo(Window* win, Window* win2, bool front)
 	if ((front && frontWin == win2) || win == frontWin) {
 		TooltipTime = 0;
 	}
-	
+
 	if (oldFront != frontWin) {
 		if (front) {
 			if (trackingWin == win2) {
@@ -213,10 +243,10 @@ bool WindowManager::OrderRelativeTo(Window* win, Window* win2, bool front)
 			}
 		}
 
-		auto event = eventMgr.CreateMouseMotionEvent(eventMgr.MousePos());
+		auto event = EventMgr::CreateMouseMotionEvent(EventMgr::MousePos());
 		WindowList::const_iterator it = windows.begin();
 		hoverWin = NextEventWindow(event, it);
-		
+
 		oldFront->FocusLost();
 		frontWin->FocusGained();
 	}
@@ -251,7 +281,7 @@ void WindowManager::CloseWindow(Window* win)
 
 	if (win == ModalWindow()) {
 		if (win->Flags() & Window::Borderless && !(win->Flags() & Window::NoSounds)) {
-			core->PlaySound(DS_WINDOW_CLOSE, SFX_CHAN_GUI);
+			core->PlaySound(DS_WINDOW_CLOSE, SFXChannel::GUI);
 		}
 
 		win->SetFlags(Window::Modal, BitOp::NAND);
@@ -296,9 +326,13 @@ void WindowManager::CloseAllWindows() const
 bool WindowManager::HotKey(const Event& event) const
 {
 	if (event.type == Event::KeyDown && event.keyboard.repeats == 1) {
+		auto& vars = core->GetDictionary();
+		bool fullscreen;
 		switch (event.keyboard.keycode) {
 			case 'f':
 				video->ToggleFullscreenMode();
+				fullscreen = (bool) vars.Get("Full Screen", 0);
+				vars.Set("Full Screen", !fullscreen);
 				return true;
 			case GEM_GRAB:
 				video->ToggleGrabInput();
@@ -323,12 +357,12 @@ Window* WindowManager::GetFocusWindow() const
 	}
 
 	// for all intents and purposes there must always be a window considered to be the focus
-	// gameWin is the "root" window so it will be considered the focus if no eligable windows are
+	// gameWin is the "root" window so it will be considered the focus if no eligible windows are
 	return gameWin;
 }
 
 #define HIT_TEST(e, w) \
-((w)->HitTest((w)->ConvertPointFromScreen(e.mouse.Pos())))
+	((w)->HitTest((w)->ConvertPointFromScreen(e.mouse.Pos())))
 
 Window* WindowManager::NextEventWindow(const Event& event, WindowList::const_iterator& current)
 {
@@ -346,11 +380,11 @@ Window* WindowManager::NextEventWindow(const Event& event, WindowList::const_ite
 		current = windows.end(); // invalidate the iterator, no other target is possible.
 		return mwin;
 	}
-	
+
 	if (event.isScreen) {
 		while (current != windows.end()) {
 			Window* win = *current++;
-			if (win->IsVisible() && HIT_TEST(event,win)) {
+			if (win->IsVisible() && HIT_TEST(event, win)) {
 				// NOTE: we want to "target" the first window hit regardless of it being disabled or otherwise
 				// we still need to update which window is under the mouse and block events from reaching the windows below
 				return win;
@@ -373,7 +407,7 @@ bool WindowManager::DispatchEvent(const Event& event)
 		return true;
 	}
 
-	if (eventMgr.MouseDown() == false && eventMgr.FingerDown() == false) {
+	if (EventMgr::MouseDown() == false && EventMgr::FingerDown() == false) {
 		if (event.type == Event::MouseUp || event.type == Event::TouchUp) {
 			// we don't deliver mouse up events if there isn't a corresponding mouse down (no trackingWin).
 			if (!trackingWin) return false;
@@ -389,23 +423,23 @@ bool WindowManager::DispatchEvent(const Event& event)
 			trackingWin = NULL;
 		}
 	} else if (event.isScreen && trackingWin) {
-			if (trackingWin->IsDisabled() == false) {
-				trackingWin->DispatchEvent(event);
-			}
-			return true;
+		if (trackingWin->IsDisabled() == false) {
+			trackingWin->DispatchEvent(event);
 		}
+		return true;
+	}
 
 	if (windows.empty()) return false;
 
-	if (event.EventMaskFromType(event.type) & Event::AllMouseMask) {
+	if (Event::EventMaskFromType(event.type) & Event::AllMouseMask) {
 		TooltipTime = GetMilliseconds();
-		
+
 		// handle when mouse leaves the window
 		if (hoverWin && HIT_TEST(event, hoverWin) == false) {
 			hoverWin->MouseLeave(event.mouse, NULL);
 			hoverWin = NULL;
 		}
-	// handled here instead of as a hotkey, so also gamecontrol can do its thing
+		// handled here instead of as a hotkey, so also gamecontrol can do its thing
 	} else if (event.type == Event::KeyDown && event.keyboard.keycode == GEM_TAB) {
 		if (TooltipTime + ToolTipDelay > GetMilliseconds()) {
 			TooltipTime -= ToolTipDelay;
@@ -421,8 +455,7 @@ bool WindowManager::DispatchEvent(const Event& event)
 				if (event.type == Event::MouseDown || event.type == Event::TouchDown) {
 					trackingWin = target;
 				}
-			} else if ((target->Flags()&(View::IgnoreEvents|View::Disabled)) == View::Disabled
-					   && event.type == Event::KeyDown && event.keyboard.keycode == GEM_ESCAPE) {
+			} else if ((target->Flags() & (View::IgnoreEvents | View::Disabled)) == View::Disabled && event.type == Event::KeyDown && event.keyboard.keycode == GEM_ESCAPE) {
 				// force close disabled windows if they aren't also ignoring events
 				target->Close();
 			}
@@ -440,7 +473,7 @@ void WindowManager::DrawMouse() const
 	if (cursorFeedback == MOUSE_NONE)
 		return;
 
-	Point cursorPos = eventMgr.MousePos();
+	Point cursorPos = EventMgr::MousePos();
 	Point tooltipPos = cursorPos;
 
 	// pst displays actor name tooltips overhead, not at the mouse position
@@ -457,7 +490,7 @@ void WindowManager::DrawMouse() const
 
 void WindowManager::DrawCursor(const Point& pos) const
 {
-	if (cursorFeedback&MOUSE_NO_CURSOR) {
+	if (cursorFeedback & MOUSE_NO_CURSOR) {
 		return;
 	}
 	// Cursor draw priority:
@@ -467,20 +500,20 @@ void WindowManager::DrawCursor(const Point& pos) const
 	// 4. WindowManager cursors
 
 	Holder<Sprite2D> cur(gameWin->View::Cursor());
-	
+
 	if (!cur && hoverWin) {
 		cur = hoverWin->Cursor();
 	}
 
 	if (!cur) {
 		// no cursor override
-		cur = (eventMgr.MouseDown()) ? CursorMouseDown : CursorMouseUp;
+		cur = (EventMgr::MouseDown()) ? CursorMouseDown : CursorMouseUp;
 	}
 	assert(cur); // must have a cursor
 
 	if (hoverWin && hoverWin->IsDisabledCursor()) {
 		// draw greyed cursor
-		video->BlitGameSprite(cur, pos, BlitFlags::GREY|BlitFlags::BLENDED, ColorGray);
+		video->BlitGameSprite(cur, pos, BlitFlags::GREY | BlitFlags::BLENDED, ColorGray);
 	} else {
 		// draw normal cursor
 		video->BlitSprite(cur, pos);
@@ -489,7 +522,7 @@ void WindowManager::DrawCursor(const Point& pos) const
 
 void WindowManager::DrawTooltip(Point pos) const
 {
-	if (cursorFeedback&MOUSE_NO_TOOLTIPS) {
+	if (cursorFeedback & MOUSE_NO_TOOLTIPS) {
 		return;
 	}
 
@@ -508,23 +541,23 @@ void WindowManager::DrawTooltip(Point pos) const
 			tooltip.tt.SetText(text);
 			if (tooltip.tooltip_sound) {
 				tooltip.tooltip_sound->Stop();
-				tooltip.tooltip_sound.release();
+				tooltip.tooltip_sound.reset();
 			}
 			if (text.length()) {
-				tooltip.tooltip_sound = core->PlaySound(DS_TOOLTIP, SFX_CHAN_GUI);
+				tooltip.tooltip_sound = core->PlaySound(DS_TOOLTIP, SFXChannel::GUI);
 			}
 			tooltip.reset = false;
 		}
 
 		// clamp pos so that the TT is all visible (TT draws centered at pos)
-		int halfW = tooltip.tt.TextSize().w/2 + 16;
-		int halfH = tooltip.tt.TextSize().h/2 + 11;
+		int halfW = tooltip.tt.TextSize().w / 2 + 16;
+		int halfH = tooltip.tt.TextSize().h / 2 + 11;
 		pos.x = Clamp<int>(pos.x, halfW, screen.w - halfW);
 		pos.y = Clamp<int>(pos.y, halfW, screen.h - halfH);
 
 		tooltip.tt.Draw(pos);
 	} else {
-		tooltip.tt.SetText(L"");
+		tooltip.tt.SetText(u"");
 	}
 }
 
@@ -536,7 +569,7 @@ void WindowManager::DrawWindowFrame(BlitFlags flags) const
 	// ... I'm not 100% certain this works for all use cases.
 	// if it doesn't... i think it might be better to just forget about the window frames once the game is loaded
 
-	video->SetScreenClip( NULL );
+	video->SetScreenClip(NULL);
 
 	Holder<Sprite2D> left_edge = WinFrameEdge(0);
 	if (left_edge) {
@@ -550,7 +583,7 @@ void WindowManager::DrawWindowFrame(BlitFlags flags) const
 		int v_margin = (screen.h - left_edge->Frame.h) / 2;
 		// Also assume top and bottom are the same width.
 		int h_margin = (screen.w - left_w - right_w - top_edge->Frame.w) / 2;
-		
+
 		const static Color dummy;
 		video->BlitGameSprite(left_edge, Point(h_margin, v_margin), flags, dummy);
 		video->BlitGameSprite(right_edge, Point(screen.w - right_w - h_margin, v_margin), flags, dummy);
@@ -566,6 +599,7 @@ WindowManager::HUDLock WindowManager::DrawHUD() const
 
 void WindowManager::DrawWindows() const
 {
+	TRACY(ZoneScoped);
 	HUDBuf->Clear();
 
 	if (windows.empty()) {
@@ -596,14 +630,14 @@ void WindowManager::DrawWindows() const
 			continue;
 
 		if (win == modalWin) {
-			drawFrame = drawFrame || !(win->Flags()&Window::Borderless);
+			drawFrame = drawFrame || !(win->Flags() & Window::Borderless);
 			continue; // will draw this later
 		}
 
 		const Region& frame = win->Frame();
 
 		// FYI... this only checks if the front window obscures... could be covered by another window too
-		if ((frontWin->Flags()&(Window::AlphaChannel|View::Invisible)) == 0 && win != frontWin && win->NeedsDraw()) {
+		if ((frontWin->Flags() & (Window::AlphaChannel | View::Invisible)) == 0 && win != frontWin && win->NeedsDraw()) {
 			Region intersect = frontWinFrame.Intersect(frame);
 			if (intersect == frame) {
 				// this window is completely obscured by the front window
@@ -612,20 +646,12 @@ void WindowManager::DrawWindows() const
 			}
 		}
 
-		if (!drawFrame && !(win->Flags()&Window::Borderless) && (frame.w < screen.w || frame.h < screen.h)) {
+		if (!drawFrame && !(win->Flags() & Window::Borderless) && (frame.w < screen.w || frame.h < screen.h)) {
 			// the window requires us to draw the frame border (happens later, on the cursor buffer)
 			drawFrame = true;
 		}
 
-		if (win->IsDisabled() && win->NeedsDraw()) {
-			// Important to only draw if the window itself is dirty
-			// controls on greyed out windows shouldn't be updating anyway
-			win->Draw();
-			Region winrgn(Point(), win->Dimensions());
-			video->DrawRect(winrgn, ColorBlack, true, BlitFlags::HALFTRANS|BlitFlags::BLENDED);
-		} else {
-			win->Draw();
-		}
+		win->Draw();
 	}
 
 	video->PushDrawingBuffer(HUDBuf);
@@ -641,12 +667,12 @@ void WindowManager::DrawWindows() const
 		auto& modalBuffer = modalWin->DrawWithoutComposition();
 		video->BlitVideoBuffer(modalBuffer, Point(), BlitFlags::BLENDED);
 	}
-	
+
 	if (drawFrame) {
 		DrawWindowFrame(frame_flags);
 	}
-	
-	if (core->InDebugMode(ID_WINDOWS)) {
+
+	if (InDebugMode(DebugMode::WINDOWS)) {
 		// ensure this is drawing over the window frames
 		if (trackingWin) {
 			Region r = trackingWin->Frame();
@@ -678,13 +704,13 @@ Holder<Sprite2D> WindowManager::GetScreenshot(Window* win)
 	if (win) { // we don't really care if we are managing the window
 		// only a screen shot of passed win
 		auto& winBuf = win->DrawWithoutComposition();
-		screenshot = video->GetScreenshot( Region(Point(), win->Dimensions()), winBuf );
+		screenshot = video->GetScreenshot(Region(Point(), win->Dimensions()), winBuf);
 	} else {
 		// redraw the windows without the mouse elements
 		auto mouseState = SetCursorFeedback(MOUSE_NONE);
 		DrawWindows();
 		video->SwapBuffers(0);
-		screenshot = video->GetScreenshot( screen );
+		screenshot = video->GetScreenshot(screen);
 		SetCursorFeedback(mouseState);
 	}
 
