@@ -24,35 +24,36 @@
 #include "Resource.h"
 #include "Sprite2D.h"
 #include "Tooltip.h"
+
+#include "GUI/Window.h"
 #include "Video/Video.h"
 
 #include <deque>
 
 namespace GemRB {
 
+class GUIFactory;
 class Sprite2D;
-class Window;
 
 using WindowList = std::deque<Window*>;
 
-struct ToolTipData
-{
+struct ToolTipData {
 	Tooltip tt;
 	tick_t time = 0;
 	Holder<SoundHandle> tooltip_sound;
 	bool reset = false;
-	
+
 	explicit ToolTipData(Tooltip tt)
-	: tt(std::move(tt)) {}
+		: tt(std::move(tt)) {}
 };
 
-class WindowManager {
+class GEM_EXPORT WindowManager {
 public:
 	enum CursorFeedback {
-		MOUSE_ALL			= 0,
-		MOUSE_NO_CURSOR		= 1,
-		MOUSE_NO_TOOLTIPS	= 2,
-		MOUSE_NONE			= MOUSE_NO_CURSOR|MOUSE_NO_TOOLTIPS
+		MOUSE_ALL = 0,
+		MOUSE_NO_CURSOR = 1,
+		MOUSE_NO_TOOLTIPS = 2,
+		MOUSE_NONE = MOUSE_NO_CURSOR | MOUSE_NO_TOOLTIPS
 	} cursorFeedback;
 
 	static Holder<Sprite2D> CursorMouseUp;
@@ -64,32 +65,36 @@ public:
 		const WindowManager& wm;
 
 		explicit HUDLock(const WindowManager& wm)
-		: wm(wm) {
+			: wm(wm)
+		{
 			wm.video->PushDrawingBuffer(wm.HUDBuf);
 		}
 
-		~HUDLock() {
+		~HUDLock()
+		{
 			wm.video->PopDrawingBuffer();
 		}
 	};
 
 private:
+	std::shared_ptr<GUIFactory> guifact;
+
 	WindowList windows;
 	WindowList closedWindows; // windows that have been closed. kept around temporarily in case they get reopened
 
-	Region screen; // only a Region for convinience. we dont use x,y
+	Region screen; // only a Region for convenience - we dont use x,y
 	Window* gameWin;
 	Window* hoverWin = nullptr;
 	Window* trackingWin = nullptr;
 
 	EventMgr eventMgr;
 
-	std::shared_ptr<Video> video;
+	PluginHolder<Video> video;
 	VideoBufferPtr HUDBuf = nullptr; // heads up display layer. Contains cursors/tooltips/borders and whatever gets drawn via DrawHUD()
 
 	// these are mutable instead of statice because Sprite2Ds must be released before the video driver is unloaded
 	mutable ToolTipData tooltip;
-	mutable std::map<ResRef, Holder<Sprite2D>> winframes;
+	mutable ResRefMap<Holder<Sprite2D>> winframes;
 
 	static tick_t ToolTipDelay;
 	static tick_t TooltipTime;
@@ -112,12 +117,15 @@ private:
 	void MarkAllDirty() const;
 
 public:
-	explicit WindowManager(const std::shared_ptr<Video>& vid);
+	WindowManager(PluginHolder<Video> vid, std::shared_ptr<GUIFactory>);
 	~WindowManager();
-	
+
 	WindowManager(const WindowManager&) = delete;
 
+	Window* LoadWindow(ScriptingId WindowID, const ScriptingGroup_t& ref, Window::WindowPosition = Window::PosCentered);
+	Window* CreateWindow(ScriptingId WindowID, const Region&);
 	Window* MakeWindow(const Region& rgn);
+
 	void CloseWindow(Window* win);
 	void CloseAllWindows() const;
 
@@ -131,7 +139,7 @@ public:
 
 	CursorFeedback SetCursorFeedback(CursorFeedback feedback);
 
-	// all drawing will be done directly on the screen until DrawingLock is destoryed
+	// all drawing will be done directly on the screen until DrawingLock is destroyed
 	HUDLock DrawHUD() const;
 
 	/*
@@ -150,7 +158,7 @@ public:
 	Window* GetGameWindow() const { return gameWin; }
 	Window* GetFocusWindow() const;
 
-	GEM_EXPORT static void SetTooltipDelay(int);
+	static void SetTooltipDelay(int);
 };
 
 
