@@ -27,11 +27,11 @@
 #ifndef WORLDMAPCONTROL_H
 #define WORLDMAPCONTROL_H
 
+#include "exports.h"
+
 #include "GUI/Control.h"
 #include "GUI/GUIAnimation.h"
 
-#include "exports.h"
-
 namespace GemRB {
 
 class Font;
@@ -44,25 +44,24 @@ class WorldMapControl;
  * allowing travelling between areas.
  */
 
-class GEM_EXPORT WorldMapControl : public Control, public View::Scrollable {
+class GEM_EXPORT WorldMapControl : public Control,
+				   public View::Scrollable {
 private:
 	/** Draws the Control on the Output Display */
 	void WillDraw(const Region& /*drawFrame*/, const Region& /*clip*/) override;
 	void DrawSelf(const Region& drawFrame, const Region&) override;
 
 public:
-	WorldMapControl(const Region& frame, Font *font);
-	WorldMapControl(const Region& frame, Font *font, const Color &normal, const Color &selected, const Color &notvisited);
+	WorldMapControl(const Region& frame, Holder<Font> font);
+	WorldMapControl(const Region& frame, Holder<Font> font, const Color& normal, const Color& selected, const Color& notvisited);
 
 	/** Allows modification of the scrolling factor from outside */
 	void ScrollDelta(const Point& delta) override;
 	void ScrollTo(const Point& pos) override;
-	/** Sets the exit direction (we need this to calculate distances) */
-	void SetDirection(int direction);
 
 	Point Pos;
 	/** pointer to last pointed area */
-	WMPAreaEntry *Area = nullptr;
+	WMPAreaEntry* Area = nullptr;
 	Holder<Sprite2D> areaIndicator;
 	ColorAnimation hoverAnim;
 
@@ -83,7 +82,7 @@ protected:
 
 private:
 	//font for printing area names
-	Font* ftext;
+	Holder<Font> ftext;
 	//current area
 	ResRef currentArea;
 
@@ -94,7 +93,6 @@ private:
 	Color color_selected;
 	/** Label color of a not yet visited area */
 	Color color_notvisited;
-
 };
 
 }
