@@ -22,9 +22,11 @@
 
 #include "Game.h"
 #include "Interface.h"
+#include "RNG.h"
+
 #include "GUI/GUIAnimation.h"
 #include "GUI/GameControl.h"
-#include "RNG.h"
+#include "GUI/WindowManager.h"
 
 namespace GemRB {
 
@@ -44,6 +46,11 @@ void GlobalTimer::Freeze()
 	game->RealTime++;
 }
 
+bool GlobalTimer::IsFading() const
+{
+	return fadeToCounter || fadeFromCounter != fadeFromMax; // add fadeOutFallback if needed, doesn't seem outright right
+}
+
 bool GlobalTimer::ViewportIsMoving() const
 {
 	return shakeCounter || (!goal.IsInvalid() && goal != currentVP.origin);
@@ -58,7 +65,9 @@ void GlobalTimer::SetMoveViewPort(Point p, int spd, bool center)
 		p.x -= currentVP.w / 2;
 		p.y -= currentVP.h / 2;
 	}
+	if (goal == p) return;
 	goal = p;
+
 	speed = spd;
 	if (speed == 0) {
 		// do this instantly, even if paused
@@ -80,17 +89,16 @@ void GlobalTimer::DoStep(int count)
 	if (p != goal && !goal.IsInvalid()) {
 		int d = Distance(goal, p);
 		int magnitude = count * speed;
-		
+
 		if (d <= magnitude) {
 			p = goal;
 		} else {
-			magnitude = std::min(magnitude, d);
 			float r = magnitude / float(d);
 			p.x = (1 - r) * p.x + r * goal.x;
 			p.y = (1 - r) * p.y + r * goal.y;
 		}
 	}
-	
+
 	if (!gc->MoveViewportTo(p, false)) {
 		// we have moved as close to the goal as possible
 		// something must have set a goal beyond the map
@@ -109,7 +117,7 @@ void GlobalTimer::DoStep(int count)
 			gc->MoveViewportUnlockedTo(shakeP, false);
 		}
 	}
-	
+
 	currentVP = gc->Viewport();
 }
 
@@ -117,11 +125,11 @@ bool GlobalTimer::UpdateViewport(tick_t thisTime)
 {
 	tick_t advance = thisTime - startTime;
 	tick_t interval = core ? (1000 / core->Time.ticksPerSec) : 66; // length of a tick in ms
-	if ( advance < interval) {
+	if (advance < interval) {
 		return false;
 	}
 
-	ieDword count = ieDword(advance/interval);
+	ieDword count = ieDword(advance / interval);
 	DoStep(count);
 	DoFadeStep(count);
 	return true;
@@ -129,8 +137,8 @@ bool GlobalTimer::UpdateViewport(tick_t thisTime)
 
 bool GlobalTimer::Update()
 {
-	Map *map;
-	Game *game;
+	Map* map;
+	Game* game;
 	const GameControl* gc;
 	tick_t thisTime = GetMilliseconds();
 
@@ -143,6 +151,11 @@ bool GlobalTimer::Update()
 		goto end;
 	}
 
+	// init fallback duration here, since it's not known in the ctor
+	if (lastFadeDuration == 0) {
+		lastFadeDuration = core->Time.fade_default;
+	}
+
 	if (UpdateViewport(thisTime) == false) {
 		return false;
 	}
@@ -155,14 +168,33 @@ bool GlobalTimer::Update()
 	if (!map) {
 		goto end;
 	}
+
+	// don't update scripts if we're fading in or out or shaking the screen
+	if (IsFading() || shakeCounter) {
+		if (!fadeToCounter) map->UpdateFog(); // needed eg. when meeting Yoshimo for the first time
+		if (shakeCounter) map->UpdateProjectiles(); // needed when Lothar is destroying the wall
+		if (thisTime) {
+			game->RealTime++;
+		}
+		return false;
+	}
+
 	//do spell effects expire in dialogs?
 	//if yes, then we should remove this condition
 	if (!gc->InDialog() || !(gc->GetDialogueFlags() & DF_FREEZE_SCRIPTS)) {
 		map->UpdateFog();
 		map->UpdateEffects();
+		map->UpdateProjectiles();
+
 		if (thisTime) {
 			//this measures in-world time (affected by effects, actions, etc)
 			game->AdvanceTime(1);
+			// drop an area comment, party oneliner or initiate party banter (with Interact)
+			// party comments have a priority, but they happen half of the time, at most
+			if (!game->CheckPartyBanter()) {
+				game->CheckAreaComment();
+			}
+			game->CheckBored();
 		}
 	}
 	//this measures time spent in the game (including pauses)
@@ -174,11 +206,21 @@ end:
 	return true;
 }
 
-
-void GlobalTimer::DoFadeStep(ieDword count) {
+void GlobalTimer::DoFadeStep(ieDword count)
+{
 	WindowManager* wm = core->GetWindowManager();
+	if (fadeOutFallback > 0) {
+		--fadeOutFallback;
+		// activate fallback if no fade out was scheduled
+		if (fadeOutFallback == 0) {
+			wm->FadeColor.a = 0;
+			return;
+		}
+	}
+
 	if (fadeToCounter) {
-		
+		if (fadeOutFallback > 0) ++fadeOutFallback;
+
 		if (count > fadeToCounter) {
 			fadeToCounter = 0;
 			fadeToFactor = 1;
@@ -186,59 +228,63 @@ void GlobalTimer::DoFadeStep(ieDword count) {
 			fadeToCounter -= count;
 		}
 
-		wm->FadeColor.a = 255 * (double( fadeToMax - fadeToCounter ) / fadeToMax / fadeToFactor);
+		wm->FadeColor.a = 255 * (double(fadeToMax - fadeToCounter) / fadeToMax / fadeToFactor);
 	}
 	//i think this 'else' is needed now because of the 'goto' cut above
-	else if (fadeFromCounter!=fadeFromMax) {
-		if (fadeFromCounter>fadeFromMax) {
-			fadeFromCounter-=count;
-			if (fadeFromCounter<fadeFromMax) {
-				fadeFromCounter=fadeFromMax;
+	else if (fadeFromCounter != fadeFromMax) {
+		if (fadeFromCounter > fadeFromMax) {
+			fadeFromCounter -= count;
+			if (fadeFromCounter < fadeFromMax) {
+				fadeFromCounter = fadeFromMax;
 				fadeFromFactor = 1;
 			}
 		} else {
-			fadeFromCounter+=count;
-			if (fadeToCounter>fadeFromMax) {
-				fadeToCounter=fadeFromMax;
+			fadeFromCounter += count;
+			if (fadeToCounter > fadeFromMax) {
+				fadeToCounter = fadeFromMax;
 				fadeToFactor = 1;
 			}
-			wm->FadeColor.a = 255 * (double( fadeFromMax - fadeFromCounter ) / fadeFromMax / fadeFromFactor);
 		}
-	}
-	if (fadeFromCounter==fadeFromMax) {
-		wm->FadeColor.a = 0;
+		wm->FadeColor.a = 255 * (double(fadeFromMax - fadeFromCounter) / fadeFromMax / fadeFromFactor);
 	}
 }
 
 void GlobalTimer::SetFadeToColor(tick_t Count, unsigned short factor)
 {
-	if (!Count) {
-		Count = 2 * core->Time.defaultTicksPerSec;
+	// oddly, if a 0 is passed, the last used duration is used (first time the engine default)
+	if (Count) {
+		lastFadeDuration = Count;
+	} else {
+		Count = lastFadeDuration;
 	}
 	fadeToCounter = Count;
 	fadeToMax = fadeToCounter;
-	//stay black for a while
-	fadeFromCounter = core->Time.fade_reset;
+	// set up a fallback in case FadeFromColor was not called
+	fadeOutFallback = core->Time.fade_reset;
+	fadeFromCounter = 0;
 	fadeFromMax = 0;
 	fadeToFactor = factor;
 }
 
 void GlobalTimer::SetFadeFromColor(tick_t Count, unsigned short factor)
 {
-	if (!Count) {
-		Count = 2 * core->Time.defaultTicksPerSec;
+	if (Count) {
+		lastFadeDuration = Count;
+	} else {
+		Count = lastFadeDuration;
 	}
+	fadeOutFallback = 0;
 	fadeFromCounter = 0;
 	fadeFromMax = Count;
 	fadeFromFactor = factor;
 }
 
-void GlobalTimer::SetScreenShake(const Point &shake, int count)
+void GlobalTimer::SetScreenShake(const Point& shake, int count)
 {
 	shakeVec.x = std::abs(shake.x);
 	shakeVec.y = std::abs(shake.y);
-	shakeCounter = count + 1;
-	
+	shakeCounter = std::max(0, count + 1);
+
 	if (goal.IsInvalid()) {
 		const GameControl* gc = core->GetGameControl();
 		currentVP = gc->Viewport();
