@@ -21,13 +21,12 @@
 #include "ImageMgr.h"
 
 #include "ImageFactory.h"
-#include "Interface.h"
 
 namespace GemRB {
 
 const TypeID ImageMgr::ID = { "ImageMgr" };
 
-int ImageMgr::GetPalette(int /*colors*/, Color* /*pal*/)
+int ImageMgr::GetPalette(int /*colors*/, Palette& /*pal*/)
 {
 	return -1;
 }
