@@ -32,7 +32,7 @@
 #include "ie_types.h"
 #include "strrefs.h"
 
-#include "Item.h"  //needs item for itmextheader
+#include "Item.h" //needs item for itmextheader
 #include "Store.h"
 
 #include <vector>
@@ -42,10 +42,10 @@ namespace GemRB {
 class Map;
 
 //AddSlotItem return values
-#define ASI_FAILED     0
-#define ASI_PARTIAL    1
-#define ASI_SUCCESS    2
-#define ASI_SWAPPED    3 //not returned normally, but Gui uses this value
+#define ASI_FAILED  0
+#define ASI_PARTIAL 1
+#define ASI_SUCCESS 2
+#define ASI_SWAPPED 3 //not returned normally, but Gui uses this value
 
 //AddSlotItem extra slot ID's
 #define SLOT_AUTOEQUIP     -1
@@ -63,7 +63,7 @@ class Map;
 #define SLOT_WEAPON    256
 #define SLOT_QUIVER    512
 #define SLOT_CLOAK     1024
-#define SLOT_ITEM      2048  //quick item
+#define SLOT_ITEM      2048 //quick item
 #define SLOT_SCROLL    4096
 #define SLOT_BAG       8192
 #define SLOT_POTION    16384
@@ -74,7 +74,7 @@ class Map;
 #define SLOT_UMD_MASK  (0x100000 - 1)
 
 //weapon slot types (1000==not equipped)
-#define IW_NO_EQUIPPED  1000
+#define IW_NO_EQUIPPED 1000
 
 /** Inventory types */
 enum class ieInventoryType {
@@ -88,17 +88,17 @@ using ieCREItemFlagBits = enum ieCREItemFlagBits : uint32_t {
 	IE_INV_ITEM_UNSTEALABLE = 2,
 	IE_INV_ITEM_STOLEN = 4, // denotes steel items in pst
 	//in iwd/iwd2 this flag means 'magical', some hack is needed
-	IE_INV_ITEM_UNDROPPABLE =8,
+	IE_INV_ITEM_UNDROPPABLE = 8,
 	//just recently acquired
-	IE_INV_ITEM_ACQUIRED = 0x10,	//this is a gemrb extension
+	IE_INV_ITEM_ACQUIRED = 0x10, //this is a gemrb extension
 	//is this item destructible normally?
-	IE_INV_ITEM_DESTRUCTIBLE = 0x20,//this is a gemrb extension
+	IE_INV_ITEM_DESTRUCTIBLE = 0x20, //this is a gemrb extension
 	//is this item already equipped?
-	IE_INV_ITEM_EQUIPPED = 0x40,	//this is a gemrb extension
+	IE_INV_ITEM_EQUIPPED = 0x40, //this is a gemrb extension
 	//selected for sale, using the same bit, hope it is ok
-	IE_INV_ITEM_SELECTED = 0x40,    //this is a gemrb extension
+	IE_INV_ITEM_SELECTED = 0x40, //this is a gemrb extension
 	//is this item stackable?
-	IE_INV_ITEM_STACKED = 0x80,	//this is a gemrb extension
+	IE_INV_ITEM_STACKED = 0x80, //this is a gemrb extension
 	//these flags are coming from the original item, but these are immutable
 	IE_INV_ITEM_CRITICAL = 0x100, //coming from original item
 	IE_INV_ITEM_TWOHANDED = 0x200,
@@ -112,30 +112,27 @@ using ieCREItemFlagBits = enum ieCREItemFlagBits : uint32_t {
 	IE_INV_ITEM_COLDIRON = 0x20000,
 	IE_INV_ITEM_STOLEN2 = 0x40000, //same as 4
 	IE_INV_ITEM_CONVERSABLE = 0x80000,
-	IE_INV_ITEM_PULSATING = 0x100000
+	IE_INV_ITEM_PULSATING = 0x100000,
+	// gap
+	IE_INV_ITEM_NO_DISPEL = 0x1000000, // matching IE_ITEM_NO_DISPEL for convenience
+	IE_INV_ITEM_NOT_OFFHAND = 0x2000000,
+	IE_INV_ITEM_ADAMANTINE = 0x4000000,
 };
 
-#define IE_INV_DEPLETABLE (IE_INV_ITEM_MAGICAL|IE_INV_ITEM_DESTRUCTIBLE)
+#define IE_INV_DEPLETABLE (IE_INV_ITEM_MAGICAL | IE_INV_ITEM_DESTRUCTIBLE)
 
 //equip flags
 #define EQUIP_NONE   0
-#define EQUIP_MELEE 1
+#define EQUIP_MELEE  1
 #define EQUIP_RANGED 2
-#define EQUIP_FORCE 4
+#define EQUIP_FORCE  4
 
-//FIXME:
-//actually this header shouldn't be THIS large, i was just
-//lazy to pick the interesting elements
-//it could be possible that some elements need to be added from the
-//item header itself
+// a mash of useful data fields from Item, ITMExtHeader and potentially CREItem
 struct ItemExtHeader {
 	ieDword slot;
 	size_t headerindex;
 	//from itmextheader
 	ieByte AttackType;
-	ieByte IDReq;
-	ieByte Location;
-	ieByte unknown1;
 	ResRef UseIcon;
 	ieStrRef Tooltip;
 	ieByte Target;
@@ -143,20 +140,9 @@ struct ItemExtHeader {
 	ieWord Range;
 	//This was commented out in ITMExtHeader
 	//ieWord ProjectileType;
-	ieWord Speed;
-	ieWord THAC0Bonus;
-	ieWord DiceSides;
-	ieWord DiceThrown;
-	ieWordSigned DamageBonus; //this must be signed!!!
-	ieWord DamageType;
-	ieWord FeatureCount;
-	ieWord FeatureOffset;
 	ieWord Charges;
 	ieWord ChargeDepletion;
-	ieDword RechargeFlags; //this is a bitfield with many bits
 	ieWord ProjectileAnimation;
-	ieWord MeleeAnimation[3];
-	int ProjectileQualifier; //this is a derived value determined on load time
 	//other data
 	ResRef itemName;
 
@@ -177,7 +163,7 @@ public:
 	//recent research showed that this field is used by the create item
 	//for days effect. This field shows the expiration in gametime hours
 	ieWord Expired = 0;
-	ieWord Usages[CHARGE_COUNTERS]{};
+	std::array<ieWord, CHARGE_COUNTERS> Usages;
 	uint32_t Flags = 0;
 	// 2 cached values from associated item. LEAVE IT SIGNED!
 	/** Weight of each item in the stack */
@@ -186,17 +172,15 @@ public:
 	int MaxStackAmount = 0;
 
 	CREItem() noexcept = default;
-	explicit CREItem(const STOItem *item)
+	explicit CREItem(const STOItem* item)
 	{
 		CopySTOItem(item);
 	};
-	void CopySTOItem(const STOItem *item)
+	void CopySTOItem(const STOItem* item)
 	{
 		ItemResRef = item->ItemResRef;
 		Expired = 0; // PurchasedAmount in STOItem
-		Usages[0] = item->Usages[0];
-		Usages[1] = item->Usages[1];
-		Usages[2] = item->Usages[2];
+		Usages = item->Usages;
 		Flags = item->Flags;
 		Weight = item->Weight;
 		MaxStackAmount = item->MaxStackAmount;
@@ -220,19 +204,20 @@ private:
 	ieWord EquippedHeader = 0;
 	/** this isn't saved */
 	ieDword ItemExcl = 0;
-	ieDword ItemTypes[8]{}; // 256 bits
-public: 
+	ieDword ItemTypes[8] {}; // 256 bits
+
+public:
 	Inventory() noexcept = default;
 	Inventory(const Inventory&) = delete;
 	virtual ~Inventory();
 	Inventory& operator=(const Inventory&) = delete;
 
 	/** duplicates the source inventory into the current one, marking items as undroppable */
-	void CopyFrom(const Actor *source);
+	void CopyFrom(const Actor* source);
 	/** adds an item to the inventory */
-	void AddItem(CREItem *item);
+	void AddItem(CREItem* item);
 	/** Returns number of items in the inventory */
-	int CountItems(const ResRef &resRef, bool charges, bool checkBags = false) const;
+	int CountItems(const ResRef& resRef, bool charges, bool checkBags = false) const;
 	/** looks for a particular item in a slot */
 	bool HasItemInSlot(const ResRef& resref, unsigned int slot) const;
 	bool IsSlotEmpty(unsigned int slot) const;
@@ -240,23 +225,23 @@ public:
 	bool HasItemType(ieDword type) const;
 	/** Looks for a particular item in the inventory.
 	 * flags: see ieCREItemFlagBits */
-	bool HasItem(const ResRef &resref, ieDword flags) const;
+	bool HasItem(const ResRef& resref, ieDword flags) const;
 
 	void SetInventoryType(ieInventoryType arg);
 	void SetOwner(Actor* act) { Owner = act; }
 
 	/** returns number of all slots in the inventory */
-	int GetSlotCount() const { return (int)Slots.size(); }
+	int GetSlotCount() const { return (int) Slots.size(); }
 
 	/** sets inventory size, for the first time */
-	void SetSlotCount(unsigned int size);
+	void SetSlotCount(size_t size);
 
 
 	/** Returns CREItem in specified slot. 
 	 * If count !=0 it splits the item and returns only requested amount */
 	CREItem* RemoveItem(unsigned int slot, unsigned int count = 0);
 	/** returns slot of removed item, you can delete the removed item */
-	int RemoveItem(const ResRef& resref, unsigned int flags, CREItem **res_item, int count = 0);
+	int RemoveItem(const ResRef& resref, unsigned int flags, CREItem** res_item, int count = 0);
 
 	/** adds CREItem to the inventory. If slot == -1, finds
 	** first eligible slot, eventually splitting the item to
@@ -266,16 +251,16 @@ public:
 	int AddSlotItem(CREItem* item, int slot, int slottype = -1, bool ranged = false);
 	/** tries to equip all inventory items in a given slot */
 	void TryEquipAll(int slot);
-	/** Adds STOItem to the inventory, it is never wielded, action might be STA_STEAL or STA_BUY */
+	/** Adds STOItem to the inventory, it is never wielded, action might be STEAL or BUY */
 	/** The amount of items is stored in PurchasedAmount */
-	int AddStoreItem(STOItem* item, int action);
+	int AddStoreItem(STOItem* item, StoreActionType action);
 
 	/** flags: see ieCREItemFlagBits */
 	/** count == ~0 means to destroy all */
 	/** returns the number of destroyed items */
 	unsigned int DestroyItem(const ResRef& resref, ieDword flags, ieDword count);
 	void SetSlotItem(CREItem* item, unsigned int slot);
-	int GetWeight() const {return Weight;}
+	int GetWeight() const { return Weight; }
 
 	bool ItemsAreCompatible(const CREItem* target, const CREItem* source) const;
 	//depletes charged items
@@ -283,19 +268,19 @@ public:
 	//charges recharging items
 	void ChargeAllItems(int hours) const;
 	/** Finds the first slot of named item, if resref is empty, finds the first filled! slot */
-	int FindItem(const ResRef &resref, unsigned int flags, unsigned int skip=0) const;
-	bool DropItemAtLocation(unsigned int slot, unsigned int flags, Map *map, const Point &loc);
-	bool DropItemAtLocation(const ResRef& resRef, unsigned int flags, Map *map, const Point &loc);
-	bool SetEquippedSlot(ieWordSigned slotcode, ieWord header, bool noFX=false);
+	int FindItem(const ResRef& resref, unsigned int flags, unsigned int skip = 0) const;
+	bool DropItemAtLocation(unsigned int slot, unsigned int flags, Map* map, const Point& loc);
+	bool DropItemAtLocation(const ResRef& resRef, unsigned int flags, Map* map, const Point& loc);
+	bool SetEquippedSlot(ieWordSigned slotcode, ieWord header, bool noFX = false);
 	int GetEquipped() const;
 	int GetEquippedHeader() const;
-	const ITMExtHeader *GetEquippedExtHeader(int header=0) const;
+	const ITMExtHeader* GetEquippedExtHeader(int header = 0) const;
 	void SetEquipped(ieWordSigned slot, ieWord header);
 	//right hand
 	int GetEquippedSlot() const;
 	//left hand
 	int GetShieldSlot() const;
-	void AddSlotEffects( ieDword slot);
+	void AddSlotEffects(ieDword slot);
 	//void AddAllEffects();
 	/** Returns item in specified slot. Does NOT change inventory */
 	CREItem* GetSlotItem(ieDword slot) const;
@@ -308,9 +293,9 @@ public:
 	bool EquipItem(ieDword slot);
 	bool UnEquipItem(ieDword slot, bool removecurse) const;
 	/** Returns equipped weapon, also its slot */
-	CREItem *GetUsedWeapon(bool leftorright, int &slot) const;
+	CREItem* GetUsedWeapon(bool leftorright, int& slot) const;
 	/** returns slot of launcher weapon currently equipped */
-	int FindRangedWeapon() const; 
+	int FindRangedWeapon() const;
 	/** returns slot of launcher weapon for specified projectile type */
 	int FindTypedRangedWeapon(unsigned int type) const;
 	/** returns slot of launcher weapon for projectile in specified slot */
@@ -318,7 +303,7 @@ public:
 	/** Returns a slot which might be empty, or capable of holding item (or part of it) */
 	int FindCandidateSlot(int slottype, size_t first_slot, const ResRef& resref = ResRef()) const;
 	/** Creates an item in the slot*/
-	void SetSlotItemRes(const ResRef& ItemResRef, int SlotID, int Charge0 = 1, int Charge1 = 0, int Charge2 = 0);
+	void SetSlotItemRes(const ResRef& ItemResRef, size_t SlotID, int Charge0 = 1, int Charge1 = 0, int Charge2 = 0);
 	/** Adds item to slot*/
 	void AddSlotItemRes(const ResRef& ItemResRef, int Slot, int Charge0 = 1, int Charge1 = 0, int Charge2 = 0);
 	/** returns the itemtype held in the left hand */
@@ -332,15 +317,15 @@ public:
 	/** Finds best ranged weapon if any and reports status */
 	bool CanEquipRanged(int& maxDamage, ieDword& bestSlot) const;
 	/** Equips best weapon */
-	void EquipBestWeapon(int flags);
+	bool EquipBestWeapon(int flags);
 	/** returns the struct of the usable items, returns true if there are more */
 	bool GetEquipmentInfo(std::vector<ItemExtHeader>& headerList, int startindex, int count) const;
 	/** returns the exclusion bits */
 	ieDword GetEquipExclusion(int index) const;
 	/** returns if a slot is temporarily blocked */
 	bool IsSlotBlocked(int slot) const;
-	/** returns true if a two handed weapon is in slot */
-	bool TwoHandedInSlot(int slot) const;
+	/** returns any HCStrings objection to using the shield slot */
+	HCStrings CanUseShieldSlot(int slot, bool ranged) const;
 	/** returns the strref for the reason why the item cannot be equipped */
 	HCStrings WhyCantEquip(int slot, int twohanded, bool ranged = false) const;
 	/** returns a slot that has a stealable item */
@@ -348,7 +333,7 @@ public:
 	/** checks if any equipped item provides critical hit aversion */
 	bool ProvidesCriticalAversion() const;
 	/** tries to merge the passed item with the one in the passed slot */
-	int MergeItems(int slot, CREItem *item);
+	int MergeItems(int slot, CREItem* item);
 	bool FistsEquipped() const;
 	bool MagicSlotEquipped() const;
 	//setting important constants
@@ -374,15 +359,16 @@ public:
 	static int GetInventorySlot();
 	int InBackpack(int slot) const;
 	void CacheAllWeaponInfo() const;
+
 private:
 	void CalculateWeight(void);
 	int FindRangedProjectile(unsigned int type) const;
 	// called by KillSlot
-	void RemoveSlotEffects(ieDword slot);
-	void KillSlot(unsigned int index);
-	inline Item *GetItemPointer(ieDword slot, CREItem *&Slot) const;
+	void RemoveSlotEffects(size_t slot);
+	void KillSlot(size_t index);
+	inline Item* GetItemPointer(ieDword slot, CREItem*& Slot) const;
 	void UpdateWeaponAnimation();
-	void UpdateShieldAnimation(const Item *it);
+	bool UpdateShieldAnimation(const Item* it);
 	void CacheWeaponInfo(bool leftOrRight) const;
 };
 
