@@ -1,13 +1,16 @@
+
 #include "MapReverb.h"
+
+#include "GameData.h"
 #include "Map.h"
 
 namespace GemRB {
 
-Map::MapReverb::MapReverb (MapEnv env, id_t reverbID)
+Map::MapReverb::MapReverb(MapEnv env, id_t reverbID)
 {
 	AutoTable reverbs = gamedata->LoadTable("reverb");
-	
-	MapReverbProperties _properties = {EFX_REVERB_GENERIC, true};
+
+	MapReverbProperties _properties = { EFX_REVERB_GENERIC, true };
 	properties = _properties;
 
 	profile_t reverbProfile = EFX_PROFILE_REVERB_INVALID;
@@ -18,7 +21,7 @@ Map::MapReverb::MapReverb (MapEnv env, id_t reverbID)
 
 		/* If still nothing, fallback to something Ok. */
 		if (EFX_PROFILE_REVERB_INVALID == reverbProfile) {
-			if (env & (AT_OUTDOOR|AT_CITY|AT_FOREST)) {
+			if (env & (AT_OUTDOOR | AT_CITY | AT_FOREST)) {
 				reverbProfile = loadProperties(reverbs, EFX_PROFILE_OUTSIDE);
 			} else if (env & AT_DUNGEON) {
 				reverbProfile = loadProperties(reverbs, EFX_PROFILE_DUNGEON);
@@ -30,45 +33,47 @@ Map::MapReverb::MapReverb (MapEnv env, id_t reverbID)
 }
 
 Map::MapReverb::MapReverb(MapEnv env, const ResRef& mapref)
-: MapReverb(env, obtainProfile(mapref))
+	: MapReverb(env, obtainProfile(mapref))
 {}
 
-Map::MapReverb::profile_t Map::MapReverb::loadProperties (const AutoTable &reverbs, id_t reverbID) {
-	if (reverbID > reverbs->GetRowCount()) {
+Map::MapReverb::profile_t Map::MapReverb::loadProperties(const AutoTable& reverbs, id_t reverbIdx)
+{
+	if (reverbIdx > reverbs->GetRowCount()) {
 		return EFX_PROFILE_REVERB_INVALID;
 	}
 
-	const ieVariable efxProfileName = reverbs->QueryField(reverbID, 0);
+	const ieVariable efxProfileName = reverbs->QueryField(reverbIdx, 0);
 
 	/* Limited to values seemingly used. */
 	if (efxProfileName == "ARENA") {
-		MapReverbProperties _properties = {EFX_REVERB_ARENA, false};
+		MapReverbProperties _properties = { EFX_REVERB_ARENA, false };
 		properties = _properties;
 	} else if (efxProfileName == "AUDITORIUM") {
-		MapReverbProperties _properties = {EFX_REVERB_AUDITORIUM, false};
+		MapReverbProperties _properties = { EFX_REVERB_AUDITORIUM, false };
 		properties = _properties;
 	} else if (efxProfileName == "CITY") {
-		MapReverbProperties _properties = {EFX_REVERB_CITY, false};
+		MapReverbProperties _properties = { EFX_REVERB_CITY, false };
 		properties = _properties;
 	} else if (efxProfileName == "FOREST") {
-		MapReverbProperties _properties = {EFX_REVERB_FOREST, false};
+		MapReverbProperties _properties = { EFX_REVERB_FOREST, false };
 		properties = _properties;
 	} else if (efxProfileName == "ROOM") {
-		MapReverbProperties _properties = {EFX_REVERB_ROOM, false};
+		MapReverbProperties _properties = { EFX_REVERB_ROOM, false };
 		properties = _properties;
 	}
 
-	float decay = strtof(reverbs->QueryField(reverbID, 2).c_str(), nullptr);
+	float decay = strtof(reverbs->QueryField(reverbIdx, 2).c_str(), nullptr);
 	if (decay >= 0.0f && decay <= 20.0f) {
 		properties.reverbData.flDecayTime = decay;
 	}
 
 	/* TODO: deal with DAMPING, REVERB_LEVEL, VOLUME */
 
-	return reverbID;
+	return reverbIdx;
 }
 
-Map::MapReverb::id_t Map::MapReverb::obtainProfile(const ResRef& mapref) {
+Map::MapReverb::id_t Map::MapReverb::obtainProfile(const ResRef& mapref)
+{
 	const AutoTable& reverbMapping = gamedata->LoadTable("reverbs", true);
 	if (!reverbMapping) return EFX_PROFILE_REVERB_INVALID;
 	TableMgr::index_t rows = reverbMapping->GetRowCount();
