@@ -23,9 +23,11 @@
 #include "RGBAColor.h"
 #include "exports.h"
 #include "ie_types.h"
-#include "Holder.h"
+
+#include "MurmurHash.h"
 
 #include <algorithm>
+#include <array>
 #include <cassert>
 #include <cstdint>
 #include <cstring>
@@ -45,48 +47,49 @@ struct RGBModifier {
 	bool locked;
 };
 
-class Palette;
-using PaletteHolder = Holder<Palette>;
-
-class GEM_EXPORT Palette : public Held<Palette>
-{
-private:
-	void CopyColorRangePrivate(const Color* srcBeg, const Color* srcEnd, Color* dst) const noexcept;
-	void UpdateAlpha() noexcept;
+class GEM_EXPORT Palette {
 public:
-	Palette(const Color &color, const Color &back) noexcept;
+	using Colors = std::array<Color, 256>;
 
-	Palette(const Color* begin, const Color* end) noexcept
-	: Palette() {
-		std::copy(begin, end, col);
-		UpdateAlpha();
+	Palette(bool named = false) noexcept;
+	Palette(const Color& color, const Color& back) noexcept;
+
+	template<class Iterator>
+	Palette(const Iterator begin, const Iterator end) noexcept
+		: Palette()
+	{
+		std::copy(begin, end, colors.begin());
+		updateVersion();
 	}
 
-	Palette() noexcept = default;
+	bool HasAlpha() const noexcept { return true; /* Drop when SDL1 is gone. */ }
 
-	Color col[256]; //< RGB or RGBA 8 bit palette
-	bool named = false; //< true if the palette comes from a bmp and cached
-
-	unsigned short GetVersion() const noexcept { return version; }
-
-	bool HasAlpha() const noexcept { return alpha; }
-
-	void SetupPaperdollColours(const ieDword* Colors, unsigned int type) noexcept;
-	void SetupRGBModification(const PaletteHolder& src, const RGBModifier* mods,
-		unsigned int type) noexcept;
-	void SetupGlobalRGBModification(const PaletteHolder& src,
-		const RGBModifier& mod) noexcept;
-
-	PaletteHolder Copy() const noexcept;
-
-	void CopyColorRange(const Color* srcBeg, const Color* srcEnd, uint8_t dst) noexcept;
 	bool operator==(const Palette&) const noexcept;
 	bool operator!=(const Palette&) const noexcept;
+
+	Colors::const_iterator cbegin() const noexcept;
+	Colors::const_iterator cend() const noexcept;
+	Colors::const_reference operator[](size_t pos) const;
+
+	template<class Iterator>
+	void CopyColors(size_t offset, Iterator begin, Iterator end)
+	{
+		std::copy(begin, end, colors.begin() + offset);
+		updateVersion();
+	}
+
+	const Color* ColorData() const;
+	Colors::const_reference GetColorAt(size_t pos) const;
+	Hash GetVersion() const;
+	bool IsNamed() const;
+	void SetColor(size_t index, const Color& c);
+
 private:
-	unsigned short version = 0;
-	bool alpha = false; // true if any colors in the palette have an alpha < 255
-	// FIXME: version is not enough since `col` is public
-	// must make it private to fully capture changes to it
+	Colors colors;
+	Hash version;
+	bool named = false; // true if the palette comes from a bmp and cached
+
+	void updateVersion();
 };
 
 }
