@@ -24,23 +24,24 @@
 #include "Game.h"
 #include "Interface.h"
 #include "TableMgr.h"
+
 #include "Video/Video.h"
 
 namespace GemRB {
 
-Color sparkcolors[MAX_SPARK_COLOR][MAX_SPARK_PHASE]{};
+Color sparkcolors[MAX_SPARK_COLOR][MAX_SPARK_PHASE] {};
 bool inited = false;
 
-static const int spark_color_indices[MAX_SPARK_COLOR] = {12, 5, 0, 6, 1, 8, 2, 7, 9, 3, 4, 10, 11};
+static const int spark_color_indices[MAX_SPARK_COLOR] = { 12, 5, 0, 6, 1, 8, 2, 7, 9, 3, 4, 10, 11 };
 
-static void TranslateColor(const char *value, Color &color)
+static void TranslateColor(const char* value, Color& color)
 {
 	//if not RGB then try to interpret it as a dword
 	if (strnicmp(value, "RGB(", 4) != 0) {
 		uint32_t c = strtounsigned<uint32_t>(value);
 		color = Color::FromABGR(c);
 	} else {
-		sscanf(value+4,"%hhu,%hhu,%hhu)", &color.r, &color.g, &color.b);
+		sscanf(value + 4, "%hhu,%hhu,%hhu)", &color.r, &color.g, &color.b);
 	}
 }
 
@@ -56,7 +57,7 @@ static void InitSparks()
 		}
 	}
 	TableMgr::index_t i = tab->GetRowCount();
-	if (i>MAX_SPARK_COLOR) {
+	if (i > MAX_SPARK_COLOR) {
 		i = MAX_SPARK_COLOR;
 	}
 	while (i--) {
@@ -68,7 +69,7 @@ static void InitSparks()
 			} else {
 				idx = i;
 			}
-			const char *value = tab->QueryField(idx,j).c_str();
+			const char* value = tab->QueryField(idx, j).c_str();
 			TranslateColor(value, sparkcolors[i][j]);
 		}
 	}
@@ -89,12 +90,18 @@ Particles::Particles(int s)
 	size = last_insert = s;
 }
 
+void Particles::SetColorIndex(ieByte c)
+{
+	colorIdx = c;
+	color = Color();
+}
+
 void Particles::SetBitmap(unsigned int FragAnimID)
 {
 	//int i;
 
-	fragments = GemRB::make_unique<CharAnimations>(FragAnimID, 0);
-/*
+	fragments = std::make_unique<CharAnimations>(FragAnimID, 0);
+	/*
 	for (i=0;i<MAX_SPARK_PHASE;i++) {
 		delete( bitmap[i] );
 	}
@@ -113,26 +120,25 @@ void Particles::SetBitmap(unsigned int FragAnimID)
 */
 }
 
-bool Particles::AddNew(const Point &point)
+bool Particles::AddNew(const Point& point)
 {
 	int st;
 
-	switch(path)
-	{
-	case SP_PATH_EXPL:
-		st = pos.h+last_insert%15;
-		break;
-	case SP_PATH_RAIN:
-	case SP_PATH_FLIT:
-		st = core->Roll(3,5,MAX_SPARK_PHASE)<<4;
-		break;
-	case SP_PATH_FOUNT:
-		st =(MAX_SPARK_PHASE + 2*pos.h);
-		break;
-	case SP_PATH_FALL:
-	default:
-		st =(MAX_SPARK_PHASE + pos.h)<<4;
-		break;
+	switch (path) {
+		case SP_PATH_EXPL:
+			st = pos.h + last_insert % 15;
+			break;
+		case SP_PATH_RAIN:
+		case SP_PATH_FLIT:
+			st = core->Roll(3, 5, MAX_SPARK_PHASE) << 4;
+			break;
+		case SP_PATH_FOUNT:
+			st = (MAX_SPARK_PHASE + 2 * pos.h);
+			break;
+		case SP_PATH_FALL:
+		default:
+			st = (MAX_SPARK_PHASE + pos.h) << 4;
+			break;
 	}
 	int i = last_insert;
 	while (i--) {
@@ -144,7 +150,7 @@ bool Particles::AddNew(const Point &point)
 		}
 	}
 	i = size;
-	while (i--!=last_insert) {
+	while (i-- != last_insert) {
 		if (points[i].state == -1) {
 			points[i].state = st;
 			points[i].pos = point;
@@ -157,12 +163,10 @@ bool Particles::AddNew(const Point &point)
 
 void Particles::Draw(Point p)
 {
-	Video *video=core->GetVideoDriver();
-	const Game *game = core->GetGame();
+	const Game* game = core->GetGame();
 
 	if (owner) {
-		p.x-=pos.x;
-		p.y-=pos.y;
+		p -= pos.origin;
 	}
 	ieWord i = size;
 	while (i--) {
@@ -171,29 +175,32 @@ void Particles::Draw(Point p)
 		}
 		int state;
 
-		switch(path) {
-		case SP_PATH_FLIT:
-		case SP_PATH_RAIN:
-			state = points[i].state>>4;
-			break;
-		default:
-			state = points[i].state;
-			break;
+		switch (path) {
+			case SP_PATH_FLIT:
+			case SP_PATH_RAIN:
+				state = points[i].state >> 4;
+				break;
+			default:
+				state = points[i].state;
+				break;
 		}
 
 		int length; //used only for raindrops
-		if (state>=MAX_SPARK_PHASE) {
-			constexpr int maxDropLength = 6;
-			length = maxDropLength - abs(state - MAX_SPARK_PHASE - maxDropLength);
+		if (state >= MAX_SPARK_PHASE) {
+			constexpr int maxDropLength = 10;
+			length = maxDropLength - std::abs(state - MAX_SPARK_PHASE - maxDropLength);
 			state = 0;
 		} else {
-			state=MAX_SPARK_PHASE-state-1;
-			length=0;
+			state = MAX_SPARK_PHASE - state - 1;
+			length = 0;
+		}
+		Color clr = color;
+		if (!clr.Packed()) {
+			clr = sparkcolors[colorIdx][state];
 		}
-		Color clr = sparkcolors[color][state];
 		switch (type) {
-		case SP_TYPE_BITMAP:
-			/*
+			case SP_TYPE_BITMAP:
+				/*
 			if (bitmap[state]) {
 				Holder<Sprite2D> frame = bitmap[state]->GetFrame(points[i].state&255);
 				video->BlitGameSprite(frame,
@@ -202,36 +209,37 @@ void Particles::Draw(Point p)
 					NULL, NULL, &screen);
 			}
 			*/
-			if (fragments) {
-				//IE_ANI_CAST stance has a simple looping animation
-				const auto* anims = fragments->GetAnimation(IE_ANI_CAST, ClampToOrientation(i));
-				if (!anims) {
-					break;
+				if (fragments) {
+					//IE_ANI_CAST stance has a simple looping animation
+					const auto* anims = fragments->GetAnimation(IE_ANI_CAST, ClampToOrientation(i));
+					if (!anims) {
+						break;
+					}
+
+					const auto anim = anims->at(0);
+					Holder<Sprite2D> nextFrame = anim->GetFrame(anim->GetCurrentFrameIndex());
+
+					BlitFlags flags = BlitFlags::NONE;
+					if (game) game->ApplyGlobalTint(clr, flags);
+
+					VideoDriver->BlitGameSpriteWithPalette(nextFrame, fragments->GetPartPalette(0),
+									       points[i].pos - p, flags, clr);
 				}
-
-				const auto anim = anims->at(0);
-				Holder<Sprite2D> nextFrame = anim->GetFrame(anim->GetCurrentFrameIndex());
-
-				BlitFlags flags = BlitFlags::NONE;
-				if (game) game->ApplyGlobalTint(clr, flags);
-
-				video->BlitGameSpriteWithPalette(nextFrame, fragments->GetPartPalette(0),
-													points[i].pos - p, flags, clr);
-			}
-			break;
-		case SP_TYPE_CIRCLE:
-			video->DrawCircle (points[i].pos - p, 2, clr);
-			break;
-		case SP_TYPE_POINT:
-		default:
-			video->DrawPoint(points[i].pos - p, clr);
-			break;
-		// this is more like a raindrop
-		case SP_TYPE_LINE:
-			if (length) {
-				video->DrawLine (points[i].pos - p, points[i].pos - p + Point((i&1), length), clr);
-			}
-			break;
+				break;
+			case SP_TYPE_CIRCLE:
+				VideoDriver->DrawCircle(points[i].pos - p, 2, clr);
+				break;
+			case SP_TYPE_POINT:
+			default:
+				VideoDriver->DrawPoint(points[i].pos - p, clr);
+				break;
+			// this is more like a raindrop
+			case SP_TYPE_LINE:
+				if (length) {
+					int y = length > 3 ? i & 1 : 0;
+					VideoDriver->DrawLine(points[i].pos - p, points[i].pos - p + Point(y, length), clr);
+				}
+				break;
 		}
 	}
 }
@@ -242,112 +250,117 @@ void Particles::AddParticles(int count)
 		Point p;
 
 		switch (path) {
-		case SP_PATH_EXPL:
-			p.x = pos.w/2+core->Roll(1,pos.w/2,pos.w/4);
-			p.y = pos.h/2+(last_insert&7);
-			break;
-		case SP_PATH_FALL:
-		default:
-			p.x = core->Roll(1,pos.w,0);
-			p.y = core->Roll(1,pos.h/2,0);
-			break;
-		case SP_PATH_RAIN:
-		case SP_PATH_FLIT:
-			p.x = core->Roll(1,pos.w,0);
-			p.y = core->Roll(1,pos.h,0);
-			break;
-		case SP_PATH_FOUNT:
-			p.x = core->Roll(1,pos.w/2,pos.w/4);
-			p.y = core->Roll(1,pos.h/2,0);
+			case SP_PATH_EXPL:
+				p.x = pos.w / 2 + core->Roll(1, pos.w / 2, pos.w / 4);
+				p.y = pos.h / 2 + (last_insert & 7);
+				break;
+			case SP_PATH_FALL:
+			default:
+				p.x = core->Roll(1, pos.w, 0);
+				p.y = core->Roll(1, pos.h / 2, 0);
+				break;
+			case SP_PATH_RAIN:
+			case SP_PATH_FLIT:
+				p.x = core->Roll(1, pos.w, 0);
+				p.y = core->Roll(1, pos.h, 0);
+				break;
+			case SP_PATH_FOUNT:
+				p.x = core->Roll(1, pos.w / 2, pos.w / 4);
+				p.y = core->Roll(1, pos.h / 2, 0);
+				break;
+		}
+		if (AddNew(p)) {
 			break;
 		}
-		if (AddNew(p) ) {
-			break;
-	 	}
 	}
 }
 
 int Particles::Update()
 {
-	int drawn=false;
+	int drawn = false;
 
-	if (phase==P_EMPTY) {
+	if (phase == P_EMPTY) {
 		return drawn;
 	}
 
+	// emulate 30 FPS
+	tick_t time = GetMilliseconds();
+	if (time - lastUpdate < 1000 / 30) return drawn;
+	lastUpdate = time;
+
 	if (timetolive) {
-		if (timetolive<core->GetGame()->GameTime) {
+		if (timetolive < core->GetGame()->GameTime) {
 			spawn_type = SP_SPAWN_NONE;
 			phase = P_FADE;
 		}
 	}
 
 	int grow;
-	switch(spawn_type) {
-	case SP_SPAWN_NONE:
-		grow = 0;
-		break;
-	case SP_SPAWN_FULL:
-		grow = size;
-		spawn_type=SP_SPAWN_NONE;
-		break;
-	case SP_SPAWN_SOME:
-	default:
-		grow = size/10;
+	switch (spawn_type) {
+		case SP_SPAWN_NONE:
+			grow = 0;
+			break;
+		case SP_SPAWN_FULL:
+			grow = size;
+			spawn_type = SP_SPAWN_NONE;
+			break;
+		case SP_SPAWN_SOME:
+		default:
+			grow = size / 10;
 	}
 	for (int i = 0; i < size; i++) {
-		if (points[i].state==-1) {
+		if (points[i].state == -1) {
 			continue;
 		}
-		drawn=true;
+		drawn = true;
 		if (!points[i].state) {
 			grow++;
 		}
 		points[i].state--;
 
 		switch (path) {
-		case SP_PATH_FALL:
-			points[i].pos.y+=3+((i>>2)&3);
-			points[i].pos.y%=pos.h;
-			break;
-		case SP_PATH_RAIN:
-			points[i].pos.x+=pos.w+(i&1);
-			points[i].pos.x%=pos.w;
-			points[i].pos.y+=3+((i>>2)&3);
-			points[i].pos.y%=pos.h;
-			break;
-		case SP_PATH_FLIT:
-			if (points[i].state<=MAX_SPARK_PHASE<<4) {
+			case SP_PATH_FALL:
+				points[i].pos.y += 3 + ((i >> 2) & 3);
+				points[i].pos.y %= pos.h;
 				break;
-			}
-			points[i].pos.x+=core->Roll(1,3,pos.w-2);
-			points[i].pos.x%=pos.w;
-			points[i].pos.y+=(i&3)+1;
-			break;
-		case SP_PATH_EXPL:
-			points[i].pos.y+=1;
-			break;
-		case SP_PATH_FOUNT:
-			if (points[i].state<=MAX_SPARK_PHASE) {
+			case SP_PATH_RAIN:
+				points[i].pos.x += pos.w + (i & 1);
+				points[i].pos.x %= pos.w;
+				points[i].pos.y += 3 + ((i >> 2) & 3);
+				points[i].pos.y %= pos.h;
 				break;
-			}
-			if (points[i].state<(MAX_SPARK_PHASE+pos.h)) {
-				if ( (points[i].state&7) == 7) {
-					points[i].pos.x+=(i&3)-1;
+			case SP_PATH_FLIT:
+				if (points[i].state <= MAX_SPARK_PHASE << 4) {
+					break;
 				}
-				points[i].pos.y+=2;
-			} else {
-				if ( (points[i].state&7) == 7) {
-					points[i].pos.x+=(i&3)-1;
+				points[i].pos.x += core->Roll(1, 3, pos.w - 2);
+				points[i].pos.x %= pos.w;
+				points[i].pos.y += (i & 3) + 1;
+				break;
+			case SP_PATH_EXPL:
+				points[i].pos.y += 1;
+				break;
+			case SP_PATH_FOUNT:
+				if (points[i].state <= MAX_SPARK_PHASE) {
+					break;
 				}
-				points[i].pos.y-=2;
-			}
-			break;
+				if (points[i].state < (MAX_SPARK_PHASE + pos.h)) {
+					if ((points[i].state & 7) == 7) {
+						points[i].pos.x += (i & 3) - 1;
+					}
+					points[i].pos.y += 2;
+				} else {
+					if ((points[i].state & 7) == 7) {
+						points[i].pos.x += (i & 3) - 1;
+					}
+					points[i].pos.y -= 2;
+				}
+				break;
 		}
 	}
-	if (phase==P_GROW) {
+	if (phase == P_GROW) {
 		AddParticles(grow);
-		drawn=true;
+		drawn = true;
 	}
 	if (!drawn) {
 		phase = P_EMPTY;
