@@ -20,7 +20,7 @@
 
 namespace GemRB {
 
-PluginMgr *PluginMgr::Get()
+PluginMgr* PluginMgr::Get()
 {
 	static PluginMgr mgr;
 	return &mgr;
@@ -31,7 +31,7 @@ bool PluginMgr::IsAvailable(SClass_ID plugintype) const
 	return plugins.find(plugintype) != plugins.end();
 }
 
-Plugin* PluginMgr::GetPlugin(SClass_ID plugintype) const
+PluginHolder<Plugin> PluginMgr::GetPlugin(SClass_ID plugintype) const
 {
 	std::map<SClass_ID, PluginFunc>::const_iterator iter = plugins.find(plugintype);
 	if (iter != plugins.end())
@@ -52,12 +52,12 @@ bool PluginMgr::RegisterPlugin(SClass_ID id, PluginFunc create)
 	return true;
 }
 
-void PluginMgr::RegisterResource(const TypeID* type, ResourceFunc create, const char *ext, ieWord keyType)
+void PluginMgr::RegisterResource(const TypeID* type, ResourceFunc create, const path_t& ext, ieWord keyType)
 {
 	resources[type].emplace_back(type, create, ext, keyType);
 }
 
-void PluginMgr::RegisterInitializer(void (*func)(void))
+void PluginMgr::RegisterInitializer(void (*func)(const CoreSettings&))
 {
 	initializerFunctions.push_back(func);
 }
@@ -67,10 +67,10 @@ void PluginMgr::RegisterCleanup(void (*func)(void))
 	cleanupFunctions.push_back(func);
 }
 
-void PluginMgr::RunInitializers() const
+void PluginMgr::RunInitializers(const CoreSettings& config) const
 {
 	for (const auto initializerFunction : initializerFunctions) {
-		initializerFunction();
+		initializerFunction(config);
 	}
 }
 
@@ -81,9 +81,9 @@ void PluginMgr::RunCleanup() const
 	}
 }
 
-bool PluginMgr::RegisterDriver(const TypeID* type, const char* name, PluginFunc create)
+bool PluginMgr::RegisterDriver(const TypeID* type, const std::string& name, PluginFunc create)
 {
-	driver_map &map = drivers[type];
+	driver_map& map = drivers[type];
 	driver_map::const_iterator iter = map.find(name);
 	if (iter != map.end())
 		return false;
@@ -91,9 +91,9 @@ bool PluginMgr::RegisterDriver(const TypeID* type, const char* name, PluginFunc
 	return true;
 }
 
-Plugin* PluginMgr::GetDriver(const TypeID* type, const char* name)
+PluginHolder<Plugin> PluginMgr::GetDriver(const TypeID* type, const std::string& name)
 {
-	driver_map &map = drivers[type];
+	driver_map& map = drivers[type];
 	if (map.begin() == map.end())
 		return NULL;
 	driver_map::const_iterator iter = map.find(name);
