@@ -30,10 +30,12 @@
 #include "SClassID.h" // For PluginID
 #include "exports.h"
 #include "globals.h"
+
 #include "Plugin.h"
-#include "Plugins/ImporterPlugin.h"
 #include "ResourceDesc.h"
 
+#include "Plugins/ImporterPlugin.h"
+
 #include <cstring>
 #include <list>
 #include <map>
@@ -42,6 +44,7 @@
 namespace GemRB {
 
 class TypeID;
+struct CoreSettings;
 
 /**
  * @class PluginMgr
@@ -52,26 +55,30 @@ class TypeID;
 
 class GEM_EXPORT PluginMgr {
 public:
-	using ResourceFunc = Resource* (*)(DataStream*);
-	using PluginFunc = Plugin* (*)();
+	using ResourceFunc = ResourceHolder<Resource> (*)(DataStream*);
+	using PluginFunc = PluginHolder<Plugin> (*)();
+
 public:
 	/** Return global instance of PluginMgr */
 	static PluginMgr* Get();
+
 private:
 	PluginMgr() noexcept {};
+
 private:
-	std::map< SClass_ID, PluginFunc> plugins;
-	std::map< const TypeID*, std::vector<ResourceDesc> > resources;
+	std::map<SClass_ID, PluginFunc> plugins;
+	std::map<const TypeID*, std::vector<ResourceDesc>> resources;
 	/** Array of initializer functions */
-	std::vector<void (*)(void)> initializerFunctions;
+	std::vector<void (*)(const CoreSettings&)> initializerFunctions;
 	/** Array of cleanup functions */
 	std::vector<void (*)(void)> cleanupFunctions;
 	using driver_map = std::map<std::string, PluginFunc>;
 	std::map<const TypeID*, driver_map> drivers;
+
 public:
 	size_t GetPluginCount() const { return plugins.size(); }
 	bool IsAvailable(SClass_ID plugintype) const;
-	Plugin* GetPlugin(SClass_ID plugintype) const;
+	PluginHolder<Plugin> GetPlugin(SClass_ID plugintype) const;
 
 
 	/**
@@ -89,16 +96,16 @@ public:
 	 * @param[in] ext Extension used for resource files.
 	 * @param[in] keyType \iespecific Type identifier used in key/biff files.
 	 */
-	void RegisterResource(const TypeID* type, ResourceFunc create, const char *ext, ieWord keyType = 0);
+	void RegisterResource(const TypeID* type, ResourceFunc create, const path_t& ext, ieWord keyType = 0);
 
 	const std::vector<ResourceDesc>& GetResourceDesc(const TypeID*);
 
 	/**
-	 * Registers a static intializer.
+	 * Registers a static initializer.
 	 *
 	 * @param[in] init Function to call on startup.
 	 */
-	void RegisterInitializer(void (*init)(void));
+	void RegisterInitializer(void (*init)(const CoreSettings&));
 	/**
 	 * Registers a static cleanup.
 	 *
@@ -106,8 +113,8 @@ public:
 	 */
 	void RegisterCleanup(void (*cleanup)(void));
 
-	/** Run intializer functions. */
-	void RunInitializers() const;
+	/** Run initializer functions. */
+	void RunInitializers(const CoreSettings&) const;
 	/** Run cleanup functions */
 	void RunCleanup() const;
 
@@ -118,7 +125,7 @@ public:
 	 * @param[in] name Name of driver.
 	 * @param[in] create Function to create instance of plugin.
 	 */
-	bool RegisterDriver(const TypeID* type, const char* name, PluginFunc create);
+	bool RegisterDriver(const TypeID* type, const std::string& name, PluginFunc create);
 
 	/**
 	 * Gets driver of specified type.
@@ -128,24 +135,24 @@ public:
 	 *
 	 * Tries to get driver associated to name, or falls back to a random one.
 	 */
-	Plugin* GetDriver(const TypeID* type, const char* name);
+	PluginHolder<Plugin> GetDriver(const TypeID* type, const std::string& name);
 };
 
-template <typename T>
-using PluginHolder = std::shared_ptr<T>;
-
-template <typename T>
-PluginHolder<T> MakePluginHolder(PluginID id) {
-	return PluginHolder<T>(static_cast<T*>(PluginMgr::Get()->GetPlugin(id)));
+template<typename T>
+PluginHolder<T> MakePluginHolder(PluginID id)
+{
+	return std::static_pointer_cast<T>(PluginMgr::Get()->GetPlugin(id));
 }
 
-template <typename T>
-PluginHolder<ImporterPlugin<T>> MakeImporterPluginHolder(PluginID id) {
+template<typename T>
+PluginHolder<ImporterPlugin<T>> MakeImporterPluginHolder(PluginID id)
+{
 	return MakePluginHolder<ImporterPlugin<T>>(id);
 }
 
-template <typename T>
-PluginHolder<T> GetImporter(PluginID id) {
+template<typename T>
+PluginHolder<T> GetImporter(PluginID id)
+{
 	auto plugin = MakeImporterPluginHolder<T>(id);
 	if (plugin) {
 		return plugin->GetImporter();
@@ -153,8 +160,9 @@ PluginHolder<T> GetImporter(PluginID id) {
 	return nullptr;
 }
 
-template <typename T>
-PluginHolder<T> GetImporter(PluginID id, DataStream* str) {
+template<typename T>
+PluginHolder<T> GetImporter(PluginID id, DataStream* str)
+{
 	auto plugin = MakeImporterPluginHolder<T>(id);
 	if (plugin) {
 		return plugin->GetImporter(str);
