@@ -32,7 +32,7 @@ namespace GemRB {
 // Construction/Destruction
 //////////////////////////////////////////////////////////////////////
 
-#define MAX_PROJ_IDX  0x1fff
+#define MAX_PROJ_IDX 0x1fff
 
 ProjectileServer::ProjectileServer() noexcept
 {
@@ -58,7 +58,7 @@ ProjectileServer::ProjectileServer() noexcept
 		projectilecount = 1;
 	}
 	projectiles.resize(projectilecount);
-	
+
 	// finally, we must read the projectile resrefs
 	if (projlist) {
 		AddSymbols(projlist);
@@ -69,51 +69,49 @@ ProjectileServer::ProjectileServer() noexcept
 		AddSymbols(gemprojlist);
 		core->DelSymbol(gemresource);
 	}
-	
+
 	AutoTable explist = gamedata->LoadTable("areapro");
 	if (explist) {
 		TableMgr::index_t rows = explist->GetRowCount();
 		//cannot handle 0xff and it is easier to set up the fields
 		//without areapro.2da anyway. So this isn't a restriction
-		if(rows>254) {
-			rows=254;
+		if (rows > 254) {
+			rows = 254;
 		}
 		explosions.resize(rows);
-		while(rows--) {
-			int i;
-
-			for(i=0;i<AP_RESCNT;i++) {
+		while (rows) {
+			--rows;
+			for (int i = 0; i < AP_RESCNT; i++) {
 				explosions[rows].resources[i] = explist->QueryField(rows, i);
 			}
-			//using i so the flags field will always be after the resources
-			explosions[rows].flags = explist->QueryFieldSigned<int>(rows,i);
+			explosions[rows].flags = explist->QueryFieldSigned<int>(rows, AP_RESCNT);
 		}
 	}
 }
 
-Projectile *ProjectileServer::CreateDefaultProjectile(size_t idx)
+Projectile* ProjectileServer::CreateDefaultProjectile(size_t idx)
 {
-	Projectile *pro = new Projectile();
+	Projectile* pro = new Projectile();
 
 	//take care, this projectile is not freed up by the server
-	if(idx==(unsigned int) ~0 ) {
+	if (idx == (unsigned int) ~0) {
 		return pro;
 	}
 
 	pro->SetIdentifiers(projectiles[idx].resname, idx);
-	projectiles[idx].projectile = make_unique<Projectile>(*pro);
-	
+	projectiles[idx].projectile = std::make_unique<Projectile>(*pro);
+
 	return pro;
 }
 
 //this function can return only projectiles listed in projectl.ids
-Projectile *ProjectileServer::GetProjectileByName(const ResRef &resname)
+Projectile* ProjectileServer::GetProjectileByName(const ResRef& resname)
 {
 	if (!core->IsAvailable(IE_PRO_CLASS_ID)) {
 		return NULL;
 	}
 	size_t idx = GetHighestProjectileNumber();
-	while(idx--) {
+	while (idx--) {
 		if (resname == projectiles[idx].resname) {
 			return GetProjectile(idx);
 		}
@@ -121,26 +119,26 @@ Projectile *ProjectileServer::GetProjectileByName(const ResRef &resname)
 	return NULL;
 }
 
-Projectile *ProjectileServer::GetProjectileByIndex(size_t idx)
+Projectile* ProjectileServer::GetProjectileByIndex(size_t idx)
 {
 	if (!core->IsAvailable(IE_PRO_CLASS_ID)) {
 		return NULL;
 	}
-	if (idx>=GetHighestProjectileNumber()) {
+	if (idx >= GetHighestProjectileNumber()) {
 		return GetProjectile(0);
 	}
 
 	return GetProjectile(idx);
 }
 
-Projectile *ProjectileServer::ReturnCopy(size_t idx)
+Projectile* ProjectileServer::ReturnCopy(size_t idx)
 {
-	Projectile *pro = new Projectile(*projectiles[idx].projectile);
+	Projectile* pro = new Projectile(*projectiles[idx].projectile);
 	pro->SetIdentifiers(projectiles[idx].resname, idx);
 	return pro;
 }
 
-Projectile *ProjectileServer::GetProjectile(size_t idx)
+Projectile* ProjectileServer::GetProjectile(size_t idx)
 {
 	if (projectiles[idx].projectile) {
 		return ReturnCopy(idx);
@@ -154,48 +152,48 @@ Projectile *ProjectileServer::GetProjectile(size_t idx)
 	if (!sm->Open(str)) {
 		return CreateDefaultProjectile(idx);
 	}
-	Projectile *pro = new Projectile();
+	Projectile* pro = new Projectile();
 	pro->SetIdentifiers(projectiles[idx].resname, idx);
 
-	sm->GetProjectile( pro );
+	sm->GetProjectile(pro);
 	int Type = 0xff;
 
-	if(pro->Extension) {
+	if (pro->Extension) {
 		Type = pro->Extension->ExplType;
 	}
-	if(Type<0xff) {
+	if (Type < 0xff) {
 		ResRef res;
 
 		//fill the spread field according to the hardcoded explosion type
-		res = GetExplosion(Type,0);
+		res = GetExplosion(Type, 0);
 		if (res) {
 			pro->Extension->Spread = res;
 		}
-	
+
 		//if the hardcoded explosion type has a center animation
 		//override the VVC animation field with it
-		res = GetExplosion(Type,1);
-		if(res) {
-			pro->Extension->AFlags|=PAF_VVC;
+		res = GetExplosion(Type, 1);
+		if (res) {
+			pro->Extension->AFlags |= PAF_VVC;
 			pro->Extension->VVCRes = res;
 		}
 
 		//fill the secondary spread field out
-		res = GetExplosion(Type,2);
-		if(res) {
+		res = GetExplosion(Type, 2);
+		if (res) {
 			pro->Extension->Secondary = res;
 		}
 
 		//the explosion sound, used for the first explosion
 		//(overrides an original field)
-		res = GetExplosion(Type,3);
-		if(res) {
+		res = GetExplosion(Type, 3);
+		if (res) {
 			pro->Extension->SoundRes = res;
 		}
 
 		//the area sound (used for subsequent explosions)
-		res = GetExplosion(Type,4);
-		if(res) {
+		res = GetExplosion(Type, 4);
+		if (res) {
 			pro->Extension->AreaSound = res;
 		}
 
@@ -203,19 +201,18 @@ Projectile *ProjectileServer::GetProjectile(size_t idx)
 		pro->Extension->APFlags = explosions[Type].flags;
 	}
 
-	projectiles[idx].projectile = make_unique<Projectile>(*pro);
+	projectiles[idx].projectile = std::make_unique<Projectile>(*pro);
 	return pro;
 }
 
-size_t ProjectileServer::PrepareSymbols(const std::shared_ptr<SymbolMgr>& projlist) const
+size_t ProjectileServer::PrepareSymbols(const PluginHolder<SymbolMgr>& projlist) const
 {
 	size_t count = 0;
 
 	size_t rows = projlist->GetSize();
-	while(rows--) {
+	while (rows--) {
 		unsigned int value = projlist->GetValueIndex(rows);
-		if (value>MAX_PROJ_IDX) {
-			//value = MAX_PROJ_IDX;
+		if (value > MAX_PROJ_IDX) {
 			Log(WARNING, "ProjectileServer", "Too high projectilenumber");
 			continue; // ignore
 		}
@@ -227,11 +224,12 @@ size_t ProjectileServer::PrepareSymbols(const std::shared_ptr<SymbolMgr>& projli
 	return count;
 }
 
-void ProjectileServer::AddSymbols(const std::shared_ptr<SymbolMgr>& projlist) {
+void ProjectileServer::AddSymbols(const PluginHolder<SymbolMgr>& projlist)
+{
 	size_t rows = projlist->GetSize();
-	while(rows--) {
+	while (rows--) {
 		unsigned int value = projlist->GetValueIndex(rows);
-		if (value>MAX_PROJ_IDX) {
+		if (value > MAX_PROJ_IDX) {
 			continue;
 		}
 		projectiles[value].resname = ResRef(projlist->GetStringIndex(rows));
