@@ -35,58 +35,56 @@ class SymbolMgr;
 #define AP_RESCNT 5
 
 //this singleton object serves the projectile objects
-class GEM_EXPORT ProjectileServer
-{
+class GEM_EXPORT ProjectileServer {
 public:
 	ProjectileServer() noexcept;
 	ProjectileServer(const ProjectileServer&) = delete;
 	ProjectileServer& operator=(const ProjectileServer&) = delete;
-	
+
 	ProjectileServer(ProjectileServer&&) noexcept = default;
 	ProjectileServer& operator=(ProjectileServer&&) noexcept = default;
 
-	Projectile *GetProjectileByIndex(size_t idx);
+	Projectile* GetProjectileByIndex(size_t idx);
 	//it is highly unlikely we need this function
-	Projectile *GetProjectileByName(const ResRef &resname);
+	Projectile* GetProjectileByName(const ResRef& resname);
 	//returns the highest projectile id
 	size_t GetHighestProjectileNumber() const;
 	//creates an empty projectile on the fly
-	Projectile *CreateDefaultProjectile(size_t idx);
+	Projectile* CreateDefaultProjectile(size_t idx);
+
 private:
 	//this represents a line of projectl.ids
-	struct ProjectileEntry
-	{
+	struct ProjectileEntry {
 		ResRef resname;
 		std::unique_ptr<Projectile> projectile;
-		
+
 		ProjectileEntry() noexcept = default;
 		~ProjectileEntry() noexcept = default;
-		
+
 		ProjectileEntry(ProjectileEntry&&) noexcept = default;
 		ProjectileEntry& operator=(ProjectileEntry&&) noexcept = default;
-		
+
 		ProjectileEntry(const ProjectileEntry&) noexcept = delete;
 		ProjectileEntry& operator=(const ProjectileEntry&) noexcept = delete;
 	};
-	
+
 	static_assert(std::is_nothrow_move_constructible<ProjectileEntry>::value, "ProjectileEntry should be noexcept MoveConstructible");
-	
-	struct ExplosionEntry
-	{
+
+	struct ExplosionEntry {
 		ResRef resources[AP_RESCNT];
 		int flags = 0;
 	};
 
 	std::vector<ProjectileEntry> projectiles; //this is the list of projectiles
-	std::vector<ExplosionEntry> explosions;   //this is the list of explosion resources
+	std::vector<ExplosionEntry> explosions; //this is the list of explosion resources
 	// internal function: what is max valid projectile id?
-	size_t PrepareSymbols(const std::shared_ptr<SymbolMgr>& projlist) const;
+	size_t PrepareSymbols(const PluginHolder<SymbolMgr>& projlist) const;
 	// internal function: read projectiles
-	void AddSymbols(const std::shared_ptr<SymbolMgr>& projlist);
+	void AddSymbols(const PluginHolder<SymbolMgr>& projlist);
 	//this method is used internally
-	Projectile *GetProjectile(size_t idx);
+	Projectile* GetProjectile(size_t idx);
 	//creates a clone from the cached projectiles
-	Projectile *ReturnCopy(size_t idx);
+	Projectile* ReturnCopy(size_t idx);
 	//returns one of the resource names
 	ResRef GetExplosion(size_t idx, int type);
 };
