@@ -28,6 +28,7 @@
 #define RESOURCE_H
 
 #include "Plugin.h"
+
 #include "Strings/CString.h"
 
 #include <unordered_map>
@@ -37,8 +38,8 @@ namespace GemRB {
 /** Resource reference */
 class DataStream;
 
-template <typename T>
-using ResRefMap = std::unordered_map<ResRef, T, CstrHashCI<ResRef>>;
+template<typename T>
+using ResRefMap = std::unordered_map<ResRef, T, CstrHashCI>;
 
 /**
  * Base class for all GemRB resources
@@ -46,6 +47,9 @@ using ResRefMap = std::unordered_map<ResRef, T, CstrHashCI<ResRef>>;
 
 using Resource = ImporterBase;
 
+template<class T>
+using ResourceHolder = std::shared_ptr<T>; // TODO: this should be type constrained
+
 }
 
 #endif
