@@ -22,12 +22,12 @@
 
 namespace GemRB {
 
-ResourceDesc::ResourceDesc(const TypeID* type, CreateFunc create, const char *ext, ieWord keyType)
+ResourceDesc::ResourceDesc(const TypeID* type, CreateFunc create, const path_t& ext, ieWord keyType)
 	: type(type), ext(ext), keyType(keyType), create(create)
 {
 }
 
-const char* ResourceDesc::GetExt() const
+const path_t& ResourceDesc::GetExt() const
 {
 	return ext;
 }
@@ -42,7 +42,7 @@ ieWord ResourceDesc::GetKeyType() const
 	return keyType;
 }
 
-Resource* ResourceDesc::Create(DataStream *stream) const
+ResourceHolder<Resource> ResourceDesc::Create(DataStream* stream) const
 {
 	return create(stream);
 }
