@@ -34,12 +34,14 @@ class TypeID;
  */
 class GEM_EXPORT ResourceDesc {
 public:
-	using CreateFunc = Resource* (*)(DataStream*);
+	using CreateFunc = ResourceHolder<Resource> (*)(DataStream*);
+
 private:
-	const TypeID *type;
-	const char *ext;
+	const TypeID* type;
+	path_t ext;
 	ieWord keyType; // IE Specific
 	CreateFunc create;
+
 public:
 	/**
 	 * Create resource descriptor.
@@ -49,11 +51,11 @@ public:
 	 * @param[in] ext Extension used for resource files.
 	 * @param[in] keyType \iespecific Type identifier used in key/biff files.
 	 */
-	ResourceDesc(const TypeID* type, CreateFunc create, const char *ext, ieWord keyType = 0);
-	const char* GetExt() const;
+	ResourceDesc(const TypeID* type, CreateFunc create, const path_t& ext, ieWord keyType = 0);
+	const path_t& GetExt() const;
 	const TypeID* GetType() const;
 	ieWord GetKeyType() const;
-	Resource* Create(DataStream*) const;
+	ResourceHolder<Resource> Create(DataStream*) const;
 };
 
 }
