@@ -21,14 +21,70 @@
 #include "ResourceManager.h"
 
 #include "Interface.h"
-#include "Logging/Logging.h"
 #include "PluginMgr.h"
 #include "Resource.h"
 #include "ResourceDesc.h"
 
+#include "Logging/Logging.h"
+
 namespace GemRB {
 
-bool ResourceManager::AddSource(const char *path, const char *description, PluginID type, int flags)
+path_t TypeExt(SClass_ID type)
+{
+	static const std::map<SClass_ID, path_t> extensions = {
+		{ IE_2DA_CLASS_ID, "2da" },
+		{ IE_ACM_CLASS_ID, "acm" },
+		{ IE_ARE_CLASS_ID, "are" },
+		{ IE_BAM_CLASS_ID, "bam" },
+		{ IE_BCS_CLASS_ID, "bcs" },
+		{ IE_BS_CLASS_ID, "bs" },
+		{ IE_BIF_CLASS_ID, "bif" },
+		{ IE_BMP_CLASS_ID, "bmp" },
+		{ IE_PNG_CLASS_ID, "png" },
+		{ IE_CHR_CLASS_ID, "chr" },
+		{ IE_CHU_CLASS_ID, "chu" },
+		{ IE_CRE_CLASS_ID, "cre" },
+		{ IE_DLG_CLASS_ID, "dlg" },
+		{ IE_EFF_CLASS_ID, "eff" },
+		{ IE_GAM_CLASS_ID, "gam" },
+		{ IE_IDS_CLASS_ID, "ids" },
+		{ IE_INI_CLASS_ID, "ini" },
+		{ IE_ITM_CLASS_ID, "itm" },
+		{ IE_MOS_CLASS_ID, "mos" },
+		{ IE_MUS_CLASS_ID, "mus" },
+		{ IE_MVE_CLASS_ID, "mve" },
+		{ IE_OGG_CLASS_ID, "ogg" },
+		{ IE_PLT_CLASS_ID, "plt" },
+		{ IE_PRO_CLASS_ID, "pro" },
+		{ IE_PVRZ_CLASS_ID, "pvrz" },
+		{ IE_SAV_CLASS_ID, "sav" },
+		{ IE_SPL_CLASS_ID, "spl" },
+		{ IE_SRC_CLASS_ID, "src" },
+		{ IE_STO_CLASS_ID, "sto" },
+		{ IE_TIS_CLASS_ID, "tis" },
+		{ IE_TLK_CLASS_ID, "tlk" },
+		{ IE_TOH_CLASS_ID, "toh" },
+		{ IE_TOT_CLASS_ID, "tot" },
+		{ IE_TTF_CLASS_ID, "ttf" },
+		{ IE_VAR_CLASS_ID, "var" },
+		{ IE_VEF_CLASS_ID, "vef" },
+		{ IE_VVC_CLASS_ID, "vvc" },
+		{ IE_WAV_CLASS_ID, "wav" },
+		{ IE_WED_CLASS_ID, "wed" },
+		{ IE_WFX_CLASS_ID, "wfx" },
+		{ IE_WMP_CLASS_ID, "wmp" },
+		{ IE_BIO_CLASS_ID, core->HasFeature(GFFlags::BIOGRAPHY_RES) ? "res" : "bio" }
+	};
+
+	const auto extIt = extensions.find(type);
+	if (extIt == extensions.end()) {
+		Log(ERROR, "Interface", "No extension associated to class ID: {}", type);
+		return "";
+	}
+	return extIt->second;
+}
+
+bool ResourceManager::AddSource(const path_t& path, const std::string& description, PluginID type, int flags)
 {
 	PluginHolder<ResourceSource> source = MakePluginHolder<ResourceSource>(type);
 	if (!source->Open(path, description)) {
@@ -49,7 +105,7 @@ bool ResourceManager::AddSource(const char *path, const char *description, Plugi
 	return true;
 }
 
-static void PrintPossibleFiles(std::string& buffer, StringView ResRef, const TypeID *type)
+static void PrintPossibleFiles(std::string& buffer, StringView ResRef, const TypeID* type)
 {
 	const std::vector<ResourceDesc>& types = PluginMgr::Get()->GetResourceDesc(type);
 	for (const auto& type2 : types) {
@@ -57,6 +113,14 @@ static void PrintPossibleFiles(std::string& buffer, StringView ResRef, const Typ
 	}
 }
 
+bool ResourceManager::Exists(const String& resource, SClass_ID type, bool silent) const
+{
+	auto mbString = MBStringFromString(resource);
+	auto mbResource = StringView { mbString };
+
+	return Exists(mbResource, type, silent);
+}
+
 bool ResourceManager::Exists(StringView ResRef, SClass_ID type, bool silent) const
 {
 	if (ResRef.empty())
@@ -69,17 +133,17 @@ bool ResourceManager::Exists(StringView ResRef, SClass_ID type, bool silent) con
 	}
 	if (!silent) {
 		Log(WARNING, "ResourceManager", "'{}.{}' not found...",
-			ResRef, core->TypeExt(type));
+		    ResRef, TypeExt(type));
 	}
 	return false;
 }
 
-bool ResourceManager::Exists(StringView ResRef, const TypeID *type, bool silent) const
+bool ResourceManager::Exists(StringView ResRef, const TypeID* type, bool silent) const
 {
 	if (ResRef[0] == '\0')
 		return false;
 	// TODO: check various caches
-	const std::vector<ResourceDesc> &types = PluginMgr::Get()->GetResourceDesc(type);
+	const std::vector<ResourceDesc>& types = PluginMgr::Get()->GetResourceDesc(type);
 	for (const auto& type2 : types) {
 		for (const auto& path : searchPath) {
 			if (path->HasResource(ResRef, type2)) {
@@ -89,7 +153,7 @@ bool ResourceManager::Exists(StringView ResRef, const TypeID *type, bool silent)
 	}
 	if (!silent) {
 		std::string buffer = fmt::format("Couldn't find '{}'... Tried ", ResRef);
-		PrintPossibleFiles(buffer, ResRef,type);
+		PrintPossibleFiles(buffer, ResRef, type);
 		Log(WARNING, "ResourceManager", "{}", buffer);
 	}
 	return false;
@@ -100,47 +164,46 @@ DataStream* ResourceManager::GetResourceStream(StringView ResRef, SClass_ID type
 	if (ResRef.empty())
 		return nullptr;
 	for (const auto& path : searchPath) {
-		DataStream *ds = path->GetResource(ResRef, type);
+		DataStream* ds = path->GetResource(ResRef, type);
 		if (ds) {
 			if (!silent) {
-				Log(MESSAGE, "ResourceManager", "Found '{}.{}' in '{}'.", ResRef, core->TypeExt(type), path->GetDescription());
+				Log(MESSAGE, "ResourceManager", "Found '{}.{}' in '{}'.", ResRef, TypeExt(type), path->GetDescription());
 			}
 			return ds;
 		}
 	}
 	if (!silent) {
-		Log(ERROR, "ResourceManager", "Couldn't find '{}.{}'.", ResRef, core->TypeExt(type));
+		Log(ERROR, "ResourceManager", "Couldn't find '{}.{}'.", ResRef, TypeExt(type));
 	}
-	return NULL;
+	return nullptr;
 }
 
-Resource* ResourceManager::GetResource(StringView ResRef, const TypeID *type, bool silent, bool useCorrupt) const
+ResourceHolder<Resource> ResourceManager::GetResource(StringView ResRef, const TypeID* type, bool silent, ieWord prefferedType) const
 {
 	if (ResRef.empty())
 		return nullptr;
 	if (!silent) {
 		Log(MESSAGE, "ResourceManager", "Searching for '{}'...", ResRef);
 	}
-	const std::vector<ResourceDesc> &types = PluginMgr::Get()->GetResourceDesc(type);
-	for (const auto& type2 : types) {
+	const std::vector<ResourceDesc>& types = PluginMgr::Get()->GetResourceDesc(type);
+	std::vector<ResourceDesc> types2 = types;
+	if (prefferedType) {
+		// sort the preferred type to the front, so we check it first
+		std::sort(types2.begin(), types2.end(), [&prefferedType](auto& a, auto& b) { return (a.GetKeyType() == prefferedType ? true : (a.GetKeyType() < b.GetKeyType())); });
+	}
+
+	for (const auto& type2 : types2) {
 		for (const auto& path : searchPath) {
-			DataStream *str = path->GetResource(ResRef, type2);
-			if (!str && useCorrupt && core->UseCorruptedHack) {
-				// don't look at other paths if requested
-				core->UseCorruptedHack = false;
-				return NULL;
-			}
-			core->UseCorruptedHack = false;
-			if (str) {
-				Resource *res = type2.Create(str);
-				if (res) {
-					if (!silent) {
-						Log(MESSAGE, "ResourceManager", "Found '{}.{}' in '{}'.",
-							ResRef, type2.GetExt(), path->GetDescription());
-					}
-					return res;
-				}
+			DataStream* str = path->GetResource(ResRef, type2);
+			if (!str) continue;
+
+			auto res = type2.Create(str);
+			if (!res) continue;
+			if (!silent) {
+				Log(MESSAGE, "ResourceManager", "Found '{}.{}' in '{}'.",
+				    ResRef, type2.GetExt(), path->GetDescription());
 			}
+			return res;
 		}
 	}
 	if (!silent) {
@@ -148,7 +211,7 @@ Resource* ResourceManager::GetResource(StringView ResRef, const TypeID *type, bo
 		PrintPossibleFiles(buffer, ResRef, type);
 		Log(WARNING, "ResourceManager", "{}", buffer);
 	}
-	return NULL;
+	return nullptr;
 }
 
 }
