@@ -31,20 +31,21 @@
 #include "SaveGameMgr.h"
 #include "Sprite2D.h"
 #include "TableMgr.h"
+
 #include "GUI/GameControl.h"
+#include "GUI/WindowManager.h"
+#include "GameScript/GameScript.h"
 #include "Scriptable/Actor.h"
 #include "Streams/FileStream.h"
-
-#ifndef R_OK
-#define R_OK 04
-#endif
+#include "System/VFS.h"
+#include "fmt/chrono.h"
 
 #include <cassert>
-#include <set>
 #include <ctime>
+#include <set>
 
 #ifdef VITA
-#include <dirent.h>
+	#include <dirent.h>
 #endif
 
 namespace GemRB {
@@ -52,7 +53,7 @@ namespace GemRB {
 const TypeID SaveGame::ID = { "SaveGame" };
 
 /** Extract date from save game ds into Date. */
-static std::string ParseGameDate(DataStream *ds)
+static std::string ParseGameDate(DataStream* ds)
 {
 	char Signature[8];
 	ieDword GameTime;
@@ -84,10 +85,12 @@ static std::string ParseGameDate(DataStream *ds)
 	}
 	delete ds;
 
-	int hours = ((int)GameTime)/core->Time.hour_sec;
-	int days = hours/24;
-	hours -= days*24;
-	std::string a, b, c;
+	int hours = ((int) GameTime) / core->Time.hour_sec;
+	int days = hours / 24;
+	hours -= days * 24;
+	std::string a;
+	std::string b;
+	std::string c;
 
 	// pst has a nice single string for everything 41277 (individual ones lack tokens)
 	SetTokenAsString("GAMEDAYS", days);
@@ -106,14 +109,14 @@ static std::string ParseGameDate(DataStream *ds)
 		}
 	}
 	if (hours || a.empty()) {
-		if (!a.empty()) b=core->GetMBString(ieStrRef::DATE1); // and
+		if (!a.empty()) b = core->GetMBString(ieStrRef::DATE1); // and
 		if (hours == 1) {
 			c = core->GetMBString(DisplayMessage::GetStringReference(HCStrings::Hour), STRING_FLAGS::NONE);
 		} else {
 			c = core->GetMBString(DisplayMessage::GetStringReference(HCStrings::Hours), STRING_FLAGS::NONE);
 		}
 	}
-	
+
 	if (!b.empty()) {
 		return a + " " + b + " " + c;
 	} else {
@@ -121,23 +124,23 @@ static std::string ParseGameDate(DataStream *ds)
 	}
 }
 
-SaveGame::SaveGame(std::string path, std::string name, const ResRef& prefix, std::string slotname, int pCount, int saveID)
-: Path(std::move(path)), Name(std::move(name)), Prefix(prefix), SlotName(std::move(slotname))
+SaveGame::SaveGame(path_t path, const path_t& name, const ResRef& prefix, std::string slotname, int pCount, int saveID)
+	: Path(std::move(path)), Prefix(prefix), SlotName(std::move(slotname))
 {
+	static const auto DATE_FMT = FMT_STRING("{:%a %Od %b %T %EY}");
 	PortraitCount = pCount;
 	SaveID = saveID;
-	char nPath[_MAX_PATH + 1] = {};
 	struct stat my_stat;
-	PathJoinExt(nPath, Path.c_str(), Prefix.c_str(), "bmp");
+	path_t nPath = PathJoinExt(Path, Prefix, "bmp");
 	memset(&my_stat, 0, sizeof(my_stat));
-	if (stat(nPath, &my_stat)) {
+	if (stat(nPath.c_str(), &my_stat)) {
 		Log(ERROR, "SaveGameIterator", "Stat call failed, using dummy time!");
-		Date = "Sun 31 Feb 00:00:01 2099";
+		Date = fmt::format(DATE_FMT, fmt::localtime(0));
 	} else {
-		strftime(nPath, _MAX_PATH, "%c", localtime(&my_stat.st_mtime));
-		Date = nPath;
+		Date = fmt::format(DATE_FMT, fmt::localtime(my_stat.st_mtime));
 	}
-	manager.AddSource(Path.c_str(), Name.c_str(), PLUGIN_RESOURCE_DIRECTORY);
+	manager.AddSource(Path, name, PLUGIN_RESOURCE_DIRECTORY);
+	Name = StringFromUtf8(name);
 }
 
 Holder<Sprite2D> SaveGame::GetPortrait(int index) const
@@ -146,7 +149,7 @@ Holder<Sprite2D> SaveGame::GetPortrait(int index) const
 		return NULL;
 	}
 
-	std::string nPath = fmt::format("PORTRT{}", index);
+	path_t nPath = fmt::format("PORTRT{}", index);
 	ResourceHolder<ImageMgr> im = manager.GetResourceHolder<ImageMgr>(nPath, true);
 	if (!im)
 		return NULL;
@@ -184,9 +187,9 @@ const std::string& SaveGame::GetGameDate() const
 }
 
 // mission pack save dir or the main one?
-static std::string SaveDir()
+static path_t SaveDir()
 {
-	return MBStringFromString(core->GetToken("SaveDir", L"save"));
+	return MBStringFromString(core->GetToken("SaveDir", u"save"));
 }
 
 /*
@@ -196,8 +199,8 @@ static int GetHole(int n)
 {
 	int mask = 1;
 	int value = 0;
-	while(n&mask) {
-		mask<<=1;
+	while (n & mask) {
+		mask <<= 1;
 		value++;
 	}
 	return value;
@@ -208,14 +211,13 @@ static int GetHole(int n)
  */
 static int IsQuickSaveSlot(StringView match, StringView slotname)
 {
-	char savegameName[_MAX_PATH];
+	char savegameName[255];
 	int savegameNumber = 0;
 	int cnt = sscanf(slotname.c_str(), SAVEGAME_DIRECTORY_MATCHER, &savegameNumber, savegameName);
 	if (cnt != 2) {
 		return 0;
 	}
-	if (stricmp(savegameName, match.c_str()) != 0)
-	{
+	if (strnicmp(savegameName, match.c_str(), sizeof(savegameName)) != 0) {
 		return 0;
 	}
 	return savegameNumber;
@@ -224,31 +226,29 @@ static int IsQuickSaveSlot(StringView match, StringView slotname)
  * Return true if directory Path/slotname is a potential save game
  * slot, otherwise return false.
  */
-static bool IsSaveGameSlot(const char* Path, const char* slotname)
+static bool IsSaveGameSlot(const path_t& Path, const path_t& slotname)
 {
-	char savegameName[_MAX_PATH];
+	char savegameName[255];
 	int savegameNumber = 0;
 
 	if (slotname[0] == '.')
 		return false;
 
-	int cnt = sscanf( slotname, SAVEGAME_DIRECTORY_MATCHER, &savegameNumber, savegameName );
+	int cnt = sscanf(slotname.c_str(), SAVEGAME_DIRECTORY_MATCHER, &savegameNumber, savegameName);
 	if (cnt != 2) {
 		//The matcher didn't match: either this is not a valid dir
 		//or the SAVEGAME_DIRECTORY_MATCHER needs updating.
 		Log(ERROR, "SaveGameIterator", "Invalid savegame directory '{}' in {}.",
-			slotname, Path);
+		    slotname, Path);
 		return false;
 	}
 
 	//The matcher got matched correctly.
-	char dtmp[_MAX_PATH];
-	PathJoin(dtmp, Path, slotname, nullptr);
+	path_t dtmp = PathJoin(Path, slotname);
 
-	char ftmp[_MAX_PATH];
-	PathJoinExt(ftmp, dtmp, core->GameNameResRef.c_str(), "bmp");
+	path_t ftmp = PathJoinExt(dtmp, core->GameNameResRef, "bmp");
 
-	if (access( ftmp, R_OK )) {
+	if (!FileExists(ftmp)) {
 		Log(WARNING, "SaveGameIterator", "Ignoring slot {} because of no appropriate preview!", dtmp);
 		return false;
 	}
@@ -256,14 +256,14 @@ static bool IsSaveGameSlot(const char* Path, const char* slotname)
 	// no worldmaps in saves in ees
 	if (core->HasFeature(GFFlags::HAS_EE_EFFECTS)) return true;
 
-	PathJoinExt(ftmp, dtmp, core->WorldMapName[0].c_str(), "wmp");
-	if (access( ftmp, R_OK )) {
+	ftmp = PathJoinExt(dtmp, core->WorldMapName[0], "wmp");
+	if (!FileExists(ftmp)) {
 		return false;
 	}
 
 	if (core->WorldMapName[1]) {
-		PathJoinExt(ftmp, dtmp, core->WorldMapName[1].c_str(), "wmp");
-		if (access(ftmp, R_OK)) {
+		ftmp = PathJoinExt(dtmp, core->WorldMapName[1], "wmp");
+		if (!FileExists(ftmp)) {
 			Log(WARNING, "SaveGameIterator", "Ignoring slot {} because of no appropriate second worldmap!", dtmp);
 			return false;
 		}
@@ -277,8 +277,7 @@ bool SaveGameIterator::RescanSaveGames()
 	// delete old entries
 	save_slots.clear();
 
-	char Path[_MAX_PATH];
-	PathJoin(Path, core->config.SavePath, SaveDir().c_str(), nullptr);
+	path_t Path = PathJoin(core->config.SavePath, SaveDir());
 
 	DirectoryIterator dir(Path);
 	// create the save game directory at first access
@@ -296,32 +295,35 @@ bool SaveGameIterator::RescanSaveGames()
 	std::set<std::string> slots;
 	dir.SetFlags(DirectoryIterator::Directories);
 	do {
-		const char *name = dir.GetName();
-		if (IsSaveGameSlot( Path, name )) {
+		const path_t& name = dir.GetName();
+		if (IsSaveGameSlot(Path, name)) {
 			slots.emplace(name);
 		}
 	} while (++dir);
 
 	for (const auto& slot : slots) {
-		save_slots.push_back(BuildSaveGame(slot));
+		auto saveGame = BuildSaveGame(slot);
+		if (saveGame) {
+			save_slots.push_back(saveGame);
+		}
 	}
 
 	return true;
 }
 
-const std::vector<Holder<SaveGame> >& SaveGameIterator::GetSaveGames()
+const std::vector<Holder<SaveGame>>& SaveGameIterator::GetSaveGames()
 {
 	RescanSaveGames();
 
 	return save_slots;
 }
 
-Holder<SaveGame> SaveGameIterator::GetSaveGame(StringView name)
+Holder<SaveGame> SaveGameIterator::GetSaveGame(const String& name)
 {
 	RescanSaveGames();
 
 	for (const auto& saveSlot : save_slots) {
-		if (saveSlot->GetName().compare(name.c_str()) == 0)
+		if (saveSlot->GetName() == name)
 			return saveSlot;
 	}
 	return NULL;
@@ -330,26 +332,20 @@ Holder<SaveGame> SaveGameIterator::GetSaveGame(StringView name)
 Holder<SaveGame> SaveGameIterator::BuildSaveGame(std::string slotname)
 {
 	int prtrt = 0;
-	char Path[_MAX_PATH];
 	//lets leave space for the filenames
-	PathJoin(Path, core->config.SavePath, SaveDir().c_str(), slotname.c_str(), nullptr);
+	path_t Path = PathJoin(core->config.SavePath, SaveDir(), slotname);
 
-	char savegameName[_MAX_PATH]={0};
+	char savegameName[255] = { 0 };
 	int savegameNumber = 0;
 
-	int cnt = sscanf(slotname.c_str(), SAVEGAME_DIRECTORY_MATCHER, &savegameNumber, savegameName);
-	//maximum pathlength == 240, without 8+3 filenames
-	if ( (cnt != 2) || (strlen(Path)>240) ) {
-		Log(WARNING, "SaveGame", "Invalid savegame directory '{}' in {}.", slotname, Path);
-		return NULL;
-	}
+	sscanf(slotname.c_str(), SAVEGAME_DIRECTORY_MATCHER, &savegameNumber, savegameName);
 
 	DirectoryIterator dir(Path);
 	if (!dir) {
 		return NULL;
 	}
 	do {
-		if (strnicmp( dir.GetName(), "PORTRT", 6 ) == 0)
+		if (strnicmp(dir.GetName().c_str(), "PORTRT", 6) == 0)
 			prtrt++;
 	} while (++dir);
 
@@ -358,8 +354,7 @@ Holder<SaveGame> SaveGameIterator::BuildSaveGame(std::string slotname)
 
 void SaveGameIterator::PruneQuickSave(StringView folder) const
 {
-	auto FormatQuickSavePath = [folder](int i)
-	{
+	auto FormatQuickSavePath = [folder](int i) {
 		return fmt::format(FMT_STRING("{}{}{}{:09d}-{}"), core->config.SavePath, SaveDir(), SPathDelimiter, i, folder);
 	};
 
@@ -369,8 +364,8 @@ void SaveGameIterator::PruneQuickSave(StringView folder) const
 		int tmp = IsQuickSaveSlot(folder, saveSlot->GetSlotName());
 		if (tmp) {
 			size_t pos = myslots.size();
-			while(pos-- && myslots[pos]>tmp) ;
-			myslots.insert(myslots.begin()+pos+1,tmp);
+			while (pos-- && myslots[pos] > tmp);
+			myslots.insert(myslots.begin() + pos + 1, tmp);
 		}
 	}
 	//now we got an integer array in myslots
@@ -380,20 +375,20 @@ void SaveGameIterator::PruneQuickSave(StringView folder) const
 		return;
 	}
 
-	int n=myslots[size-1];
+	int n = myslots[size - 1];
 	size_t hole = GetHole(n);
-	if (hole<size) {
+	if (hole < size) {
 		//prune second path
 		std::string from = FormatQuickSavePath(myslots[hole]);
-		myslots.erase(myslots.begin()+hole);
-		core->DelTree(from.c_str(), false);
+		myslots.erase(myslots.begin() + hole);
+		DelTree(from, false);
 		rmdir(from.c_str());
 	}
 	//shift paths, always do this, because they are aging
 	size = myslots.size();
 	for (size_t i = size; i > 0; i--) {
 		std::string from = FormatQuickSavePath(myslots[i]);
-		std::string to = FormatQuickSavePath(myslots[i]+1);
+		std::string to = FormatQuickSavePath(myslots[i] + 1);
 		int errnum = rename(from.c_str(), to.c_str());
 		if (errnum) {
 			error("SaveGameIterator", "Rename error {} when pruning quicksaves!", errnum);
@@ -402,13 +397,13 @@ void SaveGameIterator::PruneQuickSave(StringView folder) const
 }
 
 /** Save game to given directory */
-static bool DoSaveGame(const char *Path, bool overrideRunning)
+static bool DoSaveGame(const path_t& Path, bool overrideRunning)
 {
-	const Game *game = core->GetGame();
+	const Game* game = core->GetGame();
 	//saving areas to cache currently in memory
 	unsigned int mc = (unsigned int) game->GetLoadedMapCount();
 	while (mc--) {
-		Map *map = game->GetMap(mc);
+		Map* map = game->GetMap(mc);
 		if (core->SwapoutArea(map)) {
 			return false;
 		}
@@ -439,18 +434,18 @@ static bool DoSaveGame(const char *Path, bool overrideRunning)
 	}
 
 	//Create portraits
-	for (int i = 0; i < game->GetPartySize( false ); i++) {
-		const Actor *actor = game->GetPC( i, false );
+	for (int i = 0; i < game->GetPartySize(false); i++) {
+		const Actor* actor = game->GetPC(i, false);
 		Holder<Sprite2D> portrait = actor->CopyPortrait(true);
 
 		if (portrait) {
-			std::string fname = fmt::format("PORTRT{}", i);
+			path_t fname = fmt::format("PORTRT{}", i);
 			FileStream outfile;
-			outfile.Create(Path, fname.c_str(), IE_BMP_CLASS_ID);
+			outfile.Create(Path, fname, IE_BMP_CLASS_ID);
 			// NOTE: we save the true portrait size, even tho the preview buttons arent (always) the same
 			// we do this because: 1. the GUI should be able to use whatever size it wants
 			// and 2. its more appropriate to have a flag on the buttons to do the scaling/cropping
-			im->PutImage(&outfile, portrait);
+			im->PutImage(&outfile, std::move(portrait));
 		}
 	}
 
@@ -461,10 +456,10 @@ static bool DoSaveGame(const char *Path, bool overrideRunning)
 	Holder<Sprite2D> preview = wm->GetScreenshot(wm->GetGameWindow());
 
 	// scale down to get more of the screen and reduce the size
-	preview = core->GetVideoDriver()->SpriteScaleDown(preview, 5);
+	preview = VideoDriver->SpriteScaleDown(preview, 5);
 	FileStream outfile;
-	outfile.Create( Path, core->GameNameResRef.c_str(), IE_BMP_CLASS_ID );
-	im->PutImage( &outfile, preview );
+	outfile.Create(Path, core->GameNameResRef.c_str(), IE_BMP_CLASS_ID);
+	im->PutImage(&outfile, std::move(preview));
 
 	return true;
 }
@@ -480,12 +475,12 @@ static int CanSave()
 		return 1;
 	}
 
-	const Store *store = core->GetCurrentStore();
+	const Store* store = core->GetCurrentStore();
 	if (store) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSaveStore, FT_ANY, GUIColors::XPCHANGE);
 		return 1; //can't save while store is open
 	}
-	const GameControl *gc = core->GetGameControl();
+	const GameControl* gc = core->GetGameControl();
 	if (!gc) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return -1; //no gamecontrol!!!
@@ -495,7 +490,7 @@ static int CanSave()
 		return 2; //can't save while in dialog
 	}
 
-	const Game *game = core->GetGame();
+	const Game* game = core->GetGame();
 	if (!game) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return -1;
@@ -505,7 +500,7 @@ static int CanSave()
 		return 3;
 	}
 
-	const Map *map = game->GetCurrentArea();
+	const Map* map = game->GetCurrentArea();
 	if (!map) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return -1;
@@ -519,23 +514,23 @@ static int CanSave()
 		return 10;
 	}
 
-	if (map->AreaFlags&AF_NOSAVE) {
+	if (map->AreaFlags & AF_NOSAVE) {
 		//cannot save in area
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return 4;
 	}
 
 	int i = game->GetPartySize(true);
-	while(i--) {
-		const Actor *actor = game->GetPC(i, true);
+	while (i--) {
+		const Actor* actor = game->GetPC(i, true);
 		// can't save while (party) actors are in helpless or dead states
 		// STATE_NOSAVE tracks actors not to be stored in GAM, not game saveability
-		if (actor->GetStat(IE_STATE_ID) & (STATE_NOSAVE|STATE_MINDLESS)) {
+		if (actor->GetStat(IE_STATE_ID) & (STATE_NOSAVE | STATE_MINDLESS) || actor->GetStat(IE_CHECKFORBERSERK)) {
 			//some actor is in nosave state
 			displaymsg->DisplayMsgCentered(HCStrings::CantSaveNoCtrl, FT_ANY, GUIColors::XPCHANGE);
 			return 5;
 		}
-		if (actor->GetCurrentArea()!=map) {
+		if (actor->GetCurrentArea() != map) {
 			//scattered
 			displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 			return 6;
@@ -553,10 +548,11 @@ static int CanSave()
 		}
 	}
 
-	Point pc1 =  game->GetPC(0, true)->Pos;
-	std::vector<Actor *> nearActors = map->GetAllActorsInRadius(pc1, GA_NO_DEAD|GA_NO_UNSCHEDULED, 15);
+	Point pc1 = game->GetPC(0, true)->Pos;
+	std::vector<Actor*> nearActors = map->GetAllActorsInRadius(pc1, GA_NO_DEAD | GA_NO_UNSCHEDULED, 15);
 	for (const auto& neighbour : nearActors) {
-		if (neighbour->GetInternalFlag() & IF_NOINT) {
+		const Action* action = neighbour->GetCurrentAction();
+		if (action && action->flags & AF_DIALOG) {
 			// dialog about to start or similar
 			displaymsg->DisplayMsgCentered(HCStrings::CantSaveDialog2, FT_ANY, GUIColors::XPCHANGE);
 			return 8;
@@ -566,23 +562,23 @@ static int CanSave()
 	return 0;
 }
 
-static bool CreateSavePath(char *Path, int index, StringView slotname)
+static bool CreateSavePath(path_t& path, int index, StringView slotname)
 {
-	PathJoin(Path, core->config.SavePath, SaveDir().c_str(), nullptr);
+	path = PathJoin(core->config.SavePath, SaveDir());
 
 	//if the path exists in different case, don't make it again
-	if (!MakeDirectory(Path)) {
-		Log(ERROR, "SaveGameIterator", "Unable to create save game directory '{}'", Path);
+	if (!MakeDirectory(path)) {
+		Log(ERROR, "SaveGameIterator", "Unable to create save game directory '{}'", path);
 		return false;
 	}
 	//keep the first part we already determined existing
 
-	std::string dir = fmt::format("{:09d}-{}", index, slotname);
-	PathJoin(Path, Path, dir.c_str(), nullptr);
+	path_t dir = fmt::format("{:09d}-{}", index, slotname);
+	path = PathJoin(path, dir);
 	//this is required in case the old slot wasn't recognised but still there
-	core->DelTree(Path, false);
-	if (!MakeDirectory(Path)) {
-		Log(ERROR, "SaveGameIterator", "Unable to create save game directory '{}'", Path);
+	DelTree(path, false);
+	if (!MakeDirectory(path)) {
+		Log(ERROR, "SaveGameIterator", "Unable to create save game directory '{}'", path);
 		return false;
 	}
 	return true;
@@ -622,13 +618,13 @@ int SaveGameIterator::CreateSaveGame(int index, bool mqs) const
 		DeleteSaveGame(save);
 		break;
 	}
-	char Path[_MAX_PATH];
+	path_t Path;
 	if (!CreateSavePath(Path, index, slotname)) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return GEM_ERROR;
 	}
 
-	if (!DoSaveGame(Path, overrideRunning)) {
+	if (!DoSaveGame(Path.c_str(), overrideRunning)) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return GEM_ERROR;
 	}
@@ -642,6 +638,12 @@ int SaveGameIterator::CreateSaveGame(int index, bool mqs) const
 	return GEM_OK;
 }
 
+int SaveGameIterator::CreateSaveGame(Holder<SaveGame> save, const String& slotname, bool force) const
+{
+	auto mbSlotName = MBStringFromString(slotname);
+	return CreateSaveGame(std::move(save), StringView { mbSlotName }, force);
+}
+
 int SaveGameIterator::CreateSaveGame(Holder<SaveGame> save, StringView slotname, bool force) const
 {
 	if (!slotname) {
@@ -667,7 +669,7 @@ int SaveGameIterator::CreateSaveGame(Holder<SaveGame> save, StringView slotname,
 		}
 
 		DeleteSaveGame(save);
-		save.release();
+		save.reset();
 	} else {
 		//leave space for autosaves
 		//probably the hardcoded slot names should be read by this object
@@ -678,15 +680,30 @@ int SaveGameIterator::CreateSaveGame(Holder<SaveGame> save, StringView slotname,
 				index = save2->GetSaveID() + 1;
 			}
 		}
+
+		// we were called with an empty slot, so make sure that's true
+		// normal and expansion saves could have the same name, but we skip them
+		path_t basePath = PathJoin(core->config.SavePath, SaveDir());
+		path_t path = basePath;
+		if (!MakeDirectory(basePath)) {
+			Log(ERROR, "SaveGameIterator", "Unable to create base save game directory '{}'", path);
+			return GEM_ERROR;
+		}
+		index--;
+		while (DirExists(path)) {
+			index++;
+			path_t dir = fmt::format("{:09d}-{}", index, slotname);
+			path = PathJoin(basePath, dir);
+		}
 	}
 
-	char Path[_MAX_PATH];
+	path_t Path;
 	if (!CreateSavePath(Path, index, slotname)) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return GEM_ERROR;
 	}
 
-	if (!DoSaveGame(Path, overrideRunning)) {
+	if (!DoSaveGame(Path.c_str(), overrideRunning)) {
 		displaymsg->DisplayMsgCentered(HCStrings::CantSave, FT_ANY, GUIColors::XPCHANGE);
 		return GEM_ERROR;
 	}
@@ -702,8 +719,8 @@ void SaveGameIterator::DeleteSaveGame(const Holder<SaveGame>& game) const
 		return;
 	}
 
-	core->DelTree(game->GetPath().c_str(), false); //remove all files from folder
-	rmdir(game->GetPath().c_str());
+	DelTree(game->GetPath(), false); // remove all files from folder
+	RemoveDirectory(game->GetPath());
 }
 
 }
