@@ -21,7 +21,8 @@
 #ifndef INFOPOINT_H
 #define INFOPOINT_H
 
-#include "Scriptable/Scriptable.h"
+#include "GUI/GameControlDefs.h"
+#include "Scriptable/Highlightable.h"
 
 namespace GemRB {
 
@@ -32,16 +33,18 @@ public:
 	void SetEnter(const ResRef& resref);
 	bool TriggerTrap(int skill, ieDword ID) override;
 	//call this to check if an actor entered the trigger zone
-	bool Entered(Actor *actor);
+	bool Entered(Actor* actor);
 	ieDword GetUsePoint() const;
 	//checks if the actor may use this travel trigger
-	int CheckTravel(const Actor *actor) const;
-	std::string dump() const;
+	int CheckTravel(const Actor* actor) const;
+	std::string dump() const override;
 	int TrapResets() const override { return Flags & TRAP_RESET; }
 	bool CanDetectTrap() const override;
 	bool PossibleToSeeTrap() const override;
 	bool IsPortal() const;
-	int GetCursor(int targetMode) const;
+	int GetCursor(TargetMode targetMode) const;
+	void TryBashLock(Actor*) override { return; };
+	void TryPickLock(Actor*) override { return; };
 
 public:
 	ResRef Destination;
