@@ -39,34 +39,35 @@ class Projectile;
 
 //values for Spell usability Flags
 
-#define SF_BREAK_SANCTUARY	0x200 // EE bit to force the removal of any fx_set_sanctuary_state effects
-#define SF_HOSTILE	0x400 // bit 18
-#define SF_NO_LOS	0x800
+#define SF_BREAK_SANCTUARY 0x200 // EE bit to force the removal of any fx_set_sanctuary_state effects
+#define SF_HOSTILE         0x400 // bit 18
+#define SF_NO_LOS          0x800
 // unknown Allow spotting  0x1000
-#define SF_NOT_INDOORS	0x2000
-#define SF_HLA  	0x4000 // this means a nonmagical ability (also ignores dead-magic and wild surge effect)
-#define SF_TRIGGER	0x8000
+#define SF_NOT_INDOORS   0x2000
+#define SF_HLA           0x4000 // this means a nonmagical ability (also ignores dead-magic and wild surge effect)
+#define SF_TRIGGER       0x8000
 #define SF_NOT_IN_COMBAT 0x10000 // bit 24 unused
 // 7 unknowns, likely unused
 #define SF_TARGETS_INVISIBLE 0x1000000 // tobex/ee: can target invisible creatures
-#define SF_IGNORES_SILENCE 0x2000000 // tobex/ee: can be cast while silenced
+#define SF_IGNORES_SILENCE   0x2000000 // tobex/ee: can be cast while silenced
 //this is a relocated bit (used in iwd2 as 0x4000)
 #define SF_SIMPLIFIED_DURATION 0x40
 
 //spelltypes in spells
-#define  IE_SPL_ITEM   0
-#define  IE_SPL_WIZARD 1
-#define  IE_SPL_PRIEST 2
-#define  IE_SPL_PSION  3
-#define  IE_SPL_INNATE 4
-#define  IE_SPL_SONG   5
+#define IE_SPL_ITEM   0
+#define IE_SPL_WIZARD 1
+#define IE_SPL_PRIEST 2
+#define IE_SPL_PSION  3
+#define IE_SPL_INNATE 4
+#define IE_SPL_SONG   5
 
-//this is not the same as the book types which is 3 or 11)
+// this is not the same as the book types (which is 3 or 11)
 #define NUM_SPELL_TYPES 6
 
-#define SPEC_IDENTIFY  1  //spells that don't appear in the casting bar
-#define SPEC_SILENCE   2  //spells that can be cast when silenced
-#define SPEC_DEAD      4  //spells that can target dead actors despite their target type is 1 (pst hack)
+#define SPEC_IDENTIFY 1 //spells that don't appear in the casting bar
+#define SPEC_SILENCE  2 //spells that can be cast when silenced
+#define SPEC_DEAD     4 //spells that can target dead actors despite their target type is 1 (pst hack)
+#define SPEC_AREA     32 // spells that can target the area despite their target type being 1
 
 /**
  * @class SPLExtHeader
@@ -153,7 +154,7 @@ public:
 
 public:
 	//returns the requested extended header
-	inline const SPLExtHeader *GetExtHeader(size_t which) const
+	inline const SPLExtHeader* GetExtHeader(size_t which) const
 	{
 		if (Flags & SF_SIMPLIFIED_DURATION) {
 			which = 0;
@@ -167,15 +168,15 @@ public:
 	//converts a wanted level to block index count
 	int GetHeaderIndexFromLevel(int level) const;
 	//-1 will return the cfb
-	EffectQueue GetEffectBlock(Scriptable *self, const Point &pos, int block_index, int level, ieDword pro=0);
+	EffectQueue GetEffectBlock(Scriptable* self, const Point& pos, int block_index, int level, ieDword pro = 0);
 	// add appropriate casting glow effect
-	void AddCastingGlow(EffectQueue *fxqueue, ieDword duration, int gender) const;
+	void AddCastingGlow(EffectQueue* fxqueue, ieDword duration, int gender) const;
 	//returns a projectile created from an extended header
-	Projectile *GetProjectile(Scriptable *self, int headerindex, int level, const Point &pos);
-	unsigned int GetCastingDistance(Scriptable *Sender) const;
+	Projectile* GetProjectile(Scriptable* self, int headerindex, int level, const Point& pos);
+	unsigned int GetCastingDistance(Scriptable* Sender) const;
 	bool ContainsDamageOpcode() const;
 };
 
 }
 
-#endif  // ! SPELL_H
+#endif // ! SPELL_H
