@@ -27,16 +27,17 @@
 #ifndef SPRITE2D_H
 #define SPRITE2D_H
 
-#include <cstddef>
-
 #include "RGBAColor.h"
 #include "exports.h"
 
 #include "Palette.h"
-#include "Video/Pixels.h"
 #include "Region.h"
 #include "TypeID.h"
 
+#include "Video/Pixels.h"
+
+#include <cstddef>
+
 namespace GemRB {
 
 // Note: not all these flags make sense together.
@@ -52,7 +53,7 @@ enum BlitFlags : uint32_t {
 	ONE_MINUS_DST = 0x80, // dstRGBA = (srcRGBA * (1 - dstRGBA)) + (dstRGBA)
 	DST = 0x100, // dstRGBA = (srcRGBA * dstRGBA) + (dstRGBA)
 	SRC = 0x200, // dstRGBA = (srcRGBA * srcRGBA) + (dstRGBA)
-	BLEND_MASK = BLENDED | ADD | MOD | MUL | ONE_MINUS_DST | ONE_MINUS_DST | DST | SRC,
+	BLEND_MASK = BLENDED | ADD | MOD | MUL | ONE_MINUS_DST | DST | SRC,
 	// color/alpha mod applies to color param
 	COLOR_MOD = 0x1000, // srcC = srcC * (color / 255)
 	ALPHA_MOD = 0x2000, // srcA = srcA * (alpha / 255)
@@ -69,32 +70,32 @@ enum BlitFlags : uint32_t {
 	STENCIL_MASK = STENCIL_ALPHA | STENCIL_RED | STENCIL_GREEN | STENCIL_BLUE | STENCIL_DITHER
 };
 
-class GEM_EXPORT Sprite2D : public Held<Sprite2D> {
+class GEM_EXPORT Sprite2D {
 public:
 	static const TypeID ID;
-	
+
 	using Iterator = PixelFormatIterator;
 	Iterator GetIterator(IPixelIterator::Direction xdir = IPixelIterator::Forward,
-						 IPixelIterator::Direction ydir = IPixelIterator::Forward);
+			     IPixelIterator::Direction ydir = IPixelIterator::Forward);
 
 	Iterator GetIterator(IPixelIterator::Direction xdir,
-						 IPixelIterator::Direction ydir,
-						 const Region& clip);
-	
+			     IPixelIterator::Direction ydir,
+			     const Region& clip);
+
 	Iterator GetIterator(IPixelIterator::Direction xdir = IPixelIterator::Forward,
-						 IPixelIterator::Direction ydir = IPixelIterator::Forward) const;
+			     IPixelIterator::Direction ydir = IPixelIterator::Forward) const;
 
 	Iterator GetIterator(IPixelIterator::Direction xdir,
-						 IPixelIterator::Direction ydir,
-						 const Region& clip) const;
+			     IPixelIterator::Direction ydir,
+			     const Region& clip) const;
 
 protected:
 	void* pixels = nullptr;
 	bool freePixels = true;
-	
+
 	PixelFormat format;
-	uint16_t pitch;
-	
+	uint16_t pitch = 0;
+
 	virtual void UpdatePalette() noexcept {};
 	virtual void UpdateColorKey() noexcept {};
 
@@ -104,29 +105,29 @@ public:
 
 	Sprite2D(const Region&, void* pixels, const PixelFormat& fmt, uint16_t pitch) noexcept;
 	Sprite2D(const Region&, void* pixels, const PixelFormat& fmt) noexcept;
-	Sprite2D(const Sprite2D &obj) noexcept;
+	Sprite2D(const Sprite2D& obj) noexcept;
 	Sprite2D(Sprite2D&&) noexcept;
-	~Sprite2D() noexcept override;
+	virtual ~Sprite2D() noexcept;
 
 	virtual Holder<Sprite2D> copy() const { return MakeHolder<Sprite2D>(*this); };
 
 	virtual bool HasTransparency() const noexcept;
 	bool IsPixelTransparent(const Point& p) const noexcept;
-	
+
 	uint16_t GetPitch() const noexcept { return pitch; }
 
 	virtual const void* LockSprite() const;
 	virtual void* LockSprite();
-	virtual void UnlockSprite() const {};
+	virtual void UnlockSprite() {};
 
 	const PixelFormat& Format() const noexcept { return format; }
 	Color GetPixel(const Point&) const noexcept;
-	PaletteHolder GetPalette() const noexcept { return format.palette; }
-	void SetPalette(const PaletteHolder& pal);
-	
-	/* GetColorKey: either a px value or a palete index if sprite has a palette. */
+	Holder<Palette> GetPalette() const noexcept { return format.palette; }
+	void SetPalette(const Holder<Palette>& pal);
+
+	/* GetColorKey: either a px value or a palette index if sprite has a palette. */
 	colorkey_t GetColorKey() const noexcept { return format.ColorKey; }
-	/* SetColorKey: either a px value or a palete index if sprite has a palette. */
+	/* SetColorKey: either a px value or a palette index if sprite has a palette. */
 	void SetColorKey(colorkey_t);
 
 	virtual bool ConvertFormatTo(const PixelFormat&) noexcept;
@@ -134,4 +135,4 @@ public:
 
 }
 
-#endif  // ! SPRITE2D_H
+#endif // ! SPRITE2D_H
