@@ -30,33 +30,34 @@
 
 namespace GemRB {
 
-template <typename KeyType>
+template<typename KeyType>
 class SpriteSheet {
 protected:
 	Region SheetRegion; // FIXME: this is only needed because of a subclass
 	std::map<KeyType, Region> RegionMap;
 
-	explicit SpriteSheet(Video* video)
-	: video(video) {};
-
 public:
 	Holder<Sprite2D> Sheet;
-	Video* video;
 
 public:
-	SpriteSheet(Video* video, Holder<Sprite2D> sheet)
-	: Sheet(std::move(sheet)), video(video) {
+	explicit SpriteSheet(Holder<Sprite2D> sheet)
+		: Sheet(std::move(sheet))
+	{
 		SheetRegion = Sheet->Frame;
 	};
 
+	SpriteSheet() noexcept = default;
+
 	virtual ~SpriteSheet() noexcept = default;
 
-	const Region& operator[](KeyType key) {
+	const Region& operator[](KeyType key)
+	{
 		return RegionMap[key];
 	}
 
 	// return the passed in region, clipped to the sprite dimensions or a region with -1 w/h if outside the sprite bounds
-	const Region& MapSheetSegment(KeyType key, const Region& rgn) {
+	const Region& MapSheetSegment(KeyType key, const Region& rgn)
+	{
 		Region intersection = rgn.Intersect(SheetRegion);
 		if (!intersection.size.IsInvalid()) {
 			if (RegionMap.emplace(key, intersection).second) {
@@ -65,18 +66,19 @@ public:
 			// FIXME: should we return something like Region(0,0,0,0) here?
 			// maybe we should just use Atlas[key] = intersection too.
 		}
-		const static Region nullRgn(0,0, -1,-1);
+		const static Region nullRgn(0, 0, -1, -1);
 		return nullRgn;
 	}
 
-	void Draw(KeyType key, const Region& dest, BlitFlags flags, const Color& tint) const {
+	void Draw(KeyType key, const Region& dest, BlitFlags flags, const Color& tint) const
+	{
 		const auto& i = RegionMap.find(key);
 		if (i != RegionMap.end()) {
-			video->BlitSprite(Sheet, i->second, dest, flags, tint);
+			VideoDriver->BlitSprite(Sheet, i->second, dest, flags, tint);
 		}
 	}
 };
 
 }
 
-#endif  // ! SPRITESHEET_H
+#endif // ! SPRITESHEET_H
