@@ -21,18 +21,18 @@
 #ifndef MEMORYSTREAM_H
 #define MEMORYSTREAM_H
 
-#include "DataStream.h"
-
 #include "exports.h"
 
+#include "DataStream.h"
+
 namespace GemRB {
 
-class GEM_EXPORT MemoryStream : public DataStream
-{
+class GEM_EXPORT MemoryStream : public DataStream {
 protected:
-	char *data;
+	char* data;
+
 public:
-	MemoryStream(const char *name, void* data, strpos_t size);
+	MemoryStream(const path_t& name, void* data, strpos_t size);
 	~MemoryStream() override;
 	DataStream* Clone() const noexcept override;
 
