@@ -30,6 +30,7 @@
 
 #include "Plugin.h"
 #include "Resource.h"
+
 #include "Streams/DataStream.h"
 
 namespace GemRB {
@@ -46,20 +47,21 @@ struct StringBlock {
 	StringBlock() noexcept = default;
 
 	StringBlock(String text, const ResRef& soundRef) noexcept
-	: text(std::move(text)), Sound(soundRef) {}
-	
+		: text(std::move(text)), Sound(soundRef) {}
+
 	StringBlock(StringBlock&&) noexcept = default;
 	StringBlock(const StringBlock&) = delete;
 };
 
 enum class STRING_FLAGS : uint32_t {
-	NONE			= 0,
-	STRREFON		= 1,
-	SOUND 			= 2,
-	SPEECH			= 4,
-	ALLOW_ZERO		= 8, // 0 strref is allowed
-	RESOLVE_TAGS	= 16,
-	STRREFOFF		= 256,
+	NONE = 0,
+	STRREFON = 1,
+	SOUND = 2,
+	SPEECH = 4,
+	ALLOW_ZERO = 8, // 0 strref is allowed
+	RESOLVE_TAGS = 16,
+	STRREFOFF = 256,
+	// iwd2 also used 0x8000 to mark removed ctlk entries for recycling
 };
 
 /**
@@ -76,8 +78,9 @@ public:
 	virtual StringBlock GetStringBlock(ieStrRef strref, STRING_FLAGS flags = STRING_FLAGS::NONE) = 0;
 	virtual ieStrRef UpdateString(ieStrRef strref, const String& text) = 0;
 	virtual bool HasAltTLK() const = 0;
+	virtual ieStrRef GetNextStrRef() const = 0;
 };
 
 }
 
-#endif  // ! STRINGMGR_H
+#endif // ! STRINGMGR_H
