@@ -18,11 +18,13 @@
 
 #include "swab.h"
 
+#include <cstdint>
+
 // we use this because it works with overlapping buffers (undefined in POSIX)
-void swab_const (const void *bfrom, void *bto, long n)
+void swab_const(const void* bfrom, void* bto, long n)
 {
-	const char *from = (const char *) bfrom;
-	char *to = (char *) bto;
+	const char* from = (const char*) bfrom;
+	char* to = (char*) bto;
 
 	n &= ~((long) 1);
 	while (n > 1) {
@@ -33,7 +35,15 @@ void swab_const (const void *bfrom, void *bto, long n)
 	}
 }
 
-void swabs (void *buf, long n)
+void swabs(void* buf, long n)
 {
 	swab_const(buf, buf, n);
 }
+
+bool IsBigEndian()
+{
+	const static uint16_t endiantest = 1;
+	const static bool isBigEndian = ((char*) &endiantest)[1] == 1;
+
+	return isBigEndian;
+}
