@@ -21,23 +21,28 @@
 #include "TileMap.h"
 
 #include "Interface.h"
-#include "Video/Video.h"
 
 #include "Scriptable/Container.h"
 #include "Scriptable/Door.h"
 #include "Scriptable/InfoPoint.h"
+#include "Scriptable/TileObject.h"
+#include "Video/Video.h"
 
 namespace GemRB {
 
 TileMap::~TileMap(void)
 {
-	for (const InfoPoint *infoPoint : infoPoints) {
+	for (const InfoPoint* infoPoint : infoPoints) {
 		delete infoPoint;
 	}
 
-	for (const Door *door : doors) {
+	for (const Door* door : doors) {
 		delete door;
 	}
+
+	for (const Container* container : containers) {
+		delete container;
+	}
 }
 
 //this needs in case of a tileset switch (for extended night)
@@ -49,14 +54,14 @@ void TileMap::ClearOverlays()
 
 //tiled objects
 TileObject* TileMap::AddTile(const ResRef& ID, const ieVariable& Name, unsigned int Flags,
-	unsigned short* openindices, int opencount, unsigned short* closeindices, int closecount)
+			     unsigned short* openindices, int opencount, unsigned short* closeindices, int closecount)
 {
 	TileObject* tile = new TileObject();
-	tile->Flags=Flags;
-	tile->Name = Name; // would probably need MakeVariable if the whole class wasn't unused
-	tile->Tileset = ID;
-	tile->SetOpenTiles( openindices, opencount );
-	tile->SetClosedTiles( closeindices, closecount );
+	tile->flags = Flags;
+	tile->name = Name; // would probably need MakeVariable if the whole class wasn't unused
+	tile->tileset = ID;
+	tile->SetOpenTiles(openindices, opencount);
+	tile->SetClosedTiles(closeindices, closecount);
 	tiles.push_back(tile);
 	return tile;
 }
@@ -64,66 +69,66 @@ TileObject* TileMap::AddTile(const ResRef& ID, const ieVariable& Name, unsigned
 TileObject* TileMap::GetTile(unsigned int idx)
 {
 	if (idx >= tiles.size()) {
-		return NULL;
+		return nullptr;
 	}
 	return tiles[idx];
 }
 
 //doors
 Door* TileMap::AddDoor(const ResRef& ID, const ieVariable& Name, unsigned int Flags,
-	int ClosedIndex, std::vector<ieWord> indices, DoorTrigger&& dt)
+		       int ClosedIndex, std::vector<ieWord> indices, DoorTrigger&& dt)
 {
 	Door* door = new Door(overlays[0], std::move(dt));
 	door->Flags = Flags;
 	door->closedIndex = ClosedIndex;
 	door->SetTiles(std::move(indices));
-	door->SetName( ID );
-	door->SetScriptName( Name );
-	doors.push_back( door );
+	door->SetName(ID);
+	door->SetScriptName(Name);
+	doors.push_back(door);
 	return door;
 }
 
 Door* TileMap::GetDoor(size_t idx) const
 {
 	if (idx >= doors.size()) {
-		return NULL;
+		return nullptr;
 	}
 	return doors[idx];
 }
 
-Door* TileMap::GetDoor(const Point &p) const
+Door* TileMap::GetDoor(const Point& p) const
 {
 	for (Door* door : doors) {
 		if (door->HitTest(p)) return door;
 	}
-	return NULL;
+	return nullptr;
 }
 
-Door* TileMap::GetDoorByPosition(const Point &p) const
+Door* TileMap::GetDoorByPosition(const Point& p) const
 {
-	for (Door *door : doors) {
-		if (door->toOpen[0].x==p.x && door->toOpen[0].y==p.y) {
+	for (Door* door : doors) {
+		if (door->toOpen[0] == p) {
 			return door;
 		}
-		if (door->toOpen[1].x==p.x && door->toOpen[1].y==p.y) {
+		if (door->toOpen[1] == p) {
 			return door;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 Door* TileMap::GetDoor(const ieVariable& Name) const
 {
-	for (Door *door : doors) {
+	for (Door* door : doors) {
 		if (door->GetScriptName() == Name)
 			return door;
 	}
-	return NULL;
+	return nullptr;
 }
 
 void TileMap::UpdateDoors()
 {
-	for (Door *door : doors) {
+	for (Door* door : doors) {
 		door->SetNewOverlay(overlays[0]);
 	}
 }
@@ -133,7 +138,7 @@ void TileMap::AutoLockDoors() const
 {
 	if (!core->HasFeature(GFFlags::RANDOM_BANTER_DIALOGS)) return;
 
-	for (Door *door : doors) {
+	for (Door* door : doors) {
 		if (door->CantAutoClose()) continue;
 		if (core->Roll(1, 2, -1)) continue; // just a guess
 		door->SetDoorOpen(false, false, 0);
@@ -165,35 +170,35 @@ void TileMap::DrawOverlays(const Region& viewport, bool rain, BlitFlags flags)
 }
 
 //containers
-void TileMap::AddContainer(Container *c)
+void TileMap::AddContainer(Container* c)
 {
 	containers.push_back(c);
 }
 
-Container* TileMap::GetContainer(unsigned int idx) const
+Container* TileMap::GetContainer(size_t idx) const
 {
 	if (idx >= containers.size()) {
-		return NULL;
+		return nullptr;
 	}
 	return containers[idx];
 }
 
 Container* TileMap::GetContainer(const ieVariable& Name) const
 {
-	for (Container *container : containers) {
+	for (Container* container : containers) {
 		if (container->GetScriptName() == Name) {
 			return container;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 //look for a container at position
 //use type = IE_CONTAINER_PILE if you want to find ground piles only
 //in this case, empty piles won't be found!
-Container* TileMap::GetContainer(const Point &position, int type) const
+Container* TileMap::GetContainer(const Point& position, int type) const
 {
-	for (Container *container : containers) {
+	for (Container* container : containers) {
 		if (type != -1 && type != container->containerType) {
 			continue;
 		}
@@ -212,17 +217,17 @@ Container* TileMap::GetContainer(const Point &position, int type) const
 			return container;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
-Container* TileMap::GetContainerByPosition(const Point &position, int type) const
+Container* TileMap::GetContainerByPosition(const Point& position, int type) const
 {
-	for (Container *container : containers) {
+	for (Container* container : containers) {
 		if (type != -1 && type != container->containerType) {
 			continue;
 		}
 
-		if (container->Pos.x != position.x || container->Pos.y != position.y) {
+		if (container->Pos != position) {
 			continue;
 		}
 
@@ -237,10 +242,10 @@ Container* TileMap::GetContainerByPosition(const Point &position, int type) cons
 		}
 		return container;
 	}
-	return NULL;
+	return nullptr;
 }
 
-int TileMap::CleanupContainer(Container *container)
+int TileMap::CleanupContainer(Container* container)
 {
 	if (container->containerType != IE_CONTAINER_PILE)
 		return 0;
@@ -248,14 +253,14 @@ int TileMap::CleanupContainer(Container *container)
 		return 0;
 
 	for (size_t i = 0; i < containers.size(); i++) {
-		if (containers[i]==container) {
-			containers.erase(containers.begin()+i);
+		if (containers[i] == container) {
+			containers.erase(containers.begin() + i);
 			delete container;
 			return 1;
 		}
 	}
 	Log(ERROR, "TileMap", "Invalid container cleanup: {}",
-		container->GetScriptName());
+	    container->GetScriptName());
 	return 1;
 }
 
@@ -263,7 +268,7 @@ int TileMap::CleanupContainer(Container *container)
 InfoPoint* TileMap::AddInfoPoint(const ieVariable& Name, unsigned short Type, const std::shared_ptr<Gem_Polygon>& outline)
 {
 	InfoPoint* ip = new InfoPoint();
-	ip->SetScriptName( Name );
+	ip->SetScriptName(Name);
 	switch (Type) {
 		case 0:
 			ip->Type = ST_PROXIMITY;
@@ -285,14 +290,14 @@ InfoPoint* TileMap::AddInfoPoint(const ieVariable& Name, unsigned short Type, co
 	if (ip->outline)
 		ip->BBox = outline->BBox;
 	//ip->Active = true; //set active on creation
-	infoPoints.push_back( ip );
+	infoPoints.push_back(ip);
 	return ip;
 }
 
 //if detectable is set, then only detectable infopoints will be returned
-InfoPoint* TileMap::GetInfoPoint(const Point &p, bool skipSilent) const
+InfoPoint* TileMap::GetInfoPoint(const Point& p, bool skipSilent) const
 {
-	for (InfoPoint *infoPoint : infoPoints) {
+	for (InfoPoint* infoPoint : infoPoints) {
 		//these flags disable any kind of user interaction
 		//scripts can still access an infopoint by name
 		if (infoPoint->Flags & (INFO_DOOR | TRAP_DEACTIVATED))
@@ -304,7 +309,7 @@ InfoPoint* TileMap::GetInfoPoint(const Point &p, bool skipSilent) const
 
 		// skip portals without PORTAL_CURSOR set
 		if (infoPoint->IsPortal() && !(infoPoint->Trapped & PORTAL_CURSOR)) {
-				continue;
+			continue;
 		}
 
 		if (skipSilent && infoPoint->Flags & TRAP_SILENT) {
@@ -322,49 +327,49 @@ InfoPoint* TileMap::GetInfoPoint(const Point &p, bool skipSilent) const
 			return infoPoint;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 InfoPoint* TileMap::GetInfoPoint(const ieVariable& Name) const
 {
-	for (InfoPoint *infoPoint : infoPoints) {
+	for (InfoPoint* infoPoint : infoPoints) {
 		if (infoPoint->GetScriptName() == Name) {
 			return infoPoint;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 InfoPoint* TileMap::GetInfoPoint(size_t idx) const
 {
 	if (idx >= infoPoints.size()) {
-		return NULL;
+		return nullptr;
 	}
 	return infoPoints[idx];
 }
 
 InfoPoint* TileMap::GetTravelTo(const ResRef& Destination) const
 {
-	for (InfoPoint *infoPoint : infoPoints) {
+	for (InfoPoint* infoPoint : infoPoints) {
 		if (infoPoint->Type != ST_TRAVEL) continue;
 
 		if (infoPoint->Destination == Destination) {
 			return infoPoint;
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
-InfoPoint *TileMap::AdjustNearestTravel(Point &p)
+InfoPoint* TileMap::AdjustNearestTravel(Point& p) const
 {
-	int min = -1;
-	InfoPoint *best = NULL;
+	unsigned int min = UINT_MAX;
+	InfoPoint* best = nullptr;
 
-	for (InfoPoint *infoPoint : infoPoints) {
+	for (InfoPoint* infoPoint : infoPoints) {
 		if (infoPoint->Type != ST_TRAVEL) continue;
 
-		unsigned int dist = Distance(p, infoPoint);
-		if (dist<(unsigned int) min) {
+		unsigned int dist = SquaredDistance(p, infoPoint->Pos);
+		if (dist < min) {
 			min = dist;
 			best = infoPoint;
 		}
@@ -377,7 +382,7 @@ InfoPoint *TileMap::AdjustNearestTravel(Point &p)
 
 Size TileMap::GetMapSize() const
 {
-	return Size((XCellCount*64), (YCellCount*64));
+	return Size((XCellCount * 64), (YCellCount * 64));
 }
 
 }
