@@ -23,30 +23,31 @@
 
 #include "exports.h"
 
-#include "Holder.h"
 #include "Tile.h"
+
 #include "Video/Video.h"
 
 #include <vector>
 
 namespace GemRB {
 
-class GEM_EXPORT TileOverlay : public Held<TileOverlay> {
+class GEM_EXPORT TileOverlay {
 public:
 	Size size;
 	std::vector<Tile> tiles;
+
 public:
 	using TileOverlayPtr = Holder<TileOverlay>;
 
 	explicit TileOverlay(Size size) noexcept;
 	TileOverlay(const TileOverlay&) noexcept = delete;
 	TileOverlay& operator=(const TileOverlay&) noexcept = delete;
-	
+
 	TileOverlay(TileOverlay&&) noexcept = default;
 	TileOverlay& operator=(TileOverlay&&) noexcept = default;
 
 	void AddTile(Tile&& tile);
-	void Draw(const Region& viewport, std::vector<TileOverlayPtr> &overlays, BlitFlags flags) const;
+	void Draw(const Region& viewport, std::vector<TileOverlayPtr>& overlays, BlitFlags flags) const;
 };
 
 }
