@@ -20,14 +20,15 @@
 #ifndef VEFOBJECT_H
 #define VEFOBJECT_H
 
+#include "RGBAColor.h"
+#include "SClassID.h"
 #include "exports.h"
 #include "ie_types.h"
 
 #include "Orientation.h"
 #include "Region.h"
 #include "Resource.h"
-#include "RGBAColor.h"
-#include "SClassID.h"
+
 #include "Video/Video.h"
 
 #include <cstdint>
@@ -38,7 +39,11 @@ namespace GemRB {
 class DataStream;
 class ScriptedAnimation;
 
-enum class VEFTypes { INVALID = -1, BAM, VVC, VEF, _2DA };
+enum class VEFTypes { INVALID = -1,
+		      BAM,
+		      VVC,
+		      VEF,
+		      _2DA };
 
 struct ScheduleEntry {
 	ResRef resourceName;
@@ -46,7 +51,7 @@ struct ScheduleEntry {
 	ieDword length;
 	Point offset;
 	VEFTypes type;
-	void *ptr;
+	void* ptr;
 };
 
 class GEM_EXPORT VEFObject {
@@ -55,32 +60,35 @@ public:
 	Point Pos; // position of the effect in game coordinates
 
 	VEFObject() noexcept = default;
-	explicit VEFObject(ScriptedAnimation *sca);
+	explicit VEFObject(ScriptedAnimation* sca);
 	VEFObject(const VEFObject&) = delete;
 	~VEFObject();
 	VEFObject& operator=(const VEFObject&) = delete;
+
 private:
 	std::vector<ScheduleEntry> entries;
 	std::vector<ScheduleEntry> drawQueue;
 	bool SingleObject = false;
+
 public:
 	//adds a new entry (use when loading)
-	void AddEntry(const ResRef &res, ieDword st, ieDword len, Point pos, VEFTypes type, ieDword gtime);
+	void AddEntry(const ResRef& res, ieDword st, ieDword len, Point pos, VEFTypes type, ieDword gtime);
 	//renders the object
 	bool UpdateDrawingState(int orientation);
-	void Draw(const Region &screen, const Color &p_tint, int height, BlitFlags flags) const;
-	void Load2DA(const ResRef &resource);
-	void LoadVEF(DataStream *stream);
-	ScriptedAnimation *GetSingleObject() const;
+	void Draw(const Region& screen, const Color& p_tint, int height, BlitFlags flags) const;
+	void Load2DA(const ResRef& resource);
+	void LoadVEF(DataStream* stream);
+	ScriptedAnimation* GetSingleObject() const;
+
 private:
 	//clears the schedule, used internally
 	void Init();
 	//load a 2DA/VEF resource into the object
-	VEFObject *CreateObject(const ResRef &res, SClass_ID id);
+	VEFObject* CreateObject(const ResRef& res, SClass_ID id);
 	//load a BAM/VVC resource into the object
-	ScriptedAnimation *CreateCell(const ResRef &res, ieDword start, ieDword end);
+	ScriptedAnimation* CreateCell(const ResRef& res, ieDword start, ieDword end);
 	//load a single entry from stream
-	void ReadEntry(DataStream *stream);
+	void ReadEntry(DataStream* stream);
 };
 
 }
