@@ -22,10 +22,11 @@
 
 #include "Game.h"
 #include "Interface.h"
-#include "Logging/Logging.h"
-#include "TableMgr.h"
-#include "Video/Video.h"
 #include "RNG.h"
+#include "TableMgr.h"
+
+#include "Logging/Logging.h"
+#include "Video/Video.h"
 
 #include <list>
 #include <utility>
@@ -55,23 +56,30 @@ String WMPAreaEntry::GetTooltip()
 	return StrTooltip;
 }
 
-Holder<Sprite2D> WMPAreaEntry::GetMapIcon(const AnimationFactory *bam)
+Holder<Sprite2D> WMPAreaEntry::GetMapIcon(const AnimationFactory* bam)
 {
 	if (!bam || IconSeq == (ieDword) -1) {
 		return NULL;
 	}
 	if (!MapIcon) {
 		int frame = 0;
-		switch (AreaStatus&(WMP_ENTRY_ACCESSIBLE|WMP_ENTRY_VISITED))
-		{
-			case WMP_ENTRY_ACCESSIBLE: frame = 0; break;
-			case WMP_ENTRY_VISITED: frame = 4; break;
-			case WMP_ENTRY_ACCESSIBLE|WMP_ENTRY_VISITED: frame = 1; break;
-			case 0: frame = 2; break;
+		switch (AreaStatus & (WMP_ENTRY_ACCESSIBLE | WMP_ENTRY_VISITED)) {
+			case WMP_ENTRY_ACCESSIBLE:
+				frame = 0;
+				break;
+			case WMP_ENTRY_VISITED:
+				frame = 4;
+				break;
+			case WMP_ENTRY_ACCESSIBLE | WMP_ENTRY_VISITED:
+				frame = 1;
+				break;
+			case 0:
+				frame = 2;
+				break;
 		}
 
 		// iwd1, bg1 and pst all have this format
-		if (bam->GetCycleSize(IconSeq)<5) {
+		if (bam->GetCycleSize(IconSeq) < 5) {
 			SingleFrame = true;
 			frame = 0;
 		}
@@ -87,8 +95,8 @@ Holder<Sprite2D> WMPAreaEntry::GetMapIcon(const AnimationFactory *bam)
 ieDword WMPAreaEntry::GetAreaStatus() const
 {
 	ieDword tmp = AreaStatus;
-	if (core->HasFeature(GFFlags::KNOW_WORLD) ) {
-		tmp |=WMP_ENTRY_VISITED;
+	if (core->HasFeature(GFFlags::KNOW_WORLD)) {
+		tmp |= WMP_ENTRY_VISITED;
 	}
 	return tmp;
 }
@@ -108,11 +116,11 @@ void WorldMap::AddAreaLink(WMPAreaLink&& al)
 void WorldMap::SetAreaEntry(unsigned int x, WMPAreaEntry&& ae)
 {
 	//if index is too large, we break
-	if (x>area_entries.size()) {
+	if (x > area_entries.size()) {
 		error("WorldMap", "Trying to set invalid entry ({}/{})", x, area_entries.size());
 	}
 	//altering an existing entry
-	if (x<area_entries.size()) {
+	if (x < area_entries.size()) {
 		area_entries[x] = std::move(ae);
 	} else {
 		//adding a new entry
@@ -120,34 +128,34 @@ void WorldMap::SetAreaEntry(unsigned int x, WMPAreaEntry&& ae)
 	}
 }
 
-void WorldMap::InsertAreaLink(unsigned int areaidx, WMPDirection dir, WMPAreaLink&& arealink)
+void WorldMap::InsertAreaLink(size_t areaIdx, WMPDirection dir, WMPAreaLink&& arealink)
 {
-	ieDword idx = area_entries[areaidx].AreaLinksIndex[dir];
-	area_links.emplace(area_links.begin()+idx, std::move(arealink));
+	ieDword idx = area_entries[areaIdx].AreaLinksIndex[dir];
+	area_links.emplace(area_links.begin() + idx, std::move(arealink));
 
 	size_t max = area_entries.size();
-	for (unsigned int pos = 0; pos < max; pos++) {
+	for (size_t pos = 0; pos < max; pos++) {
 		WMPAreaEntry& ae = area_entries[pos];
 		for (WMPDirection k : EnumIterator<WMPDirection>()) {
-			if ((pos==areaidx) && (k==dir)) {
+			if (pos == areaIdx && k == dir) {
 				ae.AreaLinksCount[k]++;
 				continue;
 			}
-			if(ae.AreaLinksIndex[k]>=idx) {
+			if (ae.AreaLinksIndex[k] >= idx) {
 				ae.AreaLinksIndex[k]++;
 			}
 		}
 	}
 }
 
-void WorldMap::SetAreaLink(unsigned int x, const WMPAreaLink *arealink)
+void WorldMap::SetAreaLink(unsigned int x, const WMPAreaLink* arealink)
 {
 	//if index is too large, we break
-	if (x>area_links.size()) {
+	if (x > area_links.size()) {
 		error("WorldMap", "Trying to set invalid link ({}/{})", x, area_links.size());
 	}
 	//altering an existing link
-	if (x<area_links.size()) {
+	if (x < area_links.size()) {
 		area_links[x] = WMPAreaLink(*arealink);
 	} else {
 		//adding a new link
@@ -165,47 +173,76 @@ void WorldMap::SetMapMOS(Holder<Sprite2D> newmos)
 	MapMOS = std::move(newmos);
 }
 
-WMPAreaEntry* WorldMap::GetArea(const ResRef& areaName, unsigned int &i)
+WMPAreaEntry* WorldMap::GetArea(const ResRef& areaName)
 {
-	i=(unsigned int) area_entries.size();
-	while (i--) {
-		if (areaName == area_entries[i].AreaName) {
-			return &area_entries[i];
-		}
-	}
-	// try also with the original name (needed for centering on Candlekeep)
-	i = (unsigned int) area_entries.size();
-	while (i--) {
-		if (areaName == area_entries[i].AreaResRef) {
-			return &area_entries[i];
-		}
-	}
-	return NULL;
+	size_t i;
+	return GetArea(areaName, i);
 }
 
-const WMPAreaEntry* WorldMap::GetArea(const ResRef& areaName, unsigned int &i) const
+const WMPAreaEntry* WorldMap::GetArea(const ResRef& areaName) const
 {
-	i=(unsigned int) area_entries.size();
+	size_t i;
+	return GetArea(areaName, i);
+}
+
+WMPAreaEntry* WorldMap::GetArea(const ResRef& areaName, size_t& i)
+{
+	unsigned int entryCount = (unsigned int) area_entries.size();
+	i = entryCount;
 	while (i--) {
 		if (areaName == area_entries[i].AreaName) {
 			return &area_entries[i];
 		}
 	}
 	// try also with the original name (needed for centering on Candlekeep)
-	i = (unsigned int) area_entries.size();
+	i = entryCount;
 	while (i--) {
 		if (areaName == area_entries[i].AreaResRef) {
 			return &area_entries[i];
 		}
 	}
-	return NULL;
+	if (!core->HasFeature(GFFlags::FLEXIBLE_WMAP)) return nullptr;
+
+	// try with rounded down names, which is needed for subareas in iwd2
+	// eg. ar4101 -> ar4100
+	// we take the first lowest area entry available that isn't too different,
+	// otherwise the wrong worldmap could get picked while testing for entry presence
+	i = entryCount;
+	int areaID = atoi(areaName.c_str() + 2);
+	while (i--) {
+		int curID = atoi(area_entries[i].AreaName.c_str() + 2);
+		if (areaID > curID && areaID - curID < 100) {
+			return &area_entries[i];
+		}
+	}
+	return nullptr;
+}
+
+// revisit on c++17, where std::as_const can be used in many callers of the non-const version
+const WMPAreaEntry* WorldMap::GetArea(const ResRef& areaName, size_t& i) const
+{
+	unsigned int entryCount = (unsigned int) area_entries.size();
+	i = entryCount;
+	while (i--) {
+		if (areaName == area_entries[i].AreaName) {
+			return &area_entries[i];
+		}
+	}
+	// try also with the original name (needed for centering on Candlekeep)
+	i = entryCount;
+	while (i--) {
+		if (areaName == area_entries[i].AreaResRef) {
+			return &area_entries[i];
+		}
+	}
+	return nullptr;
 }
 
 //Find Worldmap location by nearest area with a smaller number
 //Counting backwards, stop at 1000 boundaries.
-//It is not possible to simply round to 1000, because there are 
+//It is not possible to simply round to 1000, because there are
 //WMP entries like AR8001, and we need to find the best match
-const WMPAreaEntry* WorldMap::FindNearestEntry(const ResRef& areaName, unsigned int &i) const
+const WMPAreaEntry* WorldMap::FindNearestEntry(const ResRef& areaName) const
 {
 	int value = 0;
 	ResRef tmp;
@@ -213,16 +250,14 @@ const WMPAreaEntry* WorldMap::FindNearestEntry(const ResRef& areaName, unsigned
 	sscanf(areaName.c_str() + 2, "%4d", &value);
 	do {
 		tmp.Format("{:.2}{:04d}", areaName, value);
-		const WMPAreaEntry* ret = GetArea(tmp, i);
+		const WMPAreaEntry* ret = GetArea(tmp);
 		if (ret) {
 			return ret;
 		}
-		if (value%1000 == 0) break;
+		if (value % 1000 == 0) break;
 		value--;
-	}
-	while (true); //value%1000 should protect us from infinite loops
-	i = -1;
-	return NULL;
+	} while (true); //value%1000 should protect us from infinite loops
+	return nullptr;
 }
 
 //this is a pathfinding algorithm
@@ -236,7 +271,7 @@ int WorldMap::CalculateDistances(const ResRef& areaName, WMPDirection direction)
 		return 0;
 	}
 
-	unsigned int i;
+	size_t i;
 	if (!GetArea(areaName, i)) {
 		Log(ERROR, "WorldMap", "CalculateDistances for invalid Area: {}", areaName);
 		return -1;
@@ -252,23 +287,23 @@ int WorldMap::CalculateDistances(const ResRef& areaName, WMPDirection direction)
 
 	std::vector<int> seen_entry(area_entries.size());
 
-	std::list<int> pending;
+	std::list<size_t> pending;
 	pending.push_back(i);
-	while(!pending.empty()) {
-		i=pending.front();
+	while (!pending.empty()) {
+		i = pending.front();
 		pending.pop_front();
 		const WMPAreaEntry& ae = area_entries[i];
 		std::fill(seen_entry.begin(), seen_entry.end(), -1);
 		//all directions should be used
 		for (WMPDirection d : EnumIterator<WMPDirection>()) {
-			int j=ae.AreaLinksIndex[d];
-			int k=j+ae.AreaLinksCount[d];
-			if ((size_t) k>area_links.size()) {
+			int j = ae.AreaLinksIndex[d];
+			int k = j + ae.AreaLinksCount[d];
+			if ((size_t) k > area_links.size()) {
 				Log(ERROR, "WorldMap", "The worldmap file is corrupted... and it would crash right now! Entry #: {} Direction: {}",
-					i, UnderType(d));
+				    i, UnderType(d));
 				break;
 			}
-			for(;j<k;j++) {
+			for (; j < k; j++) {
 				const WMPAreaLink& al = area_links[j];
 				const WMPAreaEntry& ae2 = area_entries[al.AreaIndex];
 				unsigned int mydistance = (unsigned int) Distances[i];
@@ -276,11 +311,11 @@ int WorldMap::CalculateDistances(const ResRef& areaName, WMPDirection direction)
 				// we must only process the FIRST seen link to each area from this one
 				if (seen_entry[al.AreaIndex] != -1) continue;
 				seen_entry[al.AreaIndex] = 0;
-/*
+				/*
 				if ( ( (ae->GetAreaStatus() & WMP_ENTRY_PASSABLE) == WMP_ENTRY_PASSABLE) &&
 				( (ae2->GetAreaStatus() & WMP_ENTRY_WALKABLE) == WMP_ENTRY_WALKABLE)
 */
-				if ( (ae2.GetAreaStatus() & WMP_ENTRY_WALKABLE) == WMP_ENTRY_WALKABLE) {
+				if ((ae2.GetAreaStatus() & WMP_ENTRY_WALKABLE) == WMP_ENTRY_WALKABLE) {
 					// al->Flags is the entry direction
 					mydistance += al.DistanceScale * 4;
 					//nonexisting distance is the biggest!
@@ -298,38 +333,34 @@ int WorldMap::CalculateDistances(const ResRef& areaName, WMPDirection direction)
 }
 
 //returns the index of the area owning this link
-unsigned int WorldMap::WhoseLinkAmI(int link_index) const
+size_t WorldMap::WhoseLinkAmI(int linkIndex) const
 {
 	unsigned int cnt = GetEntryCount();
 	for (unsigned int i = 0; i < cnt; i++) {
 		const WMPAreaEntry& ae = area_entries[i];
-		for (WMPDirection direction : EnumIterator<WMPDirection>())
-		{
-			int j=ae.AreaLinksIndex[direction];
-			if (link_index < j) continue;
+		for (WMPDirection direction : EnumIterator<WMPDirection>()) {
+			int j = ae.AreaLinksIndex[direction];
+			if (linkIndex < j) continue;
 
 			j += ae.AreaLinksCount[direction];
-			if (link_index < j) {
+			if (linkIndex < j) {
 				return i;
 			}
 		}
 	}
-	return (ieDword) -1;
+	return (size_t) -1;
 }
 
-WMPAreaLink *WorldMap::GetLink(const ResRef& A, const ResRef& B)
+WMPAreaLink* WorldMap::GetLink(const ResRef& A, const ResRef& B)
 {
-	unsigned int i;
-	const WMPAreaEntry *ae = GetArea(A, i);
-	if (!ae) {
-		return NULL;
-	}
+	const WMPAreaEntry* ae = GetArea(A);
+	if (!ae) return nullptr;
 
 	//looking for destination area, returning the first link found
 	for (WMPDirection dir : EnumIterator<WMPDirection>()) {
 		unsigned int j = ae->AreaLinksCount[dir];
 		unsigned int k = ae->AreaLinksIndex[dir];
-		while(j--) {
+		while (j--) {
 			WMPAreaLink& al = area_links[k++];
 			const WMPAreaEntry& ae2 = area_entries[al.AreaIndex];
 			//or arearesref?
@@ -344,21 +375,21 @@ WMPAreaLink *WorldMap::GetLink(const ResRef& A, const ResRef& B)
 //call this function to find out which area we fall into
 //not necessarily the target area
 //if it isn't the same, then a random encounter happened!
-WMPAreaLink *WorldMap::GetEncounterLink(const ResRef& areaName, bool &encounter)
+WMPAreaLink* WorldMap::GetEncounterLink(const ResRef& areaName, bool& encounter)
 {
-	unsigned int i;
-	const WMPAreaEntry *ae = GetArea(areaName, i); //target area
+	size_t i;
+	const WMPAreaEntry* ae = GetArea(areaName, i); //target area
 	if (!ae) {
 		Log(ERROR, "WorldMap", "No such area: {}", areaName);
 		return NULL;
 	}
 	std::list<WMPAreaLink*> walkpath;
 	Log(DEBUG, "WorldMap", "Gathering path information for: {}", areaName);
-	while (GotHereFrom[i]!=-1) {
+	while (GotHereFrom[i] != -1) {
 		Log(DEBUG, "WorldMap", "Adding path to {}", i);
 		walkpath.push_back(&area_links[GotHereFrom[i]]);
 		i = WhoseLinkAmI(GotHereFrom[i]);
-		if (i==(ieDword) -1) {
+		if (i == (size_t) -1) {
 			error("WorldMap", "Something has been screwed up here (incorrect path)!");
 		}
 	}
@@ -368,26 +399,25 @@ WMPAreaLink *WorldMap::GetEncounterLink(const ResRef& areaName, bool &encounter)
 		return NULL;
 	}
 	auto p = walkpath.rbegin();
-	WMPAreaLink *lastpath;
-	encounter=false;
+	WMPAreaLink* lastpath;
+	encounter = false;
 	do {
 		lastpath = *p;
-		if (lastpath->EncounterChance > (unsigned int) RAND(0, 99)) {
-			encounter=true;
+		if (lastpath->EncounterChance > RAND<ieDword>(0, 99)) {
+			encounter = true;
 			break;
 		}
 		++p;
-	}
-	while(p!=walkpath.rend() );
+	} while (p != walkpath.rend());
 	return lastpath;
 }
 
 //adds a temporary AreaEntry to the world map
 //this entry has two links for each direction, leading to the two areas
 //we were travelling between when using the supplied link
-void WorldMap::SetEncounterArea(const ResRef& area, const WMPAreaLink *link) {
-	unsigned int i;
-	if (GetArea(area, i)) {
+void WorldMap::SetEncounterArea(const ResRef& area, const WMPAreaLink* link)
+{
+	if (GetArea(area)) {
 		return;
 	}
 
@@ -399,14 +429,14 @@ void WorldMap::SetEncounterArea(const ResRef& area, const WMPAreaLink *link) {
 		}
 	}
 
-	i = WhoseLinkAmI(j);
-	if (i == (unsigned int) -1) {
+	size_t i = WhoseLinkAmI(j);
+	if (i == (size_t) -1) {
 		Log(ERROR, "WorldMap", "Could not add encounter area");
 		return;
 	}
 
 	WMPAreaEntry ae;
-	ae.SetAreaStatus(WMP_ENTRY_VISIBLE|WMP_ENTRY_ACCESSIBLE|WMP_ENTRY_VISITED, BitOp::SET);
+	ae.SetAreaStatus(WMP_ENTRY_VISIBLE | WMP_ENTRY_ACCESSIBLE | WMP_ENTRY_VISITED, BitOp::SET);
 	ae.AreaName = area;
 	ae.AreaResRef = area;
 	ae.LocCaptionName = ieStrRef::INVALID;
@@ -424,10 +454,10 @@ void WorldMap::SetEncounterArea(const ResRef& area, const WMPAreaLink *link) {
 	link = GetLink(dest.AreaName, src.AreaName);
 	if (!link) {
 		Log(ERROR, "WorldMap", "Could not find link from {} to {}",
-			dest.AreaName, src.AreaName);
+		    dest.AreaName, src.AreaName);
 		return;
 	}
-	
+
 	WMPAreaLink ldest = *link;
 	ldest.DistanceScale /= 2;
 	ldest.EncounterChance = 0;
@@ -444,7 +474,7 @@ void WorldMap::SetEncounterArea(const ResRef& area, const WMPAreaLink *link) {
 		ae.AreaLinksCount[dir] = 2;
 		ae.AreaLinksIndex[dir] = idx;
 	}
-	
+
 	encounterArea = area_entries.size();
 	AddAreaEntry(std::move(ae));
 }
@@ -469,7 +499,7 @@ void WorldMap::ClearEncounterArea()
 
 int WorldMap::GetDistance(const ResRef& areaName) const
 {
-	unsigned int i;
+	size_t i;
 	if (GetArea(areaName, i)) {
 		return Distances[i];
 	}
@@ -478,32 +508,29 @@ int WorldMap::GetDistance(const ResRef& areaName) const
 
 void WorldMap::UpdateAreaVisibility(const ResRef& areaName, WMPDirection direction)
 {
-	unsigned int i;
+	WMPAreaEntry* ae = GetArea(areaName);
+	if (!ae) return;
 
-	WMPAreaEntry* ae = GetArea(areaName, i);
-	if (!ae)
-		return;
 	//we are here, so we visited and it is visible too (i guess)
 	Log(DEBUG, "WorldMap", "Updated Area visibility: {} (visited, accessible and visible)", areaName);
 
-	ae->SetAreaStatus(WMP_ENTRY_VISITED|WMP_ENTRY_VISIBLE|WMP_ENTRY_ACCESSIBLE, BitOp::OR);
-	i=ae->AreaLinksCount[direction];
+	ae->SetAreaStatus(WMP_ENTRY_VISITED | WMP_ENTRY_VISIBLE | WMP_ENTRY_ACCESSIBLE, BitOp::OR);
+	if (direction == WMPDirection::NONE) return;
+	unsigned int i = ae->AreaLinksCount[direction];
 	while (i--) {
 		const WMPAreaLink& al = area_links[ae->AreaLinksIndex[direction] + i];
 		WMPAreaEntry& ae2 = area_entries[al.AreaIndex];
-		if (ae2.GetAreaStatus()&WMP_ENTRY_ADJACENT) {
+		if (ae2.GetAreaStatus() & WMP_ENTRY_ADJACENT) {
 			Log(DEBUG, "WorldMap", "Updated Area visibility: {} (accessible and visible)", ae2.AreaName);
-			ae2.SetAreaStatus(WMP_ENTRY_VISIBLE|WMP_ENTRY_ACCESSIBLE, BitOp::OR);
+			ae2.SetAreaStatus(WMP_ENTRY_VISIBLE | WMP_ENTRY_ACCESSIBLE, BitOp::OR);
 		}
 	}
 }
 
 void WorldMap::SetAreaStatus(const ResRef& areaName, int Bits, BitOp Op)
 {
-	unsigned int i;
-	WMPAreaEntry* ae = GetArea(areaName, i);
-	if (!ae)
-		return;
+	WMPAreaEntry* ae = GetArea(areaName);
+	if (!ae) return;
 	ae->SetAreaStatus(Bits, Op);
 }
 
@@ -513,7 +540,7 @@ void WorldMap::UpdateReachableAreas()
 	if (!tab) {
 		return;
 	}
-	const Game *game = core->GetGame();
+	const Game* game = core->GetGame();
 	if (!game) {
 		return;
 	}
@@ -522,7 +549,7 @@ void WorldMap::UpdateReachableAreas()
 		// 2da rows in format <name> <variable name> <area>
 		// we set the first three flags for <area> if <variable name> is set
 		const std::string& varname = tab->QueryField(idx, 0);
-		if (game->GetLocal(varname, 0)) {
+		if (game->GetGlobal(varname, 0)) {
 			const ResRef areaname = tab->QueryField(idx, 1);
 			SetAreaStatus(areaname, WMP_ENTRY_VISIBLE | WMP_ENTRY_ADJACENT | WMP_ENTRY_ACCESSIBLE, BitOp::OR);
 		}
@@ -537,9 +564,8 @@ WorldMapArray::WorldMapArray(size_t count)
 
 size_t WorldMapArray::FindAndSetCurrentMap(const ResRef& area)
 {
-	unsigned int idx;
 	for (size_t i = 0; i < maps.size(); ++i) {
-		if (maps[i].GetArea (area, idx) ) {
+		if (maps[i].GetArea(area)) {
 			CurrentMap = i;
 			return i;
 		}
@@ -547,7 +573,7 @@ size_t WorldMapArray::FindAndSetCurrentMap(const ResRef& area)
 	return CurrentMap;
 }
 
-WorldMap *WorldMapArray::NewWorldMap(size_t index)
+WorldMap* WorldMapArray::NewWorldMap(size_t index)
 {
 	return &maps[index];
 }
