@@ -27,21 +27,20 @@
 
 #include "exports.h"
 
-#ifndef _MAX_PATH
-	#ifdef WIN32
-		#define _MAX_PATH 260
-	#else
-		#include <cstdio> // for FILENAME_MAX...
-		#define _MAX_PATH FILENAME_MAX
-	#endif
-#endif
-
 #ifdef WIN32
 	#include "win32def.h"
 #elif defined(HAVE_UNISTD_H)
 	#include <unistd.h>
 #endif
 
+#ifdef USE_TRACY
+	#define TRACY_ENABLE 1
+	#include <tracy/Tracy.hpp>
+	#define TRACY(x) x
+#else
+	#define TRACY(x)
+#endif
+
 #include <cstddef>
 
-#endif  //! PLATFORM_H
+#endif //! PLATFORM_H
