@@ -22,20 +22,23 @@
 #define H_IMPORTER_PLUGIN
 
 #include "Plugin.h"
+
 #include "Plugins/export.h"
 
 namespace GemRB {
 
-template <class IMPORTER>
-class GEM_PLUGIN_EXPORT ImporterPlugin final : public Plugin
-{
+template<class IMPORTER>
+class GEM_PLUGIN_EXPORT ImporterPlugin final : public Plugin {
 	std::shared_ptr<IMPORTER> importer = MakeImporter<IMPORTER>();
+
 public:
-	std::shared_ptr<IMPORTER> GetImporter() const noexcept {
+	std::shared_ptr<IMPORTER> GetImporter() const noexcept
+	{
 		return importer;
 	}
 
-	std::shared_ptr<IMPORTER> GetImporter(DataStream* str) noexcept {
+	std::shared_ptr<IMPORTER> GetImporter(DataStream* str) noexcept
+	{
 		if (str == nullptr) {
 			return nullptr;
 		}
