@@ -24,13 +24,14 @@
 #include "globals.h"
 
 #include "Plugin.h"
+
 #include "Plugins/export.h"
 
 namespace GemRB {
 
 class GEM_PLUGIN_EXPORT IndexedArchive : public Plugin {
 public:
-	virtual int OpenArchive(const char* filename) = 0;
+	virtual int OpenArchive(const path_t& filename) = 0;
 	virtual DataStream* GetStream(unsigned long Resource, unsigned long Type) = 0;
 };
 
