@@ -67,7 +67,7 @@
  *
  * The class given must derive from a subclass of Resource that
  * contains a static member ID of type TypeID. Any number of class
- * extension pairs can be registerd. They will be tried in turn when a
+ * extension pairs can be registered. They will be tried in turn when a
  * resource of the given subclass is requested.
  *
  * If the resource exists in bif files, then \ref{PLUGIN_IE_RESOURCE}
@@ -75,13 +75,15 @@
  *
  * @def PLUGIN_IE_RESOURCE
  * Registers a resource through ResourceManager.
+ * @param[in] cls Class to register.
+ * @param[in] ext Extension of resource files.
  * @param[in] ie_id Type id that appears in BIF files.
  *
  * See \ref{PLUGIN_RESOURCE} for details. The ie_id will be used when
  * searching chitin.key.
  *
  * @def PLUGIN_INITIALIZER
- * Registers a function to do global intialization.
+ * Registers a function to do global initialization.
  * @param[in] func Function to call at startup.
  *
  * This function is called during Interface initialization.
@@ -99,30 +101,31 @@
 #ifndef PLUGINDEF_H
 #define PLUGINDEF_H
 
-#include "exports.h"
-#include "PluginMgr.h"
 #include "Platform.h"
+#include "exports.h"
+
+#include "InterfaceConfig.h"
+#include "PluginMgr.h"
 
 namespace GemRB {
 
-template <typename T>
+template<typename T>
 struct CreatePlugin {
-	static Plugin *func()
+	static PluginHolder<Plugin> func()
 	{
-		return new T();
+		return std::make_shared<T>();
 	}
 };
 
-template <typename Res>
+template<typename Res>
 struct CreateResource {
-	static Resource* func(DataStream *str)
+	static ResourceHolder<Resource> func(DataStream* str)
 	{
-		Res *res = new Res();
+		auto res = std::make_shared<Res>();
 		if (res->Open(str)) {
 			return res;
 		} else {
-			delete res;
-			return NULL;
+			return nullptr;
 		}
 	}
 };
@@ -133,81 +136,86 @@ GEM_EXPORT_DLL const char* GemRBPlugin_Version();
 
 #ifndef STATIC_LINK
 
-#ifdef WIN32
+	#ifdef WIN32
 
-BOOL APIENTRY DllMain(HANDLE, DWORD,	LPVOID);
-BOOL APIENTRY DllMain(HANDLE /*hModule*/, DWORD  /*ul_reason_for_call*/,
-	LPVOID /*lpReserved*/)
+BOOL APIENTRY DllMain(HANDLE, DWORD, LPVOID);
+BOOL APIENTRY DllMain(HANDLE /*hModule*/, DWORD /*ul_reason_for_call*/,
+		      LPVOID /*lpReserved*/)
 {
 	return true;
 }
 
-#endif
+	#endif
 
 GEM_EXPORT_DLL const char* GemRBPlugin_Version()
 {
 	return VERSION_GEMRB;
 }
 
-#define GEMRB_PLUGIN(id, desc)					\
-	namespace { using namespace GemRB;			\
-	GEM_EXPORT_DLL PluginID GemRBPlugin_ID() {		\
-		return id;					\
-	}							\
-	GEM_EXPORT_DLL const char* GemRBPlugin_Description() {	\
-		return desc;					\
-	}							\
-	GEM_EXPORT_DLL bool GemRBPlugin_Register(PluginMgr *mgr) {
+	#define GEMRB_PLUGIN(id, desc) \
+		namespace { \
+			using namespace GemRB; \
+			GEM_EXPORT_DLL PluginID GemRBPlugin_ID() \
+			{ \
+				return id; \
+			} \
+			GEM_EXPORT_DLL const char* GemRBPlugin_Description() \
+			{ \
+				return desc; \
+			} \
+			GEM_EXPORT_DLL bool GemRBPlugin_Register(PluginMgr* mgr) \
+			{
+	#define PLUGIN_CLASS(id, cls) \
+		if (!mgr->RegisterPlugin(id, &CreatePlugin<cls>::func)) \
+			return false;
 
-#define PLUGIN_CLASS(id, cls)					\
-	if (!mgr->RegisterPlugin(id, &CreatePlugin<cls>::func ))\
-		return false;
+	#define PLUGIN_DRIVER(cls, name) \
+		mgr->RegisterDriver(&cls::ID, name, &CreatePlugin<cls>::func);
 
-#define PLUGIN_DRIVER(cls, name)					\
-	mgr->RegisterDriver(&cls::ID, name, &CreatePlugin<cls>::func ); \
+	#define PLUGIN_RESOURCE(cls, ext) \
+		mgr->RegisterResource(&cls::ID, &CreateResource<cls>::func, ext);
 
-#define PLUGIN_RESOURCE(cls, ext)				\
-	mgr->RegisterResource(&cls::ID, &CreateResource<cls>::func, ext);
+	#define PLUGIN_IE_RESOURCE(cls, ext, ie_id) \
+		mgr->RegisterResource(&cls::ID, &CreateResource<cls>::func, ext, ie_id);
 
-#define PLUGIN_IE_RESOURCE(cls, ext, ie_id)			\
-	mgr->RegisterResource(&cls::ID, &CreateResource<cls>::func, ext, ie_id);
-
-#define PLUGIN_INITIALIZER(func)				\
+	#define PLUGIN_INITIALIZER(func) \
 		mgr->RegisterInitializer(func);
-#define PLUGIN_CLEANUP(func)					\
+	#define PLUGIN_CLEANUP(func) \
 		mgr->RegisterCleanup(func);
 
-		/* mgr is not null (this makes mgr used) */
-#define END_PLUGIN()						\
-		return mgr!=0;					\
-	}							\
-	}
+	/* mgr is not null (this makes mgr used) */
+	#define END_PLUGIN() \
+		return mgr != 0; \
+		} \
+		}
 
 #else /* STATIC_LINK */
 
-#define GEMRB_PLUGIN(id, desc)	\
-	namespace { using namespace GemRB;			\
+	#define GEMRB_PLUGIN(id, desc) \
+		namespace { \
+			using namespace GemRB; \
 		bool doRegisterPlugin IGNORE_UNUSED = (
 
-#define PLUGIN_CLASS(id, cls)					\
-		PluginMgr::Get()->RegisterPlugin(id, &CreatePlugin<cls>::func ),
+	#define PLUGIN_CLASS(id, cls) \
+		PluginMgr::Get()->RegisterPlugin(id, &CreatePlugin<cls>::func),
 
-#define PLUGIN_DRIVER(cls, name)					\
-		PluginMgr::Get()->RegisterDriver(&cls::ID, name, &CreatePlugin<cls>::func ),
+	#define PLUGIN_DRIVER(cls, name) \
+		PluginMgr::Get()->RegisterDriver(&cls::ID, name, &CreatePlugin<cls>::func),
 
-#define PLUGIN_RESOURCE(cls, ext)				\
+	#define PLUGIN_RESOURCE(cls, ext) \
 		PluginMgr::Get()->RegisterResource(&cls::ID, &CreateResource<cls>::func, ext),
 
-#define PLUGIN_IE_RESOURCE(cls, ext, ie_id)			\
+	#define PLUGIN_IE_RESOURCE(cls, ext, ie_id) \
 		PluginMgr::Get()->RegisterResource(&cls::ID, &CreateResource<cls>::func, ext, ie_id),
 
-#define PLUGIN_INITIALIZER(func)				\
+	#define PLUGIN_INITIALIZER(func) \
 		PluginMgr::Get()->RegisterInitializer(func),
-#define PLUGIN_CLEANUP(func)					\
+	#define PLUGIN_CLEANUP(func) \
 		PluginMgr::Get()->RegisterCleanup(func),
 
-#define END_PLUGIN()						\
-		true); }
+	#define END_PLUGIN() \
+		true); \
+		}
 
 #endif /* STATIC_LINK */
 
