@@ -26,19 +26,22 @@
 #define WIN32_LEAN_AND_MEAN
 
 #ifndef NOMINMAX
-#define NOMINMAX
+	#define NOMINMAX
 #endif
 
 #define UNICODE
 #define _UNICODE
 #define NOGDI
-#define NOCOLOR
 #define NOUSER
 
 #ifdef _DEBUG
-#include <crtdbg.h>
+	#include <crtdbg.h>
 #endif
 
-#include <windows.h>
+#include <Windows.h>
+#include <ntverp.h>
+#if defined(VER_PRODUCTBUILD) && VER_PRODUCTBUILD >= 8100
+	#include <VersionHelpers.h>
+#endif
 
-#endif  //! WIN32DEF_H
+#endif //! WIN32DEF_H
