@@ -21,10 +21,10 @@
 #ifndef P2DAIMPORTER_H
 #define P2DAIMPORTER_H
 
-#include "TableMgr.h"
-
 #include "globals.h"
 
+#include "TableMgr.h"
+
 #include <cstring>
 #include <vector>
 
@@ -39,9 +39,12 @@ private:
 	std::vector<cell_t> rowNames;
 	std::vector<row_t> rows;
 	std::string defVal;
+
 public:
+	static index_t npos;
+
 	p2DAImporter& operator=(const p2DAImporter&) = delete;
-	bool Open(DataStream* stream) override;
+	bool Open(std::unique_ptr<DataStream> stream) override;
 	/** Returns the actual number of Rows in the Table */
 	index_t GetRowCount() const override;
 
