@@ -24,9 +24,9 @@
 
 int CSubbandDecoder::init_decoder()
 {
-	int memory_size = ( levels == 0 ) ? 0 : ( 3 * ( block_size >> 1 ) - 2 );
+	int memory_size = (levels == 0) ? 0 : (3 * (block_size >> 1) - 2);
 	if (memory_size) {
-		memory_buffer = ( int * ) calloc( memory_size, sizeof( int ) );
+		memory_buffer = (int*) calloc(memory_size, sizeof(int));
 		if (!memory_buffer)
 			return 0;
 	}
@@ -38,11 +38,11 @@ void CSubbandDecoder::decode_data(int* buffer, int blocks)
 		return;
 	} // no levels - no work
 
-	int* buff_ptr = buffer, * mem_ptr = memory_buffer;
+	int *buff_ptr = buffer, *mem_ptr = memory_buffer;
 	int sb_size = block_size >> 1; // current subband size
 
 	blocks <<= 1;
-	sub_4d3fcc( ( short * ) mem_ptr, buff_ptr, sb_size, blocks );
+	sub_4d3fcc((short*) mem_ptr, buff_ptr, sb_size, blocks);
 	mem_ptr += sb_size;
 
 	for (int i = 0; i < blocks; i++)
@@ -52,14 +52,14 @@ void CSubbandDecoder::decode_data(int* buffer, int blocks)
 	blocks <<= 1;
 
 	while (sb_size != 0) {
-		sub_4d420c( mem_ptr, buff_ptr, sb_size, blocks );
+		sub_4d420c(mem_ptr, buff_ptr, sb_size, blocks);
 		mem_ptr += sb_size << 1;
 		sb_size >>= 1;
 		blocks <<= 1;
 	}
 }
 void CSubbandDecoder::sub_4d3fcc(short* memory, int* buffer, int sb_size,
-	int blocks) const
+				 int blocks) const
 {
 	int row_0, row_1, row_2 = 0, row_3 = 0, db_0, db_1;
 	int sb_size_2 = sb_size * 2, sb_size_3 = sb_size * 3;
@@ -69,8 +69,8 @@ void CSubbandDecoder::sub_4d3fcc(short* memory, int* buffer, int sb_size,
 			row_1 = buffer[sb_size];
 			buffer[0] = buffer[0] + memory[0] + 2 * memory[1];
 			buffer[sb_size] = 2 * row_0 - memory[1] - buffer[sb_size];
-			memory[0] = ( short ) row_0;
-			memory[1] = ( short ) row_1;
+			memory[0] = (short) row_0;
+			memory[1] = (short) row_1;
 
 			memory += 2;
 			buffer++;
@@ -87,8 +87,8 @@ void CSubbandDecoder::sub_4d3fcc(short* memory, int* buffer, int sb_size,
 			buffer[sb_size_2] = row_0 + 2 * row_1 + row_2;
 			buffer[sb_size_3] = -row_1 + 2 * row_2 - row_3;
 
-			memory[0] = ( short ) row_2;
-			memory[1] = ( short ) row_3;
+			memory[0] = (short) row_2;
+			memory[1] = (short) row_3;
 
 			memory += 2;
 			buffer++;
@@ -96,7 +96,7 @@ void CSubbandDecoder::sub_4d3fcc(short* memory, int* buffer, int sb_size,
 	} else {
 		for (int i = 0; i < sb_size; i++) {
 			int* buff_ptr = buffer;
-			if (( blocks >> 1 ) & 1) {
+			if ((blocks >> 1) & 1) {
 				row_0 = buff_ptr[0];
 				row_1 = buff_ptr[sb_size];
 
@@ -112,24 +112,32 @@ void CSubbandDecoder::sub_4d3fcc(short* memory, int* buffer, int sb_size,
 			}
 
 			for (int j = 0; j < blocks >> 2; j++) {
-				row_0 = buff_ptr[0];  buff_ptr[0] = db_0 + 2 * db_1 + row_0;  buff_ptr += sb_size;
-				row_1 = buff_ptr[0];  buff_ptr[0] = -db_1 + 2 * row_0 - row_1;  buff_ptr += sb_size;
-				row_2 = buff_ptr[0];  buff_ptr[0] = row_0 + 2 * row_1 + row_2;  buff_ptr += sb_size;
-				row_3 = buff_ptr[0];  buff_ptr[0] = -row_1 + 2 * row_2 -
-					row_3;  buff_ptr += sb_size;
+				row_0 = buff_ptr[0];
+				buff_ptr[0] = db_0 + 2 * db_1 + row_0;
+				buff_ptr += sb_size;
+				row_1 = buff_ptr[0];
+				buff_ptr[0] = -db_1 + 2 * row_0 - row_1;
+				buff_ptr += sb_size;
+				row_2 = buff_ptr[0];
+				buff_ptr[0] = row_0 + 2 * row_1 + row_2;
+				buff_ptr += sb_size;
+				row_3 = buff_ptr[0];
+				buff_ptr[0] = -row_1 + 2 * row_2 -
+					row_3;
+				buff_ptr += sb_size;
 
 				db_0 = row_2;
 				db_1 = row_3;
 			}
-			memory[0] = ( short ) row_2;
-			memory[1] = ( short ) row_3;
+			memory[0] = (short) row_2;
+			memory[1] = (short) row_3;
 			memory += 2;
 			buffer++;
 		}
 	}
 }
 void CSubbandDecoder::sub_4d420c(int* memory, int* buffer, int sb_size,
-	int blocks) const
+				 int blocks) const
 {
 	int row_0, row_1, row_2 = 0, row_3 = 0, db_0, db_1;
 	int sb_size_2 = sb_size * 2, sb_size_3 = sb_size * 3;
@@ -154,13 +162,22 @@ void CSubbandDecoder::sub_4d420c(int* memory, int* buffer, int sb_size,
 	} else {
 		for (int i = 0; i < sb_size; i++) {
 			int* buff_ptr = buffer;
-			db_0 = memory[0]; db_1 = memory[1];
+			db_0 = memory[0];
+			db_1 = memory[1];
 			for (int j = 0; j < blocks >> 2; j++) {
-				row_0 = buff_ptr[0];  buff_ptr[0] = db_0 + 2 * db_1 + row_0;  buff_ptr += sb_size;
-				row_1 = buff_ptr[0];  buff_ptr[0] = -db_1 + 2 * row_0 - row_1;  buff_ptr += sb_size;
-				row_2 = buff_ptr[0];  buff_ptr[0] = row_0 + 2 * row_1 + row_2;  buff_ptr += sb_size;
-				row_3 = buff_ptr[0];  buff_ptr[0] = -row_1 + 2 * row_2 -
-					row_3;  buff_ptr += sb_size;
+				row_0 = buff_ptr[0];
+				buff_ptr[0] = db_0 + 2 * db_1 + row_0;
+				buff_ptr += sb_size;
+				row_1 = buff_ptr[0];
+				buff_ptr[0] = -db_1 + 2 * row_0 - row_1;
+				buff_ptr += sb_size;
+				row_2 = buff_ptr[0];
+				buff_ptr[0] = row_0 + 2 * row_1 + row_2;
+				buff_ptr += sb_size;
+				row_3 = buff_ptr[0];
+				buff_ptr[0] = -row_1 + 2 * row_2 -
+					row_3;
+				buff_ptr += sb_size;
 
 				db_0 = row_2;
 				db_1 = row_3;
