@@ -19,6 +19,7 @@
  */
 
 #include "BAMFontManager.h"
+
 #include "Palette.h"
 #include "Sprite2D.h"
 
@@ -41,12 +42,12 @@ bool BAMFontManager::Import(DataStream* stream)
 	if (resRef.BeginsWith("STATES")) {
 		isStateFont = true;
 	}
-	
+
 	str = nullptr; // hand ownership over to bamImp
 	return bamImp->Open(stream);
 }
 
-Font* BAMFontManager::GetFont(unsigned short /*ptSize*/, FontStyle /*style*/, bool background)
+Holder<Font> BAMFontManager::GetFont(unsigned short /*ptSize*/, FontStyle /*style*/, bool background)
 {
 	auto af = bamImp->GetAnimationFactory(resRef, false); // released by BAMFont
 	// FIXME: this test only exists to let the minimal test pass
@@ -63,7 +64,7 @@ Font* BAMFontManager::GetFont(unsigned short /*ptSize*/, FontStyle /*style*/, bo
 		// Hack to work around original data where the "top row icons" have inverted x and y positions (ie level up icon)
 		// isStateFont is set in Open() and simply compares the first 6 characters of the file with "STATES"
 		// since state icons should all be the same size/position we can just take the position of the first one
-		static const ieWord topIconCycles[] = {254 /* level up icon */, 153 /* dialog icon */, 154 /* store icon */, 37 /* separator glyph (like '-')*/};
+		static const ieWord topIconCycles[] = { 254 /* level up icon */, 153 /* dialog icon */, 154 /* store icon */, 37 /* separator glyph (like '-')*/ };
 		for (size_t i = 0; i < 3; i++) {
 			Holder<Sprite2D> spr = af->GetFrame(0, topIconCycles[i]);
 			if (spr->Frame.x > 0) // not all datasets are messed up here
@@ -75,7 +76,7 @@ Font* BAMFontManager::GetFont(unsigned short /*ptSize*/, FontStyle /*style*/, bo
 	// I think cycle 1 is for determining line height (it appears to be a cursor)
 	// this is important because iterating the initials font would give an incorrect LineHeight
 	// initials should still have 13 for the line height because they have a descent that covers
-	// multiple lines (2 in BG2). numeric and state fonts don't posess these magic glyphs,
+	// multiple lines (2 in BG2). Numeric and state fonts don't possess these magic glyphs,
 	// but it is harmless to use them the same way
 	ieWord baseLine = 0;
 	ieWord lineHeight = 0;
@@ -88,7 +89,7 @@ Font* BAMFontManager::GetFont(unsigned short /*ptSize*/, FontStyle /*style*/, bo
 	}
 
 	auto pal = af->GetFrameWithoutCycle(0)->GetPalette();
-	Font* fnt = new Font(std::move(pal), lineHeight, baseLine, background);
+	auto fnt = MakeHolder<Font>(std::move(pal), lineHeight, baseLine, background);
 
 	std::map<Sprite2D*, ieWord> tmp;
 	for (ieWord cycle = 0; cycle < af->GetCycleCount(); cycle++) {
@@ -100,9 +101,9 @@ Font* BAMFontManager::GetFont(unsigned short /*ptSize*/, FontStyle /*style*/, bo
 			if (isNumeric) {
 				chr = frame + '0';
 			} else {
-				chr = ((frame << 8) | (cycle&0x00ff)) + 1;
+				chr = ((frame << 8) | (cycle & 0x00ff)) + 1;
 			}
-			Sprite2D *key = spr.get();
+			Sprite2D* key = spr.get();
 			auto i = tmp.find(key);
 			if (i != tmp.end()) {
 				// opimization for when glyphs are shared between cycles
