@@ -21,10 +21,10 @@
 #ifndef BAMIMPORTER_H
 #define BAMIMPORTER_H
 
-#include "AnimationMgr.h"
-
 #include "RGBAColor.h"
 #include "globals.h"
+
+#include "AnimationMgr.h"
 #include "Holder.h"
 
 namespace GemRB {
@@ -43,10 +43,10 @@ struct FrameEntry {
 
 class ImageMgr;
 class Palette;
-using PaletteHolder = Holder<Palette>;
 
 enum class BAMVersion {
-	V1, V2
+	V1,
+	V2
 };
 
 struct BAMV2DataBlock {
@@ -60,7 +60,7 @@ class BAMImporter : public AnimationMgr {
 public:
 	bool Import(DataStream* stream) override;
 	index_t GetCycleSize(index_t Cycle) override;
-	std::shared_ptr<AnimationFactory> GetAnimationFactory(const ResRef &resref, bool allowCompression = true) override;
+	std::shared_ptr<AnimationFactory> GetAnimationFactory(const ResRef& resref, bool allowCompression = true) override;
 	/** Debug Function: Returns the Global Animation Palette as a Sprite2D Object.
 	If the Global Animation Palette is NULL, returns NULL. */
 	Holder<Sprite2D> GetPalette() override;
@@ -68,25 +68,26 @@ public:
 	{
 		return cycles.size();
 	}
+
 private:
 	using CycleEntry = AnimationFactory::CycleEntry;
 
 	BAMVersion version = BAMVersion::V1;
 	std::vector<FrameEntry> frames;
 	std::vector<CycleEntry> cycles;
-	PaletteHolder palette;
+	Holder<Palette> palette;
 	ieByte CompressedColorIndex = 0;
 	ieDword FLTOffset = 0;
 	ieDword CyclesOffset = 0;
 	ieDword FramesOffset = 0;
 	strpos_t DataStart = 0;
-	std::shared_ptr<ImageMgr> lastPVRZ;
+	ResourceHolder<ImageMgr> lastPVRZ;
 	ieDword lastPVRZPage = 0;
 
 	void Blit(const FrameEntry& frame, const BAMV2DataBlock& dataBlock, uint8_t* data);
 	std::vector<index_t> CacheFLT();
 	Holder<Sprite2D> GetV2Frame(const FrameEntry& frame);
-	Holder<Sprite2D> GetFrameInternal(const FrameEntry& frame, bool RLESprite, uint8_t* data);
+	Holder<Sprite2D> GetFrameInternal(const FrameEntry& frame, bool RLESprite, uint8_t* data) const;
 };
 
 }
