@@ -21,10 +21,9 @@
 #ifndef BIFIMPORTER_H
 #define BIFIMPORTER_H
 
-#include "Plugins/IndexedArchive.h"
-
 #include "globals.h"
 
+#include "Plugins/IndexedArchive.h"
 #include "Streams/DataStream.h"
 
 namespace GemRB {
@@ -33,8 +32,8 @@ struct FileEntry {
 	ieDword resLocator;
 	ieDword dataOffset;
 	ieDword fileSize;
-	ieWord  type;
-	ieWord  u1; //Unknown Field, part of type dword in ee
+	ieWord type;
+	ieWord u1; //Unknown Field, part of type dword in ee
 };
 
 struct TileEntry {
@@ -42,8 +41,8 @@ struct TileEntry {
 	ieDword dataOffset;
 	ieDword tilesCount;
 	ieDword tileSize; //named tilesize so it isn't confused
-	ieWord  type;
-	ieWord  u1; //Unknown Field, part of type dword in ee
+	ieWord type;
+	ieWord u1; //Unknown Field, part of type dword in ee
 };
 
 class BIFImporter : public IndexedArchive {
@@ -53,16 +52,18 @@ private:
 	ieDword fentcount = 0;
 	ieDword tentcount = 0;
 	DataStream* stream = nullptr;
+
 public:
 	BIFImporter() noexcept = default;
 	BIFImporter(const BIFImporter&) = delete;
 	~BIFImporter() override;
 	BIFImporter& operator=(const BIFImporter&) = delete;
-	int OpenArchive(const char* filename) override;
+	int OpenArchive(const path_t& filename) override;
 	DataStream* GetStream(unsigned long Resource, unsigned long Type) override;
+
 private:
-	static DataStream* DecompressBIF(DataStream* compressed, const char* path);
-	static DataStream* DecompressBIFC(DataStream* compressed, const char* path);
+	static DataStream* DecompressBIF(DataStream* compressed, const path_t& path);
+	static DataStream* DecompressBIFC(DataStream* compressed, const path_t& path);
 	int ReadBIF();
 };
 
