@@ -19,43 +19,47 @@
 #ifndef DIRIMP_H
 #define DIRIMP_H
 
-#include <unordered_map>
-
 #include "ResourceSource.h"
 
+#include "Strings/CString.h"
+#include "System/VFS.h"
+
+#include <set>
+
 namespace GemRB {
 
 class ResourceDesc;
 
 class DirectoryImporter : public ResourceSource {
 protected:
-	char path[_MAX_PATH] {};
+	path_t path;
 
 public:
 	DirectoryImporter() noexcept = default;
-	bool Open(const char *dir, const char *desc) override;
+	bool Open(const path_t& dir, std::string desc) override;
 	/** predicts the availability of a resource */
 	bool HasResource(StringView resname, SClass_ID type) override;
-	bool HasResource(StringView resname, const ResourceDesc &type) override;
+	bool HasResource(StringView resname, const ResourceDesc& type) override;
 	/** returns resource */
 	DataStream* GetResource(StringView resname, SClass_ID type) override;
-	DataStream* GetResource(StringView resname, const ResourceDesc &type) override;
+	DataStream* GetResource(StringView resname, const ResourceDesc& type) override;
 };
 
 class CachedDirectoryImporter : public DirectoryImporter {
 protected:
-	std::unordered_map<std::string, std::string> cache;
+	// the case is case insensitive, but we will only store valid names
+	std::set<path_t, CstrLessCI> cache;
 
 public:
 	CachedDirectoryImporter() noexcept = default;
-	bool Open(const char *dir, const char *desc) override;
+	bool Open(const path_t& dir, std::string desc) override;
 	void Refresh();
 	/** predicts the availability of a resource */
 	bool HasResource(StringView resname, SClass_ID type) override;
-	bool HasResource(StringView resname, const ResourceDesc &type) override;
+	bool HasResource(StringView resname, const ResourceDesc& type) override;
 	/** returns resource */
 	DataStream* GetResource(StringView resname, SClass_ID type) override;
-	DataStream* GetResource(StringView resname, const ResourceDesc &type) override;
+	DataStream* GetResource(StringView resname, const ResourceDesc& type) override;
 };
 
 
