@@ -17,19 +17,18 @@
  */
 
 #include "PythonConversions.h"
-#include "PythonErrors.h"
 
 #include "GameData.h"
-#include "Interface.h"
 #include "ImageMgr.h"
+#include "Interface.h"
+#include "PythonErrors.h"
+
+#include "Strings/Iconv.h"
 
 namespace GemRB {
 
-/*
- If we ever move to C++11 we can simpy use a variadic template for these...
-*/
-
-Color ColorFromPy(PyObject* obj) {
+Color ColorFromPy(PyObject* obj)
+{
 	if (obj && PyDict_Check(obj)) {
 		Color c;
 		// PyLong_AsLong may return -1 on error and we would like this to = 0
@@ -53,7 +52,8 @@ Color ColorFromPy(PyObject* obj) {
 	return Color();
 }
 
-Point PointFromPy(PyObject* obj) {
+Point PointFromPy(PyObject* obj)
+{
 	if (PyDict_Check(obj)) {
 		Point p;
 		PyObject* pyVal = PyDict_GetItemString(obj, "x");
@@ -65,7 +65,8 @@ Point PointFromPy(PyObject* obj) {
 	return Point();
 }
 
-Region RectFromPy(PyObject* obj) {
+Region RectFromPy(PyObject* obj)
+{
 	if (PyDict_Check(obj)) {
 		Region r;
 		PyObject* pyVal = PyDict_GetItemString(obj, "x");
@@ -91,9 +92,9 @@ PyObject* PyLong_FromStrRef(ieStrRef str)
 	return PyLong_FromLong(ieDword(str));
 }
 
-std::shared_ptr<SymbolMgr> GetSymbols(PyObject* obj)
+PluginHolder<SymbolMgr> GetSymbols(PyObject* obj)
 {
-	std::shared_ptr<SymbolMgr> sm;
+	PluginHolder<SymbolMgr> sm;
 
 	PyObject* id = PyObject_GetAttrString(obj, "ID");
 	if (!id) {
@@ -107,7 +108,7 @@ std::shared_ptr<SymbolMgr> GetSymbols(PyObject* obj)
 Holder<Sprite2D> SpriteFromPy(PyObject* pypic)
 {
 	Holder<Sprite2D> pic;
-	if (PyObject_TypeCheck( pypic, &PyUnicode_Type )) {
+	if (PyObject_TypeCheck(pypic, &PyUnicode_Type)) {
 		ResourceHolder<ImageMgr> im = gamedata->GetResourceHolder<ImageMgr>(PyString_AsStringView(pypic));
 		if (im) {
 			pic = im->GetSprite2D();
@@ -133,31 +134,91 @@ PyObject* PyString_FromResRef(const ResRef& resRef)
 {
 	return PyString_FromASCII(resRef);
 }
-	
+
 PyObject* PyString_FromStringObj(const std::string& s)
 {
 	return PyUnicode_Decode(s.c_str(), s.length(), core->TLKEncoding.encoding.c_str(), "strict");
 }
-	
+
 PyObject* PyString_FromStringObj(const String& s)
 {
-	// FIXME: this is wrong, python needs to know the encoding
-	std::string mbstr = MBStringFromString(s);
-	return PyString_FromStringObj(mbstr);
+	return PyUnicode_Decode(reinterpret_cast<const char*>(s.c_str()), s.length() * sizeof(char16_t), "UTF-16", "strict");
 }
 
-String* PyString_AsStringObj(PyObject* obj)
+String PyString_AsStringObj(PyObject* obj)
 {
-	auto wrap = PyStringWrapper(obj, core->TLKEncoding.encoding.c_str());
-	return StringFromCString(wrap.CString());
+#if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION < 12
+	if (PyUnicode_READY(obj) != 0) {
+		Log(ERROR, "PythonConversions", "Failed to prepare a Python string for encoding.");
+		return u"";
+	}
+#endif
+
+	auto unicodeKind = PyUnicode_KIND(obj);
+	std::string encoding = "ISO-8859-1";
+	bool isWide = false;
+	uint8_t encodingSize = 1;
+
+	if (unicodeKind == PyUnicode_4BYTE_KIND) {
+		encoding = "UCS-4";
+		isWide = true;
+		encodingSize = 4;
+	} else if (unicodeKind == PyUnicode_2BYTE_KIND) {
+		encoding = "UCS-2";
+		isWide = true;
+		encodingSize = 2;
+	} else if (unicodeKind != PyUnicode_1BYTE_KIND) {
+		// technically there is PyUnicode_WCHAR_KIND before v3.12
+		assert(false);
+	}
+
+	if (isWide) {
+		encoding += (IsBigEndian() ? "BE" : "LE");
+	}
+
+	iconv_t cd = nullptr;
+	if (IsBigEndian()) {
+		cd = iconv_open("UTF-16BE", encoding.c_str());
+	} else {
+		cd = iconv_open("UTF-16LE", encoding.c_str());
+	}
+
+	if (cd == (iconv_t) -1) {
+		Log(ERROR, "PythonConversions", "iconv_open(UTF-16, {}) failed with error: {}", encoding, strerror(errno));
+		return u"";
+	}
+
+	auto numCodepoints = PyUnicode_GET_LENGTH(obj);
+	size_t inLen = numCodepoints * encodingSize;
+	size_t outLen = numCodepoints * 4;
+	size_t outLenLeft = outLen;
+	String buffer(numCodepoints * 2, u'\0');
+
+	auto in = reinterpret_cast<char*>(PyUnicode_DATA(obj));
+	auto outBuf = reinterpret_cast<char*>(const_cast<char16_t*>(buffer.data()));
+
+	size_t ret = portableIconv(cd, &in, &inLen, &outBuf, &outLenLeft);
+	iconv_close(cd);
+
+	if (ret == static_cast<size_t>(-1)) {
+		Log(ERROR, "PythonConversions", "iconv failed to convert a Python string from {} to UTF-16 with error: {}", encoding, strerror(errno));
+		return u"";
+	}
+
+	auto zero = buffer.find(u'\0');
+	if (zero != decltype(buffer)::npos) {
+		buffer.resize(zero);
+	}
+
+	return buffer;
 }
 
 PyStringWrapper PyString_AsStringView(PyObject* obj)
 {
 	// TODO: this is the same as PyString_AsString
-	// it exists to diferentiate uses so that we can weed out PyString_AsString
+	// it exists to differentiate uses so that we can weed out PyString_AsString
 	// and replace them with PyUnicode_Decode or other alternatives
-	return PyStringWrapper(obj, core->SystemEncoding);
+	return PyStringWrapper(obj, core->config.SystemEncoding.c_str());
 }
 
 }
