@@ -20,8 +20,6 @@
 
 #include "IDSImporter.h"
 
-#include "IDSImporterDefs.h"
-
 #include "globals.h"
 
 #include <cstring>
@@ -30,12 +28,8 @@ using namespace GemRB;
 
 const std::string blank;
 
-bool IDSImporter::Open(DataStream* str)
+bool IDSImporter::Open(std::unique_ptr<DataStream> str)
 {
-	if (str == NULL) {
-		return false;
-	}
-
 	str->CheckEncrypted();
 	std::string line;
 	str->ReadLine(line, 10);
@@ -46,26 +40,25 @@ bool IDSImporter::Open(DataStream* str)
 		if (line.length() == 0) {
 			continue;
 		}
-		
+
 		auto parts = Explode<std::string, std::string>(line, ' ', 1);
 		if (parts.size() < 2) {
 			continue; // bad data?
 		}
-		
+
 		int val = strtosigned<int>(parts[0].c_str(), nullptr, 0);
 		StringToLower(parts[1]);
 		pairs.emplace_back(val, std::move(parts[1]));
 	}
 
-	delete str;
 	return true;
 }
 
 int IDSImporter::GetValue(StringView txt) const
 {
 	for (const auto& pair : pairs) {
-		if (stricmp(pair.str.c_str(), txt.c_str()) == 0) {
-			return pair.val;
+		if (stricmp(pair.second.c_str(), txt.c_str()) == 0) {
+			return pair.first;
 		}
 	}
 	return -1;
@@ -74,8 +67,8 @@ int IDSImporter::GetValue(StringView txt) const
 const std::string& IDSImporter::GetValue(int val) const
 {
 	for (const auto& pair : pairs) {
-		if (pair.val == val) {
-			return pair.str;
+		if (pair.first == val) {
+			return pair.second;
 		}
 	}
 	return blank;
@@ -86,22 +79,20 @@ const std::string& IDSImporter::GetStringIndex(size_t Index) const
 	if (Index >= pairs.size()) {
 		return blank;
 	}
-	return pairs[Index].str;
+	return pairs[Index].second;
 }
 
 int IDSImporter::GetValueIndex(size_t Index) const
 {
-	if (Index >= pairs.size()) {
-		return 0;
-	}
-	return pairs[Index].val;
+	assert(Index < pairs.size());
+	return pairs[Index].first;
 }
 
 int IDSImporter::FindString(StringView str) const
 {
 	int i = static_cast<int>(pairs.size());
-	while(i--) {
-		if (strnicmp(pairs[i].str.c_str(), str.c_str(), str.length()) == 0) {
+	while (i--) {
+		if (strnicmp(pairs[i].second.c_str(), str.c_str(), str.length()) == 0) {
 			return i;
 		}
 	}
@@ -111,8 +102,8 @@ int IDSImporter::FindString(StringView str) const
 int IDSImporter::FindValue(int val) const
 {
 	int i = static_cast<int>(pairs.size());
-	while(i--) {
-		if(pairs[i].val==val) {
+	while (i--) {
+		if (pairs[i].first == val) {
 			return i;
 		}
 	}
@@ -127,10 +118,10 @@ int IDSImporter::GetHighestValue() const
 	}
 	//the highest value is likely at the last line
 	i--;
-	int max = pairs[i].val;
+	int max = pairs[i].first;
 	while (i--) {
-		if (pairs[i].val > max) {
-			max = pairs[i].val;
+		if (pairs[i].first > max) {
+			max = pairs[i].first;
 		}
 	}
 	return max;
