@@ -23,45 +23,42 @@
 #include "globals.h"
 
 #include "Interface.h"
-#include "Logging/Logging.h"
 #include "ResourceDesc.h"
+
+#include "Logging/Logging.h"
 #include "Streams/FileStream.h"
 
 using namespace GemRB;
 
-static char* AddCBF(const char *file)
+static path_t AddCBF(path_t file)
 {
-	assert(strnlen(file, _MAX_PATH/2) < _MAX_PATH/2);
-	// This is safe in single-threaded, since the
-	// return value is passed straight to PathJoin.
-	static char cbf[_MAX_PATH];
-	strcpy(cbf,file);
-	char *dot = strrchr(cbf, '.');
-	if (dot)
-		strcpy(dot, ".cbf");
-	else
-		strcat(cbf, ".cbf");
-	return cbf;
+	size_t pos = file.find_last_of('.');
+	if (pos != path_t::npos) {
+		file.replace(pos, 4, ".cbf");
+	} else {
+		file += ".cbf";
+	}
+	return file;
 }
 
-static bool PathExists(BIFEntry *entry, const char *path)
+static bool PathExists(BIFEntry* entry, const path_t& path)
 {
-	PathJoin(entry->path, path, entry->name.c_str(), nullptr);
-	if (file_exists(entry->path)) {
+	entry->path = PathJoin(path, entry->name);
+	if (FileExists(entry->path)) {
 		return true;
 	}
-	PathJoin(entry->path, path, AddCBF(entry->name.c_str()), nullptr);
-	if (file_exists(entry->path)) {
+	entry->path = PathJoin(path, AddCBF(entry->name));
+	if (FileExists(entry->path)) {
 		return true;
 	}
 
 	return false;
 }
 
-static bool PathExists(BIFEntry *entry, const std::vector<std::string> &pathlist)
+static bool PathExists(BIFEntry* entry, const std::vector<std::string>& pathlist)
 {
 	for (const auto& path : pathlist) {
-		if (PathExists(entry, path.c_str())) {
+		if (PathExists(entry, path)) {
 			return true;
 		}
 	}
@@ -69,7 +66,7 @@ static bool PathExists(BIFEntry *entry, const std::vector<std::string> &pathlist
 	return false;
 }
 
-static void FindBIF(BIFEntry *entry)
+static void FindBIF(BIFEntry* entry)
 {
 	entry->cd = 0;
 	entry->found = PathExists(entry, core->config.GamePath);
@@ -77,8 +74,7 @@ static void FindBIF(BIFEntry *entry)
 		return;
 	}
 	// also check the data/Data path for gog
-	char path[_MAX_PATH];
-	PathJoin(path, core->config.GamePath, core->config.GameDataPath, nullptr);
+	path_t path = PathJoin(core->config.GamePath, core->config.GameDataPath);
 	entry->found = PathExists(entry, path);
 	if (entry->found) {
 		return;
@@ -95,10 +91,10 @@ static void FindBIF(BIFEntry *entry)
 	Log(ERROR, "KEYImporter", "Cannot find {}...", entry->name);
 }
 
-bool KEYImporter::Open(const char *resfile, const char *desc)
+bool KEYImporter::Open(const path_t& resfile, std::string desc)
 {
-	description = desc;
-	if (!core->IsAvailable( IE_BIF_CLASS_ID )) {
+	description = std::move(desc);
+	if (!core->IsAvailable(IE_BIF_CLASS_ID)) {
 		Log(ERROR, "KEYImporter", "An Archive Plug-in is not Available");
 		return false;
 	}
@@ -109,7 +105,7 @@ bool KEYImporter::Open(const char *resfile, const char *desc)
 	if (!f) {
 		// Check for backslashes (false escape characters)
 		// this check probably belongs elsewhere (e.g. ResolveFilePath)
-		if (strstr( resfile, "\\ " )) {
+		if (resfile.find("\\ ") != path_t::npos) {
 			Log(MESSAGE, "KEYImporter", "Escaped space(s) detected in path!. Do not escape spaces in your GamePath!");
 		}
 		Log(ERROR, "KEYImporter", "Cannot open Chitin.key");
@@ -119,8 +115,8 @@ bool KEYImporter::Open(const char *resfile, const char *desc)
 	}
 	Log(MESSAGE, "KEYImporter", "Checking file type...");
 	char Signature[8];
-	f->Read( Signature, 8 );
-	if (strncmp( Signature, "KEY V1  ", 8 ) != 0) {
+	f->Read(Signature, 8);
+	if (strncmp(Signature, "KEY V1  ", 8) != 0) {
 		Log(ERROR, "KEYImporter", "File has an Invalid Signature.");
 		delete f;
 		return false;
@@ -132,32 +128,39 @@ bool KEYImporter::Open(const char *resfile, const char *desc)
 	f->ReadDword(BifOffset);
 	f->ReadDword(ResOffset);
 	Log(MESSAGE, "KEYImporter", "BIF Files Count: {} (Starting at {} Bytes)",
-			BifCount, BifOffset );
+	    BifCount, BifOffset);
 	Log(MESSAGE, "KEYImporter", "RES Count: {} (Starting at {} Bytes)",
-		ResCount, ResOffset);
-	f->Seek( BifOffset, GEM_STREAM_START );
+	    ResCount, ResOffset);
+	f->Seek(BifOffset, GEM_STREAM_START);
 
 	ieDword BifLen, ASCIIZOffset;
 	ieWord ASCIIZLen;
 	for (unsigned int i = 0; i < BifCount; i++) {
 		BIFEntry be;
-		f->Seek( BifOffset + ( 12 * i ), GEM_STREAM_START );
+		f->Seek(BifOffset + (12 * i), GEM_STREAM_START);
 		f->ReadDword(BifLen);
 		f->ReadDword(ASCIIZOffset);
 		f->ReadWord(ASCIIZLen);
 		f->ReadWord(be.BIFLocator);
 		be.name.resize(ASCIIZLen);
-		f->Seek( ASCIIZOffset, GEM_STREAM_START );
+		f->Seek(ASCIIZOffset, GEM_STREAM_START);
 		f->Read(&be.name[0], ASCIIZLen);
+
+		// IWD ToTL: \\data\\zcHMar.bif
+		if (be.name[0] == '\\') {
+			be.name.erase(0, 1);
+			ASCIIZLen -= 1;
+		}
+
 		for (int p = 0; p < ASCIIZLen; p++) {
 			//some MAC versions use : as delimiter
 			if (be.name[p] == '\\' || be.name[p] == ':')
 				be.name[p] = PathDelimiter;
 		}
 		FindBIF(&be);
-		biffiles.push_back( be );
+		biffiles.push_back(be);
 	}
-	f->Seek( ResOffset, GEM_STREAM_START );
+	f->Seek(ResOffset, GEM_STREAM_START);
 
 	MapKey key;
 	ieDword ResLocator;
@@ -181,10 +184,10 @@ bool KEYImporter::Open(const char *resfile, const char *desc)
 
 bool KEYImporter::HasResource(StringView resname, SClass_ID type)
 {
-	return resources.find({ResRef(resname), type}) != resources.cend();
+	return resources.find({ ResRef(resname), type }) != resources.cend();
 }
 
-bool KEYImporter::HasResource(StringView resname, const ResourceDesc &type)
+bool KEYImporter::HasResource(StringView resname, const ResourceDesc& type)
 {
 	return HasResource(resname, type.GetKeyType());
 }
@@ -194,12 +197,12 @@ DataStream* KEYImporter::GetStream(const ResRef& resname, ieWord type)
 	if (type == 0)
 		return NULL;
 
-	const auto lookup = resources.find({resname, type});
+	const auto lookup = resources.find({ resname, type });
 	if (lookup == resources.cend())
 		return 0;
 
 	auto ResLocator = lookup->second;
-	unsigned int bifnum = ( ResLocator & 0xFFF00000 ) >> 20;
+	unsigned int bifnum = (ResLocator & 0xFFF00000) >> 20;
 
 	// supports BIFF-less, KEY'd games (demo)
 	if (bifnum >= biffiles.size()) {
@@ -208,22 +211,20 @@ DataStream* KEYImporter::GetStream(const ResRef& resname, ieWord type)
 
 	if (!biffiles[bifnum].found) {
 		Log(ERROR, "KEYImporter", "Cannot find {}... Resource unavailable.",
-				biffiles[bifnum].name.c_str());
+		    biffiles[bifnum].name);
 		return NULL;
 	}
 
 	PluginHolder<IndexedArchive> ai = MakePluginHolder<IndexedArchive>(IE_BIF_CLASS_ID);
-	if (ai->OpenArchive( biffiles[bifnum].path ) == GEM_ERROR) {
+	if (ai->OpenArchive(biffiles[bifnum].path) == GEM_ERROR) {
 		Log(ERROR, "KEYImporter", "Cannot open archive {}", biffiles[bifnum].path);
 		return NULL;
 	}
 
-	DataStream* ret = ai->GetStream( ResLocator, type );
+	DataStream* ret = ai->GetStream(ResLocator, type);
 	if (ret) {
-		auto it = StringToLower(resname.begin(), resname.end(), ret->filename);
-		*it = '\0';
-		strcat( ret->filename, "." );
-		strcat( ret->filename, core->TypeExt( type ) );
+		ret->filename.Format("{}.{}", resname, TypeExt(type));
+		StringToLower(ret->filename);
 		return ret;
 	}
 
@@ -233,10 +234,10 @@ DataStream* KEYImporter::GetStream(const ResRef& resname, ieWord type)
 DataStream* KEYImporter::GetResource(StringView resname, SClass_ID type)
 {
 	//the word masking is a hack for synonyms, currently used for bcs==bs
-	return GetStream(ResRef(resname), type&0xFFFF);
+	return GetStream(ResRef(resname), type & 0xFFFF);
 }
 
-DataStream* KEYImporter::GetResource(StringView resname, const ResourceDesc &type)
+DataStream* KEYImporter::GetResource(StringView resname, const ResourceDesc& type)
 {
 	return GetStream(ResRef(resname), type.GetKeyType());
 }
