@@ -21,11 +21,12 @@
 #ifndef KEYIMP_H
 #define KEYIMP_H
 
+#include "PluginMgr.h"
+#include "Resource.h"
 #include "ResourceSource.h"
 
 #include "Plugins/IndexedArchive.h"
-#include "PluginMgr.h"
-#include "Resource.h"
+#include "System/VFS.h"
 
 #include <unordered_map>
 #include <utility>
@@ -37,33 +38,37 @@ class DataStream;
 class ResourceDesc;
 
 struct BIFEntry {
-	std::string name;
+	path_t name;
 	ieWord BIFLocator;
-	char path[_MAX_PATH];
+	path_t path;
 	int cd;
 	bool found;
 };
 
 struct MapKey {
 	ResRef ref;
-	uint64_t type;
+	uint64_t type = 0;
 
-	MapKey() : type(0) {}
-	MapKey(const ResRef& ref, uint64_t type) : ref{ref}, type{type} {}
-	MapKey(ResRef && ref, uint64_t type) : ref{std::move(ref)}, type{type} {}
+	MapKey() = default;
+	MapKey(const ResRef& ref, uint64_t type)
+		: ref { ref }, type { type } {}
+	MapKey(ResRef&& ref, uint64_t type)
+		: ref { std::move(ref) }, type { type } {}
 
-	bool operator==(const MapKey& other) const {
+	bool operator==(const MapKey& other) const
+	{
 		return ref == other.ref && type == other.type;
 	}
 };
 
 struct MapKeyHash {
-	size_t operator()(const MapKey& key) const {
-		size_t h{key.type};
-		const char *c = key.ref.c_str();
+	size_t operator()(const MapKey& key) const
+	{
+		uint64_t h { key.type };
 
-		for (unsigned int i = 0; *c && i < 9; ++i)
-			h = (h << 5) + h + tolower(*c++);
+		for (const char c : key.ref) {
+			h = (h << 5) + h + tolower(c);
+		}
 
 		return h;
 	}
@@ -78,19 +83,20 @@ struct KEYCache {
 
 class KEYImporter : public ResourceSource {
 private:
-	std::vector< BIFEntry> biffiles;
+	std::vector<BIFEntry> biffiles;
 	std::unordered_map<MapKey, ieDword, MapKeyHash> resources;
 
-	/** Gets the stream assoicated to a RESKey */
-	DataStream *GetStream(const ResRef&, ieWord type);
+	/** Gets the stream associated to a RESKey */
+	DataStream* GetStream(const ResRef&, ieWord type);
+
 public:
-	bool Open(const char *file, const char *desc) override;
+	bool Open(const path_t& file, std::string desc) override;
 	/* predicts the availability of a resource */
 	bool HasResource(StringView resname, SClass_ID type) override;
-	bool HasResource(StringView resname, const ResourceDesc &type) override;
+	bool HasResource(StringView resname, const ResourceDesc& type) override;
 	/* returns resource */
 	DataStream* GetResource(StringView resname, SClass_ID type) override;
-	DataStream* GetResource(StringView resname, const ResourceDesc &type) override;
+	DataStream* GetResource(StringView resname, const ResourceDesc& type) override;
 };
 
 }
