@@ -20,20 +20,22 @@
 
 #include "MOSImporter.h"
 
-#include "Interface.h"
+#include "GameData.h"
+
+#include "Video/Video.h"
 
 using namespace GemRB;
 
 bool MOSImporter::Import(DataStream* str)
 {
 	char Signature[8];
-	str->Read( Signature, 8 );
-	if (strncmp( Signature, "MOSCV1  ", 8 ) == 0) {
-		str->Seek( 4, GEM_CURRENT_POS );
+	str->Read(Signature, 8);
+	if (strncmp(Signature, "MOSCV1  ", 8) == 0) {
+		str->Seek(4, GEM_CURRENT_POS);
 		str = DecompressStream(str);
 		if (!str)
 			return false;
-		str->Read( Signature, 8 );
+		str->Read(Signature, 8);
 	}
 
 	if (strncmp(Signature, "MOS V2  ", 8) == 0) {
@@ -58,17 +60,17 @@ bool MOSImporter::Import(DataStream* str)
 	return true;
 }
 
-void MOSImporter::Blit(const MOSV2DataBlock& dataBlock, uint8_t *frameData) {
+void MOSImporter::Blit(const MOSV2DataBlock& dataBlock, uint8_t* frameData)
+{
 	// Pages appear to be used multiple times
 	if (!lastPVRZ || dataBlock.pvrzPage != lastPVRZPage) {
 		auto resRef = fmt::format("mos{:04d}", dataBlock.pvrzPage);
-		StringView resRefView(resRef.c_str(), 7);
 
-		lastPVRZ = gamedata->GetResourceHolder<ImageMgr>(resRefView, true);
+		lastPVRZ = gamedata->GetResourceHolder<ImageMgr>(resRef, true);
 		lastPVRZPage = dataBlock.pvrzPage;
 	}
 
-	auto sprite = lastPVRZ->GetSprite2D(Region{dataBlock.source.x, dataBlock.source.y, dataBlock.size.w, dataBlock.size.h});
+	auto sprite = lastPVRZ->GetSprite2D(Region { dataBlock.source.x, dataBlock.source.y, dataBlock.size.w, dataBlock.size.h });
 	if (!sprite) {
 		return;
 	}
@@ -82,14 +84,14 @@ void MOSImporter::Blit(const MOSV2DataBlock& dataBlock, uint8_t *frameData) {
 		std::copy(
 			spritePixels + offset,
 			spritePixels + offset + sprite->Frame.w * 4,
-			frameData + destOffset
-		);
+			frameData + destOffset);
 	}
 
 	sprite->UnlockSprite();
 }
 
-Holder<Sprite2D> MOSImporter::GetSprite2D() {
+Holder<Sprite2D> MOSImporter::GetSprite2D()
+{
 	if (version == MOSVersion::V2) {
 		return GetSprite2Dv2();
 	} else {
@@ -97,9 +99,10 @@ Holder<Sprite2D> MOSImporter::GetSprite2D() {
 	}
 }
 
-Holder<Sprite2D> MOSImporter::GetSprite2Dv2() {
+Holder<Sprite2D> MOSImporter::GetSprite2Dv2()
+{
 	size_t imageSize = size.Area() * 4;
-	uint8_t *imageData = static_cast<uint8_t*>(malloc(imageSize));
+	uint8_t* imageData = static_cast<uint8_t*>(malloc(imageSize));
 	std::fill(imageData, imageData + imageSize, 0);
 
 	str->Seek(layout.v2.BlockOffset, GEM_STREAM_START);
@@ -118,42 +121,44 @@ Holder<Sprite2D> MOSImporter::GetSprite2Dv2() {
 	}
 
 	PixelFormat fmt = PixelFormat::ARGB32Bit();
-	Region region{0, 0, size.w, size.h};
+	Region region { 0, 0, size.w, size.h };
 
-	return {core->GetVideoDriver()->CreateSprite(region, imageData, fmt)};
+	return { VideoDriver->CreateSprite(region, imageData, fmt) };
 }
 
-Holder<Sprite2D> MOSImporter::GetSprite2Dv1() {
+Holder<Sprite2D> MOSImporter::GetSprite2Dv1()
+{
 	Color Col[256];
-	unsigned char * pixels = ( unsigned char * ) malloc(size.Area() * 4);
-	unsigned char * blockpixels = ( unsigned char * )
-	malloc( layout.v1.BlockSize * layout.v1.BlockSize );
+	unsigned char* pixels = (unsigned char*) malloc(size.Area() * 4);
+	unsigned char* blockpixels = (unsigned char*)
+		malloc(layout.v1.BlockSize * layout.v1.BlockSize);
 	ieDword blockoffset;
 	const ieDword& PalOffset = layout.v1.PalOffset;
 
 	for (int y = 0; y < Rows; y++) {
-		int bh = ( y == Rows - 1 ) ?
-			( ( size.h % 64 ) == 0 ? 64 : size.h % 64 ) :
+		int bh = (y == Rows - 1) ?
+			((size.h % 64) == 0 ? 64 : size.h % 64) :
 			64;
 		for (int x = 0; x < Cols; x++) {
-			int bw = ( x == Cols - 1 ) ?
-				( ( size.w % 64 ) == 0 ? 64 : size.w % 64 ) :
+			int bw = (x == Cols - 1) ?
+				((size.w % 64) == 0 ? 64 : size.w % 64) :
 				64;
-			str->Seek( PalOffset + ( y * Cols * 1024 ) +
-				( x * 1024 ), GEM_STREAM_START );
-			str->Read( &Col[0], 1024 );
-			str->Seek( PalOffset + ( Rows * Cols * 1024 ) +
-				( y * Cols * 4 ) + ( x * 4 ),
-				GEM_STREAM_START );
+			str->Seek(PalOffset + (y * Cols * 1024) +
+					  (x * 1024),
+				  GEM_STREAM_START);
+			str->Read(&Col[0], 1024);
+			str->Seek(PalOffset + (Rows * Cols * 1024) +
+					  (y * Cols * 4) + (x * 4),
+				  GEM_STREAM_START);
 			str->ReadDword(blockoffset);
-			str->Seek( PalOffset + ( Rows * Cols * 1024 ) +
-				( Rows * Cols * 4 ) + blockoffset,
-				GEM_STREAM_START );
-			str->Read( blockpixels, bw * bh );
+			str->Seek(PalOffset + (Rows * Cols * 1024) +
+					  (Rows * Cols * 4) + blockoffset,
+				  GEM_STREAM_START);
+			str->Read(blockpixels, bw * bh);
 			const unsigned char* bp = blockpixels;
-			unsigned char * startpixel = pixels +
-				( ( size.w * 4 * y ) * 64 ) +
-				( 4 * x * 64 );
+			unsigned char* startpixel = pixels +
+				((size.w * 4 * y) * 64) +
+				(4 * x * 64);
 			for (int h = 0; h < bh; h++) {
 				for (int w = 0; w < bw; w++) {
 					*startpixel = Col[*bp].r;
@@ -166,24 +171,24 @@ Holder<Sprite2D> MOSImporter::GetSprite2Dv1() {
 					startpixel++;
 					bp++;
 				}
-				startpixel = startpixel + ( size.w * 4 ) - ( 4 * bw );
+				startpixel = startpixel + (size.w * 4) - (4 * bw);
 			}
 		}
 	}
-	free( blockpixels );
-	
+	free(blockpixels);
+
 	constexpr uint32_t red_mask = 0x00ff0000;
 	constexpr uint32_t green_mask = 0x0000ff00;
 	constexpr uint32_t blue_mask = 0x000000ff;
 	PixelFormat fmt(4, red_mask, green_mask, blue_mask, 0);
 	fmt.HasColorKey = true;
 	fmt.ColorKey = green_mask;
-	
-	return core->GetVideoDriver()->CreateSprite(Region(0,0, size.w, size.h), pixels,fmt);
+
+	return VideoDriver->CreateSprite(Region(0, 0, size.w, size.h), pixels, fmt);
 }
 
 #include "plugindef.h"
 
 GEMRB_PLUGIN(0x167B73E, "MOS File Importer")
-PLUGIN_IE_RESOURCE(MOSImporter, "mos", (ieWord)IE_MOS_CLASS_ID)
+PLUGIN_IE_RESOURCE(MOSImporter, "mos", (ieWord) IE_MOS_CLASS_ID)
 END_PLUGIN()
