@@ -22,10 +22,11 @@
 
 #include "Audio.h"
 #include "GameData.h" // For ResourceHolder
-#include "Logging/Logging.h"
 #include "Interface.h"
 #include "SoundMgr.h"
 
+#include "Logging/Logging.h"
+
 using namespace GemRB;
 
 static char musicsubfolder[6] = "music";
@@ -33,8 +34,7 @@ static char musicsubfolder[6] = "music";
 MUSImporter::MUSImporter()
 {
 	str = new FileStream();
-	char path[_MAX_PATH];
-	PathJoin(path, core->config.GamePath, musicsubfolder, nullptr);
+	path_t path = PathJoin(core->config.GamePath, musicsubfolder);
 	manager.AddSource(path, "Music", PLUGIN_RESOURCE_DIRECTORY);
 }
 
@@ -50,25 +50,34 @@ bool MUSImporter::Init()
 	return true;
 }
 
-#define SKIP_BLANKS while (i < len) {\
-	if (isblank(line[i])) {\
-		i++;\
-	} else {\
-		break;\
-	}\
-}
-
-#define FILL_VAR(VAR) while (i < len) {\
-	if (!isblank(line[i])) {\
-		pls.VAR[p++] = line[i++];\
-	} else {\
-		break;\
-	}\
-}
+#define SKIP_BLANKS \
+	while (i < len) { \
+		if (isblank(line[i])) { \
+			i++; \
+		} else { \
+			break; \
+		} \
+	}
 
 /** Loads a PlayList for playing */
 bool MUSImporter::OpenPlaylist(const ieVariable& name)
 {
+	size_t i = 0;
+	size_t len = 0;
+	std::string line;
+
+	auto fillVar = [&i, len, &line](MUSString& var) {
+		int p = 0;
+		while (i < len) {
+			if (!isblank(line[i])) {
+				var[p++] = line[i++];
+			} else {
+				break;
+			}
+		}
+		var[var.Size - 1] = 0;
+	};
+
 	if (Playing || IsCurrentPlayList(name)) {
 		return true;
 	}
@@ -79,14 +88,13 @@ bool MUSImporter::OpenPlaylist(const ieVariable& name)
 	if (IsStar(name)) {
 		return false;
 	}
-	char path[_MAX_PATH];
-	PathJoin(path, core->config.GamePath, musicsubfolder, name.c_str(), nullptr);
+	path_t path = PathJoin(core->config.GamePath, musicsubfolder, name);
 	Log(MESSAGE, "MUSImporter", "Loading {}...", path);
 	if (!str->Open(path)) {
 		Log(ERROR, "MUSImporter", "Didn't find playlist '{}'.", path);
 		return false;
 	}
-	std::string line;
+
 	str->ReadLine(line);
 	PLName = line;
 	size_t c = line.length();
@@ -102,8 +110,8 @@ bool MUSImporter::OpenPlaylist(const ieVariable& name)
 	int count = atoi(line.c_str());
 	while (count != 0) {
 		str->ReadLine(line);
-		size_t len = line.length();
-		size_t i = 0;
+		len = line.length();
+		i = 0;
 		int p = 0;
 		PLString pls;
 		while (i < len) {
@@ -114,24 +122,19 @@ bool MUSImporter::OpenPlaylist(const ieVariable& name)
 				break;
 			}
 		}
-		pls.PLFile[p] = 0;
-		p = 0;
+
 		if (i < len && line[i] != '@') {
-			FILL_VAR(PLTag)
-			pls.PLTag[std::min(p, 9)] = 0;
-			p = 0;
+			fillVar(pls.PLTag);
 			SKIP_BLANKS
-			if (line[i] == '@')
-				strcpy( pls.PLLoop, pls.PLTag );
-			else {
-				FILL_VAR(PLLoop)
-				pls.PLLoop[p] = 0;
+			if (line[i] == '@') {
+				pls.PLLoop = pls.PLTag;
+			} else {
+				fillVar(pls.PLLoop);
 			}
 			SKIP_BLANKS
-			p = 0;
 		} else {
-			pls.PLTag[0] = 0;
-			pls.PLLoop[0] = 0;
+			pls.PLTag.clear();
+			pls.PLLoop.clear();
 		}
 		while (i < len) {
 			if (!isblank(line[i]))
@@ -141,9 +144,8 @@ bool MUSImporter::OpenPlaylist(const ieVariable& name)
 				break;
 			}
 		}
-		FILL_VAR(PLEnd)
-		pls.PLEnd[p] = 0;
-		playlist.push_back( pls );
+		fillVar(pls.PLEnd);
+		playlist.push_back(pls);
 		count--;
 	}
 	return true;
@@ -155,9 +157,9 @@ void MUSImporter::Start()
 	if (playlist.empty()) return;
 
 	PLpos = 0;
-	if (playlist[PLpos].PLLoop[0] != 0) {
+	if (playlist[PLpos].PLLoop) {
 		for (unsigned int i = 0; i < playlist.size(); i++) {
-			if (stricmp(playlist[i].PLFile, playlist[PLpos].PLLoop) == 0) {
+			if (playlist[i].PLFile == playlist[PLpos].PLLoop) {
 				PLnext = i;
 				break;
 			}
@@ -180,10 +182,10 @@ void MUSImporter::End()
 	if (!Playing) return;
 	if (playlist.empty()) return;
 
-	if (playlist[PLpos].PLEnd[0] != 0) {
-		if (stricmp(playlist[PLpos].PLEnd, "end") != 0) {
-			PlayMusic(playlist[PLpos].PLEnd);
-		}
+	if (playlist[PLpos].PLEnd && playlist[PLpos].PLEnd != "end") {
+		PlayMusic(playlist[PLpos].PLEnd);
+	} else {
+		HardEnd();
 	}
 	PLnext = -1;
 }
@@ -216,7 +218,7 @@ int MUSImporter::SwitchPlayList(const ieVariable& name, bool Hard)
 		}
 	}
 
-	if (OpenPlaylist( name )) {
+	if (OpenPlaylist(name)) {
 		Start();
 		return 0;
 	}
@@ -230,21 +232,21 @@ void MUSImporter::PlayNext()
 		return;
 	}
 	if (PLnext != -1) {
-		PlayMusic( PLnext );
+		PlayMusic(PLnext);
 		PLpos = PLnext;
-		if (playlist[PLpos].PLLoop[0] != 0) {
+		if (playlist[PLpos].PLLoop) {
 			for (unsigned int i = 0; i < playlist.size(); i++) {
-				if (stricmp( playlist[i].PLFile, playlist[PLpos].PLLoop ) == 0) {
+				if (playlist[i].PLFile == playlist[PLpos].PLLoop) {
 					PLnext = i;
 					break;
 				}
 			}
 		} else {
-			if (stricmp( playlist[PLnext].PLEnd, "end" ) == 0)
+			if (playlist[PLnext].PLEnd == "end")
 				PLnext = -1;
 			else
 				PLnext = PLpos + 1;
-			if ((unsigned int) PLnext >= playlist.size() ) {
+			if ((unsigned int) PLnext >= playlist.size()) {
 				PLnext = 0;
 			}
 		}
@@ -256,35 +258,33 @@ void MUSImporter::PlayNext()
 			if (OpenPlaylist(PLNameNew)) {
 				Start();
 			}
-			PLNameNew[0]='\0';
+			PLNameNew[0] = '\0';
 		}
 	}
 }
 
 void MUSImporter::PlayMusic(int pos)
 {
-	PlayMusic( playlist[pos].PLFile );
+	PlayMusic(playlist[pos].PLFile);
 }
 
 void MUSImporter::PlayMusic(const ieVariable& name)
 {
-	char FName[_MAX_PATH];
+	path_t FName;
 	if (name.BeginsWith("mx9000")) { //iwd2
-		PathJoin(FName, "mx9000", name, nullptr);
+		FName = PathJoin("mx9000", name);
 	} else if (name.BeginsWith("mx0000")) { //iwd
-		PathJoin(FName, "mx0000", name, nullptr);
+		FName = PathJoin("mx0000", name);
 	} else if (!name.BeginsWith("SPC")) { //bg2
-		char File[_MAX_PATH];
-		auto end = fmt::format_to(File, "{}{}", PLName, name);
-		*end = '\0';
-		PathJoin(FName, PLName.c_str(), File, nullptr);
+		path_t file = fmt::format("{}{}", PLName, name);
+		FName = PathJoin(PLName, file);
 	} else {
-		strlcpy(FName, name.c_str(), _MAX_PATH);
+		FName = path_t(name);
 	}
 
 	ResourceHolder<SoundMgr> sound = manager.GetResourceHolder<SoundMgr>(FName, true);
 	if (sound) {
-		int soundID = core->GetAudioDrv()->CreateStream( sound );
+		int soundID = core->GetAudioDrv()->CreateStream(std::move(sound));
 		if (soundID == -1) {
 			core->GetAudioDrv()->Stop();
 		}
@@ -294,7 +294,8 @@ void MUSImporter::PlayMusic(const ieVariable& name)
 	Log(MESSAGE, "MUSImporter", "Playing {}...", FName);
 }
 
-bool MUSImporter::IsCurrentPlayList(const ieVariable& name) {
+bool MUSImporter::IsCurrentPlayList(const ieVariable& name)
+{
 	return name == PLName;
 }
 
