@@ -22,8 +22,8 @@
 #define MUSIMPORTER_H
 
 #include "MusicMgr.h"
-
 #include "ResourceManager.h"
+
 #include "Streams/FileStream.h"
 
 #include <cstdio>
@@ -34,11 +34,12 @@ namespace GemRB {
   *@author GemRB Development Team
   */
 
+using MUSString = FixedSizeString<10>;
 struct PLString {
-	char PLFile[10]{};
-	char PLLoop[10]{};
-	char PLTag[10]{};
-	char PLEnd[10]{};
+	MUSString PLFile;
+	MUSString PLLoop;
+	MUSString PLTag;
+	MUSString PLEnd;
 	unsigned int soundID = 0;
 };
 
@@ -51,12 +52,14 @@ private:
 	int PLpos = 0;
 	int PLnext = -1;
 	FileStream* str;
-	std::vector< PLString> playlist;
+	std::vector<PLString> playlist;
 	unsigned int lastSound = 0xffffffff;
 	ResourceManager manager;
+
 private:
 	void PlayMusic(int pos);
 	void PlayMusic(const ieVariable& name);
+
 public:
 	MUSImporter();
 	MUSImporter(const MUSImporter&) = delete;
