@@ -21,12 +21,11 @@
 #ifndef MVEPLAY_H
 #define MVEPLAY_H
 
-#include "MoviePlayer.h"
-
-#include "mve_player.h"
-
 #include "globals.h"
 
+#include "MoviePlayer.h"
+#include "mve_player.h"
+
 namespace GemRB {
 
 class Video;
@@ -35,10 +34,10 @@ class MVEPlay : public MoviePlayer {
 	friend class MVEPlayer;
 	MVEPlayer decoder;
 	VideoBuffer* vidBuf;
-	PaletteHolder g_palette;
+	Holder<Palette> g_palette;
 
 private:
-	Video *video;
+	PluginHolder<Video> video;
 	bool validVideo;
 	int doPlay();
 	unsigned int fileRead(void* buf, unsigned int count);
@@ -48,8 +47,8 @@ private:
 	int setAudioStream() const;
 	void freeAudioStream(int stream) const;
 	void queueBuffer(int stream, unsigned short bits,
-				int channels, short* memory,
-				int size, int samplerate) const;
+			 int channels, short* memory,
+			 int size, int samplerate) const;
 
 protected:
 	bool DecodeFrame(VideoBuffer&) override;
