@@ -22,13 +22,14 @@
  */
 
 #include "gstmvedemux.h"
+
 #include <cstring>
 
-#define PIXEL(s) GST_READ_UINT16_LE (s)
+#define PIXEL(s) GST_READ_UINT16_LE(s)
 
 #define CHECK_STREAM(l, n) \
 	do { \
-		if (G_UNLIKELY (*(l) < (n))) { \
+		if (G_UNLIKELY(*(l) < (n))) { \
 			GST_ERROR2("wanted to read %d bytes from stream, %d available", (n), *(l)); \
 			return -1; \
 		} \
@@ -37,22 +38,22 @@
 
 /* copy an 8x8 block from the stream to the frame buffer */
 static int
-ipvideo_copy_block (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned short *src, int offset)
+	ipvideo_copy_block(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned short* src, int offset)
 {
 	ptrdiff_t frame_offset = frame - s->back_buf1 + offset;
 
-	if (G_UNLIKELY (frame_offset < 0)) {
+	if (G_UNLIKELY(frame_offset < 0)) {
 		GST_ERROR("frame offset < 0 (%ld)", static_cast<long>(frame_offset));
 		return -1;
-	} else if (G_UNLIKELY ((guint32)frame_offset > s->max_block_offset)) {
+	} else if (G_UNLIKELY((guint32) frame_offset > s->max_block_offset)) {
 		GST_ERROR2("frame offset above limit (%ld > %u)",
-				static_cast<long>(frame_offset), s->max_block_offset);
+			   static_cast<long>(frame_offset), s->max_block_offset);
 		return -1;
 	}
 
 	for (int i = 0; i < 8; ++i) {
-		memcpy (frame, src, 16);
+		memcpy(frame, src, 16);
 		frame += s->width;
 		src += s->width;
 	}
@@ -61,15 +62,15 @@ ipvideo_copy_block (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0x2 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x2(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned char B;
 	int x, y;
 	int offset;
 
 	/* copy block from 2 frames ago using a motion vector */
-	CHECK_STREAM (len, 1);
+	CHECK_STREAM(len, 1);
 	B = *(*data)++;
 
 	if (B < 56) {
@@ -81,19 +82,19 @@ ipvideo_decode_0x2 (const GstMveDemuxStream * s, unsigned short *frame,
 	}
 	offset = y * s->width + x;
 
-	return ipvideo_copy_block (s, frame, frame + offset, offset);
+	return ipvideo_copy_block(s, frame, frame + offset, offset);
 }
 
 static int
-ipvideo_decode_0x3 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x3(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned char B;
 	int x, y;
 	int offset;
 
 	/* copy 8x8 block from current frame from an up/left block */
-	CHECK_STREAM (len, 1);
+	CHECK_STREAM(len, 1);
 	B = *(*data)++;
 
 	if (B < 56) {
@@ -105,49 +106,46 @@ ipvideo_decode_0x3 (const GstMveDemuxStream * s, unsigned short *frame,
 	}
 	offset = y * s->width + x;
 
-	return ipvideo_copy_block (s, frame, frame + offset, offset);
+	return ipvideo_copy_block(s, frame, frame + offset, offset);
 }
 
 static int
-ipvideo_decode_0x4 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x4(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	int x, y;
 	unsigned char B;
 	int offset;
 
 	/* copy a block from the previous frame */
-	CHECK_STREAM (len, 1);
+	CHECK_STREAM(len, 1);
 	B = *(*data)++;
 	x = -8 + (B & 0x0F);
 	y = -8 + (B >> 4);
 	offset = y * s->width + x;
 
-	return ipvideo_copy_block (s, frame, frame +
-			(s->back_buf2 - s->back_buf1) + offset, offset);
+	return ipvideo_copy_block(s, frame, frame + (s->back_buf2 - s->back_buf1) + offset, offset);
 }
 
 static int
-ipvideo_decode_0x5 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x5(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	signed char x, y;
 	int offset;
 
 	/* copy a block from the previous frame using an expanded range */
-	CHECK_STREAM (len, 2);
+	CHECK_STREAM(len, 2);
 	x = (signed char) *(*data)++;
 	y = (signed char) *(*data)++;
 	offset = y * s->width + x;
 
-	return ipvideo_copy_block (s, frame, frame +
-			(s->back_buf2 - s->back_buf1) +
-			offset, offset);
+	return ipvideo_copy_block(s, frame, frame + (s->back_buf2 - s->back_buf1) + offset, offset);
 }
 
 static int
-ipvideo_decode_0x7 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x7(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	int x, y;
 	unsigned short P0, P1;
@@ -155,16 +153,15 @@ ipvideo_decode_0x7 (const GstMveDemuxStream * s, unsigned short *frame,
 	int bitmask;
 
 	/* 2-color encoding */
-	CHECK_STREAM (len, 4 + 2);
-	P0 = PIXEL (*data);
+	CHECK_STREAM(len, 4 + 2);
+	P0 = PIXEL(*data);
 	(*data) += 2;
-	P1 = PIXEL (*data);
+	P1 = PIXEL(*data);
 	(*data) += 2;
 
 	if (!(P0 & 0x8000)) {
-
 		/* need 8 more bytes from the stream */
-		CHECK_STREAM (len, 8 - 2);
+		CHECK_STREAM(len, 8 - 2);
 
 		for (y = 0; y < 8; ++y) {
 			flags = *(*data)++;
@@ -207,8 +204,8 @@ ipvideo_decode_0x7 (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x8(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	int x, y;
 	unsigned short P[8];
@@ -220,35 +217,34 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 
 	/* 2-color encoding for each 4x4 quadrant, or 2-color encoding on
 	 * either top and bottom or left and right halves */
-	CHECK_STREAM (len, 6 + 10);
+	CHECK_STREAM(len, 6 + 10);
 
-	P[0] = PIXEL (*data);
+	P[0] = PIXEL(*data);
 	(*data) += 2;
-	P[1] = PIXEL (*data);
+	P[1] = PIXEL(*data);
 	(*data) += 2;
 	B[0] = *(*data)++;
 	B[1] = *(*data)++;
 
 	if (!(P[0] & 0x8000)) {
-
 		/* need 18 more bytes */
-		CHECK_STREAM (len, 18 - 10);
+		CHECK_STREAM(len, 18 - 10);
 
-		P[2] = PIXEL (*data);
+		P[2] = PIXEL(*data);
 		(*data) += 2;
-		P[3] = PIXEL (*data);
+		P[3] = PIXEL(*data);
 		(*data) += 2;
 		B[2] = *(*data)++;
 		B[3] = *(*data)++;
-		P[4] = PIXEL (*data);
+		P[4] = PIXEL(*data);
 		(*data) += 2;
-		P[5] = PIXEL (*data);
+		P[5] = PIXEL(*data);
 		(*data) += 2;
 		B[4] = *(*data)++;
 		B[5] = *(*data)++;
-		P[6] = PIXEL (*data);
+		P[6] = PIXEL(*data);
 		(*data) += 2;
-		P[7] = PIXEL (*data);
+		P[7] = PIXEL(*data);
 		(*data) += 2;
 		B[6] = *(*data)++;
 		B[7] = *(*data)++;
@@ -258,10 +254,9 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 			((B[1] & 0xF0) << 20) | ((B[5] & 0xF0) << 24) |
 			((B[1] & 0x0F) << 16) | ((B[5] & 0x0F) << 20);
 		bitmask = 0x00000001;
-		lower_half = 0;             /* still on top half */
+		lower_half = 0; /* still on top half */
 
 		for (y = 0; y < 8; ++y) {
-
 			/* time to reload flags? */
 			if (y == 4) {
 				flags = ((B[2] & 0xF0) << 4) | ((B[6] & 0xF0) << 8) |
@@ -296,9 +291,9 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 		/* need 10 more bytes */
 		B[2] = *(*data)++;
 		B[3] = *(*data)++;
-		P[2] = PIXEL (*data);
+		P[2] = PIXEL(*data);
 		(*data) += 2;
-		P[3] = PIXEL (*data);
+		P[3] = PIXEL(*data);
 		(*data) += 2;
 		B[4] = *(*data)++;
 		B[5] = *(*data)++;
@@ -309,14 +304,13 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 			/* vertical split; left & right halves are 2-color encoded */
 
 			flags =
-					((B[0] & 0xF0) << 4) | ((B[4] & 0xF0) << 8) |
-					((B[0] & 0x0F)) | ((B[4] & 0x0F) << 4) |
-					((B[1] & 0xF0) << 20) | ((B[5] & 0xF0) << 24) |
-					((B[1] & 0x0F) << 16) | ((B[5] & 0x0F) << 20);
+				((B[0] & 0xF0) << 4) | ((B[4] & 0xF0) << 8) |
+				((B[0] & 0x0F)) | ((B[4] & 0x0F) << 4) |
+				((B[1] & 0xF0) << 20) | ((B[5] & 0xF0) << 24) |
+				((B[1] & 0x0F) << 16) | ((B[5] & 0x0F) << 20);
 			bitmask = 0x00000001;
 
 			for (y = 0; y < 8; ++y) {
-
 				/* time to reload flags? */
 				if (y == 4) {
 					flags = ((B[2] & 0xF0) << 4) | ((B[6] & 0xF0) << 8) |
@@ -351,7 +345,6 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 			P1 = P[1];
 
 			for (y = 0; y < 8; ++y) {
-
 				flags = B[y];
 				if (y == 4) {
 					P0 = P[2] & ~0x8000;
@@ -359,7 +352,6 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 				}
 
 				for (bitmask = 0x01; bitmask <= 0x80; bitmask <<= 1) {
-
 					if (flags & bitmask)
 						*frame++ = P1;
 					else
@@ -374,8 +366,8 @@ ipvideo_decode_0x8 (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0x9 (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0x9(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	int x, y;
 	unsigned short P[4];
@@ -385,21 +377,20 @@ ipvideo_decode_0x9 (const GstMveDemuxStream * s, unsigned short *frame,
 	unsigned short pix;
 
 	/* 4-color encoding */
-	CHECK_STREAM (len, 8 + 4);
+	CHECK_STREAM(len, 8 + 4);
 
-	P[0] = PIXEL (*data);
+	P[0] = PIXEL(*data);
 	(*data) += 2;
-	P[1] = PIXEL (*data);
+	P[1] = PIXEL(*data);
 	(*data) += 2;
-	P[2] = PIXEL (*data);
+	P[2] = PIXEL(*data);
 	(*data) += 2;
-	P[3] = PIXEL (*data);
+	P[3] = PIXEL(*data);
 	(*data) += 2;
 
 	if (!(P[0] & 0x8000) && !(P[2] & 0x8000)) {
-
 		/* 1 of 4 colors for each pixel, need 16 more bytes */
-		CHECK_STREAM (len, 16 - 4);
+		CHECK_STREAM(len, 16 - 4);
 
 		for (y = 0; y < 8; ++y) {
 			/* get the next set of 8 2-bit flags */
@@ -439,7 +430,7 @@ ipvideo_decode_0x9 (const GstMveDemuxStream * s, unsigned short *frame,
 
 		/* 1 of 4 colors for each 2x1 block, need 8 more bytes */
 
-		CHECK_STREAM (len, 8 - 4);
+		CHECK_STREAM(len, 8 - 4);
 		for (y = 0; y < 8; ++y) {
 			/* time to reload flags? */
 			if ((y == 0) || (y == 4)) {
@@ -463,7 +454,7 @@ ipvideo_decode_0x9 (const GstMveDemuxStream * s, unsigned short *frame,
 		P[2] &= ~0x8000;
 
 		/* 1 of 4 colors for each 1x2 block, need 8 more bytes */
-		CHECK_STREAM (len, 8 - 4);
+		CHECK_STREAM(len, 8 - 4);
 
 		for (y = 0; y < 8; y += 2) {
 			/* time to reload flags? */
@@ -488,8 +479,8 @@ ipvideo_decode_0x9 (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0xa(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned int x, y;
 	unsigned short P[16];
@@ -502,21 +493,20 @@ ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
 
 	/* 4-color encoding for each 4x4 quadrant, or 4-color encoding on
 	 * either top and bottom or left and right halves */
-	CHECK_STREAM (len, 8 + 24);
+	CHECK_STREAM(len, 8 + 24);
 
-	P[0] = PIXEL (*data);
+	P[0] = PIXEL(*data);
 	(*data) += 2;
-	P[1] = PIXEL (*data);
+	P[1] = PIXEL(*data);
 	(*data) += 2;
-	P[2] = PIXEL (*data);
+	P[2] = PIXEL(*data);
 	(*data) += 2;
-	P[3] = PIXEL (*data);
+	P[3] = PIXEL(*data);
 	(*data) += 2;
 
 	if (!(P[0] & 0x8000)) {
-
 		/* 4-color encoding for each quadrant; need 40 more bytes */
-		CHECK_STREAM (len, 40 - 24);
+		CHECK_STREAM(len, 40 - 24);
 
 		B[0] = *(*data)++;
 		B[1] = *(*data)++;
@@ -524,7 +514,7 @@ ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
 		B[3] = *(*data)++;
 		for (y = 4; y < 16; y += 4) {
 			for (x = y; x < y + 4; ++x) {
-				P[x] = PIXEL (*data);
+				P[x] = PIXEL(*data);
 				(*data) += 2;
 			}
 			for (x = y; x < y + 4; ++x)
@@ -532,7 +522,6 @@ ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
 		}
 
 		for (y = 0; y < 8; ++y) {
-
 			lower_half = (y >= 4) ? 4 : 0;
 			flags = (B[y + 8] << 8) | B[y];
 
@@ -551,24 +540,22 @@ ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
 		/* 4-color encoding for either left and right or top and bottom
 		 * halves; need 24 more bytes */
 
-		memcpy (&B[0], *data, 8);
+		memcpy(&B[0], *data, 8);
 		(*data) += 8;
-		P[4] = PIXEL (*data);
+		P[4] = PIXEL(*data);
 		(*data) += 2;
-		P[5] = PIXEL (*data);
+		P[5] = PIXEL(*data);
 		(*data) += 2;
-		P[6] = PIXEL (*data);
+		P[6] = PIXEL(*data);
 		(*data) += 2;
-		P[7] = PIXEL (*data);
+		P[7] = PIXEL(*data);
 		(*data) += 2;
-		memcpy (&B[8], *data, 8);
+		memcpy(&B[8], *data, 8);
 		(*data) += 8;
 
 		if (!(P[4] & 0x8000)) {
-
 			/* block is divided into left and right halves */
 			for (y = 0; y < 8; ++y) {
-
 				flags = (B[y + 8] << 8) | B[y];
 				split = 0;
 
@@ -587,7 +574,6 @@ ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
 			/* block is divided into top and bottom halves */
 			split = 0;
 			for (y = 0; y < 8; ++y) {
-
 				flags = (B[y * 2 + 1] << 8) | B[y * 2];
 				if (y == 4)
 					split = 4;
@@ -604,15 +590,15 @@ ipvideo_decode_0xa (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0xb (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0xb(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	/* 64-color encoding (each pixel in block is a different color) */
-	CHECK_STREAM (len, 128);
+	CHECK_STREAM(len, 128);
 
 	for (int y = 0; y < 8; ++y) {
 		for (int x = 0; x < 8; ++x) {
-			*frame++ = PIXEL (*data);
+			*frame++ = PIXEL(*data);
 			(*data) += 2;
 		}
 		frame += s->width - 8;
@@ -622,17 +608,17 @@ ipvideo_decode_0xb (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0xc (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0xc(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned short pix;
 
 	/* 16-color block encoding: each 2x2 block is a different color */
-	CHECK_STREAM (len, 32);
+	CHECK_STREAM(len, 32);
 
 	for (int y = 0; y < 8; y += 2) {
 		for (int x = 0; x < 8; x += 2) {
-			pix = PIXEL (*data);
+			pix = PIXEL(*data);
 			(*data) += 2;
 			*(frame + x) = pix;
 			*(frame + x + 1) = pix;
@@ -646,22 +632,22 @@ ipvideo_decode_0xc (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0xd (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0xd(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned short P[4];
 	unsigned char index = 0;
 
 	/* 4-color block encoding: each 4x4 block is a different color */
-	CHECK_STREAM (len, 8);
+	CHECK_STREAM(len, 8);
 
-	P[0] = PIXEL (*data);
+	P[0] = PIXEL(*data);
 	(*data) += 2;
-	P[1] = PIXEL (*data);
+	P[1] = PIXEL(*data);
 	(*data) += 2;
-	P[2] = PIXEL (*data);
+	P[2] = PIXEL(*data);
 	(*data) += 2;
-	P[3] = PIXEL (*data);
+	P[3] = PIXEL(*data);
 	(*data) += 2;
 
 	for (int y = 0; y < 8; ++y) {
@@ -682,15 +668,15 @@ ipvideo_decode_0xd (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0xe (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0xe(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned short pix;
 
 	/* 1-color encoding: the whole block is 1 solid color */
-	CHECK_STREAM (len, 2);
+	CHECK_STREAM(len, 2);
 
-	pix = PIXEL (*data);
+	pix = PIXEL(*data);
 	(*data) += 2;
 
 	for (int y = 0; y < 8; ++y) {
@@ -704,17 +690,17 @@ ipvideo_decode_0xe (const GstMveDemuxStream * s, unsigned short *frame,
 }
 
 static int
-ipvideo_decode_0xf (const GstMveDemuxStream * s, unsigned short *frame,
-		const unsigned char **data, unsigned short *len)
+	ipvideo_decode_0xf(const GstMveDemuxStream* s, unsigned short* frame,
+			   const unsigned char** data, unsigned short* len)
 {
 	unsigned short P[2];
 
 	/* dithered encoding */
-	CHECK_STREAM (len, 4);
+	CHECK_STREAM(len, 4);
 
-	P[0] = PIXEL (*data);
+	P[0] = PIXEL(*data);
 	(*data) += 2;
-	P[1] = PIXEL (*data);
+	P[1] = PIXEL(*data);
 	(*data) += 2;
 
 	for (int y = 0; y < 8; ++y) {
@@ -728,22 +714,21 @@ ipvideo_decode_0xf (const GstMveDemuxStream * s, unsigned short *frame,
 	return 0;
 }
 
-int
-ipvideo_decode_frame16 (const GstMveDemuxStream * s, const unsigned char *data,
-		unsigned short len)
+int ipvideo_decode_frame16(const GstMveDemuxStream* s, const unsigned char* data,
+			   unsigned short len)
 {
 	int rc = 0;
 	int index = 0;
 	unsigned char opcode;
 
-	CHECK_STREAM (&len, 2);
+	CHECK_STREAM(&len, 2);
 
 	unsigned short offset = (data[1] << 8) | data[0];
-	const unsigned char *data2 = data + offset;
+	const unsigned char* data2 = data + offset;
 	unsigned short len2 = len - offset + 2;
 	data += 2;
 
-	unsigned short *frame = s->back_buf1;
+	unsigned short* frame = s->back_buf1;
 
 	/* decoding is done in 8x8 blocks */
 	int xx = s->width >> 3;
@@ -765,56 +750,55 @@ ipvideo_decode_frame16 (const GstMveDemuxStream * s, const unsigned char *data,
 			switch (opcode) {
 				case 0x0:
 					/* copy a block from the previous frame */
-					rc = ipvideo_copy_block (s, frame, frame +
-						(s->back_buf2 - s->back_buf1), 0);
+					rc = ipvideo_copy_block(s, frame, frame + (s->back_buf2 - s->back_buf1), 0);
 					break;
 				case 0x1:
 					/* copy block from 2 frames ago; since we switched the back
 					 * buffers we don't actually have to do anything here */
 					break;
 				case 0x2:
-					rc = ipvideo_decode_0x2 (s, frame, &data2, &len2);
+					rc = ipvideo_decode_0x2(s, frame, &data2, &len2);
 					break;
 				case 0x3:
-					rc = ipvideo_decode_0x3 (s, frame, &data2, &len2);
+					rc = ipvideo_decode_0x3(s, frame, &data2, &len2);
 					break;
 				case 0x4:
-					rc = ipvideo_decode_0x4 (s, frame, &data2, &len2);
+					rc = ipvideo_decode_0x4(s, frame, &data2, &len2);
 					break;
 				case 0x5:
-					rc = ipvideo_decode_0x5 (s, frame, &data, &len);
+					rc = ipvideo_decode_0x5(s, frame, &data, &len);
 					break;
 				case 0x6:
 					/* mystery opcode? skip multiple blocks? */
-					GST_WARNING ("encountered unsupported opcode 0x6");
+					GST_WARNING("encountered unsupported opcode 0x6");
 					rc = -1;
 					break;
 				case 0x7:
-					rc = ipvideo_decode_0x7 (s, frame, &data, &len);
+					rc = ipvideo_decode_0x7(s, frame, &data, &len);
 					break;
 				case 0x8:
-					rc = ipvideo_decode_0x8 (s, frame, &data, &len);
+					rc = ipvideo_decode_0x8(s, frame, &data, &len);
 					break;
 				case 0x9:
-					rc = ipvideo_decode_0x9 (s, frame, &data, &len);
+					rc = ipvideo_decode_0x9(s, frame, &data, &len);
 					break;
 				case 0xa:
-					rc = ipvideo_decode_0xa (s, frame, &data, &len);
+					rc = ipvideo_decode_0xa(s, frame, &data, &len);
 					break;
 				case 0xb:
-					rc = ipvideo_decode_0xb (s, frame, &data, &len);
+					rc = ipvideo_decode_0xb(s, frame, &data, &len);
 					break;
 				case 0xc:
-					rc = ipvideo_decode_0xc (s, frame, &data, &len);
+					rc = ipvideo_decode_0xc(s, frame, &data, &len);
 					break;
 				case 0xd:
-					rc = ipvideo_decode_0xd (s, frame, &data, &len);
+					rc = ipvideo_decode_0xd(s, frame, &data, &len);
 					break;
 				case 0xe:
-					rc = ipvideo_decode_0xe (s, frame, &data, &len);
+					rc = ipvideo_decode_0xe(s, frame, &data, &len);
 					break;
 				case 0xf:
-					rc = ipvideo_decode_0xf (s, frame, &data, &len);
+					rc = ipvideo_decode_0xf(s, frame, &data, &len);
 					break;
 			}
 
