@@ -20,15 +20,15 @@
 
 #include "globals.h"
 
-#include "Interface.h"
 #include "ResourceDesc.h"
+
 #include "Streams/FileStream.h"
 
 using namespace GemRB;
 
-bool NullSource::Open(const char *, const char *desc)
+bool NullSource::Open(const path_t&, std::string desc)
 {
-	description = desc;
+	description = std::move(desc);
 	return true;
 }
 
