@@ -27,11 +27,11 @@ namespace GemRB {
 
 class NullSource : public ResourceSource {
 public:
-	bool Open(const char *filename, const char *description) override;
+	bool Open(const path_t& filename, std::string description) override;
 	bool HasResource(StringView resname, SClass_ID type) override;
-	bool HasResource(StringView resname, const ResourceDesc &type) override;
+	bool HasResource(StringView resname, const ResourceDesc& type) override;
 	DataStream* GetResource(StringView resname, SClass_ID type) override;
-	DataStream* GetResource(StringView resname, const ResourceDesc &type) override;
+	DataStream* GetResource(StringView resname, const ResourceDesc& type) override;
 };
 
 }
