@@ -22,20 +22,22 @@
 
 #include "GameData.h"
 #include "Interface.h"
+
 #include "Logging/Logging.h"
 
 #include <cassert>
 #include <cstdio>
 
 #ifdef __clang__
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
+	#pragma clang diagnostic push
+	#pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
 using namespace GemRB;
 
-template <typename TO, typename FROM>
-TO fnptr_cast(FROM ptr) {
+template<typename TO, typename FROM>
+TO fnptr_cast(FROM ptr)
+{
 	union {
 		FROM ptr_from;
 		TO ptr_to;
@@ -56,7 +58,8 @@ static LPALEFFECTF alEffectf = NULL;
 static LPALAUXILIARYEFFECTSLOTI alAuxiliaryEffectSloti = NULL;
 #endif
 
-static bool checkALError(const char* msg, log_level level) {
+static bool checkALError(const char* msg, LogLevel level)
+{
 	int error = alGetError();
 	if (error != AL_NO_ERROR) {
 		Log(level, "OpenAL", "{}: {:#x} - {}", msg, error, alGetString(error));
@@ -65,7 +68,8 @@ static bool checkALError(const char* msg, log_level level) {
 	return false;
 }
 
-static void showALCError(const char* msg, log_level level, ALCdevice *device) {
+static void showALCError(const char* msg, LogLevel level, ALCdevice* device)
+{
 	int error = alcGetError(device);
 	if (error != AL_NO_ERROR) {
 		Log(level, "OpenAL", "{}: {:#x}", msg, error);
@@ -74,46 +78,54 @@ static void showALCError(const char* msg, log_level level, ALCdevice *device) {
 	}
 }
 
-void OpenALSoundHandle::SetPos(const Point& p) {
+void OpenALSoundHandle::SetPos(const Point& p)
+{
 	if (!parent) return;
 
-	ALfloat SourcePos[] = {
-		float(p.x), float(p.y), 0.0f
-	};
-
-	alSourcefv(parent->Source, AL_POSITION, SourcePos);
-	checkALError("Unable to set source position", WARNING);
+	parent->SetPos(p);
 }
 
-bool OpenALSoundHandle::Playing() {
+bool OpenALSoundHandle::Playing()
+{
 	if (!parent) return false;
 
 	parent->ClearIfStopped();
 	return parent != 0;
 }
 
-void OpenALSoundHandle::Stop() {
+void OpenALSoundHandle::Stop()
+{
 	if (!parent) return;
 
 	parent->ForceClear();
 }
 
-void OpenALSoundHandle::StopLooping() {
+void OpenALSoundHandle::StopLooping()
+{
 	if (!parent) return;
 
-	alSourcei(parent->Source, AL_LOOPING, 0);
-	checkALError("Unable to stop audio loop", WARNING);
+	parent->StopLooping();
 }
 
 void AudioStream::ClearProcessedBuffers() const
+{
+	if (sources.first) {
+		ClearProcessedBuffers(sources.first);
+	}
+	if (sources.second) {
+		ClearProcessedBuffers(sources.second);
+	}
+}
+
+void AudioStream::ClearProcessedBuffers(ALuint Source) const
 {
 	ALint processed = 0;
-	alGetSourcei( Source, AL_BUFFERS_PROCESSED, &processed );
+	alGetSourcei(Source, AL_BUFFERS_PROCESSED, &processed);
 	checkALError("Failed to get processed buffers", WARNING);
 
 	if (processed > 0) {
-		ALuint * b = new ALuint[processed];
-		alSourceUnqueueBuffers( Source, processed, b );
+		ALuint* b = new ALuint[processed];
+		alSourceUnqueueBuffers(Source, processed, b);
 		checkALError("Failed to unqueue buffers", WARNING);
 
 		if (delete_buffers) {
@@ -123,9 +135,9 @@ void AudioStream::ClearProcessedBuffers() const
 				why Apple's implementation of alSourceUnqueueBuffers seems to delay (threading thing?)
 				and possible how better to deal with this.
 			*/
-			do{
+			do {
 				alDeleteBuffers(processed, b);
-			}while(alGetError() != AL_NO_ERROR);
+			} while (alGetError() != AL_NO_ERROR);
 #else
 			alDeleteBuffers(processed, b);
 			checkALError("Failed to delete buffers", WARNING);
@@ -134,64 +146,137 @@ void AudioStream::ClearProcessedBuffers() const
 
 		delete[] b;
 	}
-
 }
 
 void AudioStream::ClearIfStopped()
 {
 	if (free || locked) return;
 
+	bool sourceDeleted = ClearIfStopped(sources.first);
+	if (sources.second) {
+		ClearIfStopped(sources.second);
+	}
+
+	if (sourceDeleted) {
+		free = true;
+		locked = false;
+		delete_buffers = false;
+		ambient = false;
+		sources = { 0, 0 };
+		buffers = { 0, 0 };
+		if (handle) {
+			handle->Invalidate();
+			handle.reset();
+		}
+	}
+}
+
+bool AudioStream::ClearIfStopped(ALuint Source)
+{
 	if (!Source || !alIsSource(Source)) {
 		checkALError("No AL Context", WARNING);
-		return;
+		return false;
 	}
 
 	ALint state;
-	alGetSourcei( Source, AL_SOURCE_STATE, &state );
+	alGetSourcei(Source, AL_SOURCE_STATE, &state);
 	if (!checkALError("Failed to check source state", WARNING) &&
-			state == AL_STOPPED)
-	{
-		ClearProcessedBuffers();
-		alDeleteSources( 1, &Source );
+	    state == AL_STOPPED) {
+		ClearProcessedBuffers(Source);
+		alDeleteSources(1, &Source);
 		checkALError("Failed to delete source", WARNING);
-		Source = 0;
-		Buffer = 0;
-		free = true;
-		if (handle) { handle->Invalidate(); handle.release(); }
-		ambient = false;
-		locked = false;
-		delete_buffers = false;
+
+		return true;
+	}
+
+	return false;
+}
+
+void AudioStream::Stop() const
+{
+	Stop(sources.first);
+	if (sources.second) {
+		Stop(sources.second);
 	}
 }
 
 void AudioStream::ForceClear()
 {
-	if (!Source || !alIsSource(Source)) return;
-
-	alSourceStop(Source);
-	checkALError("Failed to stop source", WARNING);
+	Stop();
 	ClearProcessedBuffers();
 	ClearIfStopped();
 }
 
+void AudioStream::Stop(ALuint source) const
+{
+	if (!source || !alIsSource(source)) return;
+
+	alSourceStop(source);
+	checkALError("Failed to stop source", WARNING);
+}
+
+void AudioStream::StopLooping() const
+{
+	alSourcei(sources.first, AL_LOOPING, 0);
+	if (sources.second) {
+		alSourcei(sources.second, AL_LOOPING, 0);
+	}
+	checkALError("Unable to stop audio loop", WARNING);
+}
+
+void AudioStream::SetPitch(int pitch) const
+{
+	float fPitch = 0.01f * pitch;
+
+	alSourcef(sources.first, AL_PITCH, fPitch);
+	if (sources.second) {
+		alSourcef(sources.second, AL_PITCH, fPitch);
+	}
+	checkALError("Unable to set ambient pitch", WARNING);
+}
+
+void AudioStream::SetPos(const Point& p) const
+{
+	ALfloat SourcePos[] = {
+		float(p.x), float(p.y), 0.0f
+	};
+
+	alSourcefv(sources.first, AL_POSITION, SourcePos);
+	if (sources.second) {
+		alSourcefv(sources.second, AL_POSITION, SourcePos);
+	}
+	checkALError("Unable to set source position", WARNING);
+}
+
+void AudioStream::SetVolume(int volume) const
+{
+	float fVolume = 0.01f * volume;
+
+	alSourcef(sources.first, AL_GAIN, fVolume);
+	if (sources.second) {
+		alSourcef(sources.second, AL_GAIN, fVolume);
+	}
+	checkALError("Unable to set ambient volume", WARNING);
+}
+
 OpenALAudioDriver::OpenALAudioDriver(void)
 {
-	music_memory = (short*) malloc(ACM_BUFFERSIZE);
+	musicBuffer.resize(ACM_BUFFERSIZE / sizeof(short));
 	memset(&reverbProperties.reverbData, 0, sizeof(reverbProperties.reverbData));
 	reverbProperties.reverbDisabled = true;
 }
 
 void OpenALAudioDriver::PrintDeviceList() const
 {
-	const char *deviceList;
+	const char* deviceList;
 
 	if (alcIsExtensionPresent(nullptr, (const ALchar*) "ALC_ENUMERATION_EXT") == AL_TRUE) { // try out enumeration extension
 		Log(MESSAGE, "OpenAL", "Usable audio output devices:");
 		deviceList = alcGetString(nullptr, ALC_DEVICE_SPECIFIER);
 
-		while(deviceList && *deviceList) {
-			Log(MESSAGE,"OpenAL", "Devices: {}", deviceList);
-			deviceList+=strlen(deviceList)+1;
+		while (deviceList && *deviceList) {
+			Log(MESSAGE, "OpenAL", "Devices: {}", deviceList);
+			deviceList += strlen(deviceList) + 1;
 		}
 		return;
 	}
@@ -204,39 +289,39 @@ bool OpenALAudioDriver::Init(void)
 	const char* renderer = alGetString(AL_RENDERER);
 	const char* vendor = alGetString(AL_VENDOR);
 	Log(MESSAGE, "OpenAL", "Initializing OpenAL driver:\nAL Version: {}\nAL Renderer: {}\nAL Vendor: {}",
-		version ? version : "", renderer ? renderer : "", vendor ? vendor : "");
+	    version ? version : "", renderer ? renderer : "", vendor ? vendor : "");
 
-	ALCdevice *device;
-	ALCcontext *context;
+	ALCdevice* device;
+	ALCcontext* context;
 
-	device = alcOpenDevice (NULL);
+	device = alcOpenDevice(NULL);
 	if (device == NULL) {
 		showALCError("Failed to open device", ERROR, device);
 		PrintDeviceList();
 		return false;
 	}
 
-	context = alcCreateContext (device, NULL);
+	context = alcCreateContext(device, NULL);
 	if (context == NULL) {
 		showALCError("Failed to create context", ERROR, device);
-		alcCloseDevice (device);
+		alcCloseDevice(device);
 		return false;
 	}
 
-	if (!alcMakeContextCurrent (context)) {
+	if (!alcMakeContextCurrent(context)) {
 		showALCError("Failed to select context", ERROR, device);
-		alcDestroyContext (context);
-		alcCloseDevice (device);
+		alcDestroyContext(context);
+		alcCloseDevice(device);
 		return false;
 	}
 	alutContext = context;
 
 	//1 for speech
-	int sources = CountAvailableSources(MAX_STREAMS+1);
+	int sources = CountAvailableSources(MAX_STREAMS + 1);
 	num_streams = sources - 1;
 
 	Log(MESSAGE, "OpenAL", "Allocated {} streams.{}",
-		num_streams, (num_streams < MAX_STREAMS ? " (Fewer than desired.)" : "" ));
+	    num_streams, (num_streams < MAX_STREAMS ? " (Fewer than desired.)" : ""));
 
 	musicThread = std::thread(&OpenALAudioDriver::MusicManager, this);
 
@@ -244,15 +329,18 @@ bool OpenALAudioDriver::Init(void)
 		Log(MESSAGE, "OpenAL", "EFX not available.");
 	}
 
+	// The higher the listener pos, the smoother the L/R transitions but the more gain required
+	// to compensate for lower volume
+	alListenerf(AL_GAIN, 1.25f);
+
 	ambim = new AmbientMgr;
-	speech.free = true;
-	speech.ambient = false;
 	return true;
 }
 
-bool OpenALAudioDriver::InitEFX(void) {
+bool OpenALAudioDriver::InitEFX(void)
+{
 #ifdef HAVE_OPENAL_EFX_H
-	ALCdevice *device = alcGetContextsDevice (alutContext);
+	ALCdevice* device = alcGetContextsDevice(alutContext);
 	ALCint auxSends = 0;
 	hasEFX = false;
 
@@ -309,9 +397,9 @@ bool OpenALAudioDriver::InitEFX(void) {
 
 int OpenALAudioDriver::CountAvailableSources(int limit)
 {
-	ALuint* src = new ALuint[limit+2];
+	ALuint* src = new ALuint[limit + 2];
 	int i;
-	for (i = 0; i < limit+2; ++i) {
+	for (i = 0; i < limit + 2; ++i) {
 		alGenSources(1, &src[i]);
 		if (alGetError() != AL_NO_ERROR)
 			break;
@@ -338,11 +426,11 @@ OpenALAudioDriver::~OpenALAudioDriver(void)
 	}
 
 	stayAlive = false;
-	
+
 	// AmigaOS4 should be built with -athread=native or this may not work
 	musicThread.join();
 
-	for(int i =0; i<num_streams; i++) {
+	for (int i = 0; i < num_streams; i++) {
 		streams[i].ForceClear();
 	}
 	speech.ForceClear();
@@ -355,28 +443,24 @@ OpenALAudioDriver::~OpenALAudioDriver(void)
 	}
 #endif
 
-	ALCdevice *device;
+	ALCdevice* device;
 
-	alcMakeContextCurrent (NULL);
+	alcMakeContextCurrent(NULL);
 
-	device = alcGetContextsDevice (alutContext);
-	alcDestroyContext (alutContext);
-	if (alcGetError (device) == ALC_NO_ERROR) {
-		alcCloseDevice (device);
+	device = alcGetContextsDevice(alutContext);
+	alcDestroyContext(alutContext);
+	if (alcGetError(device) == ALC_NO_ERROR) {
+		alcCloseDevice(device);
 	}
 	alutContext = NULL;
 
-	free(music_memory);
-
 	delete ambim;
 }
 
-ALuint OpenALAudioDriver::loadSound(StringView ResRef, tick_t &time_length)
+std::pair<ALuint, ALuint> OpenALAudioDriver::loadSound(StringView ResRef, tick_t& time_length, bool spatial)
 {
-	ALuint Buffer = 0;
-
 	if (ResRef.empty()) {
-		return 0;
+		return { 0, 0 };
 	}
 
 	auto entry = buffercache.Lookup(ResRef);
@@ -385,52 +469,71 @@ ALuint OpenALAudioDriver::loadSound(StringView ResRef, tick_t &time_length)
 		return entry->Buffer;
 	}
 
-	//no cache entry...
-	alGenBuffers(1, &Buffer);
-	if (checkALError("Unable to create sound buffer", ERROR)) {
-		return 0;
-	}
+	ALuint buffers[2] = { 0, 0 };
 
 	ResourceHolder<SoundMgr> acm = gamedata->GetResourceHolder<SoundMgr>(ResRef);
 	if (!acm) {
-		alDeleteBuffers( 1, &Buffer );
-		checkALError("Unable to delete buffer!", ERROR);
-		return 0;
+		return { 0, 0 };
 	}
-	int cnt = acm->get_length();
-	unsigned int riff_chans = acm->get_channels();
+
+	unsigned int channels = acm->get_channels();
+	assert(channels <= 2);
+	bool spatialStereo = channels > 1 && spatial;
+
+	alGenBuffers(spatialStereo ? 2 : 1, buffers);
+	if (checkALError("Unable to create sound buffer", ERROR)) {
+		return { 0, 0 };
+	}
+
 	int samplerate = acm->get_samplerate();
-	//multiply always by 2 because it is in 16 bits
-	int rawsize = cnt * 2;
-	short* memory = (short*) malloc(rawsize);
-	//multiply always with 2 because it is in 16 bits
-	unsigned int cnt1 = acm->read_samples( memory, cnt ) * 2;
-	//Sound Length in milliseconds
-	time_length = ((cnt / riff_chans) * 1000) / samplerate;
-	//it is always reading the stuff into 16 bits
-	alBufferData( Buffer, GetFormatEnum( riff_chans, 16 ), memory, cnt1, samplerate );
-	free(memory);
+	auto numSamples = acm->get_length();
+	auto totalBytesPerChannel = numSamples * 2;
+
+	// Positional sound doesn't work for stereo in all known implementations
+	// so make two sources and play them in parallel: https://openal.org/pipermail/openal/2016-August/000527.html
+	if (spatialStereo) {
+		std::vector<char> channel1;
+		std::vector<char> channel2;
+		channel1.resize(totalBytesPerChannel);
+		channel2.resize(totalBytesPerChannel);
+		auto actualSamples = acm->ReadSamplesIntoChannels(channel1.data(), channel2.data(), numSamples);
+
+		auto format = GetFormatEnum(1, 16);
+		alBufferData(buffers[0], format, channel1.data(), actualSamples * 2, samplerate);
+		alBufferData(buffers[1], format, channel2.data(), actualSamples * 2, samplerate);
+	} else {
+		std::vector<short> memory;
+		memory.resize(totalBytesPerChannel / sizeof(short));
+
+		// multiply always with 2 because it is in 16 bits
+		unsigned int cnt1 = acm->read_samples(memory.data(), numSamples) * 2;
+		// it is always reading the stuff into 16 bits
+		alBufferData(buffers[0], GetFormatEnum(channels, 16), memory.data(), cnt1, samplerate);
+	}
+
+	// Sound length in milliseconds
+	time_length = ((numSamples / channels) * 1000) / samplerate;
 
 	if (checkALError("Unable to fill buffer", ERROR)) {
-		alDeleteBuffers( 1, &Buffer );
+		alDeleteBuffers(spatialStereo ? 2 : 1, buffers);
 		checkALError("Error deleting buffer", WARNING);
-		return 0;
+		return { 0, 0 };
 	}
 
-	buffercache.SetAt(ResRef, Buffer, time_length);
+	std::pair<ALuint, ALuint> bufferPair { buffers[0], buffers[1] };
+	buffercache.SetAt(ResRef, bufferPair, time_length);
 
-	return Buffer;
+	return bufferPair;
 }
 
-Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, unsigned int channel, const Point& p,
-	unsigned int flags, tick_t *length)
+Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, SFXChannel channel, const Point& p,
+					    unsigned int flags, tick_t* length)
 {
-	ALuint Buffer;
-
 	if (ResRef.empty()) {
-		if((flags & GEM_SND_SPEECH) && (speech.Source && alIsSource(speech.Source))) {
+		auto source = speech.sources.first;
+		if ((flags & GEM_SND_SPEECH) && (source && alIsSource(source))) {
 			//So we want him to be quiet...
-			alSourceStop( speech.Source );
+			alSourceStop(source);
 			checkALError("Unable to stop speech", WARNING);
 			speech.ClearProcessedBuffers();
 		}
@@ -438,8 +541,8 @@ Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, unsigned int chan
 	}
 
 	tick_t time_length;
-	Buffer = loadSound( ResRef, time_length );
-	if (Buffer == 0) {
+	auto buffers = loadSound(ResRef, time_length, flags & GEM_SND_SPATIAL);
+	if (buffers.first == 0) {
 		return Holder<SoundHandle>();
 	}
 
@@ -447,13 +550,6 @@ Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, unsigned int chan
 		*length = time_length;
 	}
 
-	ALfloat SourcePos[] = {
-		float(p.x), float(p.y), 0.0f
-	};
-	ALfloat SourceVel[] = {
-		0.0f, 0.0f, 0.0f
-	};
-
 	ieDword volume = 100;
 	ALint loop = (flags & GEM_SND_LOOPING) ? 1 : 0;
 
@@ -466,14 +562,15 @@ Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, unsigned int chan
 			//speech has a single channel, if a new speech started
 			//we stop the previous one
 
-			if(!speech.free && (speech.Source && alIsSource(speech.Source))) {
-				alSourceStop( speech.Source );
+			auto source = speech.sources.first;
+			if (!speech.free && (source && alIsSource(source))) {
+				alSourceStop(source);
 				checkALError("Unable to stop speech", WARNING);
 				speech.ClearProcessedBuffers();
 			}
 		}
 
-		volume = core->GetVariable("Volume Voices", 100);
+		volume = core->GetDictionary().Get("Volume Voices", 100);
 
 		loop = 0; // Speech ignores GEM_SND_LOOPING
 	} else {
@@ -486,7 +583,7 @@ Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, unsigned int chan
 			}
 		}
 
-		volume = core->GetVariable("Volume SFX", 100);
+		volume = core->GetDictionary().Get("Volume SFX", 100);
 
 		if (stream == NULL) {
 			// Failed to assign new sound.
@@ -496,45 +593,78 @@ Holder<SoundHandle> OpenALAudioDriver::Play(StringView ResRef, unsigned int chan
 	}
 
 	assert(stream);
-	ALuint Source = stream->Source;
 
-	if(!Source || !alIsSource(Source)) {
-		alGenSources( 1, &Source );
-		if (checkALError("Error creating source", ERROR)) {
-			return Holder<SoundHandle>();
-		}
+	auto& sources = stream->sources;
+	sources.first = CreateAndConfigSource(sources.first, volume, loop, flags, p, channel);
+	if (buffers.second) {
+		sources.second = CreateAndConfigSource(sources.second, volume, loop, flags, p, channel);
 	}
 
-	alSourcef( Source, AL_PITCH, 1.0f );
-	alSourcefv( Source, AL_VELOCITY, SourceVel );
-	alSourcei( Source, AL_LOOPING, loop);
-	alSourcef( Source, AL_REFERENCE_DISTANCE, REFERENCE_DISTANCE );
-	alSourcef( Source, AL_GAIN, 0.01f * (volume / 100.0f) * GetVolume(channel) );
-	alSourcei( Source, AL_SOURCE_RELATIVE, flags & GEM_SND_RELATIVE );
-	alSourcefv( Source, AL_POSITION, SourcePos );
-	checkALError("Unable to set audio parameters", WARNING);
-
-#ifdef HAVE_OPENAL_EFX_H
-	ieDword efxSetting = core->GetVariable("Environmental Audio", 0);
-
-	if (efxSetting && hasReverbProperties && (!p.IsZero() || (flags & GEM_SND_RELATIVE))) {
-		alSource3i(Source, AL_AUXILIARY_SEND_FILTER, efxEffectSlot, 0, 0);
-	} else {
-		alSource3i(Source, AL_AUXILIARY_SEND_FILTER, 0, 0, 0);
-	}
-#endif
-
 	assert(!stream->delete_buffers);
-
-	stream->Source = Source;
 	stream->free = false;
 
-	if (QueueALBuffer(Source, Buffer) != GEM_OK) {
+	if (QueueALBuffers(stream->sources, buffers) != GEM_OK) {
 		return Holder<SoundHandle>();
 	}
 
 	stream->handle = MakeHolder<OpenALSoundHandle>(stream);
-	return Holder<SoundHandle>(stream->handle.get()); // TODO: we need something like static_ptr_cast
+	return stream->handle;
+}
+
+ALuint OpenALAudioDriver::CreateAndConfigSource(ALuint source, ieDword volume, ALint loop, unsigned int flags, const Point& p, SFXChannel channel) const
+{
+	if (!source || !alIsSource(source)) {
+		alGenSources(1, &source);
+
+		if (checkALError("Error creating source", ERROR)) {
+			return 0;
+		}
+	}
+
+	ConfigSource(source, volume, loop, flags, p, channel);
+
+	return source;
+}
+
+void OpenALAudioDriver::ConfigSource(ALuint source, ieDword volume, ALint loop, unsigned int flags, const Point& p, SFXChannel channel) const
+{
+	ALfloat sourceVel[] = {
+		0.0f, 0.0f, 0.0f
+	};
+
+	ALfloat sourcePos[] = {
+		float(p.x), float(p.y), GetHeight(channel)
+	};
+
+	bool spatial = flags & GEM_SND_SPATIAL;
+	alSourcef(source, AL_PITCH, 1.0f);
+	alSourcefv(source, AL_VELOCITY, sourceVel);
+	alSourcei(source, AL_LOOPING, loop);
+	alSourcef(source, AL_REFERENCE_DISTANCE, REFERENCE_DISTANCE);
+	alSourcef(source, AL_GAIN, 0.01f * (volume / 100.0f) * GetVolume(channel));
+	// AL_SOURCE_RELATIVE = source pos & co to be interpreted as if listener was at (0, 0, 0)
+	alSourcei(source, AL_SOURCE_RELATIVE, !spatial);
+	alSourcefv(source, AL_POSITION, sourcePos);
+
+	if (spatial) {
+		auto keepDistance = std::max(screenSize.w, screenSize.h);
+		auto offsetDistance = keepDistance * 4;
+		alSourcei(source, AL_REFERENCE_DISTANCE, keepDistance);
+		alSourcei(source, AL_MAX_DISTANCE, offsetDistance);
+		alSourcei(source, AL_ROLLOFF_FACTOR, 25);
+	}
+
+	checkALError("Unable to set audio parameters", WARNING);
+
+#ifdef HAVE_OPENAL_EFX_H
+	ieDword efxSetting = core->GetDictionary().Get("Environmental Audio", 0);
+
+	if (efxSetting && hasReverbProperties && (flags & (GEM_SND_SPATIAL | GEM_SND_EFX))) {
+		alSource3i(source, AL_AUXILIARY_SEND_FILTER, efxEffectSlot, 0, 0);
+	} else {
+		alSource3i(source, AL_AUXILIARY_SEND_FILTER, 0, 0, 0);
+	}
+#endif
 }
 
 void OpenALAudioDriver::UpdateVolume(unsigned int flags)
@@ -543,14 +673,14 @@ void OpenALAudioDriver::UpdateVolume(unsigned int flags)
 
 	if (flags & GEM_SND_VOL_MUSIC) {
 		musicMutex.lock();
-		volume = core->GetVariable("Volume Music", 0);
+		volume = core->GetDictionary().Get("Volume Music", 0);
 		if (MusicSource && alIsSource(MusicSource))
 			alSourcef(MusicSource, AL_GAIN, volume * 0.01f);
 		musicMutex.unlock();
 	}
 
 	if (flags & GEM_SND_VOL_AMBIENTS) {
-		volume = core->GetVariable("Volume Ambients", volume);
+		volume = core->GetDictionary().Get("Volume Ambients", volume);
 		ambim->UpdateVolume(volume);
 	}
 }
@@ -567,12 +697,12 @@ void OpenALAudioDriver::ResetMusics()
 	if (MusicSource && alIsSource(MusicSource)) {
 		alSourceStop(MusicSource);
 		checkALError("Unable to stop music source", WARNING);
-		alDeleteSources(1, &MusicSource );
+		alDeleteSources(1, &MusicSource);
 		checkALError("Unable to delete music source", WARNING);
 		MusicSource = 0;
-		for (int i=0; i<MUSICBUFFERS; i++) {
+		for (int i = 0; i < MUSICBUFFERS; i++) {
 			if (alIsBuffer(MusicBuffer[i])) {
-				alDeleteBuffers(1, MusicBuffer+i);
+				alDeleteBuffers(1, MusicBuffer + i);
 				checkALError("Unable to delete music buffer", WARNING);
 			}
 		}
@@ -592,14 +722,14 @@ bool OpenALAudioDriver::Play()
 bool OpenALAudioDriver::Stop()
 {
 	std::lock_guard<std::recursive_mutex> l(musicMutex);
-	
-	if (!MusicSource || !alIsSource( MusicSource )) {
+
+	if (!MusicSource || !alIsSource(MusicSource)) {
 		return false;
 	}
-	alSourceStop( MusicSource );
+	alSourceStop(MusicSource);
 	checkALError("Unable to stop music source", WARNING);
 	MusicPlaying = false;
-	alDeleteSources( 1, &MusicSource );
+	alDeleteSources(1, &MusicSource);
 	checkALError("Unable to delete music source", WARNING);
 	MusicSource = 0;
 	return true;
@@ -608,7 +738,7 @@ bool OpenALAudioDriver::Stop()
 bool OpenALAudioDriver::Pause()
 {
 	std::lock_guard<std::recursive_mutex> l(musicMutex);
-	if (!MusicSource || !alIsSource( MusicSource )) {
+	if (!MusicSource || !alIsSource(MusicSource)) {
 		return false;
 	}
 	alSourcePause(MusicSource);
@@ -623,7 +753,7 @@ bool OpenALAudioDriver::Resume()
 {
 	{
 		std::lock_guard<std::recursive_mutex> l(musicMutex);
-		if (!MusicSource || !alIsSource( MusicSource )) {
+		if (!MusicSource || !alIsSource(MusicSource)) {
 			return false;
 		}
 		alSourcePlay(MusicSource);
@@ -634,7 +764,7 @@ bool OpenALAudioDriver::Resume()
 	return true;
 }
 
-int OpenALAudioDriver::CreateStream(std::shared_ptr<SoundMgr> newMusic)
+int OpenALAudioDriver::CreateStream(ResourceHolder<SoundMgr> newMusic)
 {
 	std::lock_guard<std::recursive_mutex> l(musicMutex);
 
@@ -645,14 +775,14 @@ int OpenALAudioDriver::CreateStream(std::shared_ptr<SoundMgr> newMusic)
 	}
 
 	if (MusicBuffer[0] == 0) {
-		alGenBuffers( MUSICBUFFERS, MusicBuffer );
+		alGenBuffers(MUSICBUFFERS, MusicBuffer);
 		if (checkALError("Unable to create music buffers", ERROR)) {
 			return -1;
 		}
 	}
 
 	if (MusicSource == 0) {
-		alGenSources( 1, &MusicSource );
+		alGenSources(1, &MusicSource);
 		if (checkALError("Unable to create music source", ERROR)) {
 			alDeleteBuffers(MUSICBUFFERS, MusicBuffer);
 			return -1;
@@ -665,13 +795,13 @@ int OpenALAudioDriver::CreateStream(std::shared_ptr<SoundMgr> newMusic)
 			0.0f, 0.0f, 0.0f
 		};
 
-		ieDword volume = core->GetVariable("Volume Music", 0);
-		alSourcef( MusicSource, AL_PITCH, 1.0f );
-		alSourcef( MusicSource, AL_GAIN, 0.01f * volume );
-		alSourcei( MusicSource, AL_SOURCE_RELATIVE, 1 );
-		alSourcefv( MusicSource, AL_POSITION, SourcePos );
-		alSourcefv( MusicSource, AL_VELOCITY, SourceVel );
-		alSourcei( MusicSource, AL_LOOPING, 0 );
+		ieDword volume = core->GetDictionary().Get("Volume Music", 0);
+		alSourcef(MusicSource, AL_PITCH, 1.0f);
+		alSourcef(MusicSource, AL_GAIN, 0.01f * volume);
+		alSourcei(MusicSource, AL_SOURCE_RELATIVE, 1);
+		alSourcefv(MusicSource, AL_POSITION, SourcePos);
+		alSourcefv(MusicSource, AL_VELOCITY, SourceVel);
+		alSourcei(MusicSource, AL_LOOPING, 0);
 		checkALError("Unable to set music parameters", WARNING);
 	}
 
@@ -687,42 +817,41 @@ void OpenALAudioDriver::UpdateListenerPos(const Point& p)
 Point OpenALAudioDriver::GetListenerPos()
 {
 	ALfloat listen[3];
-	alGetListenerfv( AL_POSITION, listen );
+	alGetListenerfv(AL_POSITION, listen);
 	if (checkALError("Unable to get listener pos", ERROR)) return {};
 	return Point(listen[0], listen[1]);
 }
 
-bool OpenALAudioDriver::ReleaseStream(int stream, bool HardStop)
+bool OpenALAudioDriver::ReleaseStream(int streamIdx, bool HardStop)
 {
-	if (stream < 0 || streams[stream].free || !streams[stream].locked)
+	auto& stream = streams[streamIdx];
+	if (stream.free || !stream.locked)
 		return false;
-	streams[stream].locked = false;
+	stream.locked = false;
 	if (!HardStop) {
 		// it's now unlocked, so it will automatically be reclaimed when needed
 		return true;
 	}
 
-	ALuint Source = streams[stream].Source;
-	alSourceStop(Source);
-	checkALError("Unable to stop source", WARNING);
-	streams[stream].ClearIfStopped();
+	stream.Stop();
+	stream.ClearIfStopped();
 	return true;
 }
 
 //This one is used for movies and ambients.
 int OpenALAudioDriver::SetupNewStream(int x, int y, int z,
-		            ieWord gain, bool point, int ambientRange)
+				      ieWord gain, bool point, int ambientRange)
 {
 	// Find a free (or finished) stream for this sound
-	int stream = -1;
+	int streamIdx = -1;
 	for (int i = 0; i < num_streams; i++) {
 		streams[i].ClearIfStopped();
 		if (streams[i].free) {
-			stream = i;
+			streamIdx = i;
 			break;
 		}
 	}
-	if (stream == -1) {
+	if (streamIdx == -1) {
 		Log(ERROR, "OpenAL", "No available audio streams out of {}", num_streams);
 		return -1;
 	}
@@ -733,68 +862,83 @@ int OpenALAudioDriver::SetupNewStream(int x, int y, int z,
 		return -1;
 	}
 
-	ALfloat position[] = { (float) x, (float) y, (float) z };
-	alSourcef( source, AL_PITCH, 1.0f );
-	alSourcefv( source, AL_POSITION, position );
-	alSourcef( source, AL_GAIN, 0.01f * gain );
-	// AL_REFERENCE_DISTANCE is the distance under which the volume would normally drop by half
-	alSourcei(source, AL_REFERENCE_DISTANCE, ambientRange > 0 ? ambientRange : REFERENCE_DISTANCE);
-	alSourcei( source, AL_ROLLOFF_FACTOR, point ? 1 : 0 );
-	alSourcei( source, AL_LOOPING, 0 );
+	alSourcef(source, AL_PITCH, 1.0f);
+	alSourcei(source, AL_LOOPING, 0);
+	alSourcef(source, AL_GAIN, 0.003f * gain);
+	alSourcei(source, AL_REFERENCE_DISTANCE, REFERENCE_DISTANCE);
+	alSourcei(source, AL_ROLLOFF_FACTOR, 0);
+	alSourcei(source, AL_SOURCE_RELATIVE, !point);
+
+	if (point) {
+		ALfloat position[] = { (float) x, (float) y, (float) z };
+		alSourcefv(source, AL_POSITION, position);
+
+		// under default sound distance model (AL_INVERSE_DISTANCE_CLAMPED) the formula is:
+		//   dist = max(dist, AL_REFERENCE_DISTANCE);
+		//   dist = min(dist, AL_MAX_DISTANCE);
+		//   gain = AL_REFERENCE_DISTANCE / (AL_REFERENCE_DISTANCE + AL_ROLLOFF_FACTOR * (dist – AL_REFERENCE_DISTANCE) );
+		alSourcei(source, AL_ROLLOFF_FACTOR, 5);
+		alSourcei(source, AL_MAX_DISTANCE, ambientRange);
+		alSourcef(source, AL_GAIN, 0.07f * gain);
+	} else {
+		ALfloat position[] = { 0.0f, 0.0f, 0.0f };
+		alSourcefv(source, AL_POSITION, position);
+	}
+
 	checkALError("Unable to set stream parameters", WARNING);
 
-	streams[stream].Buffer = 0;
-	streams[stream].Source = source;
-	streams[stream].free = false;
-	streams[stream].ambient = ambientRange > 0;
-	streams[stream].locked = true;
+	auto& stream = streams[streamIdx];
+	stream.buffers = { 0, 0 };
+	stream.sources = { source, 0 };
+	stream.free = false;
+	stream.ambient = ambientRange > 0;
+	stream.locked = true;
 
-	return stream;
+	return streamIdx;
 }
 
-tick_t OpenALAudioDriver::QueueAmbient(int stream, const ResRef& sound)
+tick_t OpenALAudioDriver::QueueAmbient(int streamIdx, const ResRef& sound, bool spatial)
 {
-	if (streams[stream].free || !streams[stream].ambient)
+	auto& stream = streams[streamIdx];
+	if (stream.free || !stream.ambient)
 		return -1;
 
-	ALuint source = streams[stream].Source;
+	ALuint source = stream.sources.first;
 
 	// first dequeue any processed buffers
-	streams[stream].ClearProcessedBuffers();
+	stream.ClearProcessedBuffers();
 
 	tick_t time_length;
-	ALuint Buffer = loadSound(sound, time_length);
+	ALuint Buffer = loadSound(sound, time_length, spatial).first;
 	if (0 == Buffer) {
 		return -1;
 	}
 
-	assert(!streams[stream].delete_buffers);
+	assert(!stream.delete_buffers);
 
-	if (QueueALBuffer(source, Buffer) != GEM_OK) {
+	if (QueueALBuffers({ source, 0 }, { Buffer, 0 }) != GEM_OK) {
 		return GEM_ERROR;
 	}
 
 	return time_length;
 }
 
-void OpenALAudioDriver::SetAmbientStreamVolume(int stream, int volume)
+void OpenALAudioDriver::SetAmbientStreamVolume(int streamIdx, int volume)
 {
-	if (streams[stream].free || !streams[stream].ambient)
+	auto& stream = streams[streamIdx];
+	if (stream.free || !stream.ambient)
 		return;
 
-	ALuint source = streams[stream].Source;
-	alSourcef( source, AL_GAIN, 0.01f * volume );
-	checkALError("Unable to set ambient volume", WARNING);
+	stream.SetVolume(volume);
 }
 
-void OpenALAudioDriver::SetAmbientStreamPitch(int stream, int pitch)
+void OpenALAudioDriver::SetAmbientStreamPitch(int streamIdx, int pitch)
 {
-	if (streams[stream].free || !streams[stream].ambient)
+	auto& stream = streams[streamIdx];
+	if (stream.free || !stream.ambient)
 		return;
 
-	ALuint source = streams[stream].Source;
-	alSourcef( source, AL_PITCH, 0.01f * pitch );
-	checkALError("Unable to set ambient pitch", WARNING);
+	stream.SetPitch(pitch);
 }
 
 ALenum OpenALAudioDriver::GetFormatEnum(int channels, int bits) const
@@ -824,7 +968,7 @@ int OpenALAudioDriver::MusicManager(void* arg)
 		std::lock_guard<std::recursive_mutex> l(driver->musicMutex);
 		if (driver->MusicPlaying) {
 			ALint state;
-			alGetSourcei( driver->MusicSource, AL_SOURCE_STATE, &state );
+			alGetSourcei(driver->MusicSource, AL_SOURCE_STATE, &state);
 			if (checkALError("Unable to query music source state", ERROR)) {
 				driver->MusicPlaying = false;
 				return -1;
@@ -841,18 +985,20 @@ int OpenALAudioDriver::MusicManager(void* arg)
 					// ensure that MusicSource has no buffers attached by passing "NULL" buffer
 					alSourcei(driver->MusicSource, AL_BUFFER, 0);
 					checkALError("Unable to detach buffers from music source.", WARNING);
+
 					for (unsigned int buffer : driver->MusicBuffer) {
-						driver->MusicReader->read_samples( driver->music_memory, ACM_BUFFERSIZE >> 1 );
+						driver->MusicReader->read_samples(driver->musicBuffer.data(), ACM_BUFFERSIZE >> 1);
 						alBufferData(buffer, AL_FORMAT_STEREO16,
-							driver->music_memory, ACM_BUFFERSIZE,
-							driver->MusicReader->get_samplerate() );
+							     driver->musicBuffer.data(), ACM_BUFFERSIZE,
+							     driver->MusicReader->get_samplerate());
 					}
+
 					checkALError("Unable to buffer data.", ERROR);
 					// FIXME: determine if we should error out if any data fails to buffer
-					alSourceQueueBuffers( driver->MusicSource, MUSICBUFFERS, driver->MusicBuffer );
+					alSourceQueueBuffers(driver->MusicSource, MUSICBUFFERS, driver->MusicBuffer);
 					if (!checkALError("Unable to queue buffer.", ERROR)) {
-						if (driver->MusicSource && alIsSource( driver->MusicSource )) {
-							alSourcePlay( driver->MusicSource );
+						if (driver->MusicSource && alIsSource(driver->MusicSource)) {
+							alSourcePlay(driver->MusicSource);
 							if (!checkALError("Error playing music source", ERROR)) {
 								// no errors happened
 								bFinished = AL_FALSE;
@@ -865,8 +1011,8 @@ int OpenALAudioDriver::MusicManager(void* arg)
 					return -1;
 				case AL_STOPPED:
 					Log(MESSAGE, "OpenAL", "WARNING: Buffer Underrun. AutoRestarting Stream Playback");
-					if (driver->MusicSource && alIsSource( driver->MusicSource )) {
-						alSourcePlay( driver->MusicSource );
+					if (driver->MusicSource && alIsSource(driver->MusicSource)) {
+						alSourcePlay(driver->MusicSource);
 						checkALError("Error playing music source", ERROR);
 					}
 					break;
@@ -874,7 +1020,7 @@ int OpenALAudioDriver::MusicManager(void* arg)
 					break;
 			}
 			ALint processed;
-			alGetSourcei( driver->MusicSource, AL_BUFFERS_PROCESSED, &processed );
+			alGetSourcei(driver->MusicSource, AL_BUFFERS_PROCESSED, &processed);
 			if (checkALError("Unable to query music source state", ERROR)) {
 				driver->MusicPlaying = false;
 				return -1;
@@ -882,37 +1028,39 @@ int OpenALAudioDriver::MusicManager(void* arg)
 			if (processed > 0) {
 				while (processed) {
 					ALuint BufferID;
-					alSourceUnqueueBuffers( driver->MusicSource, 1, &BufferID );
+					alSourceUnqueueBuffers(driver->MusicSource, 1, &BufferID);
 					if (checkALError("Unable to unqueue music buffers", ERROR)) {
 						driver->MusicPlaying = false;
 						return -1;
 					}
 					if (bFinished == AL_FALSE) {
 						int size = ACM_BUFFERSIZE;
-						int cnt = driver->MusicReader->read_samples( driver->music_memory, ACM_BUFFERSIZE >> 1 );
-						size -= ( cnt * 2 );
+						int cnt = driver->MusicReader->read_samples(driver->musicBuffer.data(), ACM_BUFFERSIZE >> 1);
+						size -= (cnt * 2);
 						if (size != 0)
 							bFinished = AL_TRUE;
 						if (bFinished) {
 							Log(MESSAGE, "OpenAL", "Playing Next Music");
 							core->GetMusicMgr()->PlayNext();
+
+							auto bufferPos = driver->musicBuffer.data() + cnt;
 							if (driver->MusicPlaying) {
 								Log(MESSAGE, "OpenAL", "Queuing New Music");
-								driver->MusicReader->read_samples( ( driver->music_memory + cnt ), size >> 1 );
+								driver->MusicReader->read_samples(bufferPos, size >> 1);
 								bFinished = AL_FALSE;
 							} else {
 								Log(MESSAGE, "OpenAL", "No Other Music to play");
-								memset( driver->music_memory + cnt, 0, size );
+								std::fill(bufferPos, bufferPos + size, 0);
 								driver->MusicPlaying = false;
 								break;
 							}
 						}
-						alBufferData( BufferID, AL_FORMAT_STEREO16, driver->music_memory, ACM_BUFFERSIZE, driver->MusicReader->get_samplerate() );
+						alBufferData(BufferID, AL_FORMAT_STEREO16, driver->musicBuffer.data(), ACM_BUFFERSIZE, driver->MusicReader->get_samplerate());
 						if (checkALError("Unable to buffer music data", ERROR)) {
 							driver->MusicPlaying = false;
 							return -1;
 						}
-						alSourceQueueBuffers( driver->MusicSource, 1, &BufferID );
+						alSourceQueueBuffers(driver->MusicSource, 1, &BufferID);
 						if (checkALError("Unable to queue music buffers", ERROR)) {
 							driver->MusicPlaying = false;
 							return -1;
@@ -927,12 +1075,13 @@ int OpenALAudioDriver::MusicManager(void* arg)
 }
 
 //This one is used for movies, might be useful for others ?
-void OpenALAudioDriver::QueueBuffer(int stream, unsigned short bits,
-		        int channels, short* memory,
-		        int size, int samplerate)
+void OpenALAudioDriver::QueueBuffer(int streamIdx, unsigned short bits,
+				    int channels, short* memory,
+				    int size, int samplerate)
 {
-	streams[stream].delete_buffers = true;
-	streams[stream].ClearProcessedBuffers();
+	auto& stream = streams[streamIdx];
+	stream.delete_buffers = true;
+	stream.ClearProcessedBuffers();
 
 	ALuint Buffer;
 	alGenBuffers(1, &Buffer);
@@ -946,27 +1095,48 @@ void OpenALAudioDriver::QueueBuffer(int stream, unsigned short bits,
 		return;
 	}
 
-	QueueALBuffer(streams[stream].Source, Buffer);
+	QueueALBuffers({ stream.sources.first, 0 }, { Buffer, 0 });
 }
 
-// !!!!!!!!!!!!!!!
-// Private Methods
-// !!!!!!!!!!!!!!!
+int OpenALAudioDriver::QueueALBuffers(OpenALuintPair sources, OpenALuintPair buffers) const
+{
+	ALenum state;
+	auto result = QueueALBuffer(sources.first, buffers.first);
+	if (result == GEM_ERROR) {
+		return GEM_ERROR;
+	}
+
+	if (sources.second) {
+		auto result = QueueALBuffer(sources.second, buffers.second);
+		if (result == GEM_ERROR) {
+			return GEM_ERROR;
+		}
+	}
+
+	alGetSourcei(sources.first, AL_SOURCE_STATE, &state);
+	if (checkALError("Unable to query source state", ERROR)) {
+		return GEM_ERROR;
+	}
+
+	// queueing always implies playing for us
+	if (state != AL_PLAYING) {
+		ALuint alSources[2] = { sources.first, sources.second };
+		alSourcePlayv(sources.second ? 2 : 1, alSources);
+
+		if (checkALError("Unable to play source", ERROR)) {
+			return GEM_ERROR;
+		}
+	}
+
+	return GEM_OK;
+}
 
 int OpenALAudioDriver::QueueALBuffer(ALuint source, ALuint buffer) const
 {
-#ifdef DEBUG_AUDIO
-	ALint frequency, bits, channels;
-	alGetBufferi(buffer, AL_FREQUENCY, &frequency);
-	alGetBufferi(buffer, AL_BITS, &bits);
-	alGetBufferi(buffer, AL_CHANNELS, &channels);
-	checkALError("Error querying buffer properties.", WARNING);
-	Log(DEBUG, "OpenAL", "Attempting to buffer audio source: {}\nFrequency: {}\nBits: {}\nChannels: {}",
-		source, frequency, bits, channels);
-#endif
 	ALint type;
+
 	alGetSourcei(source, AL_SOURCE_TYPE, &type);
-	if (type == AL_STATIC || checkALError("Cannot get AL source type.", ERROR)) {
+	if (checkALError("Cannot get AL source type.", ERROR) || type == AL_STATIC) {
 		Log(ERROR, "OpenAL", "Cannot queue a buffer to a static source.");
 		return GEM_ERROR;
 	}
@@ -975,23 +1145,11 @@ int OpenALAudioDriver::QueueALBuffer(ALuint source, ALuint buffer) const
 		return GEM_ERROR;
 	}
 
-	ALenum state;
-	alGetSourcei(source, AL_SOURCE_STATE, &state);
-	if (checkALError("Unable to query source state", ERROR)) {
-		return GEM_ERROR;
-	}
-
-	// queueing always implies playing for us
-	if (state != AL_PLAYING ) {
-		alSourcePlay(source);
-		if (checkALError("Unable to play source", ERROR)) {
-			return GEM_ERROR;
-		}
-	}
 	return GEM_OK;
 }
 
-void OpenALAudioDriver::UpdateMapAmbient(const MapReverbProperties& props) {
+void OpenALAudioDriver::UpdateMapAmbient(const MapReverbProperties& props)
+{
 	if (hasEFX) {
 		reverbProperties = props;
 		hasReverbProperties = true;
@@ -1022,14 +1180,14 @@ void OpenALAudioDriver::UpdateMapAmbient(const MapReverbProperties& props) {
 		alAuxiliaryEffectSloti(efxEffectSlot, AL_EFFECTSLOT_EFFECT, efxEffect);
 #else
 		// avoid warnings for unused members
-		(void)efxEffectSlot;
-		(void)efxEffect;
+		(void) efxEffectSlot;
+		(void) efxEffect;
 #endif
 	}
 }
 
 #ifdef __clang__
-#pragma clang diagnostic pop
+	#pragma clang diagnostic pop
 #endif
 
 #include "plugindef.h"
