@@ -21,47 +21,48 @@
 #ifndef OPENALAUDIO_H_INCLUDED
 #define OPENALAUDIO_H_INCLUDED
 
-#include "Audio.h"
-
-#include "AmbientMgr.h"
-
 #include "ie_types.h"
 
+#include "AmbientMgr.h"
+#include "Audio.h"
 #include "LRUCache.h"
 #include "MusicMgr.h"
 #include "SoundMgr.h"
+
 #include "Streams/FileStream.h"
 
 #include <mutex>
 #include <thread>
+#include <utility>
 
 #if __APPLE__
-#include <OpenAL/OpenAL.h> // umbrella include for all the headers we want
+	#include <OpenAL/OpenAL.h> // umbrella include for all the headers we want
 #else
-#include "al.h"
-#include "alc.h"
-#ifdef HAVE_OPENAL_EFX_H
-# include "efx.h"
-#endif
+	#include "al.h"
+	#include "alc.h"
+	#ifdef HAVE_OPENAL_EFX_H
+		#include "efx.h"
+	#endif
 #endif
 
-#define RETRY 5
-#define BUFFER_CACHE_SIZE 100
-#define MAX_STREAMS 30
-#define MUSICBUFFERS 10
+#define RETRY              5
+#define BUFFER_CACHE_SIZE  100
+#define MAX_STREAMS        30
+#define MUSICBUFFERS       10
 #define REFERENCE_DISTANCE 50
-#define ACM_BUFFERSIZE 8192
+#define ACM_BUFFERSIZE     8192
 
-#define LISTENER_HEIGHT 100.0f
+#define LISTENER_HEIGHT 200.0f
 
 namespace GemRB {
 
 class OpenALSoundHandle : public SoundHandle {
 protected:
-	struct AudioStream *parent;
+	struct AudioStream* parent;
 
 public:
-	explicit OpenALSoundHandle(AudioStream *p) : parent(p) { }
+	explicit OpenALSoundHandle(AudioStream* p)
+		: parent(p) {}
 	void SetPos(const Point&) override;
 	bool Playing() override;
 	void Stop() override;
@@ -69,9 +70,13 @@ public:
 	void Invalidate() { parent = 0; }
 };
 
+using OpenALuintPair = std::pair<ALuint, ALuint>;
+
 struct AudioStream {
-	ALuint Buffer = 0;
-	ALuint Source = 0;
+	// Spatial stereo is laid out as two sources and buffers,
+	// for every other case, just the first value is relevant.
+	OpenALuintPair buffers = { 0, 0 };
+	OpenALuintPair sources = { 0, 0 };
 	int Duration = 0;
 	bool free = true;
 	bool ambient = false;
@@ -79,45 +84,67 @@ struct AudioStream {
 	bool delete_buffers = false;
 
 	void ClearIfStopped();
+	bool ClearIfStopped(ALuint source);
 	void ClearProcessedBuffers() const;
+	void ClearProcessedBuffers(ALuint source) const;
 	void ForceClear();
+	void SetPitch(int pitch) const;
+	void SetPos(const Point&) const;
+	void SetVolume(int volume) const;
+	void StopLooping() const;
+	void Stop() const;
+	void Stop(ALuint source) const;
 
 	Holder<OpenALSoundHandle> handle;
 };
 
 struct CacheEntry {
-	ALuint Buffer;
+	OpenALuintPair Buffer;
 	tick_t Length;
 
-	CacheEntry(ALuint buffer, tick_t length) : Buffer(buffer), Length(length) {}
+	CacheEntry(OpenALuintPair buffer, tick_t length)
+		: Buffer(buffer), Length(length) {}
 	CacheEntry(const CacheEntry&) = delete;
-	CacheEntry(CacheEntry && other) noexcept : Buffer(other.Buffer), Length(other.Length) {
-		other.Buffer = 0;
+	CacheEntry(CacheEntry&& other) noexcept
+		: Buffer(other.Buffer), Length(other.Length)
+	{
+		other.Buffer = { 0, 0 };
 	}
 	CacheEntry& operator=(const CacheEntry&) = delete;
-	CacheEntry& operator=(CacheEntry && other) noexcept {
+	CacheEntry& operator=(CacheEntry&& other) noexcept
+	{
 		this->Buffer = other.Buffer;
-		other.Buffer = 0;
+		other.Buffer = { 0, 0 };
 		this->Length = other.Length;
 
 		return *this;
 	}
 
-	void evictionNotice() {
-		Buffer = 0;
+	void evictionNotice()
+	{
+		Buffer = { 0, 0 };
 	}
 
-	~CacheEntry() {
-		if (Buffer != 0) {
-			alDeleteBuffers(1, &Buffer);
+	~CacheEntry()
+	{
+		alDeleteBuffers(1, &Buffer.first);
+		if (Buffer.second != 0) {
+			alDeleteBuffers(1, &Buffer.second);
 		}
 	}
 };
 
 struct OpenALPlaying {
-	bool operator()(const CacheEntry& entry) const {
-		alDeleteBuffers(1, &entry.Buffer);
-		return alGetError() == AL_NO_ERROR;
+	bool operator()(const CacheEntry& entry) const
+	{
+		alDeleteBuffers(1, &entry.Buffer.first);
+		bool success = alGetError() == AL_NO_ERROR;
+
+		if (success && entry.Buffer.second) {
+			alDeleteBuffers(1, &entry.Buffer.second);
+		}
+
+		return success;
 	}
 };
 
@@ -127,30 +154,32 @@ public:
 	~OpenALAudioDriver(void) override;
 	void PrintDeviceList() const;
 	bool Init(void) override;
-	Holder<SoundHandle> Play(StringView ResRef, unsigned int channel,
-					const Point&, unsigned int flags = 0,
-					tick_t *length = nullptr) override;
+	Holder<SoundHandle> Play(StringView ResRef, SFXChannel channel,
+				 const Point&, unsigned int flags = 0,
+				 tick_t* length = nullptr) override;
 	void UpdateVolume(unsigned int flags) override;
 	bool CanPlay() override;
-	void ResetMusics() override;
+	void ResetMusics() final;
 	bool Play() override;
 	bool Stop() override;
 	bool Pause() override;
 	bool Resume() override;
-	int CreateStream(std::shared_ptr<SoundMgr>) override;
+	int CreateStream(ResourceHolder<SoundMgr>) override;
 	void UpdateListenerPos(const Point&) override;
 	Point GetListenerPos() override;
 	bool ReleaseStream(int stream, bool HardStop) override;
 	int SetupNewStream(int x, int y, int z,
-					ieWord gain, bool point, int ambientRange) override;
-	tick_t QueueAmbient(int stream, const ResRef& sound) override;
+			   ieWord gain, bool point, int ambientRange) override;
+	tick_t QueueAmbient(int stream, const ResRef& sound, bool spatial) override;
 	void SetAmbientStreamVolume(int stream, int volume) override;
 	void SetAmbientStreamPitch(int stream, int pitch) override;
 	void QueueBuffer(int stream, unsigned short bits,
-				int channels, short* memory,
-				int size, int samplerate) override;
+			 int channels, short* memory,
+			 int size, int samplerate) override;
 	void UpdateMapAmbient(const MapReverbProperties&) override;
+
 private:
+	int QueueALBuffers(OpenALuintPair source, OpenALuintPair buffer) const;
 	int QueueALBuffer(ALuint source, ALuint buffer) const;
 
 private:
@@ -158,15 +187,15 @@ private:
 	ALuint MusicSource = 0;
 	bool MusicPlaying = false;
 	std::recursive_mutex musicMutex;
-	ALuint MusicBuffer[MUSICBUFFERS]{};
-	std::shared_ptr<SoundMgr> MusicReader;
-	LRUCache<CacheEntry, OpenALPlaying> buffercache{BUFFER_CACHE_SIZE};
+	ALuint MusicBuffer[MUSICBUFFERS] {};
+	ResourceHolder<SoundMgr> MusicReader;
+	LRUCache<CacheEntry, OpenALPlaying> buffercache { BUFFER_CACHE_SIZE };
 	AudioStream speech;
 	AudioStream streams[MAX_STREAMS];
 	int num_streams = 0;
 
-	std::atomic_bool stayAlive {true};
-	short* music_memory;
+	std::atomic_bool stayAlive { true };
+	std::vector<short> musicBuffer;
 	std::thread musicThread;
 
 	bool hasReverbProperties = false;
@@ -175,7 +204,7 @@ private:
 	ALuint efxEffect = 0;
 	MapReverbProperties reverbProperties;
 
-	ALuint loadSound(StringView ResRef, tick_t &time_length);
+	OpenALuintPair loadSound(StringView ResRef, tick_t& time_length, bool spatial = false);
 	int CountAvailableSources(int limit);
 	bool evictBuffer();
 	void clearBufferCache(bool force);
@@ -183,6 +212,8 @@ private:
 	static int MusicManager(void* args);
 
 	bool InitEFX(void);
+	ALuint CreateAndConfigSource(ALuint source, ieDword volume, ALint loop, unsigned int flags, const Point& p, SFXChannel channel) const;
+	void ConfigSource(ALuint source, ieDword volume, ALint loop, unsigned int flags, const Point& p, SFXChannel channel) const;
 };
 
 }
