@@ -23,16 +23,17 @@
 #include "AmbientMgr.h"
 #include "GameData.h"
 #include "Interface.h" // GetMusicMgr()
-#include "Logging/Logging.h"
 #include "MusicMgr.h"
 #include "SoundMgr.h"
 
+#include "Logging/Logging.h"
+
 #include <SDL.h>
 #include <SDL_mixer.h>
 
 using namespace GemRB;
 
-static void SetChannelPosition(const Point &listenerPos, const Point &p, int channel, float rolloff)
+static void SetChannelPosition(const Point& listenerPos, const Point& p, int channel, float rolloff)
 {
 	int16_t angle = AngleFromPoints(listenerPos, p) * 180 / M_PI - 90;
 	if (angle < 0) {
@@ -59,7 +60,7 @@ bool SDLAudioSoundHandle::Playing()
 
 void SDLAudioSoundHandle::Stop()
 {
-	// Mix_FadeOutChannel is not as agressive sounding (especially when stopping spellcasting) as Mix_HaltChannel
+	// Mix_FadeOutChannel is not as aggressive sounding (especially when stopping spellcasting) as Mix_HaltChannel
 	Mix_FadeOutChannel(chunkChannel, 500);
 }
 
@@ -69,7 +70,8 @@ void SDLAudioSoundHandle::StopLooping()
 	Mix_FadeOutChannel(chunkChannel, 1000);
 }
 
-SDLAudio::SDLAudio(void) : buffercache(BUFFER_CACHE_SIZE)
+SDLAudio::SDLAudio(void)
+	: buffercache(BUFFER_CACHE_SIZE)
 {
 }
 
@@ -81,19 +83,17 @@ SDLAudio::~SDLAudio(void)
 	Mix_HookMusic(NULL, NULL);
 	FreeBuffers();
 	Mix_ChannelFinished(NULL);
+
+	SDL_QuitSubSystem(SDL_INIT_AUDIO);
 }
 
 bool SDLAudio::Init(void)
 {
-	// TODO: we assume SDLVideo already got loaded
 	if (SDL_InitSubSystem(SDL_INIT_AUDIO) < 0) {
+		Log(ERROR, "SDLAudio", "InitSubSystem failed: {}", SDL_GetError());
 		return false;
 	}
-#ifdef RPI
 	if (Mix_OpenAudio(22050, MIX_DEFAULT_FORMAT, 2, 512) < 0) {
-#else
-	if (Mix_OpenAudio(22050, MIX_DEFAULT_FORMAT, 2, 8192) < 0) {
-#endif
 		return false;
 	}
 
@@ -103,22 +103,22 @@ bool SDLAudio::Init(void)
 		return false;
 	}
 
-	Mix_QuerySpec(&audio_rate, (Uint16 *)&audio_format, &audio_channels);
+	Mix_QuerySpec(&audio_rate, (Uint16*) &audio_format, &audio_channels);
 	Mix_ReserveChannels(AMBIENT_CHANNELS + 1); // for speech and ambients
 	ambim = new AmbientMgr();
 
 	return true;
 }
 
-void SDLAudio::SetAudioStreamVolume(uint8_t *stream, int len, int volume)
+void SDLAudio::SetAudioStreamVolume(uint8_t* stream, int len, int volume)
 {
 	// since it's at max volume by default
 	if (volume == MIX_MAX_VOLUME)
 		return;
-	uint8_t *mixData = new uint8_t[len];
+	uint8_t* mixData = new uint8_t[len];
 	memcpy(mixData, stream, len * sizeof(uint8_t));
 	memset(stream, 0, len); // mix audio data against silence
-#if SDL_VERSION_ATLEAST(2,0,0)
+#if SDL_VERSION_ATLEAST(2, 0, 0)
 	SDL_MixAudioFormat(stream, mixData, MIX_DEFAULT_FORMAT, len, MIX_MAX_VOLUME);
 #else
 	SDL_MixAudio(stream, mixData, len, MIX_MAX_VOLUME);
@@ -126,25 +126,25 @@ void SDLAudio::SetAudioStreamVolume(uint8_t *stream, int len, int volume)
 	delete[] mixData;
 }
 
-void SDLAudio::music_callback(void *udata, uint8_t *stream, int len)
+void SDLAudio::music_callback(void* udata, uint8_t* stream, int len)
 {
-	ieDword volume = core->GetVariable("Volume Music", 100);
+	ieDword volume = core->GetDictionary().Get("Volume Music", 100);
 
 	// No point of bothering if it's off anyway
 	if (volume == 0) {
 		return;
 	}
 
-	uint8_t *mixerStream = stream;
+	uint8_t* mixerStream = stream;
 	int mixerLen = len;
 
-	SDLAudio *driver = (SDLAudio *)udata;
+	SDLAudio* driver = (SDLAudio*) udata;
 
 	do {
 		std::lock_guard<std::recursive_mutex> l(driver->MusicMutex);
 
 		int num_samples = len / 2;
-		int cnt = driver->MusicReader->read_samples(( short* ) stream, num_samples);
+		int cnt = driver->MusicReader->read_samples((short*) stream, num_samples);
 
 		// Done?
 		if (cnt == num_samples)
@@ -163,14 +163,14 @@ void SDLAudio::music_callback(void *udata, uint8_t *stream, int len)
 			Mix_HookMusic(NULL, NULL);
 			break;
 		}
-	} while(true);
+	} while (true);
 
 	SetAudioStreamVolume(mixerStream, mixerLen, MIX_MAX_VOLUME * volume / 100);
 }
 
-Mix_Chunk* SDLAudio::loadSound(StringView ResRef, tick_t &time_length)
+Mix_Chunk* SDLAudio::loadSound(StringView ResRef, tick_t& time_length)
 {
-	Mix_Chunk *chunk = nullptr;
+	Mix_Chunk* chunk = nullptr;
 
 	if (ResRef.empty()) {
 		return chunk;
@@ -191,18 +191,18 @@ Mix_Chunk* SDLAudio::loadSound(StringView ResRef, tick_t &time_length)
 	int riff_chans = acm->get_channels();
 	int samplerate = acm->get_samplerate();
 	// Use 16-bit word for memory allocation because read_samples takes a 16 bit alignment
-	short *memory = (short*) malloc(cnt*2);
+	short* memory = (short*) malloc(cnt * 2);
 	//multiply always with 2 because it is in 16 bits
-	int cnt1 = acm->read_samples( memory, cnt ) * 2;
+	int cnt1 = acm->read_samples(memory, cnt) * 2;
 	//Sound Length in milliseconds
 	time_length = ((cnt / riff_chans) * 1000) / samplerate;
 
 	// convert our buffer, if necessary
 	SDL_AudioCVT cvt;
 	SDL_BuildAudioCVT(&cvt, AUDIO_S16SYS, riff_chans, samplerate,
-			audio_format, audio_channels, audio_rate);
-	cvt.buf = (Uint8*)malloc(cnt1*cvt.len_mult);
-	memcpy(cvt.buf, (char*)memory, cnt1);
+			  audio_format, audio_channels, audio_rate);
+	cvt.buf = (Uint8*) malloc(cnt1 * cvt.len_mult);
+	memcpy(cvt.buf, (char*) memory, cnt1);
 	cvt.len = cnt1;
 	SDL_ConvertAudio(&cvt);
 
@@ -210,7 +210,7 @@ Mix_Chunk* SDLAudio::loadSound(StringView ResRef, tick_t &time_length)
 	free(memory);
 
 	// make SDL_mixer chunk
-	chunk = Mix_QuickLoad_RAW(cvt.buf, cvt.len*cvt.len_ratio);
+	chunk = Mix_QuickLoad_RAW(cvt.buf, cvt.len * cvt.len_ratio);
 	if (!chunk) {
 		Log(ERROR, "SDLAudio", "Error loading chunk!");
 		free(cvt.buf);
@@ -222,10 +222,10 @@ Mix_Chunk* SDLAudio::loadSound(StringView ResRef, tick_t &time_length)
 	return chunk;
 }
 
-Holder<SoundHandle> SDLAudio::Play(StringView ResRef, unsigned int channel,
-	const Point& p, unsigned int flags, tick_t *length)
+Holder<SoundHandle> SDLAudio::Play(StringView ResRef, SFXChannel channel,
+				   const Point& p, unsigned int flags, tick_t* length)
 {
-	Mix_Chunk *chunk;
+	Mix_Chunk* chunk;
 
 	if (ResRef.empty()) {
 		if (flags & GEM_SND_SPEECH) {
@@ -241,9 +241,9 @@ Holder<SoundHandle> SDLAudio::Play(StringView ResRef, unsigned int channel,
 	if (flags & GEM_SND_SPEECH) {
 		chan = 0;
 		loop = 0; // Speech ignores GEM_SND_LOOPING
-		volume = core->GetVariable("Volume Voices", 100);
+		volume = core->GetDictionary().Get("Volume Voices", 100);
 	} else {
-		volume = core->GetVariable("Volume SFX", 100);
+		volume = core->GetDictionary().Get("Volume SFX", 100);
 	}
 
 	if (volume == 0) {
@@ -269,12 +269,12 @@ Holder<SoundHandle> SDLAudio::Play(StringView ResRef, unsigned int channel,
 	}
 	Mix_Volume(chan, MIX_MAX_VOLUME * volume / 100);
 
-	if (!(flags & GEM_SND_RELATIVE)) {
+	if (flags & GEM_SND_SPATIAL) {
 		SetChannelPosition(listenerPos, p, chan, AUDIO_DISTANCE_ROLLOFF_MOD);
 	}
 
 	// TODO: we need something like static_ptr_cast
-	return Holder<SoundHandle>(new SDLAudioSoundHandle(chunk, chan, flags & GEM_SND_RELATIVE));
+	return Holder<SoundHandle>(new SDLAudioSoundHandle(chunk, SFXChannel(chan), flags));
 }
 
 bool SDLAudio::Pause()
@@ -289,7 +289,7 @@ bool SDLAudio::Resume()
 	return true;
 }
 
-int SDLAudio::CreateStream(std::shared_ptr<SoundMgr> newMusic)
+int SDLAudio::CreateStream(ResourceHolder<SoundMgr> newMusic)
 {
 	std::lock_guard<std::recursive_mutex> l(MusicMutex);
 
@@ -314,7 +314,7 @@ bool SDLAudio::Play()
 		return false;
 	}
 	MusicPlaying = true;
-	Mix_HookMusic((void (*)(void*, Uint8*, int))music_callback, this);
+	Mix_HookMusic((void (*)(void*, Uint8*, int)) music_callback, this);
 	return true;
 }
 
@@ -329,7 +329,7 @@ void SDLAudio::UpdateVolume(unsigned int flags)
 	ieDword volume = 0;
 
 	if (flags & GEM_SND_VOL_AMBIENTS) {
-		volume = core->GetVariable("Volume Ambients", 0);
+		volume = core->GetDictionary().Get("Volume Ambients", 0);
 		((AmbientMgr*) ambim)->UpdateVolume(volume);
 	}
 }
@@ -356,20 +356,20 @@ Point SDLAudio::GetListenerPos()
 	return listenerPos;
 }
 
-void SDLAudio::buffer_callback(void *udata, uint8_t *stream, int len)
+void SDLAudio::buffer_callback(void* udata, uint8_t* stream, int len)
 {
 	// Check only movie volume, since ambiens aren't supported right now
-	ieDword volume = core->GetVariable("Volume Movie", 100);
+	ieDword volume = core->GetDictionary().Get("Volume Movie", 100);
 
 	// No point of bothering if it's off anyway
 	if (volume == 0) {
 		return;
 	}
 
-	uint8_t *mixerStream = stream;
+	uint8_t* mixerStream = stream;
 	int mixerLen = len;
 
-	SDLAudio *driver = (SDLAudio *)udata;
+	SDLAudio* driver = (SDLAudio*) udata;
 	unsigned int remaining = len;
 
 	while (remaining && !driver->buffers.empty()) {
@@ -401,7 +401,7 @@ void SDLAudio::buffer_callback(void *udata, uint8_t *stream, int len)
 }
 
 int SDLAudio::SetupNewStream(int x, int y, int z,
-			ieWord gain, bool point, int ambientRange)
+			     ieWord gain, bool point, int ambientRange)
 {
 	std::lock_guard<std::recursive_mutex> l(MusicMutex);
 
@@ -427,18 +427,18 @@ int SDLAudio::SetupNewStream(int x, int y, int z,
 	}
 
 	// TODO: maybe don't ignore these
-	(void)z;
+	(void) z;
 
 	Log(MESSAGE, "SDLAudio", "SDLAudio allocating stream...");
 
 	// TODO: buggy
 	MusicPlaying = false;
 	curr_buffer_offset = 0;
-	Mix_HookMusic((void (*)(void*, Uint8*, int))buffer_callback, this);
+	Mix_HookMusic((void (*)(void*, Uint8*, int)) buffer_callback, this);
 	return 0;
 }
 
-tick_t SDLAudio::QueueAmbient(int stream, const ResRef& sound)
+tick_t SDLAudio::QueueAmbient(int stream, const ResRef& sound, bool spatial)
 {
 	if (stream <= 0 || stream > AMBIENT_CHANNELS) {
 		return -1;
@@ -449,13 +449,13 @@ tick_t SDLAudio::QueueAmbient(int stream, const ResRef& sound)
 	}
 
 	tick_t time_length;
-	Mix_Chunk *chunk = loadSound(sound, time_length);
+	Mix_Chunk* chunk = loadSound(sound, time_length);
 
 	if (chunk == nullptr) {
 		return -1;
 	}
 
-	if (ambientStreams[stream - 1].point) {
+	if (spatial && ambientStreams[stream - 1].point) {
 		SetChannelPosition(listenerPos, ambientStreams[stream - 1].streamPos, stream, AMBIENT_DISTANCE_ROLLOFF_MOD);
 	}
 	Mix_PlayChannel(stream, chunk, 0);
@@ -480,11 +480,8 @@ bool SDLAudio::ReleaseStream(int stream, bool HardStop)
 
 	Log(MESSAGE, "SDLAudio", "Releasing stream...");
 
-	(void)HardStop;
-
-	assert(!MusicPlaying);
-
-	Mix_HookMusic(NULL, NULL);
+	(void) HardStop;
+	Stop();
 	FreeBuffers();
 
 	return true;
@@ -493,15 +490,15 @@ bool SDLAudio::ReleaseStream(int stream, bool HardStop)
 void SDLAudio::FreeBuffers()
 {
 	std::lock_guard<std::recursive_mutex> l(MusicMutex);
-	for (unsigned int i = 0; i < buffers.size(); i++) {
-		free(buffers[i].buf);
+	for (const auto& buffer : buffers) {
+		free(buffer.buf);
 	}
 	buffers.clear();
 }
 
 void SDLAudio::SetAmbientStreamVolume(int stream, int volume)
 {
- 	Mix_Volume(stream, MIX_MAX_VOLUME * volume  / 100);
+	Mix_Volume(stream, MIX_MAX_VOLUME * volume / 100);
 }
 
 void SDLAudio::SetAmbientStreamPitch(int, int)
@@ -510,7 +507,7 @@ void SDLAudio::SetAmbientStreamPitch(int, int)
 }
 
 void SDLAudio::QueueBuffer(int stream, unsigned short bits,
-			int channels, short* memory, int size, int samplerate)
+			   int channels, short* memory, int size, int samplerate)
 {
 	if (stream != 0) {
 		return;
@@ -524,21 +521,21 @@ void SDLAudio::QueueBuffer(int stream, unsigned short bits,
 	if (bits != 16 || channels != audio_channels || samplerate != audio_rate) {
 		SDL_AudioCVT cvt;
 		if (SDL_BuildAudioCVT(&cvt, (bits == 8 ? AUDIO_S8 : AUDIO_S16SYS), channels, samplerate,
-				audio_format, audio_channels, audio_rate) == 0) {
+				      audio_format, audio_channels, audio_rate) == 0) {
 			Log(ERROR, "SDLAudio", "Couldn't convert video stream! trying to convert {} bits, {} channels, {} rate",
-				bits, channels, samplerate);
+			    bits, channels, samplerate);
 			return;
 		}
-		cvt.buf = (Uint8*)malloc(size*cvt.len_mult);
+		cvt.buf = (Uint8*) malloc(size * cvt.len_mult);
 		memcpy(cvt.buf, memory, size);
 		cvt.len = size;
 		SDL_ConvertAudio(&cvt);
 
-		d.size = cvt.len*cvt.len_ratio;
-		d.buf = (char *)cvt.buf;
+		d.size = cvt.len * cvt.len_ratio;
+		d.buf = (char*) cvt.buf;
 	} else {
 		d.size = size;
-		d.buf = (char *)malloc(d.size);
+		d.buf = (char*) malloc(d.size);
 		memcpy(d.buf, memory, d.size);
 	}
 
