@@ -22,11 +22,10 @@
 
 #include "Game.h"
 #include "Interface.h"
-#include "SDLPixelIterator.h"
-#include "SDLSurfaceSprite2D.h"
 #include "SDL12GamepadMappings.h"
-
+#include "SDLPixelIterator.h"
 #include "SDLSpriteRendererRLE.h"
+#include "SDLSurfaceSprite2D.h"
 
 using namespace GemRB;
 
@@ -39,29 +38,22 @@ SDL12VideoDriver::SDL12VideoDriver() noexcept
 SDL12VideoDriver::~SDL12VideoDriver() noexcept
 {
 	if (gameController != nullptr) {
- 		SDL_JoystickClose(gameController);
+		SDL_JoystickClose(gameController);
 	}
 }
 
 int SDL12VideoDriver::Init(void)
 {
 	int ret = SDLVideoDriver::Init();
-	if (ret==GEM_OK) {
-		SDL_EnableUNICODE( 1 );
-		SDL_EnableKeyRepeat( 500, 50 );
+	if (ret == GEM_OK) {
+		SDL_EnableUNICODE(1);
+		SDL_EnableKeyRepeat(500, 50);
 #if TARGET_OS_MAC
 		// Apple laptops have single buttons,
 		// but actually produce more then left mouse events with that single button
 		// this may limit people actually using very old single button mice, but who cares :)
 		setenv("SDL_HAS3BUTTONMOUSE", "SDL_HAS3BUTTONMOUSE", 1);
 #endif
-		if (SDL_InitSubSystem(SDL_INIT_JOYSTICK) == -1) {
-			Log(ERROR, "SDLJoystick", "InitSubSystem failed: {}", SDL_GetError());
-		} else {
-			if (SDL_NumJoysticks() > 0) {
-				gameController = SDL_JoystickOpen(0);
-			}
-		}
 	}
 
 	if (SDL_InitSubSystem(SDL_INIT_JOYSTICK) == -1) {
@@ -82,8 +74,8 @@ int SDL12VideoDriver::CreateSDLDisplay(const char* title, bool vsync)
 	vsyncRequest = vsync;
 
 	Log(MESSAGE, "SDL 1.2 Driver", "SDL_SetVideoMode...");
-	disp = SDL_SetVideoMode(screenSize.w, screenSize.h, bpp, flags );
-	SDL_WM_SetCaption( title, 0 );
+	disp = SDL_SetVideoMode(screenSize.w, screenSize.h, bpp, flags);
+	SDL_WM_SetCaption(title, 0);
 	if (disp == NULL) {
 		Log(ERROR, "SDL 1.2 Driver", "{}", SDL_GetError());
 		return GEM_ERROR;
@@ -116,7 +108,7 @@ VideoBuffer* SDL12VideoDriver::NewVideoBuffer(const Region& r, BufferFormat fmt)
 			buf = SDL_DisplayFormat(tmp);
 			SDL_FreeSurface(tmp);
 		}
-		
+
 		if (buf == nullptr) {
 			Log(ERROR, "SDL 1.2", "{}", SDL_GetError());
 			return nullptr;
@@ -130,11 +122,11 @@ IAlphaIterator* SDL12VideoDriver::StencilIterator(BlitFlags flags, const Region&
 {
 	struct SurfaceAlphaIterator : RGBAChannelIterator {
 		SDLPixelIteratorWrapper wrap;
-		
+
 		SurfaceAlphaIterator(SDL_Surface* surface, const Region& clip, Uint32 mask, Uint8 shift,
-							 IPixelIterator::Direction x, IPixelIterator::Direction y)
-		: RGBAChannelIterator(wrap.it, mask, shift), wrap(MakeSDLPixelIterator(surface, x, y, clip)) {}
-	} *maskit = nullptr;
+				     IPixelIterator::Direction x, IPixelIterator::Direction y)
+			: RGBAChannelIterator(wrap.it, mask, shift), wrap(MakeSDLPixelIterator(surface, x, y, clip)) {}
+	}* maskit = nullptr;
 
 	if (flags & BlitFlags::STENCIL_MASK) {
 		SDL_Surface* maskSurf = CurrentStencilBuffer();
@@ -142,35 +134,35 @@ IAlphaIterator* SDL12VideoDriver::StencilIterator(BlitFlags flags, const Region&
 
 		Uint32 mask = 0;
 		Uint8 shift = 0;
-		if (flags&BlitFlags::STENCIL_RED) {
+		if (flags & BlitFlags::STENCIL_RED) {
 			mask = fmt->Rmask;
 			shift = fmt->Rshift;
-		} else if (flags&BlitFlags::STENCIL_GREEN) {
+		} else if (flags & BlitFlags::STENCIL_GREEN) {
 			mask = fmt->Gmask;
 			shift = fmt->Gshift;
-		} else if (flags&BlitFlags::STENCIL_BLUE) {
+		} else if (flags & BlitFlags::STENCIL_BLUE) {
 			mask = fmt->Bmask;
 			shift = fmt->Bshift;
 		} else {
 			mask = fmt->Amask;
 			shift = fmt->Ashift;
 		}
-		
+
 		const Point& stencilOrigin = stencilBuffer->Origin();
 		maskclip.x -= stencilOrigin.x;
 		maskclip.y -= stencilOrigin.y;
-		IPixelIterator::Direction xdir = (flags&BlitFlags::MIRRORX) ? IPixelIterator::Reverse : IPixelIterator::Forward;
-		IPixelIterator::Direction ydir = (flags&BlitFlags::MIRRORY) ? IPixelIterator::Reverse : IPixelIterator::Forward;
+		IPixelIterator::Direction xdir = (flags & BlitFlags::MIRRORX) ? IPixelIterator::Reverse : IPixelIterator::Forward;
+		IPixelIterator::Direction ydir = (flags & BlitFlags::MIRRORY) ? IPixelIterator::Reverse : IPixelIterator::Forward;
 		maskit = new SurfaceAlphaIterator(maskSurf, maskclip, mask, shift, xdir, ydir);
 	}
-	
+
 	return maskit;
 }
 
 void SDL12VideoDriver::BlitSpriteRLEClipped(const Holder<Sprite2D>& spr, const Region& src, const Region& dst,
-											BlitFlags flags, const Color* t)
+					    BlitFlags flags, const Color* t)
 {
-	Color tint(255,255,255,255);
+	Color tint(255, 255, 255, 255);
 	if (t) {
 		tint = *t;
 	}
@@ -194,7 +186,7 @@ void SDL12VideoDriver::BlitSpriteRLEClipped(const Holder<Sprite2D>& spr, const R
 
 	// other combinations use general case
 
-	PaletteHolder palette = spr->GetPalette();
+	Holder<Palette> palette = spr->GetPalette();
 	SDL_Surface* currentBuf = CurrentRenderBuffer();
 
 	IAlphaIterator* maskit = StencilIterator(flags, dst);
@@ -203,7 +195,7 @@ void SDL12VideoDriver::BlitSpriteRLEClipped(const Holder<Sprite2D>& spr, const R
 	unsigned int remflags = flags & ~(BlitFlags::BLENDED | BlitFlags::MIRRORX | BlitFlags::MIRRORY | BlitFlags::STENCIL_MASK);
 	if (remflags & BlitFlags::GREY) remflags &= ~BlitFlags::SEPIA;
 
-	// TODO: we technically only need SRBlender_Alpha when there is a mask. Could boost performance noticably to account for that.
+	// TODO: we technically only need SRBlender_Alpha when there is a mask. Could boost performance noticeably to account for that.
 
 	if (remflags == BlitFlags::COLOR_MOD && tint.a == 255) {
 		SRTinter_Tint<true, true> tinter(tint);
@@ -256,7 +248,7 @@ void SDL12VideoDriver::BlitSpriteRLEClipped(const Holder<Sprite2D>& spr, const R
 void SDL12VideoDriver::BlitSpriteNativeClipped(const sprite_t* spr, const Region& srect, const Region& drect, BlitFlags flags, const SDL_Color* tint)
 {
 	Color c;
-	if (tint && (flags & (BlitFlags::COLOR_MOD | BlitFlags::ALPHA_MOD))){
+	if (tint && (flags & (BlitFlags::COLOR_MOD | BlitFlags::ALPHA_MOD))) {
 		c = Color(tint->r, tint->g, tint->b, tint->unused);
 	}
 
@@ -298,47 +290,45 @@ void SDL12VideoDriver::BlitSpriteNativeClipped(const sprite_t* spr, const Region
 	if (flags & BlitFlags::GREY) flags &= ~BlitFlags::SEPIA;
 
 	IAlphaIterator* maskIt = StencilIterator(flags, drect);
-	
+
 	SDL_Surface* surf = spr->GetSurface();
-	bool nativeBlit = (flags & ~(BlitFlags::HALFTRANS | BlitFlags::ALPHA_MOD | BlitFlags::BLENDED)) == 0
-						&& maskIt == nullptr && ((surf->flags & SDL_SRCCOLORKEY) != 0
-						|| (flags & BlitFlags::BLENDED) == 0);
+	bool nativeBlit = (flags & ~(BlitFlags::HALFTRANS | BlitFlags::ALPHA_MOD | BlitFlags::BLENDED)) == 0 && maskIt == nullptr && ((surf->flags & SDL_SRCCOLORKEY) != 0 || (flags & BlitFlags::BLENDED) == 0);
 	if (nativeBlit) {
 		SDL_Rect s = RectFromRegion(srect);
 		SDL_Rect d = RectFromRegion(drect);
 		BlitSpriteNativeClipped(surf, &s, &d, flags, tint);
-	} else {		
-		SDLPixelIterator::Direction xdir = (flags&BlitFlags::MIRRORX) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
-		SDLPixelIterator::Direction ydir = (flags&BlitFlags::MIRRORY) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
+	} else {
+		SDLPixelIterator::Direction xdir = (flags & BlitFlags::MIRRORX) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
+		SDLPixelIterator::Direction ydir = (flags & BlitFlags::MIRRORY) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
 
 		auto src = MakeSDLPixelIterator(surf, xdir, ydir, srect);
 		auto dst = MakeSDLPixelIterator(CurrentRenderBuffer(), SDLPixelIterator::Forward, SDLPixelIterator::Forward, drect);
-		
+
 		BlitWithPipeline(src, dst, maskIt, flags, tint);
 	}
-	
+
 	delete maskIt;
 }
 
 void SDL12VideoDriver::BlitSpriteNativeClipped(SDL_Surface* surf, SDL_Rect* src, SDL_Rect* dst, BlitFlags flags, Color tint)
 {
-	// must be checked afer palette versioning is done
-	
+	// must be checked after palette versioning is done
+
 	// the gamewin is an RGB surface (no alpha)
 	// RGBA->RGB with SDL_SRCALPHA
 	//     The source is alpha-blended with the destination, using the alpha channel. SDL_SRCCOLORKEY and the per-surface alpha are ignored.
 	// RGBA->RGB without SDL_SRCALPHA
 	//     The RGB data is copied from the source. The source alpha channel and the per-surface alpha value are ignored.
-	
+
 	Uint8 alpha = SDL_ALPHA_OPAQUE;
 	if (flags & BlitFlags::ALPHA_MOD) {
 		alpha = tint.a;
 	}
-	
+
 	if (flags & BlitFlags::HALFTRANS) {
 		alpha /= 2;
 	}
-	
+
 	if (flags & BlitFlags::BLENDED) {
 		SDL_SetAlpha(surf, SDL_SRCALPHA, alpha);
 	} else {
@@ -364,29 +354,29 @@ void SDL12VideoDriver::BlitWithPipeline(SDLPixelIterator& src, SDLPixelIterator&
 	// FIXME: this always assumes some kind of blending if any "shader" flags are set
 	// we don't currently have a need for non blended sprites (we do for primitives, which is handled elsewhere)
 	// however, it could make things faster if we handled it
-	
+
 	void (*BlendFn)(const Color& src, Color& dst) = ShaderBlend<true>;
 	if (flags & BlitFlags::ADD) {
 		BlendFn = ShaderAdditive;
 	} else if (flags & BlitFlags::MOD) {
 		BlendFn = ShaderTint;
 	}
-	
+
 	if (flags & (BlitFlags::COLOR_MOD | BlitFlags::ALPHA_MOD)) {
-		if (flags&BlitFlags::GREY) {
+		if (flags & BlitFlags::GREY) {
 			RGBBlendingPipeline<SHADER::GREYSCALE, true> blender(tint, BlendFn);
 			BlitBlendedRect(src, dst, blender, maskIt);
-		} else if (flags&BlitFlags::SEPIA) {
+		} else if (flags & BlitFlags::SEPIA) {
 			RGBBlendingPipeline<SHADER::SEPIA, true> blender(tint, BlendFn);
 			BlitBlendedRect(src, dst, blender, maskIt);
 		} else {
 			RGBBlendingPipeline<SHADER::TINT, true> blender(tint, BlendFn);
 			BlitBlendedRect(src, dst, blender, maskIt);
 		}
-	} else if (flags&BlitFlags::GREY) {
+	} else if (flags & BlitFlags::GREY) {
 		RGBBlendingPipeline<SHADER::GREYSCALE, true> blender(BlendFn);
 		BlitBlendedRect(src, dst, blender, maskIt);
-	} else if (flags&BlitFlags::SEPIA) {
+	} else if (flags & BlitFlags::SEPIA) {
 		RGBBlendingPipeline<SHADER::SEPIA, true> blender(BlendFn);
 		BlitBlendedRect(src, dst, blender, maskIt);
 	} else {
@@ -400,31 +390,30 @@ void SDL12VideoDriver::BlitVideoBuffer(const VideoBufferPtr& buf, const Point& p
 	auto surface = static_cast<SDLSurfaceVideoBuffer&>(*buf).Surface();
 	const Region& r = buf->Rect();
 	Point origin = r.origin + p;
-	
-	bool nativeBlit = (flags & ~(BlitFlags::HALFTRANS | BlitFlags::ALPHA_MOD | BlitFlags::BLENDED)) == 0
-						&& ((surface->flags & SDL_SRCCOLORKEY) != 0 || (flags & BlitFlags::BLENDED) == 0);
+
+	bool nativeBlit = (flags & ~(BlitFlags::HALFTRANS | BlitFlags::ALPHA_MOD | BlitFlags::BLENDED)) == 0 && ((surface->flags & SDL_SRCCOLORKEY) != 0 || (flags & BlitFlags::BLENDED) == 0);
 
 	if (nativeBlit) {
-		SDL_Rect srect = {0, 0, Uint16(r.w), Uint16(r.h)};
-		SDL_Rect drect = {Sint16(origin.x), Sint16(origin.y), Uint16(r.w), Uint16(r.h)};
+		SDL_Rect srect = { 0, 0, Uint16(r.w), Uint16(r.h) };
+		SDL_Rect drect = { Sint16(origin.x), Sint16(origin.y), Uint16(r.w), Uint16(r.h) };
 		BlitSpriteNativeClipped(surface, &srect, &drect, flags, tint);
 	} else {
-		const Region& srect = {Point(), r.size};
-		const Region& drect = {origin, r.size};
+		const Region& srect = { Point(), r.size };
+		const Region& drect = { origin, r.size };
 
-		SDLPixelIterator::Direction xdir = (flags&BlitFlags::MIRRORX) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
-		SDLPixelIterator::Direction ydir = (flags&BlitFlags::MIRRORY) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
+		SDLPixelIterator::Direction xdir = (flags & BlitFlags::MIRRORX) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
+		SDLPixelIterator::Direction ydir = (flags & BlitFlags::MIRRORY) ? SDLPixelIterator::Reverse : SDLPixelIterator::Forward;
 
 		auto src = MakeSDLPixelIterator(surface, xdir, ydir, srect);
 		auto dst = MakeSDLPixelIterator(CurrentRenderBuffer(), SDLPixelIterator::Forward, SDLPixelIterator::Forward, drect);
-		
+
 		BlitWithPipeline(src, dst, nullptr, flags, tint);
 	}
 }
 
-void SDL12VideoDriver::DrawPointImp(const Point& p, const Color& color, BlitFlags flags)
+void SDL12VideoDriver::DrawPointImp(const BasePoint& p, const Color& color, BlitFlags flags)
 {
-	if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+	if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 		DrawPointSurface<SHADER::BLEND>(CurrentRenderBuffer(), p, CurrentRenderClip(), color);
 	} else if (flags & BlitFlags::MOD) {
 		DrawPointSurface<SHADER::TINT>(CurrentRenderBuffer(), p, CurrentRenderClip(), color);
@@ -433,9 +422,9 @@ void SDL12VideoDriver::DrawPointImp(const Point& p, const Color& color, BlitFlag
 	}
 }
 
-void SDL12VideoDriver::DrawPointsImp(const std::vector<Point>& points, const Color& color, BlitFlags flags)
+void SDL12VideoDriver::DrawPointsImp(const std::vector<BasePoint>& points, const Color& color, BlitFlags flags)
 {
-	if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+	if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 		DrawPointsSurface<SHADER::BLEND>(CurrentRenderBuffer(), points, CurrentRenderClip(), color);
 	} else if (flags & BlitFlags::MOD) {
 		DrawPointsSurface<SHADER::TINT>(CurrentRenderBuffer(), points, CurrentRenderClip(), color);
@@ -446,7 +435,7 @@ void SDL12VideoDriver::DrawPointsImp(const std::vector<Point>& points, const Col
 
 void SDL12VideoDriver::DrawSDLPoints(const std::vector<SDL_Point>& points, const SDL_Color& color, BlitFlags flags)
 {
-	if (flags&BlitFlags::BLENDED && color.unused < 0xff) {
+	if (flags & BlitFlags::BLENDED && color.unused < 0xff) {
 		DrawPointsSurface<SHADER::BLEND>(CurrentRenderBuffer(), points, CurrentRenderClip(), reinterpret_cast<const Color&>(color));
 	} else if (flags & BlitFlags::MOD) {
 		DrawPointsSurface<SHADER::TINT>(CurrentRenderBuffer(), points, CurrentRenderClip(), reinterpret_cast<const Color&>(color));
@@ -457,7 +446,7 @@ void SDL12VideoDriver::DrawSDLPoints(const std::vector<SDL_Point>& points, const
 
 void SDL12VideoDriver::DrawPolygonImp(const Gem_Polygon* poly, const Point& origin, const Color& color, bool fill, BlitFlags flags)
 {
-	if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+	if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 		DrawPolygonSurface<SHADER::BLEND>(CurrentRenderBuffer(), poly, origin, CurrentRenderClip(), color, fill);
 	} else if (flags & BlitFlags::MOD) {
 		DrawPolygonSurface<SHADER::TINT>(CurrentRenderBuffer(), poly, origin, CurrentRenderClip(), color, fill);
@@ -466,9 +455,9 @@ void SDL12VideoDriver::DrawPolygonImp(const Gem_Polygon* poly, const Point& orig
 	}
 }
 
-void SDL12VideoDriver::DrawLineImp(const Point& start, const Point& end, const Color& color, BlitFlags flags)
+void SDL12VideoDriver::DrawLineImp(const BasePoint& start, const BasePoint& end, const Color& color, BlitFlags flags)
 {
-	if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+	if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 		DrawLineSurface<SHADER::BLEND>(CurrentRenderBuffer(), start, end, CurrentRenderClip(), color);
 	} else if (flags & BlitFlags::MOD) {
 		DrawLineSurface<SHADER::TINT>(CurrentRenderBuffer(), start, end, CurrentRenderClip(), color);
@@ -479,7 +468,7 @@ void SDL12VideoDriver::DrawLineImp(const Point& start, const Point& end, const C
 
 void SDL12VideoDriver::DrawLinesImp(const std::vector<Point>& points, const Color& color, BlitFlags flags)
 {
-	if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+	if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 		DrawLinesSurface<SHADER::BLEND>(CurrentRenderBuffer(), points, CurrentRenderClip(), color);
 	} else if (flags & BlitFlags::MOD) {
 		DrawLinesSurface<SHADER::TINT>(CurrentRenderBuffer(), points, CurrentRenderClip(), color);
@@ -494,21 +483,21 @@ void SDL12VideoDriver::DrawRectImp(const Region& rgn, const Color& color, bool f
 	SDL_Surface* currentBuf = CurrentRenderBuffer();
 
 	if (fill) {
-		if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+		if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 			assert(rgn.w > 0 && rgn.h > 0);
-			
+
 			const static OneMinusSrcA<false, false> blender;
-			
+
 			Region clippedrgn = ClippedDrawingRect(rgn);
 			auto dstit = MakeSDLPixelIterator(currentBuf, clippedrgn);
 			auto dstend = SDLPixelIterator::end(dstit);
 			ColorFill(color, dstit, dstend, blender);
 		} else {
-			Uint32 val = SDL_MapRGBA( currentBuf->format, color.r, color.g, color.b, color.a );
+			Uint32 val = SDL_MapRGBA(currentBuf->format, color.r, color.g, color.b, color.a);
 			SDL_Rect drect = RectFromRegion(ClippedDrawingRect(rgn));
-			SDL_FillRect( currentBuf, &drect, val );
+			SDL_FillRect(currentBuf, &drect, val);
 		}
-	} else if (flags&BlitFlags::BLENDED && color.a < 0xff) {
+	} else if (flags & BlitFlags::BLENDED && color.a < 0xff) {
 		DrawHLineSurface<SHADER::BLEND>(currentBuf, rgn.origin, rgn.x + rgn.w - 1, screenClip, color);
 		DrawVLineSurface<SHADER::BLEND>(currentBuf, rgn.origin, rgn.y + rgn.h - 1, screenClip, color);
 		DrawHLineSurface<SHADER::BLEND>(currentBuf, Point(rgn.x, rgn.y + rgn.h - 1), rgn.x + rgn.w - 1, screenClip, color);
@@ -531,7 +520,7 @@ void SDL12VideoDriver::DrawRectImp(const Region& rgn, const Color& color, bool f
 // WARNING: SDL 1.2.13 crashes in SetGamma on Windows (it was fixed in SDL's #3533 Revision)
 void SDL12VideoDriver::SetGamma(int brightness, int /*contrast*/)
 {
-	SDL_SetGamma(0.8+brightness/50.0,0.8+brightness/50.0,0.8+brightness/50.0);
+	SDL_SetGamma(0.8 + brightness / 50.0, 0.8 + brightness / 50.0, 0.8 + brightness / 50.0);
 }
 
 bool SDL12VideoDriver::SetFullscreenMode(bool set)
@@ -541,7 +530,7 @@ bool SDL12VideoDriver::SetFullscreenMode(bool set)
 		flags ^= SDL_FULLSCREEN;
 		disp = SDL_SetVideoMode(disp->w, disp->h, disp->format->BitsPerPixel, flags | SDL_SWSURFACE | SDL_ANYFORMAT);
 
-		fullscreen=set;
+		fullscreen = set;
 		return true;
 	}
 	return false;
@@ -555,15 +544,17 @@ void SDL12VideoDriver::SwapBuffers(VideoBuffers& buffers)
 	for (; it != buffers.end(); ++it) {
 		flip = (*it)->RenderOnDisplay(disp) || flip;
 	}
-	
-	if (flip) SDL_Flip( disp );
+
+	if (flip) SDL_Flip(disp);
 }
 
-int SDL12VideoDriver::GetDisplayRefreshRate() const {
+int SDL12VideoDriver::GetDisplayRefreshRate() const
+{
 	return 30;
 }
 
-int SDL12VideoDriver::GetVirtualRefreshCap() const {
+int SDL12VideoDriver::GetVirtualRefreshCap() const
+{
 	// We don't know the value in SDL1, so have it fixed or unlimited
 	return vsyncRequest ? GetDisplayRefreshRate() : 0;
 }
@@ -586,19 +577,19 @@ SDLVideoDriver::vid_buf_t* SDL12VideoDriver::CurrentStencilBuffer() const
 	return std::static_pointer_cast<SDLSurfaceVideoBuffer>(stencilBuffer)->Surface();
 }
 
-Holder<Sprite2D> SDL12VideoDriver::GetScreenshot(Region r,  const VideoBufferPtr& buf)
+Holder<Sprite2D> SDL12VideoDriver::GetScreenshot(Region r, const VideoBufferPtr& buf)
 {
 	unsigned int Width = r.w ? r.w : screenSize.w;
 	unsigned int Height = r.h ? r.h : screenSize.h;
 
 	static const PixelFormat fmt(3, 0x00ff0000, 0x0000ff00, 0x000000ff, 0);
-	SDLSurfaceSprite2D *screenshot = new SDLSurfaceSprite2D(Region(0,0, Width, Height), fmt);
+	SDLSurfaceSprite2D* screenshot = new SDLSurfaceSprite2D(Region(0, 0, Width, Height), fmt);
 	SDL_Rect src = RectFromRegion(r);
 	if (buf) {
 		auto surface = static_cast<SDLSurfaceVideoBuffer&>(*buf).Surface();
-		SDL_BlitSurface( surface, (r.w && r.h) ? &src : NULL, screenshot->GetSurface(), NULL);
+		SDL_BlitSurface(surface, (r.w && r.h) ? &src : NULL, screenshot->GetSurface(), NULL);
 	} else {
-		SDL_BlitSurface( disp, (r.w && r.h) ? &src : NULL, screenshot->GetSurface(), NULL);
+		SDL_BlitSurface(disp, (r.w && r.h) ? &src : NULL, screenshot->GetSurface(), NULL);
 	}
 
 	return Holder<Sprite2D>(screenshot);
@@ -606,12 +597,11 @@ Holder<Sprite2D> SDL12VideoDriver::GetScreenshot(Region r,  const VideoBufferPtr
 
 bool SDL12VideoDriver::ToggleGrabInput()
 {
-	if (SDL_GRAB_OFF == SDL_WM_GrabInput( SDL_GRAB_QUERY )) {
-		SDL_WM_GrabInput( SDL_GRAB_ON );
+	if (SDL_GRAB_OFF == SDL_WM_GrabInput(SDL_GRAB_QUERY)) {
+		SDL_WM_GrabInput(SDL_GRAB_ON);
 		return true;
-	}
-	else {
-		SDL_WM_GrabInput( SDL_GRAB_OFF );
+	} else {
+		SDL_WM_GrabInput(SDL_GRAB_OFF);
 		return false;
 	}
 }
@@ -629,60 +619,59 @@ int SDL12VideoDriver::ProcessEvent(const SDL_Event& event)
 		return GEM_OK;
 	}
 
-	if ((SDL_EVENTMASK(event.type) & (SDL_MOUSEBUTTONDOWNMASK))
-		&& (event.button.button == SDL_BUTTON_WHEELUP || event.button.button == SDL_BUTTON_WHEELDOWN)) {
+	if ((SDL_EVENTMASK(event.type) & (SDL_MOUSEBUTTONDOWNMASK)) && (event.button.button == SDL_BUTTON_WHEELUP || event.button.button == SDL_BUTTON_WHEELDOWN)) {
 		// remap these to mousewheel events
 		int speed = core->GetMouseScrollSpeed();
 		speed *= (event.button.button == SDL_BUTTON_WHEELUP) ? 1 : -1;
 		Event e;
 		if (SDL_GetModState() & KMOD_SHIFT) {
 			e = EventMgr::CreateMouseWheelEvent(Point(speed, 0));
-		} else{
+		} else {
 			e = EventMgr::CreateMouseWheelEvent(Point(0, speed));
 		}
 		EvntManager->DispatchEvent(std::move(e));
 		return GEM_OK;
 	}
-	
+
 	if (InTextInput()) {
 		if (event.type == SDL_KEYDOWN) {
 			int modstate = GetModState(SDL_GetModState());
 			Uint16 chr = event.key.keysym.unicode;
 
 			if (isprint(chr) && modstate <= GEM_MOD_SHIFT) {
-				char text[2] = { (char)chr, '\0' };
+				char text[2] = { (char) chr, '\0' };
 				Event e = EventMgr::CreateTextEvent(text);
 				EvntManager->DispatchEvent(std::move(e));
 				return GEM_OK;
 			}
 		} else if (event.type == SDL_JOYBUTTONDOWN) {
 			Event bsp = EventMgr::CreateKeyEvent(GEM_BACKSP, true);
-			
-			switch(event.jbutton.button) {
-			case SDL_CONTROLLER_BUTTON_DPAD_LEFT:
-				dPadSoftKeyboard.RemoveCharacter();
-				EvntManager->DispatchEvent(std::move(bsp));
-				return GEM_OK;
-			case SDL_CONTROLLER_BUTTON_DPAD_RIGHT:
-				dPadSoftKeyboard.AddCharacter();
-				EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
-				return GEM_OK;
-			case SDL_CONTROLLER_BUTTON_DPAD_DOWN:
-				dPadSoftKeyboard.NextCharacter();
-				EvntManager->DispatchEvent(std::move(bsp));
-				EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
-				return GEM_OK;
-			case SDL_CONTROLLER_BUTTON_DPAD_UP:
-				dPadSoftKeyboard.PreviousCharacter();
-				EvntManager->DispatchEvent(std::move(bsp));
-				EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
-				return GEM_OK;
-			case SDL_CONTROLLER_BUTTON_LEFTSHOULDER:
-			case SDL_CONTROLLER_BUTTON_RIGHTSHOULDER:
-				dPadSoftKeyboard.ToggleUppercase();
-				EvntManager->DispatchEvent(std::move(bsp));
-				EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
-				return GEM_OK;
+
+			switch (event.jbutton.button) {
+				case SDL_CONTROLLER_BUTTON_DPAD_LEFT:
+					dPadSoftKeyboard.RemoveCharacter();
+					EvntManager->DispatchEvent(std::move(bsp));
+					return GEM_OK;
+				case SDL_CONTROLLER_BUTTON_DPAD_RIGHT:
+					dPadSoftKeyboard.AddCharacter();
+					EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
+					return GEM_OK;
+				case SDL_CONTROLLER_BUTTON_DPAD_DOWN:
+					dPadSoftKeyboard.NextCharacter();
+					EvntManager->DispatchEvent(std::move(bsp));
+					EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
+					return GEM_OK;
+				case SDL_CONTROLLER_BUTTON_DPAD_UP:
+					dPadSoftKeyboard.PreviousCharacter();
+					EvntManager->DispatchEvent(std::move(bsp));
+					EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
+					return GEM_OK;
+				case SDL_CONTROLLER_BUTTON_LEFTSHOULDER:
+				case SDL_CONTROLLER_BUTTON_RIGHTSHOULDER:
+					dPadSoftKeyboard.ToggleUppercase();
+					EvntManager->DispatchEvent(std::move(bsp));
+					EvntManager->DispatchEvent(dPadSoftKeyboard.GetTextEvent());
+					return GEM_OK;
 			}
 		}
 	}
