@@ -20,17 +20,25 @@
 
 #include "SDL20Video.h"
 
+#include "Audio.h"
 #include "Interface.h"
 
+#ifdef USE_TRACY
+	#include <tracy/TracyOpenGL.hpp>
+#endif
+
+// don't move this up
+#include <SDL2/SDL_syswm.h>
+
 using namespace GemRB;
 
 #ifdef BAKE_ICON
-#include "gemrb-icon.h"
+	#include "gemrb-icon.h"
 
 static void SetWindowIcon(SDL_Window* window)
 {
 	// gemrb_icon and gemrb_icon_size are generated in gemrb-icon.h
-	SDL_RWops* const iconStream = SDL_RWFromConstMem((void *) gemrb_icon, gemrb_icon_size);
+	SDL_RWops* const iconStream = SDL_RWFromConstMem((void*) gemrb_icon, gemrb_icon_size);
 	if (!iconStream) {
 		Log(WARNING, "SDL 2 Driver", "Failed to create icon stream.");
 		return;
@@ -51,20 +59,20 @@ SDL20VideoDriver::SDL20VideoDriver() noexcept
 	window = NULL;
 
 	stencilAlphaBlender = SDL_ComposeCustomBlendMode(SDL_BLENDFACTOR_ZERO, SDL_BLENDFACTOR_ONE,
-													 SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_ZERO,
-													 SDL_BLENDFACTOR_ONE_MINUS_SRC_ALPHA, SDL_BLENDOPERATION_ADD);
-	
+							 SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_ZERO,
+							 SDL_BLENDFACTOR_ONE_MINUS_SRC_ALPHA, SDL_BLENDOPERATION_ADD);
+
 	oneMinusDstBlender = SDL_ComposeCustomBlendMode(SDL_BLENDFACTOR_ONE_MINUS_DST_COLOR, SDL_BLENDFACTOR_ONE,
-													SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_ONE_MINUS_DST_COLOR,
-													SDL_BLENDFACTOR_ONE, SDL_BLENDOPERATION_ADD);
-	
+							SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_ONE_MINUS_DST_COLOR,
+							SDL_BLENDFACTOR_ONE, SDL_BLENDOPERATION_ADD);
+
 	dstBlender = SDL_ComposeCustomBlendMode(SDL_BLENDFACTOR_DST_COLOR, SDL_BLENDFACTOR_ONE,
-											SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_DST_COLOR,
-											SDL_BLENDFACTOR_ONE, SDL_BLENDOPERATION_ADD);
-	
+						SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_DST_COLOR,
+						SDL_BLENDFACTOR_ONE, SDL_BLENDOPERATION_ADD);
+
 	srcBlender = SDL_ComposeCustomBlendMode(SDL_BLENDFACTOR_SRC_COLOR, SDL_BLENDFACTOR_ONE,
-											SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_SRC_COLOR,
-											SDL_BLENDFACTOR_ONE, SDL_BLENDOPERATION_ADD);
+						SDL_BLENDOPERATION_ADD, SDL_BLENDFACTOR_SRC_COLOR,
+						SDL_BLENDFACTOR_ONE, SDL_BLENDOPERATION_ADD);
 
 	// WARNING: do _not_ call opengl here
 	// all function pointers will be NULL
@@ -77,6 +85,10 @@ SDL20VideoDriver::SDL20VideoDriver() noexcept
 
 SDL20VideoDriver::~SDL20VideoDriver() noexcept
 {
+#if USE_OPENGL_BACKEND
+	delete blitRGBAShader;
+#endif
+
 	if (SDL_GameControllerGetAttached(gameController)) {
 		SDL_GameControllerClose(gameController);
 	}
@@ -88,10 +100,6 @@ SDL20VideoDriver::~SDL20VideoDriver() noexcept
 
 	SDL_DestroyRenderer(renderer);
 	SDL_DestroyWindow(window);
-
-#if USE_OPENGL_BACKEND
-	delete blitRGBAShader;
-#endif
 }
 
 int SDL20VideoDriver::Init()
@@ -120,19 +128,19 @@ int SDL20VideoDriver::Init()
 int SDL20VideoDriver::CreateSDLDisplay(const char* title, bool vsync)
 {
 	Log(MESSAGE, "SDL 2 Driver", "Creating display");
-	SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "best");
+	SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, core->config.ScaleQuality.c_str());
 
 #if USE_OPENGL_BACKEND
-#if USE_OPENGL_API
+	#if USE_OPENGL_API
 	const char* driverName = "opengl";
-#elif USE_GLES_API
+	#elif USE_GLES_API
 	const char* driverName = "opengles2";
-#endif
+	#endif
 	SDL_SetHint(SDL_HINT_RENDER_DRIVER, driverName);
 #endif
 
 #if SDL_VERSION_ATLEAST(2, 0, 10)
-	if (sdl2_runtime_version >= SDL_VERSIONNUM(2,0,10)) {
+	if (sdl2_runtime_version >= SDL_VERSIONNUM(2, 0, 10)) {
 		SDL_SetHint(SDL_HINT_RENDER_BATCHING, "1");
 	}
 #endif
@@ -143,30 +151,34 @@ int SDL20VideoDriver::CreateSDLDisplay(const char* title, bool vsync)
 	SDL_GL_SetAttribute(SDL_GL_CONTEXT_MAJOR_VERSION, 2);
 #endif
 
-
-#ifdef SDL_RESOLUTION_INDEPENDANCE
-	SDL_DisplayMode current;
-
-	int should_be_zero = SDL_GetCurrentDisplayMode(0, &current);
-
-	if (should_be_zero != 0) {
-		Log(ERROR, "SDL 2 Driver", "couldnt get resolution: {}", SDL_GetError());
-		return GEM_ERROR;
-	}
-
-	Log(DEBUG, "SDL 2 Driver", "Game Resolution: {}x{}, Screen Resolution: {}x{}",
-		screenSize.w, screenSize.h, current.w, current.h);
-	window = SDL_CreateWindow(title, SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, current.w, current.h, winFlags);
-#else
-
 	window = SDL_CreateWindow(title, SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, screenSize.w, screenSize.h, winFlags);
-#endif
-
 	if (window == NULL) {
-		Log(ERROR, "SDL 2 Driver", "couldnt create window: {}", SDL_GetError());
+		Log(ERROR, "SDL 2 Driver", "couldn't create window: {}", SDL_GetError());
 		return GEM_ERROR;
 	}
 
+#if SDL_VERSION_ATLEAST(2, 0, 16)
+	// On some slow devices (RPi) it's the fastest to try launching the game from TTY
+	// so SDL2 will do EGL + KMS. Unfortunately, a true fullscreen may be painfully slow
+	// at high resolutions. So instead, do a window at the same aspect ratio instead at next smallest
+	// resolution. Less pixels will gain much more performance while looking identical to a display full screen.
+	//
+	// In a window manager, there is probably little to gain anyway, and more powerful devices won't need anything like this.
+	SDL_SysWMinfo wmInfo;
+	auto infoResult = SDL_GetWindowWMInfo(window, &wmInfo);
+	if (infoResult && wmInfo.subsystem == SDL_SYSWM_KMSDRM) {
+		SDL_DisplayMode currentMode;
+
+		// SDL won't know the display size until it has tried
+		SetFullscreenMode(true);
+		if (SDL_GetCurrentDisplayMode(0, &currentMode) == 0) {
+			CalculateCustomFullscreen(&currentMode);
+			Log(MESSAGE, "SDL2", "Will perform a soft-fullscreen to {}x{}", customFullscreenSize.w, customFullscreenSize.h);
+		}
+		SetFullscreenMode(false);
+	}
+#endif
+
 #ifdef BAKE_ICON
 	SetWindowIcon(window);
 #endif
@@ -180,7 +192,7 @@ int SDL20VideoDriver::CreateSDLDisplay(const char* title, bool vsync)
 
 	// Moved this here to fix a weird rendering issue
 
-	// we set logical size so that platforms where the window can be a diffrent size then requested
+	// we set logical size so that platforms where the window can be a different size then requested
 	// function properly. eg iPhone and Android the requested size may be 640x480,
 	// but the window will always be the size of the screen
 	SDL_RenderSetLogicalSize(renderer, screenSize.w, screenSize.h);
@@ -211,19 +223,21 @@ int SDL20VideoDriver::CreateSDLDisplay(const char* title, bool vsync)
 		return GEM_ERROR;
 	}
 
-#if defined(_WIN32) && defined(USE_OPENGL_API)
+	#if defined(_WIN32) && defined(USE_OPENGL_API)
 	glewInit();
-#endif
+	#endif
+
+	TRACY(TracyGpuContext);
 
 	scratchBuffer = CreateBuffer(Region(Point(), screenSize), BufferFormat::DISPLAY_ALPHA);
 	scratchBuffer->Clear();
 
 	// Try to grab the texture shader program of SDL
-	static const SDL_Rect r = {0, 0, 1, 1};
+	static const SDL_Rect r = { 0, 0, 1, 1 };
 	SDL_RenderCopy(renderer, ScratchBuffer(), &r, &r);
-#if SDL_VERSION_ATLEAST(2, 0, 10)
+	#if SDL_VERSION_ATLEAST(2, 0, 10)
 	SDL_RenderFlush(renderer);
-#endif
+	#endif
 
 	GLuint rgbaProgramID = 0;
 	glGetIntegerv(GL_CURRENT_PROGRAM, reinterpret_cast<GLint*>(&rgbaProgramID));
@@ -256,12 +270,32 @@ int SDL20VideoDriver::CreateSDLDisplay(const char* title, bool vsync)
 	return GEM_OK;
 }
 
+void SDL20VideoDriver::CalculateCustomFullscreen(const SDL_DisplayMode* mode)
+{
+	// Only cover the case when screen is larger than the actual game window
+	if (!(mode->w >= screenSize.w && mode->h >= screenSize.h)) {
+		return;
+	}
+
+	// Only cover the case when width and height have the same alignment in both cases
+	if (!(mode->w / mode->h > 0 && screenSize.w / screenSize.h > 0)) {
+		return;
+	}
+
+	// e. g. display is 1920x1080, game is 1024x768 -> fullscreen window 1366x768
+	auto width = (mode->w * screenSize.h) / mode->h;
+	if (width % 2 != 0) {
+		width += 1;
+	}
+	customFullscreenSize = { width, screenSize.h };
+}
+
 VideoBuffer* SDL20VideoDriver::NewVideoBuffer(const Region& r, BufferFormat fmt)
 {
 	Uint32 format = SDLPixelFormatFromBufferFormat(fmt, renderer);
 	if (format == SDL_PIXELFORMAT_UNKNOWN)
 		return nullptr;
-	
+
 	SDL_Texture* tex = SDL_CreateTexture(renderer, format, SDL_TEXTUREACCESS_TARGET, r.w, r.h);
 	if (tex == nullptr) {
 		Log(ERROR, "SDL 2", "{}", SDL_GetError());
@@ -278,6 +312,8 @@ void SDL20VideoDriver::SwapBuffers(VideoBuffers& buffers)
 	blitRGBAShader->SetUniformValue("u_stencil", 1, 0);
 	blitRGBAShader->SetUniformValue("u_dither", 1, 0);
 	blitRGBAShader->SetUniformValue("u_rgba", 1, 1);
+	blitRGBAShader->SetUniformValue("u_brightness", 1, 1);
+	blitRGBAShader->SetUniformValue("u_contrast", 1, 1);
 #endif
 
 	SDL_SetRenderTarget(renderer, NULL);
@@ -290,7 +326,15 @@ void SDL20VideoDriver::SwapBuffers(VideoBuffers& buffers)
 		(*it)->RenderOnDisplay(renderer);
 	}
 
-	SDL_RenderPresent( renderer );
+	{
+		TRACY(ZoneScopedN("SDL_RenderPresent"));
+		SDL_RenderPresent(renderer);
+	}
+#if USE_OPENGL_BACKEND
+	TRACY(TracyGpuCollect);
+#endif
+
+	TRACY(FrameMark);
 }
 
 SDLVideoDriver::vid_buf_t* SDL20VideoDriver::ScratchBuffer() const
@@ -324,8 +368,7 @@ int SDL20VideoDriver::UpdateRenderTarget(const Color* color, BlitFlags flags)
 		return ret;
 	}
 
-	if (screenClip.size == screenSize)
-	{
+	if (screenClip.size == screenSize) {
 		// Some SDL backends complain on having a clip rect of the entire renderer size
 		// I'm not sure if it is an SDL bug; possibly its just 0 based so it is out of bounds?
 		SDL_RenderSetClipRect(renderer, NULL);
@@ -350,35 +393,24 @@ int SDL20VideoDriver::UpdateRenderTarget(const Color* color, BlitFlags flags)
 
 void SDL20VideoDriver::BlitSpriteNativeClipped(const SDLTextureSprite2D* spr, const Region& src, const Region& dst, BlitFlags flags, const SDL_Color* tint)
 {
-	BlitFlags version = BlitFlags::NONE;
-#if !USE_OPENGL_BACKEND
-	// we need to isolate flags that require software rendering to use as the "version"
-	version = (BlitFlags::GREY | BlitFlags::SEPIA) & flags;
-#endif
-	// WARNING: software fallback == slow
-	if (spr->Format().Bpp == 1 && (flags & BlitFlags::ALPHA_MOD)) {
-		version |= BlitFlags::ALPHA_MOD;
-		flags &= ~spr->RenderWithFlags(version, reinterpret_cast<const Color*>(tint));
-	} else {
-		flags &= ~spr->RenderWithFlags(version);
-	}
-
+	flags &= ~spr->PrepareForRendering(flags, reinterpret_cast<const Color*>(tint));
 	SDL_Texture* tex = spr->GetTexture(renderer);
 	BlitSpriteNativeClipped(tex, src, dst, flags, tint);
 }
 
 void SDL20VideoDriver::BlitSpriteNativeClipped(SDL_Texture* texSprite, const Region& srgn, const Region& drgn, BlitFlags flags, const SDL_Color* tint)
 {
+	TRACY(ZoneScoped);
 	SDL_Rect srect = RectFromRegion(srgn);
 	SDL_Rect drect = RectFromRegion(drgn);
-	
+
 	int ret = 0;
 #if USE_OPENGL_BACKEND
 	UpdateRenderTarget();
 	ret = RenderCopyShaded(texSprite, &srect, &drect, flags, tint);
-#if SDL_VERSION_ATLEAST(2, 0, 10)
+	#if SDL_VERSION_ATLEAST(2, 0, 10)
 	SDL_RenderFlush(renderer);
-#endif
+	#endif
 #else
 	if (flags & BlitFlags::STENCIL_MASK) {
 		// 1. clear scratchpad segment
@@ -390,7 +422,7 @@ void SDL20VideoDriver::BlitSpriteNativeClipped(SDL_Texture* texSprite, const Reg
 
 		SDL_Texture* stencilTex = CurrentStencilBuffer();
 		SDL_SetTextureBlendMode(stencilTex, stencilAlphaBlender);
-		RenderCopyShaded(texSprite, &srect, &drect, flags & ~(BlitFlags::ALPHA_MOD|BlitFlags::HALFTRANS), tint);
+		RenderCopyShaded(texSprite, &srect, &drect, flags & ~(BlitFlags::ALPHA_MOD | BlitFlags::HALFTRANS), tint);
 		// alpha masking only
 		SDL_Rect stencilRect = drect;
 		stencilRect.x -= stencilBuffer->Origin().x;
@@ -402,14 +434,14 @@ void SDL20VideoDriver::BlitSpriteNativeClipped(SDL_Texture* texSprite, const Reg
 			if (flags & BlitFlags::ALPHA_MOD) {
 				alpha = tint->a;
 			}
-			
+
 			if (flags & BlitFlags::HALFTRANS) {
 				alpha /= 2;
 			}
 			SDL_SetTextureAlphaMod(ScratchBuffer(), alpha);
 		}
 		SDL_SetRenderTarget(renderer, CurrentRenderBuffer());
-		SDL_SetTextureBlendMode(ScratchBuffer(), SDL_BLENDMODE_BLEND);
+		SetTextureBlendMode(ScratchBuffer(), flags);
 		ret = SDL_RenderCopy(renderer, ScratchBuffer(), &drect, &drect);
 	} else {
 		UpdateRenderTarget();
@@ -428,26 +460,26 @@ void SDL20VideoDriver::BlitVideoBuffer(const VideoBufferPtr& buf, const Point& p
 	const Region& r = buf->Rect();
 	Point origin = r.origin + p;
 
-	const Region& srect = {0, 0, r.w, r.h};
-	const Region& drect = {origin, r.size};
+	const Region& srect = { 0, 0, r.w, r.h };
+	const Region& drect = { origin, r.size };
 	BlitSpriteNativeClipped(tex, srect, drect, flags, reinterpret_cast<const SDL_Color*>(&tint));
 }
 
 int SDL20VideoDriver::RenderCopyShaded(SDL_Texture* texture, const SDL_Rect* srcrect,
-									   const SDL_Rect* dstrect, BlitFlags flags, const SDL_Color* tint)
+				       const SDL_Rect* dstrect, BlitFlags flags, const SDL_Color* tint)
 {
 #if USE_OPENGL_BACKEND
-#if SDL_VERSION_ATLEAST(2, 0, 10)
+	#if SDL_VERSION_ATLEAST(2, 0, 10)
 	SDL_RenderFlush(renderer);
-#endif
+	#endif
 
 	uint32_t format = 0;
 	SDL_QueryTexture(texture, &format, nullptr, nullptr, nullptr);
 	blitRGBAShader->Use();
-	
+
 	blitRGBAShader->SetUniformValue("s_sprite", 1, 0);
 	blitRGBAShader->SetUniformValue("s_stencil", 1, 1);
-	
+
 	bool isRGBA = SDL_ISPIXELFORMAT_ALPHA(format);
 	blitRGBAShader->SetUniformValue("u_rgba", 1, isRGBA ? 1 : 0);
 
@@ -460,6 +492,9 @@ int SDL20VideoDriver::RenderCopyShaded(SDL_Texture* texture, const SDL_Rect* src
 
 	blitRGBAShader->SetUniformValue("u_greyMode", 1, greyMode);
 
+	blitRGBAShader->SetUniformValue("u_brightness", 1, brightness);
+	blitRGBAShader->SetUniformValue("u_contrast", 1, contrast);
+
 	GLint channel = 3;
 	if (flags & BlitFlags::STENCIL_RED) {
 		channel = 0;
@@ -480,66 +515,70 @@ int SDL20VideoDriver::RenderCopyShaded(SDL_Texture* texture, const SDL_Rect* src
 		bool doDither = flags & BlitFlags::STENCIL_DITHER;
 		blitRGBAShader->SetUniformValue("u_dither", 1, doDither ? 1 : 0);
 
-		int texW = 0, texH = 0;
+		int texW = 0;
+		int texH = 0;
 		SDL_QueryTexture(CurrentStencilBuffer(), nullptr, nullptr, &texW, &texH);
 
-		GLfloat stencilTexW = 1.0f, stencilTexH = 1.0f,
-			stencilTexX = 0.0f, stencilTexY = 0.0f;
+		GLfloat stencilTexW = 1.0f;
+		GLfloat stencilTexH = 1.0f;
+		GLfloat stencilTexX = 0.0f;
+		GLfloat stencilTexY = 0.0f;
 
-		float scaleX = 0.0f, scaleY = 0.0f;
+		float scaleX = 0.0f;
+		float scaleY = 0.0f;
 		SDL_RenderGetScale(renderer, &scaleX, &scaleY);
-		
+
 		SDL_Rect stencilRect = *dstrect;
 		stencilRect.x -= stencilBuffer->Origin().x;
 		stencilRect.y -= stencilBuffer->Origin().y;
 
 		if (stencilRect.x < dstrect->x && stencilRect.y < dstrect->y) {
-			stencilTexX = -dstrect->x;
-			stencilTexY = -dstrect->y;
+			stencilTexX = -static_cast<GLfloat>(dstrect->x);
+			stencilTexY = -static_cast<GLfloat>(dstrect->y);
 		}
 
-#if !SDL_VERSION_ATLEAST(2, 0, 18)
-		// In versions earler, SDL uses a different vertex setup in case
+	#if !SDL_VERSION_ATLEAST(2, 0, 18)
+		// In versions earlier, SDL uses a different vertex setup in case
 		// of flipping: (-w/2, -h/2) to (w/2, h/2) that are transformed by
 		// the OpenGL backend via matrices.
 		if (flags & BlitFlags::MIRRORX) {
 			stencilTexX = dstrect->w / 2.0f + stencilRect.x;
 			stencilTexY = dstrect->h / 2.0f + stencilRect.y;
 		}
-#endif
+	#endif
 
-		stencilTexW = 1.0f / (texW * scaleX);
-		stencilTexH = 1.0f / (texH * scaleY);
+		stencilTexW = 1.0f / (static_cast<float>(texW) * scaleX);
+		stencilTexH = 1.0f / (static_cast<float>(texH) * scaleY);
 
 		GLfloat mat[3][3] = {
-			{ stencilTexW,        0.0f, 0.0f },
-			{        0.0f, stencilTexH, 0.0f },
+			{ stencilTexW, 0.0f, 0.0f },
+			{ 0.0f, stencilTexH, 0.0f },
 			{ stencilTexX * stencilTexW, stencilTexY * stencilTexH, 1.0f }
 		};
 
 		blitRGBAShader->SetUniformMatrixValue("u_stencilMat", 3, 1, reinterpret_cast<GLfloat*>(&mat));
-		
+
 		// Ask OpenGL about the texture handle (that lies hidden in SDL_Texture otherwise)
-		auto texture = std::static_pointer_cast<SDLTextureVideoBuffer>(stencilBuffer)->GetTexture();
-		SDL_GL_BindTexture(texture, nullptr, nullptr);
+		auto curTexture = std::static_pointer_cast<SDLTextureVideoBuffer>(stencilBuffer)->GetTexture();
+		SDL_GL_BindTexture(curTexture, nullptr, nullptr);
 		GLuint stencilTextureID;
 		glGetIntegerv(GL_TEXTURE_BINDING_2D, reinterpret_cast<GLint*>(&stencilTextureID));
-		SDL_GL_UnbindTexture(texture);
+		SDL_GL_UnbindTexture(curTexture);
 
 		glActiveTexture(GL_TEXTURE1);
 		glBindTexture(GL_TEXTURE_2D, stencilTextureID);
 	}
 #endif
-	
+
 	Uint8 alpha = SDL_ALPHA_OPAQUE;
 	if (flags & BlitFlags::ALPHA_MOD) {
 		alpha = tint->a;
 	}
-	
+
 	if (flags & BlitFlags::HALFTRANS) {
 		alpha /= 2;
 	}
-	
+
 	SDL_SetTextureAlphaMod(texture, alpha);
 
 	if (flags & BlitFlags::COLOR_MOD) {
@@ -547,7 +586,17 @@ int SDL20VideoDriver::RenderCopyShaded(SDL_Texture* texture, const SDL_Rect* src
 	} else {
 		SDL_SetTextureColorMod(texture, 0xff, 0xff, 0xff);
 	}
-	
+
+	SetTextureBlendMode(texture, flags);
+
+	SDL_RendererFlip flipflags = (flags & BlitFlags::MIRRORY) ? SDL_FLIP_VERTICAL : SDL_FLIP_NONE;
+	flipflags = static_cast<SDL_RendererFlip>(flipflags | ((flags & BlitFlags::MIRRORX) ? SDL_FLIP_HORIZONTAL : SDL_FLIP_NONE));
+
+	return SDL_RenderCopyEx(renderer, texture, srcrect, dstrect, 0.0, nullptr, flipflags);
+}
+
+void SDL20VideoDriver::SetTextureBlendMode(SDL_Texture* texture, BlitFlags flags) const
+{
 	if (flags & BlitFlags::ADD) {
 		SDL_SetTextureBlendMode(texture, SDL_BLENDMODE_ADD);
 	} else if (flags & BlitFlags::MOD) {
@@ -567,45 +616,47 @@ int SDL20VideoDriver::RenderCopyShaded(SDL_Texture* texture, const SDL_Rect* src
 	} else {
 		SDL_SetTextureBlendMode(texture, SDL_BLENDMODE_NONE);
 	}
-
-	SDL_RendererFlip flipflags = (flags & BlitFlags::MIRRORY) ? SDL_FLIP_VERTICAL : SDL_FLIP_NONE;
-	flipflags = static_cast<SDL_RendererFlip>(flipflags | ((flags & BlitFlags::MIRRORX) ? SDL_FLIP_HORIZONTAL : SDL_FLIP_NONE));
-
-	return SDL_RenderCopyEx(renderer, texture, srcrect, dstrect, 0.0, nullptr, flipflags);
 }
 
 void SDL20VideoDriver::DrawRawGeometry(
 	const std::vector<float>& vertices,
 	const std::vector<Color>& colors,
-	BlitFlags blitFlags
-) {
+	BlitFlags blitFlags)
+{
 #if SDL_VERSION_ATLEAST(2, 0, 18)
 	if (blitFlags & BlitFlags::BLENDED) {
 		SDL_SetRenderDrawBlendMode(renderer, SDL_BLENDMODE_BLEND);
 	}
 
+	#if !SDL_VERSION_ATLEAST(2, 0, 20)
+	static_assert(sizeof(int) == sizeof(SDL_Color), "Incompatible types to cast");
+	#endif
+
 	SDL_RenderGeometryRaw(
 		renderer,
 		nullptr,
 		vertices.data(),
 		2 * sizeof(float),
+	#if SDL_VERSION_ATLEAST(2, 0, 20)
 		reinterpret_cast<const SDL_Color*>(colors.data()),
+	#else
+		reinterpret_cast<const int*>(colors.data()),
+	#endif
 		sizeof(Color),
 		nullptr,
 		0,
 		vertices.size() / 2,
 		nullptr,
 		0,
-		0
-	);
+		0);
 #else
-	(void)vertices;
-	(void)colors;
-	(void)blitFlags;
+	(void) vertices;
+	(void) colors;
+	(void) blitFlags;
 #endif
 }
 
-void SDL20VideoDriver::DrawPointsImp(const std::vector<Point>& points, const Color& color, BlitFlags flags)
+void SDL20VideoDriver::DrawPointsImp(const std::vector<BasePoint>& points, const Color& color, BlitFlags flags)
 {
 	DrawSDLPoints(reinterpret_cast<const std::vector<SDL_Point>&>(points), reinterpret_cast<const SDL_Color&>(color), flags);
 }
@@ -619,7 +670,7 @@ void SDL20VideoDriver::DrawSDLPoints(const std::vector<SDL_Point>& points, const
 	SDL_RenderDrawPoints(renderer, &points[0], int(points.size()));
 }
 
-void SDL20VideoDriver::DrawPointImp(const Point& p, const Color& color, BlitFlags flags)
+void SDL20VideoDriver::DrawPointImp(const BasePoint& p, const Color& color, BlitFlags flags)
 {
 	UpdateRenderTarget(&color, flags);
 	SDL_RenderDrawPoint(renderer, p.x, p.y);
@@ -636,7 +687,7 @@ void SDL20VideoDriver::DrawSDLLines(const std::vector<SDL_Point>& points, const
 	SDL_RenderDrawLines(renderer, &points[0], int(points.size()));
 }
 
-void SDL20VideoDriver::DrawLineImp(const Point& p1, const Point& p2, const Color& color, BlitFlags flags)
+void SDL20VideoDriver::DrawLineImp(const BasePoint& p1, const BasePoint& p2, const Color& color, BlitFlags flags)
 {
 	UpdateRenderTarget(&color, flags);
 	SDL_RenderDrawLine(renderer, p1.x, p1.y, p2.x, p2.y);
@@ -657,8 +708,7 @@ void SDL20VideoDriver::DrawPolygonImp(const Gem_Polygon* poly, const Point& orig
 	if (fill) {
 		UpdateRenderTarget(&color, flags);
 
-		for (const auto& lineSegments : poly->rasterData)
-		{
+		for (const auto& lineSegments : poly->rasterData) {
 			for (const auto& segment : lineSegments) {
 				// SDL_RenderDrawLines actually is for drawing polygons so it is, ironically, not what we want
 				// when drawing the "rasterized" data. doing so would work ok most of the time, but other times
@@ -692,7 +742,7 @@ Holder<Sprite2D> SDL20VideoDriver::GetScreenshot(Region r, const VideoBufferPtr&
 	unsigned int Height = r.h ? r.h : screenSize.h;
 
 	static const PixelFormat fmt(3, 0x00ff0000, 0x0000ff00, 0x000000ff, 0);
-	SDLTextureSprite2D* screenshot = new SDLTextureSprite2D(Region(0,0, Width, Height), fmt);
+	SDLTextureSprite2D* screenshot = new SDLTextureSprite2D(Region(0, 0, Width, Height), fmt);
 
 	SDL_Texture* target = SDL_GetRenderTarget(renderer);
 	if (buf) {
@@ -710,7 +760,7 @@ Holder<Sprite2D> SDL20VideoDriver::GetScreenshot(Region r, const VideoBufferPtr&
 	return Holder<Sprite2D>(screenshot);
 }
 
-int SDL20VideoDriver::GetTouchFingers(TouchEvent::Finger(&fingers)[FINGER_MAX], SDL_TouchID device) const
+int SDL20VideoDriver::GetTouchFingers(TouchEvent::Finger (&fingers)[FINGER_MAX], SDL_TouchID device) const
 {
 	int numf = SDL_GetNumTouchFingers(device);
 
@@ -722,7 +772,7 @@ int SDL20VideoDriver::GetTouchFingers(TouchEvent::Finger(&fingers)[FINGER_MAX],
 		fingers[i].x = finger->x * screenSize.w;
 		fingers[i].y = finger->y * screenSize.h;
 
-		const TouchEvent::Finger* current = EvntManager->FingerState(finger->id);
+		const TouchEvent::Finger* current = EventMgr::FingerState(finger->id);
 		if (current) {
 			fingers[i].deltaX = fingers[i].x - current->x;
 			fingers[i].deltaY = fingers[i].y - current->y;
@@ -732,7 +782,7 @@ int SDL20VideoDriver::GetTouchFingers(TouchEvent::Finger(&fingers)[FINGER_MAX],
 	return numf;
 }
 
-int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
+int SDL20VideoDriver::ProcessEvent(const SDL_Event& event)
 {
 	int modstate = GetModState(SDL_GetModState());
 	Event e;
@@ -741,7 +791,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 #ifdef USE_SDL_CONTROLLER_API
 		case SDL_CONTROLLERDEVICEREMOVED:
 			if (gameController != nullptr) {
-				const SDL_GameController *removedController = SDL_GameControllerFromInstanceID(event.jdevice.which);
+				const SDL_GameController* removedController = SDL_GameControllerFromInstanceID(event.jdevice.which);
 				if (removedController == gameController) {
 					SDL_GameControllerClose(gameController);
 					gameController = nullptr;
@@ -761,7 +811,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 				// FIXME: I'm sure this delta needs to be scaled
 				int delta = xaxis ? pct * screenSize.w : pct * screenSize.h;
 				InputAxis axis = InputAxis(event.caxis.axis);
-				e = EvntManager->CreateControllerAxisEvent(axis, delta, pct);
+				e = EventMgr::CreateControllerAxisEvent(axis, delta, pct);
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
@@ -770,35 +820,35 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 			{
 				bool down = (event.type == SDL_JOYBUTTONDOWN) ? true : false;
 				EventButton btn = EventButton(event.cbutton.button);
-				e = EvntManager->CreateControllerButtonEvent(btn, down);
+				e = EventMgr::CreateControllerButtonEvent(btn, down);
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
 #endif
-		case SDL_FINGERDOWN: // fallthough
+		case SDL_FINGERDOWN: // fallthrough
 		case SDL_FINGERUP:
 			{
-				TouchEvent::Finger fingers[1] = { };
+				TouchEvent::Finger fingers[1] = {};
 				fingers[0].x = event.tfinger.x * screenSize.w;
 				fingers[0].y = event.tfinger.y * screenSize.h;
 				fingers[0].deltaX = event.tfinger.dx * screenSize.w;
 				fingers[0].deltaY = event.tfinger.dy * screenSize.h;
 				fingers[0].id = event.tfinger.fingerId;
 
-				e = EvntManager->CreateTouchEvent(fingers, 1, event.type == SDL_FINGERDOWN, event.tfinger.pressure);
+				e = EventMgr::CreateTouchEvent(fingers, 1, event.type == SDL_FINGERDOWN, event.tfinger.pressure);
 				e.mod = modstate;
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
-		// For swipes only. gestures requireing pinch or rotate need to use SDL_MULTIGESTURE or SDL_DOLLARGESTURE
+		// For swipes only. Gestures requiring pinch or rotate need to use SDL_MULTIGESTURE or SDL_DOLLARGESTURE
 		case SDL_FINGERMOTION:
 			{
-				TouchEvent::Finger fingers[FINGER_MAX] = { }; // 0 init
+				TouchEvent::Finger fingers[FINGER_MAX] = {}; // 0 init
 				int numf = GetTouchFingers(fingers, event.mgesture.touchId);
 
-				Event touch = EvntManager->CreateTouchEvent(fingers, numf, true, event.tfinger.pressure);
+				Event touch = EventMgr::CreateTouchEvent(fingers, numf, true, event.tfinger.pressure);
 				// TODO: it may make more sense to calculate a pinch/rotation from screen center?
-				e = EvntManager->CreateTouchGesture(touch.touch, 0.0, 0.0);
+				e = EventMgr::CreateTouchGesture(touch.touch, 0.0, 0.0);
 				e.mod = modstate;
 				EvntManager->DispatchEvent(std::move(e));
 			}
@@ -807,16 +857,15 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 			// TODO: this could be useful for predefining gestures
 			// might work better than manually programming everything
 			break;
-		case SDL_MULTIGESTURE:// use this for pinch or rotate gestures. see also SDL_DOLLARGESTURE
+		case SDL_MULTIGESTURE: // use this for pinch or rotate gestures. see also SDL_DOLLARGESTURE
 			{
-				TouchEvent::Finger fingers[FINGER_MAX] = { }; // 0 init
+				TouchEvent::Finger fingers[FINGER_MAX] = {}; // 0 init
 				int numf = GetTouchFingers(fingers, event.mgesture.touchId);
 
 				// TODO: it may make more sense to calculate the pressure as an avg?
-				Event touch = EvntManager->CreateTouchEvent(fingers, numf, true, 0.0);
-				e = EvntManager->CreateTouchGesture(touch.touch, event.mgesture.dTheta, event.mgesture.dDist);
-				if (e.gesture.deltaX != 0 || e.gesture.deltaY != 0)
-				{
+				Event touch = EventMgr::CreateTouchEvent(fingers, numf, true, 0.0);
+				e = EventMgr::CreateTouchGesture(touch.touch, event.mgesture.dTheta, event.mgesture.dDist);
+				if (e.gesture.deltaX != 0 || e.gesture.deltaY != 0) {
 					e.mod = modstate;
 					EvntManager->DispatchEvent(std::move(e));
 				}
@@ -827,28 +876,28 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 				if (SDL_TOUCH_MOUSEID == event.wheel.which) {
 					break;
 				}
-				
+
 				// HACK: some mouse devices report the delta in pixels, but others (like regular mouse wheels) are going to be in "clicks"
 				// there is no good way to find which is the case so heuristically we will just switch if we see a delta larger than one
-				// hopefully no devices will be merging several repeated whell clicks together
+				// hopefully no devices will be merging several repeated wheel clicks together
 				static bool unitIsPixels = false;
 				if (event.wheel.y > 1 || event.wheel.x > 1) {
 					unitIsPixels = true;
 				}
-				
+
 				int speed = unitIsPixels ? 1 : core->GetMouseScrollSpeed();
 				if (SDL_GetModState() & KMOD_SHIFT) {
-					e = EvntManager->CreateMouseWheelEvent(Point(event.wheel.y * speed, event.wheel.x * speed));
+					e = EventMgr::CreateMouseWheelEvent(Point(event.wheel.y * speed, event.wheel.x * speed));
 				} else {
-					e = EvntManager->CreateMouseWheelEvent(Point(event.wheel.x * speed, event.wheel.y * speed));
+					e = EventMgr::CreateMouseWheelEvent(Point(event.wheel.x * speed, event.wheel.y * speed));
 				}
-				
+
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
 		/* not user input events */
 		case SDL_TEXTINPUT:
-			e = EvntManager->CreateTextEvent(event.text.text);
+			e = EventMgr::CreateTextEvent(event.text.text);
 			EvntManager->DispatchEvent(std::move(e));
 			break;
 		/* not user input events */
@@ -857,32 +906,35 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 		case SDL_RENDER_DEVICE_RESET:
 			// TODO: must destroy all SDLTextureSprite2D textures
 
-			// fallthough
+			// fallthrough
 		case SDL_APP_DIDENTERFOREGROUND:
 		case SDL_RENDER_TARGETS_RESET:
 			e = EventMgr::CreateRedrawRequestEvent();
 			EvntManager->DispatchEvent(std::move(e));
 			break;
-		case SDL_WINDOWEVENT://SDL 1.2
+		case SDL_WINDOWEVENT: //SDL 1.2
 			switch (event.window.event) {
-				case SDL_WINDOWEVENT_MINIMIZED://SDL 1.3
+				case SDL_WINDOWEVENT_LEAVE:
+					if (core->config.GUIEnhancements & 8) core->DisableGameControl(true);
+					break;
+				case SDL_WINDOWEVENT_ENTER:
+					if (core->config.GUIEnhancements & 8) core->DisableGameControl(false);
+					break;
+				case SDL_WINDOWEVENT_MINIMIZED: //SDL 1.3
 					// We pause the game and audio when the window is minimized.
 					// on iOS/Android this happens when leaving the application or when play is interrupted (ex phone call)
 					// but it's annoying on desktops, so we try to detect them
 					if (TouchInputEnabled()) {
-						core->GetAudioDrv()->Pause();//this is for ANDROID mostly
-						core->SetPause(PAUSE_ON);
+						core->GetAudioDrv()->Pause(); //this is for ANDROID mostly
+						core->SetPause(PauseState::On);
 					}
 					break;
 				case SDL_WINDOWEVENT_RESTORED: //SDL 1.3
-					core->GetAudioDrv()->Resume();//this is for ANDROID mostly
+					core->GetAudioDrv()->Resume(); //this is for ANDROID mostly
 					break;
-					/*
-				case SDL_WINDOWEVENT_RESIZED: //SDL 1.2
-					// this event exists in SDL 1.2, but this handler is only getting compiled under 1.3+
-					Log(WARNING, "SDL 2 Driver",  "Window resized so your window surface is now invalid.");
+				// SDL_WINDOWEVENT_RESIZED and SDL_WINDOWEVENT_SIZE_CHANGED are handled automatically
+				default:
 					break;
-					 */
 			}
 			break;
 
@@ -901,15 +953,12 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 				 * As being SDL2-only, try to query the clipboard state to
 				 * paste when middle clicking the mouse.
 				 */
-				
-				if (event.button.button == SDL_BUTTON_MIDDLE
-					&& event.type == SDL_MOUSEBUTTONDOWN
-					&& SDL_HasClipboardText()
-				) {
-					char *pasteValue = SDL_GetClipboardText();
+
+				if (event.button.button == SDL_BUTTON_MIDDLE && event.type == SDL_MOUSEBUTTONDOWN && SDL_HasClipboardText()) {
+					char* pasteValue = SDL_GetClipboardText();
 
 					if (pasteValue != NULL) {
-						e = EvntManager->CreateTextEvent(pasteValue);
+						e = EventMgr::CreateTextEvent(pasteValue);
 						EvntManager->DispatchEvent(std::move(e));
 						SDL_free(pasteValue);
 					}
@@ -923,7 +972,7 @@ int SDL20VideoDriver::ProcessEvent(const SDL_Event & event)
 					case SDLK_v:
 						if (SDL_HasClipboardText()) {
 							char* text = SDL_GetClipboardText();
-							e = EvntManager->CreateTextEvent(text);
+							e = EventMgr::CreateTextEvent(text);
 							SDL_free(text);
 							EvntManager->DispatchEvent(std::move(e));
 							return GEM_OK;
@@ -951,7 +1000,7 @@ void SDL20VideoDriver::StartTextInput()
 	// UseSoftKeyboard probably has no effect since SDL delegates SDL_StartTextInput to the OS
 	// on iOS this is going to be a user preference and depends on a physical keyboard presence
 #if ANDROID
-	if (core->UseSoftKeyboard){
+	if (core->UseSoftKeyboard) {
 		SDL_StartTextInput();
 	} else {
 		Event e = EvntManager->CreateTextEvent(L"");
@@ -973,7 +1022,8 @@ bool SDL20VideoDriver::TouchInputEnabled()
 	return SDL_GetNumTouchDevices() > 0;
 }
 
-bool SDL20VideoDriver::CanDrawRawGeometry() const {
+bool SDL20VideoDriver::CanDrawRawGeometry() const
+{
 #if SDL_VERSION_ATLEAST(2, 0, 18)
 	return true;
 #else
@@ -981,30 +1031,44 @@ bool SDL20VideoDriver::CanDrawRawGeometry() const {
 #endif
 }
 
-void SDL20VideoDriver::SetGamma(int brightness, int /*contrast*/)
+void SDL20VideoDriver::SetGamma(int newBrightness, int newContrast)
 {
-	// FIXME: hardcoded hack. in in Interface our default brigtness value is 10
-	// so we assume that to be "normal" (1.0) value.
-	SDL_SetWindowBrightness(window, (float)brightness/10.0);
+	// Steps chosen empirically to give ranges close to originals.
+	brightness = 1.0 + (float) newBrightness * 0.0015;
+	contrast = 1.0 + (float) newContrast * 0.05;
 }
 
 bool SDL20VideoDriver::SetFullscreenMode(bool set)
 {
 	Uint32 flags = 0;
-	if (set) {
-		flags = SDL_WINDOW_FULLSCREEN_DESKTOP|SDL_WINDOW_BORDERLESS;
-	}
-	if (SDL_SetWindowFullscreen(window, flags) == GEM_OK) {
+	if (customFullscreenSize.IsInvalid()) {
+		if (set) {
+			flags = SDL_WINDOW_FULLSCREEN_DESKTOP | SDL_WINDOW_BORDERLESS;
+		}
+		if (SDL_SetWindowFullscreen(window, flags) == GEM_OK) {
+			fullscreen = set;
+			return true;
+		}
+	} else {
+		SDL_SetWindowFullscreen(window, 0);
+
+		if (set) {
+			SDL_SetWindowSize(window, customFullscreenSize.w, customFullscreenSize.h);
+		} else {
+			SDL_SetWindowSize(window, screenSize.w, screenSize.h);
+		}
 		fullscreen = set;
+
 		return true;
 	}
+
 	return false;
 }
 
 bool SDL20VideoDriver::ToggleGrabInput()
 {
 	bool isGrabbed = SDL_GetWindowGrab(window);
-	SDL_SetWindowGrab(window, (SDL_bool)!isGrabbed);
+	SDL_SetWindowGrab(window, (SDL_bool) !isGrabbed);
 	return (isGrabbed != SDL_GetWindowGrab(window));
 }
 
