@@ -28,12 +28,12 @@
 
 namespace GemRB {
 
-SDLSurfaceSprite2D::SDLSurfaceSprite2D (const Region& rgn, void* px, const PixelFormat& fmt) noexcept
-: Sprite2D(rgn, px, fmt)
+SDLSurfaceSprite2D::SDLSurfaceSprite2D(const Region& rgn, void* px, const PixelFormat& fmt) noexcept
+	: Sprite2D(rgn, px, fmt)
 {
 	if (px) {
 		surface = SDL_CreateRGBSurfaceFrom(px, Frame.w, Frame.h, fmt.Depth, Frame.w * fmt.Bpp,
-										   fmt.Rmask, fmt.Gmask, fmt.Bmask, fmt.Amask);
+						   fmt.Rmask, fmt.Gmask, fmt.Bmask, fmt.Amask);
 	} else {
 		assert(fmt.Depth >= 8);
 		surface = SDL_CreateRGBSurface(0, Frame.w, Frame.h, fmt.Depth, fmt.Rmask, fmt.Gmask, fmt.Bmask, fmt.Amask);
@@ -43,49 +43,36 @@ SDLSurfaceSprite2D::SDLSurfaceSprite2D (const Region& rgn, void* px, const Pixel
 
 	assert(surface);
 	pitch = surface->pitch;
-	
+
+	UpdateColorKey();
+	format = PixelFormatForSurface(surface, format.palette);
+
 	if (format.palette) {
 		UpdatePalette();
 	}
-	UpdateColorKey();
-	
-	format = PixelFormatForSurface(surface, format.palette);
-	
-	renderedSurface = surface;
 }
 
-SDLSurfaceSprite2D::SDLSurfaceSprite2D (const Region& rgn, const PixelFormat& fmt) noexcept
-: SDLSurfaceSprite2D(rgn, nullptr, fmt)
+SDLSurfaceSprite2D::SDLSurfaceSprite2D(const Region& rgn, const PixelFormat& fmt) noexcept
+	: SDLSurfaceSprite2D(rgn, nullptr, fmt)
 {}
 
-SDLSurfaceSprite2D::SDLSurfaceSprite2D(const SDLSurfaceSprite2D &obj) noexcept
-: SDLSurfaceSprite2D(obj.Frame, nullptr, obj.format)
+SDLSurfaceSprite2D::SDLSurfaceSprite2D(const SDLSurfaceSprite2D& obj) noexcept
+	: SDLSurfaceSprite2D(obj.Frame, nullptr, obj.format)
 {
-	SDL_BlitSurface(obj.surface, nullptr, surface, nullptr);
 	renderFlags = obj.renderFlags;
+	appliedBlitFlags = obj.appliedBlitFlags;
+	appliedTint = obj.appliedTint;
+
+	// note: make sure that src & dest have the same palette applied before this
+	// everything else will end up in SDL color transformation magic
+	SDL_BlitSurface(obj.surface, nullptr, surface, nullptr);
 }
 
 SDLSurfaceSprite2D::~SDLSurfaceSprite2D() noexcept
 {
-	if (renderedSurface != surface) {
-		SDL_FreeSurface(renderedSurface);
-	}
 	SDL_FreeSurface(surface);
 }
 
-void SDLSurfaceSprite2D::UpdateSurfacePalette() const noexcept
-{
-	assert (format.Depth <= 8);
-	
-	const auto& pal = format.palette;
-	SDLVideoDriver::SetSurfacePalette(surface, reinterpret_cast<const SDL_Color*>(pal->col), 0x01 << format.Depth);
-#if SDL_VERSION_ATLEAST(1,3,0)
-	// must reset the color key or SDL 2 won't render properly
-	SDL_SetColorKey(surface, SDL_bool(format.HasColorKey), GetColorKey());
-#endif
-	palVersion = pal->GetVersion();
-}
-
 Holder<Sprite2D> SDLSurfaceSprite2D::copy() const
 {
 	return Holder<Sprite2D>(new SDLSurfaceSprite2D(*this));
@@ -103,35 +90,23 @@ void* SDLSurfaceSprite2D::LockSprite()
 	return surface->pixels;
 }
 
-void SDLSurfaceSprite2D::UnlockSprite() const
+void SDLSurfaceSprite2D::UnlockSprite()
 {
 	SDL_UnlockSurface(surface);
 	Invalidate();
 }
 
-bool SDLSurfaceSprite2D::IsPaletteStale() const noexcept
+void SDLSurfaceSprite2D::Invalidate() noexcept
 {
-	// a 'version' implies tha palette was color modified
-	// however, the only caller her is RenderWithFlags
-	// where we already compare the version with the requested one
-	// the version includes the color modification so for now we dont worry about it
-	
-	const PaletteHolder& pal = format.palette;
-	assert(pal);
-	return pal->GetVersion() != palVersion;
-}
-
-void SDLSurfaceSprite2D::UpdatePalette() noexcept
-{
-	Invalidate();
+	surfaceInvalidated = true;
 }
 
 void SDLSurfaceSprite2D::UpdateColorKey() noexcept
 {
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 	SDL_SetColorKey(surface, SDL_bool(format.HasColorKey), format.ColorKey);
 	// don't RLE with SDL 2
-	// this only benifits SDL_BlitSurface which we don't use. its a slowdown for us.
+	// this only benefits SDL_BlitSurface which we don't use. its a slowdown for us.
 #else
 	Uint32 flag = format.HasColorKey ? SDL_SRCCOLORKEY : 0;
 	SDL_SetColorKey(surface, flag | SDL_RLEACCEL, format.ColorKey);
@@ -141,7 +116,7 @@ void SDLSurfaceSprite2D::UpdateColorKey() noexcept
 bool SDLSurfaceSprite2D::HasTransparency() const noexcept
 {
 	const SDL_PixelFormat* fmt = surface->format;
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 	return SDL_ISPIXELFORMAT_ALPHA(fmt->format) || SDL_GetColorKey(surface, NULL) != -1;
 #else
 	return fmt->Amask > 0 || ((surface)->flags & SDL_SRCCOLORKEY);
@@ -154,7 +129,7 @@ bool SDLSurfaceSprite2D::ConvertFormatTo(const PixelFormat& tofmt) noexcept
 		return false;
 	}
 
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 	Uint32 fmt = SDL_MasksToPixelFormatEnum(tofmt.Bpp * 8, tofmt.Rmask, tofmt.Gmask, tofmt.Bmask, tofmt.Amask);
 	if (fmt != SDL_PIXELFORMAT_UNKNOWN) {
 		SDL_Surface* ns = SDL_ConvertSurfaceFormat(surface, fmt, 0);
@@ -172,122 +147,153 @@ bool SDLSurfaceSprite2D::ConvertFormatTo(const PixelFormat& tofmt) noexcept
 			surface = ns;
 			format = PixelFormatForSurface(ns);
 			if (ns->format->palette) {
-				UpdateSurfacePalette();
+				UpdatePaletteForSurface(*format.palette);
+				palVersion = format.palette->GetVersion();
 			}
 			return true;
 		} else {
 			Log(MESSAGE, "SDLSurfaceSprite2D",
-#if SDL_VERSION_ATLEAST(1,3,0)
-				"Cannot convert sprite to format: %s\nError: %s", SDL_GetPixelFormatName(fmt),
+#if SDL_VERSION_ATLEAST(1, 3, 0)
+			    "Cannot convert sprite to format: %s\nError: %s", SDL_GetPixelFormatName(fmt),
 #else
-				"Cannot convert sprite to format: %s",
+			    "Cannot convert sprite to format: %s",
 #endif
-				SDL_GetError());
+			    SDL_GetError());
 		}
 	}
 	return false;
 }
 
-void SDLSurfaceSprite2D::Invalidate() const noexcept
+void SDLSurfaceSprite2D::EnsureShadedPalette() const noexcept
 {
-	version = 0;
-	if (renderedSurface != surface) {
-		SDL_FreeSurface(renderedSurface);
-		renderedSurface = surface;
-	}
-	if (format.Depth <= 8) {
-		UpdateSurfacePalette();
+	if (!shadedPalette) {
+		shadedPalette = MakeHolder<Palette>();
 	}
 }
 
-void* SDLSurfaceSprite2D::NewVersion(version_t newversion) const noexcept
+void SDLSurfaceSprite2D::ShadePalette(BlitFlags renderflags, const Color* tint) const noexcept
 {
-	if (newversion == 0 || version != newversion) {
-		Invalidate();
-		version = newversion;
-	}
+	Palette::Colors buffer;
+	buffer[0] = format.palette->GetColorAt(0);
 
-	if (format.Bpp == 1) {
-		// we just allow overwritting the palette
-		return surface->format->palette;
-	}
+	size_t startIndex = format.HasColorKey ? 1 : 0;
+	for (size_t i = startIndex; i < 256; ++i) {
+		buffer[i] = format.palette->GetColorAt(i);
 
-	palVersion = 0;
-
-	if (version != newversion) {
-		renderedSurface = SDL_ConvertSurface(surface, surface->format, 0);
-	}
-	return renderedSurface;
-}
-	
-BlitFlags SDLSurfaceSprite2D::RenderWithFlags(BlitFlags renderflags, const Color* tint) const noexcept
-{
-	SDLSurfaceSprite2D::version_t oldVersion = version;
-	SDLSurfaceSprite2D::version_t newVersion = renderflags;
-	auto ret = (BlitFlags::GREY | BlitFlags::SEPIA) & newVersion;
-	
-	if (format.Bpp == 1) {
-		if (tint) {
-			assert(renderflags & (BlitFlags::COLOR_MOD | BlitFlags::ALPHA_MOD));
-			uint64_t tintv = *reinterpret_cast<const uint32_t*>(tint);
-			newVersion |= tintv << 32;
+		if (renderflags & BlitFlags::COLOR_MOD && tint) {
+			ShaderTint(*tint, buffer[i]);
 		}
-		
-		if (oldVersion != newVersion || IsPaletteStale()) {
-			SDL_Palette* pal = static_cast<SDL_Palette*>(NewVersion(newVersion));
 
-			for (size_t i = 1; i < 256; ++i) {
-				Color& dstc = reinterpret_cast<Color&>(pal->colors[i]);
-
-				if (renderflags&BlitFlags::COLOR_MOD) {
-					assert(tint);
-					ShaderTint(*tint, dstc);
-					ret |= BlitFlags::COLOR_MOD;
-				}
-				
-				if (renderflags & BlitFlags::ALPHA_MOD) {
-					assert(tint);
-					dstc.a = tint->a;
-					ret |= BlitFlags::ALPHA_MOD;
-				}
-
-				if (renderflags&BlitFlags::GREY) {
-					ShaderGreyscale(dstc);
-				} else if (renderflags&BlitFlags::SEPIA) {
-					ShaderSepia(dstc);
-				}
-			}
-		} else {
-			ret |= (BlitFlags::COLOR_MOD | BlitFlags::ALPHA_MOD) & newVersion;
+		if (renderflags & BlitFlags::ALPHA_MOD && tint) {
+			buffer[i].a = tint->a;
 		}
-	} else if (oldVersion != newVersion) {
-		SDL_Surface* newV = (SDL_Surface*)NewVersion(newVersion);
-		SDL_LockSurface(newV);
-
-		const Region& r = {0, 0, newV->w, newV->h};
-		SDLPixelIterator beg = MakeSDLPixelIterator(newV, r);
-		SDLPixelIterator end = SDLPixelIterator::end(beg);
-		StaticAlphaIterator alpha(0xff);
 
 		if (renderflags & BlitFlags::GREY) {
-			RGBBlendingPipeline<SHADER::GREYSCALE, true> blender;
-			Blit(beg, beg, end, alpha, blender);
+			ShaderGreyscale(buffer[i]);
 		} else if (renderflags & BlitFlags::SEPIA) {
-			RGBBlendingPipeline<SHADER::SEPIA, true> blender;
-			Blit(beg, beg, end, alpha, blender);
+			ShaderSepia(buffer[i]);
 		}
-		SDL_UnlockSurface(newV);
 	}
-	return static_cast<BlitFlags>(ret);
+
+	shadedPalette->CopyColors(0, buffer.cbegin(), buffer.cend());
 }
 
-#if SDL_VERSION_ATLEAST(1,3,0)
+bool SDLSurfaceSprite2D::NeedToUpdatePalette() const noexcept
+{
+	return format.palette && palVersion != format.palette->GetVersion();
+}
+
+bool SDLSurfaceSprite2D::NeedToReshade(const Color* tint, BlitFlags flags) const noexcept
+{
+	return flags != appliedBlitFlags || surfaceInvalidated || NeedToUpdatePalette() || ((flags & BlitFlags::COLOR_MOD) && tint && (appliedTint.Packed() & 0xFFFFFF00) != (tint->Packed() & 0xFFFFFF00)) || ((flags & BlitFlags::ALPHA_MOD) && tint && (appliedTint.Packed() & 0xFF) != (tint->Packed() & 0xFF));
+}
+
+BlitFlags SDLSurfaceSprite2D::PrepareForRendering(BlitFlags renderflags, const Color* tint) const noexcept
+{
+	// Non-paletted surfaces can only have their pixels changed: refresh texture
+	if (format.Bpp > 1) {
+		if (surfaceInvalidated) {
+			OnSurfaceUpdate();
+			surfaceInvalidated = false;
+		}
+
+		// All surface operations to be done by SDL
+		return BlitFlags::NONE;
+	}
+
+	auto blitFlags = (BlitFlags::GREY | BlitFlags::SEPIA) & renderflags;
+	if (tint) {
+		blitFlags |= (BlitFlags::COLOR_MOD | BlitFlags::ALPHA_MOD) & renderflags;
+	}
+
+	// Something has changed/is new?
+	if (NeedToReshade(tint, blitFlags)) {
+		// modifiers for shaded version of palette/surface?
+		if (blitFlags) {
+			EnsureShadedPalette();
+			ShadePalette(blitFlags, tint);
+		}
+
+		bool flagsChanged = blitFlags != appliedBlitFlags;
+		surfaceInvalidated = false;
+		appliedBlitFlags = blitFlags;
+		if (tint) {
+			appliedTint = *tint;
+		}
+
+		UpdatePalettesState(flagsChanged);
+	}
+
+	return appliedBlitFlags;
+}
+
+void SDLSurfaceSprite2D::UpdatePalette() noexcept
+{
+	PrepareForRendering(appliedBlitFlags, &appliedTint);
+}
+
+void SDLSurfaceSprite2D::UpdatePaletteForSurface(const Palette& pal) const noexcept
+{
+	SDLVideoDriver::SetSurfacePalette(surface, reinterpret_cast<const SDL_Color*>(pal.ColorData()), 0x01 << format.Depth);
+#if SDL_VERSION_ATLEAST(1, 3, 0)
+	// must reset the color key or SDL 2 won't render properly
+	SDL_SetColorKey(surface, SDL_bool(format.HasColorKey), GetColorKey());
+#endif
+}
+
+void SDLSurfaceSprite2D::UpdatePalettesState(bool flagsChanged) const noexcept
+{
+	// effects modified?
+	if (appliedBlitFlags && shadedPaletteVersion != shadedPalette->GetVersion()) {
+		UpdatePaletteForSurface(*shadedPalette);
+		shadedPaletteVersion = shadedPalette->GetVersion();
+		// main palette modified or all effects lost?
+	} else if (!appliedBlitFlags && (flagsChanged || NeedToUpdatePalette())) {
+		UpdatePaletteForSurface(*format.palette);
+	}
+	// version has been applied in either case
+	palVersion = format.palette->GetVersion();
+
+	if (!appliedBlitFlags && shadedPalette) {
+		shadedPalette.reset();
+		shadedPaletteVersion = 0;
+	}
+
+	OnSurfaceUpdate();
+}
+
+SDL_Surface* SDLSurfaceSprite2D::GetSurface() const
+{
+	return surface;
+}
+
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 SDLTextureSprite2D::SDLTextureSprite2D(const Region& rgn, void* pixels, const PixelFormat& fmt) noexcept
-: SDLSurfaceSprite2D(rgn, pixels, fmt)
+	: SDLSurfaceSprite2D(rgn, pixels, fmt)
 {}
 
 SDLTextureSprite2D::SDLTextureSprite2D(const Region& rgn, const PixelFormat& fmt) noexcept
-: SDLSurfaceSprite2D(rgn, fmt)
+	: SDLSurfaceSprite2D(rgn, fmt)
 {}
 
 SDLTextureSprite2D::~SDLTextureSprite2D() noexcept
@@ -296,7 +302,7 @@ SDLTextureSprite2D::~SDLTextureSprite2D() noexcept
 }
 
 SDLTextureSprite2D::SDLTextureSprite2D(const SDLTextureSprite2D& other) noexcept
-	: SDLSurfaceSprite2D(other), texFormat(other.texFormat), texture(nullptr)
+	: SDLSurfaceSprite2D(other), texFormat(other.texFormat)
 {}
 
 Holder<Sprite2D> SDLTextureSprite2D::copy() const
@@ -310,11 +316,11 @@ SDL_Texture* SDLTextureSprite2D::GetTexture(SDL_Renderer* renderer) const
 		texture = SDL_CreateTextureFromSurface(renderer, GetSurface());
 		SDL_QueryTexture(texture, &texFormat, nullptr, nullptr, nullptr);
 	} else if (staleTexture) {
-		SDL_Surface *surface = GetSurface();
+		SDL_Surface* surface = GetSurface();
 		if (texFormat == surface->format->format) {
 			SDL_UpdateTexture(texture, nullptr, surface->pixels, surface->pitch);
 		} else {
-			SDL_Surface *temp = SDL_ConvertSurfaceFormat(surface, texFormat, 0);
+			SDL_Surface* temp = SDL_ConvertSurfaceFormat(surface, texFormat, 0);
 			assert(temp);
 			SDL_UpdateTexture(texture, nullptr, temp->pixels, temp->pitch);
 			SDL_FreeSurface(temp);
@@ -324,10 +330,9 @@ SDL_Texture* SDLTextureSprite2D::GetTexture(SDL_Renderer* renderer) const
 	return texture;
 }
 
-void SDLTextureSprite2D::Invalidate() const noexcept
+void SDLTextureSprite2D::OnSurfaceUpdate() const noexcept
 {
 	staleTexture = true;
-	SDLSurfaceSprite2D::Invalidate();
 }
 #endif
 
