@@ -21,19 +21,20 @@
 #include "SDLVideo.h"
 
 #include "Interface.h"
-#include "Video/RLE.h"
 #include "SDLPixelIterator.h"
 
+#include "Video/RLE.h"
+
 using namespace GemRB;
 
 SDLVideoDriver::~SDLVideoDriver(void)
 {
-	SDL_Quit();
+	SDL_QuitSubSystem(SDL_INIT_GAMECONTROLLER | SDL_INIT_JOYSTICK | SDL_INIT_VIDEO);
 }
 
 int SDLVideoDriver::Init(void)
 {
-	if (SDL_InitSubSystem( SDL_INIT_VIDEO ) == -1) {
+	if (SDL_InitSubSystem(SDL_INIT_VIDEO) == -1) {
 		Log(ERROR, "SDLVideo", "InitSubSystem failed: {}", SDL_GetError());
 		return GEM_ERROR;
 	}
@@ -122,14 +123,14 @@ static SDL_Keycode TranslateKeycode(SDLKey sym)
 		case SDLK_F12:
 			//assuming they come sequentially,
 			//also, there is no need to ever produce more than 12
-			return GEM_FUNCTIONX(1) + sym-SDLK_F1;
+			return GEM_FUNCTIONX(1) + sym - SDLK_F1;
 		default:
 			break;
 	}
 	return sym;
 }
 
-int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
+int SDLVideoDriver::ProcessEvent(const SDL_Event& event)
 {
 	if (!EvntManager)
 		return GEM_ERROR;
@@ -152,7 +153,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 		case SDL_KEYUP:
 			key = TranslateKeycode(sym);
 			if (key != 0) {
-				e = EvntManager->CreateKeyEvent(key, false, modstate);
+				e = EventMgr::CreateKeyEvent(key, false, modstate);
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
@@ -160,26 +161,43 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 			// reenable special numpad keys unless numlock is off
 			if (SDL_GetModState() & KMOD_NUM) {
 				switch (sym) {
-					case SDLK_KP1: sym = SDLK_1; break;
-					case SDLK_KP2: sym = SDLK_2; break;
-					case SDLK_KP3: sym = SDLK_3; break;
-					case SDLK_KP4: sym = SDLK_4; break;
+					case SDLK_KP1:
+						sym = SDLK_1;
+						break;
+					case SDLK_KP2:
+						sym = SDLK_2;
+						break;
+					case SDLK_KP3:
+						sym = SDLK_3;
+						break;
+					case SDLK_KP4:
+						sym = SDLK_4;
+						break;
 					// 5 is not special
-					case SDLK_KP6: sym = SDLK_6; break;
-					case SDLK_KP7: sym = SDLK_7; break;
-					case SDLK_KP8: sym = SDLK_8; break;
-					case SDLK_KP9: sym = SDLK_9; break;
-					default: break;
+					case SDLK_KP6:
+						sym = SDLK_6;
+						break;
+					case SDLK_KP7:
+						sym = SDLK_7;
+						break;
+					case SDLK_KP8:
+						sym = SDLK_8;
+						break;
+					case SDLK_KP9:
+						sym = SDLK_9;
+						break;
+					default:
+						break;
 				}
 			}
 			key = TranslateKeycode(sym);
 
-			e = EvntManager->CreateKeyEvent(key, true, modstate);
+			e = EventMgr::CreateKeyEvent(key, true, modstate);
 			if (e.keyboard.character) {
 				if (InTextInput() && modstate == 0) {
 					return GEM_OK;
 				}
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 				e.keyboard.character = SDL_GetKeyFromScancode(event.key.keysym.scancode);
 #else
 				e.keyboard.character = event.key.keysym.unicode;
@@ -189,7 +207,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 			EvntManager->DispatchEvent(std::move(e));
 			break;
 		case SDL_MOUSEMOTION:
-			e = EvntManager->CreateMouseMotionEvent(Point(event.motion.x, event.motion.y), modstate);
+			e = EventMgr::CreateMouseMotionEvent(Point(event.motion.x, event.motion.y), modstate);
 			EvntManager->DispatchEvent(std::move(e));
 			break;
 		case SDL_MOUSEBUTTONDOWN:
@@ -202,7 +220,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 					// on at least some platforms
 					bool down = (event.type == SDL_MOUSEBUTTONDOWN) ? true : false;
 					Point p(event.button.x, event.button.y);
-					e = EvntManager->CreateMouseBtnEvent(p, btn, down, modstate);
+					e = EventMgr::CreateMouseBtnEvent(p, btn, down, modstate);
 					EvntManager->DispatchEvent(std::move(e));
 				}
 			}
@@ -215,7 +233,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 				// FIXME: I'm sure this delta needs to be scaled
 				int delta = xaxis ? pct * screenSize.w : pct * screenSize.h;
 				InputAxis axis = InputAxis(event.jaxis.axis);
-				e = EvntManager->CreateControllerAxisEvent(axis, delta, pct);
+				e = EventMgr::CreateControllerAxisEvent(axis, delta, pct);
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
@@ -224,7 +242,7 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 			{
 				bool down = (event.type == SDL_JOYBUTTONDOWN) ? true : false;
 				EventButton btn = EventButton(event.jbutton.button);
-				e = EvntManager->CreateControllerButtonEvent(btn, down);
+				e = EventMgr::CreateControllerButtonEvent(btn, down);
 				EvntManager->DispatchEvent(std::move(e));
 			}
 			break;
@@ -238,22 +256,22 @@ int SDLVideoDriver::ProcessEvent(const SDL_Event & event)
 Holder<Sprite2D> SDLVideoDriver::CreateSprite(const Region& rgn, void* pixels, const PixelFormat& fmt)
 {
 	if (fmt.RLE) {
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 		// SDL2 should not allow RLE sprites so convert it
 		void* newpixels = DecodeRLEData(static_cast<uint8_t*>(pixels), rgn.size, fmt.ColorKey);
 		free(pixels);
 		PixelFormat newfmt = fmt;
 		newfmt.RLE = false;
-		return Holder<Sprite2D>(new sprite_t(rgn, newpixels, newfmt));
+		return MakeHolder<sprite_t>(rgn, newpixels, newfmt);
 #else
-		return MakeHolder<Sprite2D>(rgn, pixels, fmt);
+		return MakeHolder<sprite_t>(rgn, pixels, fmt);
 #endif
 	}
-	return Holder<Sprite2D>(new sprite_t(rgn, pixels, fmt));
+	return MakeHolder<sprite_t>(rgn, pixels, fmt);
 }
 
 void SDLVideoDriver::BlitSprite(const Holder<Sprite2D>& spr, const Region& src, Region dst,
-								BlitFlags flags, Color tint)
+				BlitFlags flags, Color tint)
 {
 	dst.x -= spr->Frame.x;
 	dst.y -= spr->Frame.y;
@@ -261,7 +279,7 @@ void SDLVideoDriver::BlitSprite(const Holder<Sprite2D>& spr, const Region& src,
 }
 
 void SDLVideoDriver::BlitGameSprite(const Holder<Sprite2D>& spr, const Point& p,
-									BlitFlags flags, Color tint)
+				    BlitFlags flags, Color tint)
 {
 	Region srect(Point(0, 0), spr->Frame.size);
 	Region drect = Region(p - spr->Frame.origin, spr->Frame.size);
@@ -280,24 +298,24 @@ Region SDLVideoDriver::CurrentRenderClip() const
 
 void SDLVideoDriver::DrawEllipseImp(const Region& rect, const Color& color, BlitFlags flags)
 {
-	const std::vector<Point> points = PlotEllipse(rect);
+	const std::vector<BasePoint> points = PlotEllipse(rect);
 	DrawPoints(points, color, flags);
 }
 
 void SDLVideoDriver::DrawCircleImp(const Point& origin, uint16_t r, const Color& color, BlitFlags flags)
 {
-	const std::vector<Point> points = PlotCircle(origin, r, 0xff);
+	const std::vector<BasePoint> points = PlotCircle(origin, r, 0xff);
 	DrawPoints(points, color, flags);
 }
 
 void SDLVideoDriver::BlitSpriteClipped(const Holder<Sprite2D>& spr, Region src, const Region& dst, BlitFlags flags, const Color* tint)
 {
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 	// in SDL2 SDL_RenderCopyEx will flip the src rect internally if BlitFlags::MIRRORX or BlitFlags::MIRRORY is set
 	// instead of doing this and then reversing it in that case only for SDL to reverse it yet again
 	// lets just not worry about clipping on SDL2. the backends handle all of that for us unlike with SDL 1 where we
 	// might walk off a memory buffer; we have no danger of that in SDL 2.
-	// This fixes bizzare clipping issues when a "flipped" sprite is partially offscreen
+	// This fixes bizarre clipping issues when a "flipped" sprite is partially offscreen
 	// we still will clip with screenClip later so no worries there
 	// we still want to do the clipping for the purposes of avoiding calls to BlitSpriteNativeClipped where
 	// expensive calls to SDLSurfaceSprite2D::RenderWithFlags may take place
@@ -326,16 +344,16 @@ void SDLVideoDriver::BlitSpriteClipped(const Holder<Sprite2D>& spr, Region src,
 
 	assert(dclipped.w == src.w && dclipped.h == src.h);
 
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 	dclipped = dst;
 	src = originalSrc;
 #endif
 
-	if (spr->renderFlags&BlitFlags::MIRRORX) {
+	if (spr->renderFlags & BlitFlags::MIRRORX) {
 		flags ^= BlitFlags::MIRRORX;
 	}
 
-	if (spr->renderFlags&BlitFlags::MIRRORY) {
+	if (spr->renderFlags & BlitFlags::MIRRORY) {
 		flags ^= BlitFlags::MIRRORY;
 	}
 
@@ -344,26 +362,28 @@ void SDLVideoDriver::BlitSpriteClipped(const Holder<Sprite2D>& spr, Region src,
 	if (!spr->HasTransparency()) {
 		flags &= ~BlitFlags::BLENDED;
 	}
-	
+
 	auto pal = spr->GetPalette();
 	Color ck = ColorBlack;
 	if (flags & (BlitFlags::ONE_MINUS_DST | BlitFlags::DST | BlitFlags::SRC)) {
 		// FIXME: this is a hack. the video driver just needs to be able to ignore the color key during any blending
-		if (pal && pal->col[0] != ColorBlack) {
-			ck = pal->col[0];
-			pal->CopyColorRange(&ColorBlack, &ColorBlack + 1, 0);
+		if (pal) {
+			ck = pal->GetColorAt(0);
+			if (ck != ColorBlack) {
+				pal->SetColor(0, ColorBlack);
+			}
 		}
 	}
 
 	if (spr->Format().RLE) {
 		BlitSpriteRLEClipped(spr, src, dclipped, flags, tint);
 	} else {
-		const sprite_t* native = static_cast<const sprite_t*>(spr.get ());
+		const sprite_t* native = static_cast<const sprite_t*>(spr.get());
 		BlitSpriteNativeClipped(native, src, dclipped, flags, reinterpret_cast<const SDL_Color*>(tint));
 	}
-	
+
 	if (ck != ColorBlack) {
-		pal->CopyColorRange(&ck, &ck + 1, 0);
+		pal->SetColor(0, ck);
 	}
 }
 
@@ -372,11 +392,11 @@ void SDLVideoDriver::BlitSpriteClipped(const Holder<Sprite2D>& spr, Region src,
 bool SDLVideoDriver::SetSurfacePalette(SDL_Surface* surf, const SDL_Color* pal, int numcolors)
 {
 	if (pal) {
-#if SDL_VERSION_ATLEAST(1,3,0)
+#if SDL_VERSION_ATLEAST(1, 3, 0)
 		return SDL_SetPaletteColors(surf->format->palette, pal, 0, numcolors) == 0;
 #else
 		// const_cast because SDL doesn't alter this and we want our interface to be const correct
-		return SDL_SetPalette( surf, SDL_LOGPAL, const_cast<SDL_Color*>(pal), 0, numcolors );
+		return SDL_SetPalette(surf, SDL_LOGPAL, const_cast<SDL_Color*>(pal), 0, numcolors);
 #endif
 	}
 	return -1;
