@@ -52,7 +52,6 @@ static void Initializer()
 			gamedata->castingHits[i].Reset();
 		}
 	}
-
 }
 
 static int GetCGSound(ieDword CastingGraphics)
@@ -65,9 +64,9 @@ static int GetCGSound(ieDword CastingGraphics)
 		return -1;
 	}
 	int ret = -1;
-	if (core->HasFeature(GFFlags::CASTING_SOUNDS) ) {
+	if (core->HasFeature(GFFlags::CASTING_SOUNDS)) {
 		ret = gamedata->castingSounds[CastingGraphics];
-		if (core->HasFeature(GFFlags::CASTING_SOUNDS2) ) {
+		if (core->HasFeature(GFFlags::CASTING_SOUNDS2)) {
 			ret |= 0x100;
 		}
 	} else if (!core->HasFeature(GFFlags::CASTING_SOUNDS2)) {
@@ -89,10 +88,10 @@ bool SPLImporter::Open(DataStream* stream)
 	delete str;
 	str = stream;
 	char Signature[8];
-	str->Read( Signature, 8 );
-	if (strncmp( Signature, "SPL V1  ", 8 ) == 0) {
+	str->Read(Signature, 8);
+	if (strncmp(Signature, "SPL V1  ", 8) == 0) {
 		version = 1;
-	} else if (strncmp( Signature, "SPL V2.0", 8 ) == 0) {
+	} else if (strncmp(Signature, "SPL V2.0", 8) == 0) {
 		version = 20;
 	} else {
 		Log(WARNING, "SPLImporter", "This file is not a valid SPL file! Actual signature: {}", Signature);
@@ -102,26 +101,26 @@ bool SPLImporter::Open(DataStream* stream)
 	return true;
 }
 
-Spell* SPLImporter::GetSpell(Spell *s, bool /*silent*/)
+Spell* SPLImporter::GetSpell(Spell* s, bool /*silent*/)
 {
 	str->ReadStrRef(s->SpellName);
 	str->ReadStrRef(s->SpellNameIdentified);
-	str->ReadResRef( s->CompletionSound );
+	str->ReadResRef(s->CompletionSound);
 	str->ReadDword(s->Flags);
 	str->ReadWord(s->SpellType);
 	str->ReadWord(s->ExclusionSchool);
 	str->ReadWord(s->PriestType);
 	str->ReadWord(s->CastingGraphics);
 	s->CastingSound = GetCGSound(s->CastingGraphics);
-	str->Read( &s->unknown1, 1 );
+	str->Read(&s->unknown1, 1);
 	str->ReadWord(s->PrimaryType);
-	str->Read( &s->SecondaryType, 1 );
+	str->Read(&s->SecondaryType, 1);
 	str->ReadDword(s->unknown2);
 	str->ReadDword(s->unknown3);
 	str->ReadDword(s->unknown4);
 	str->ReadDword(s->SpellLevel);
 	str->ReadWord(s->unknown5);
-	str->ReadResRef( s->SpellbookIcon );
+	str->ReadResRef(s->SpellbookIcon);
 	//this hack is needed in ToB at least
 	if (!s->SpellbookIcon.IsEmpty() && core->HasFeature(GFFlags::SPELLBOOKICONHACK)) {
 		*s->SpellbookIcon.rbegin() = 'c'; // replace last character
@@ -143,16 +142,16 @@ Spell* SPLImporter::GetSpell(Spell *s, bool /*silent*/)
 	str->ReadWord(s->CastingFeatureOffset);
 	str->ReadWord(s->CastingFeatureCount);
 
-	memset( s->unknown13, 0, 14 );
+	memset(s->unknown13, 0, 14);
 	if (version == 20) {
 		//these fields are used in simplified duration
-		str->Read( &s->TimePerLevel, 1);
-		str->Read( &s->TimeConstant, 1 );
-		str->Read( s->unknown13, 14 );
+		str->Read(&s->TimePerLevel, 1);
+		str->Read(&s->TimeConstant, 1);
+		str->Read(s->unknown13, 14);
 		//moving some bits, because bg2 uses them differently
 		//the low byte is unused, so we can keep the iwd2 bits there
-		s->Flags|=(s->Flags>>8)&0xc0;
-		s->Flags&=~0xc000;
+		s->Flags |= (s->Flags >> 8) & 0xc0;
+		s->Flags &= ~0xc000;
 	} else if (s->Flags & SF_SIMPLIFIED_DURATION) {
 		// in case of old format, use some unused fields for gemrb's simplified duration
 		// to simulate IWD2's useful feature (this is needed for some pst projectiles)
@@ -166,16 +165,16 @@ Spell* SPLImporter::GetSpell(Spell *s, bool /*silent*/)
 	s->ext_headers = std::vector<SPLExtHeader>(headerCount);
 
 	for (ieWord i = 0; i < headerCount; i++) {
-		str->Seek( s->ExtHeaderOffset + i * 40, GEM_STREAM_START );
+		str->Seek(s->ExtHeaderOffset + i * 40, GEM_STREAM_START);
 		GetExtHeader(s, &s->ext_headers[i]);
 	}
 
 	s->casting_features.reserve(s->CastingFeatureCount);
-	str->Seek( s->FeatureBlockOffset + 48*s->CastingFeatureOffset,
-			GEM_STREAM_START );
+	str->Seek(s->FeatureBlockOffset + 48 * s->CastingFeatureOffset,
+		  GEM_STREAM_START);
 	for (int i = 0; i < s->CastingFeatureCount; i++) {
 		Effect* fx = GetFeature(s);
-		 // pst's fx_tint_screen has some instances and elsewhere it was noted to never use preset targets in global effects
+		// pst's fx_tint_screen has some instances and elsewhere it was noted to never use preset targets in global effects
 		if (fx->Target == FX_TARGET_PRESET) fx->Target = FX_TARGET_SELF;
 		s->casting_features.push_back(std::move(*fx));
 		delete fx;
@@ -184,20 +183,24 @@ Spell* SPLImporter::GetSpell(Spell *s, bool /*silent*/)
 	return s;
 }
 
-void SPLImporter::GetExtHeader(const Spell *s, SPLExtHeader* eh)
+void SPLImporter::GetExtHeader(const Spell* s, SPLExtHeader* eh)
 {
-	str->Read( &eh->SpellForm, 1 );
+	str->Read(&eh->SpellForm, 1);
 	//this byte is used in PST
-	str->Read( &eh->Hostile, 1 );
-	str->Read( &eh->Location, 1 );
-	str->Read( &eh->unknown2, 1 );
+	str->Read(&eh->Hostile, 1);
+	str->Read(&eh->Location, 1);
+	str->Read(&eh->unknown2, 1);
 	str->ReadResRef(eh->memorisedIcon);
-	str->Read( &eh->Target, 1 );
+	str->Read(&eh->Target, 1);
 
 	//this hack is to let gemrb target dead actors by some spells
+	// and knock in non-pst, since it's also set to target actors
 	if (eh->Target == 1) {
-		if (gamedata->GetSpecialSpell(s->Name) & SPEC_DEAD) {
+		int flags = gamedata->GetSpecialSpell(s->Name);
+		if (flags & SPEC_DEAD) {
 			eh->Target = 3;
+		} else if (flags & SPEC_AREA) {
+			eh->Target = 4;
 		}
 	}
 	str->Read(&eh->TargetNumber, 1);
@@ -223,7 +226,7 @@ void SPLImporter::GetExtHeader(const Spell *s, SPLExtHeader* eh)
 		eh->ProjectileAnimation--;
 	}
 	eh->features.reserve(featureCount);
-	str->Seek( s->FeatureBlockOffset + 48*eh->FeatureOffset, GEM_STREAM_START );
+	str->Seek(s->FeatureBlockOffset + 48 * eh->FeatureOffset, GEM_STREAM_START);
 	for (ieWord i = 0; i < featureCount; ++i) {
 		Effect* fx = GetFeature(s);
 		eh->features.push_back(std::move(*fx));
@@ -231,12 +234,13 @@ void SPLImporter::GetExtHeader(const Spell *s, SPLExtHeader* eh)
 	}
 }
 
-Effect *SPLImporter::GetFeature(const Spell *s)
+Effect* SPLImporter::GetFeature(const Spell* s)
 {
 	PluginHolder<EffectMgr> eM = MakePluginHolder<EffectMgr>(IE_EFF_CLASS_ID);
-	eM->Open( str, false );
+	eM->Open(str, false);
 	Effect* fx = eM->GetEffect();
 	fx->SourceRef = s->Name;
+	fx->SourceType = 2;
 	fx->PrimaryType = s->PrimaryType;
 	fx->SecondaryType = s->SecondaryType;
 	return fx;
