@@ -23,8 +23,9 @@
 #include "RGBAColor.h"
 
 #include "Interface.h"
-#include "Logging/Logging.h"
 #include "Sprite2D.h"
+
+#include "Logging/Logging.h"
 #include "Video/Video.h"
 
 using namespace GemRB;
@@ -42,10 +43,10 @@ bool TISImporter::Open(DataStream* stream)
 	delete str;
 	str = stream;
 	char Signature[8];
-	str->Read( Signature, 8 );
+	str->Read(Signature, 8);
 	headerShift = 0;
 	if (Signature[0] == 'T' && Signature[1] == 'I' && Signature[2] == 'S') {
-		if (strncmp( Signature, "TIS V1  ", 8 ) != 0) {
+		if (strncmp(Signature, "TIS V1  ", 8) != 0) {
 			Log(ERROR, "TISImporter", "Not a Valid TIS file!");
 			return false;
 		}
@@ -61,13 +62,13 @@ bool TISImporter::Open(DataStream* stream)
 			hasPVRData = true;
 			TilesSectionLen = 0xc;
 		}
-		str->Seek( -8, GEM_CURRENT_POS );
+		str->Seek(-8, GEM_CURRENT_POS);
 	}
 	return true;
 }
 
 Tile* TISImporter::GetTile(const std::vector<ieWord>& indexes,
-						   unsigned short* secondary)
+			   unsigned short* secondary)
 {
 	size_t count = indexes.size();
 	std::vector<Animation::frame_t> frames;
@@ -75,22 +76,22 @@ Tile* TISImporter::GetTile(const std::vector<ieWord>& indexes,
 	for (size_t i = 0; i < count; i++) {
 		frames.push_back(GetTile(indexes[i]));
 	}
-	
-	Animation ani = Animation(std::move(frames));
+
+	Animation ani = Animation(std::move(frames), ANI_DEFAULT_FRAMERATE);
 	//pause key stops animation
 	ani.gameAnimation = true;
 	//the turning crystal in ar3202 (bg1) requires animations to be synced
 	ani.frameIdx = 0;
-	
+
 	if (secondary) {
 		frames.clear();
 		for (size_t i = 0; i < count; i++) {
 			frames.push_back(GetTile(secondary[i]));
 		}
-		Animation sec = Animation(frames);
-		return new Tile(ani, std::move(sec));
+		Animation sec = Animation(std::move(frames), ANI_DEFAULT_FRAMERATE);
+		return new Tile(std::move(ani), std::move(sec));
 	}
-	return new Tile(ani);
+	return new Tile(std::move(ani));
 }
 
 Holder<Sprite2D> TISImporter::GetTile(int index)
@@ -114,9 +115,9 @@ Holder<Sprite2D> TISImporter::GetTilePVR(int index)
 	Blit(dataBlock, imageData);
 
 	PixelFormat fmt = PixelFormat::ARGB32Bit();
-	Region region{0, 0, static_cast<int>(TileSize), static_cast<int>(TileSize)};
+	Region region { 0, 0, static_cast<int>(TileSize), static_cast<int>(TileSize) };
 
-	return {core->GetVideoDriver()->CreateSprite(region, imageData, fmt)};
+	return { VideoDriver->CreateSprite(region, imageData, fmt) };
 }
 
 void TISImporter::Blit(const TISPVRBlock& dataBlock, uint8_t* frameData)
@@ -130,14 +131,14 @@ void TISImporter::Blit(const TISPVRBlock& dataBlock, uint8_t* frameData)
 		// we cheat and just derive the middle from the tis name as well
 		ResRef suffix(&str->filename[2], 5);
 		if (suffix[4] == '.') suffix.erase(4, 1);
-		auto resRef = fmt::format("{}{}{:02d}", str->filename[0], suffix.c_str(), dataBlock.pvrzPage);
-		StringView resRefView(resRef.c_str(), 7);
+		auto resRef = fmt::format("{}{:.4}{:02d}", str->filename[0], suffix, dataBlock.pvrzPage);
 
-		lastPVRZ = gamedata->GetResourceHolder<ImageMgr>(resRefView, true);
+		lastPVRZ = gamedata->GetResourceHolder<ImageMgr>(resRef, true);
 		lastPVRZPage = dataBlock.pvrzPage;
 	}
 
-	auto sprite = lastPVRZ->GetSprite2D(Region{dataBlock.source.x, dataBlock.source.y, static_cast<int>(TileSize), static_cast<int>(TileSize)});
+	if (!lastPVRZ) return;
+	auto sprite = lastPVRZ->GetSprite2D(Region { dataBlock.source.x, dataBlock.source.y, static_cast<int>(TileSize), static_cast<int>(TileSize) });
 	if (!sprite) {
 		return;
 	}
@@ -150,8 +151,7 @@ void TISImporter::Blit(const TISPVRBlock& dataBlock, uint8_t* frameData)
 		std::copy(
 			spritePixels + offset,
 			spritePixels + offset + sprite->Frame.w * 4,
-			frameData + destOffset
-		);
+			frameData + destOffset);
 	}
 
 	sprite->UnlockSprite();
@@ -159,64 +159,68 @@ void TISImporter::Blit(const TISPVRBlock& dataBlock, uint8_t* frameData)
 
 Holder<Sprite2D> TISImporter::GetTilePaletted(int index)
 {
-	strpos_t pos = index *(1024+4096) + headerShift;
+	strpos_t pos = index * (1024 + 4096) + headerShift;
 	if (str->Size() < pos + 1024 + 4096) {
 		// original PS:T AR0609 and AR0612 report far more tiles than are actually present :(
-		
+
 		if (badTile == nullptr) {
 			// we only want to generate a single bad tile on demand
-			PaletteHolder pal = MakeHolder<Palette>();
+			Holder<Palette> pal = MakeHolder<Palette>();
 			PixelFormat fmt = PixelFormat::Paletted8Bit(std::move(pal));
-			badTile = core->GetVideoDriver()->CreateSprite(Region(0,0,64,64), nullptr, fmt);
+			badTile = VideoDriver->CreateSprite(Region(0, 0, 64, 64), nullptr, fmt);
 		}
-		
+
 		// try to only report error once per file
-		static const TISImporter *last_corrupt = nullptr;
+		static const TISImporter* last_corrupt = nullptr;
 		if (last_corrupt != this) {
 			Log(ERROR, "TISImporter", "Corrupt WED file encountered; couldn't find any more tiles at tile {}", index);
 			last_corrupt = this;
 		}
-	
+
 		return badTile;
 	}
-	
-	PaletteHolder pal = MakeHolder<Palette>();
+
+	Holder<Palette> pal = MakeHolder<Palette>();
 	PixelFormat fmt = PixelFormat::Paletted8Bit(pal);
 	colorkey_t ck = 0;
-	
+
 	auto ckTest = [](const Color& c) {
 		// work around bad data in BG2 AR1700
 		return c.r <= 4 && c.b <= 4 && c.g >= 78;
 	};
 
-	str->Seek( pos, GEM_STREAM_START );
-	str->Read(pal->col, 1024);
-	for (Color& c : pal->col) {
+	str->Seek(pos, GEM_STREAM_START);
+	Palette::Colors buffer;
+	str->Read(buffer.data(), 1024);
+
+	for (Color& c : buffer) {
 		std::swap(c.b, c.r); // argb format
 		c.a = c.a ? c.a : 255; // alpha is unused by the originals but SDL will happily use it
 		if (ck == 0 && ckTest(c)) {
 			c = ColorGreen;
-			ck = colorkey_t(&c - pal->col);
+			ck = colorkey_t(&c - buffer.data());
 		}
 	}
-	
-	fmt.ColorKey = ck;
-	fmt.HasColorKey = pal->col[ck] == ColorGreen;
 
-	auto spr = core->GetVideoDriver()->CreateSprite(Region(0,0,64,64), nullptr, fmt);
+	pal->CopyColors(0, buffer.cbegin(), buffer.cend());
+
+	fmt.ColorKey = ck;
+	fmt.HasColorKey = pal->GetColorAt(ck) == ColorGreen;
+
+	auto spr = VideoDriver->CreateSprite(Region(0, 0, 64, 64), nullptr, fmt);
 	uint8_t* pixels = static_cast<uint8_t*>(spr->LockSprite());
 	str->Read(pixels, 4096);
-	
+
 	// work around bad data in BG2 AR1700
 	for (int i = 0; i < 4096; ++i) {
 		uint8_t& val = pixels[i];
-		const Color& c = pal->col[val];
+		const Color& c = pal->GetColorAt(val);
 		if (ckTest(c)) {
 			assert(fmt.HasColorKey);
 			val = ck;
 		}
 	}
-	
+
 	spr->UnlockSprite();
 	return spr;
 }
