@@ -18,9 +18,6 @@
  *
  */
 
-#include <tuple>
-#include <utility>
-
 #include "TLKImporter.h"
 
 #include "Audio.h"
@@ -28,20 +25,24 @@
 #include "DialogHandler.h"
 #include "Game.h"
 #include "Interface.h"
-#include "Logging/Logging.h"
 #include "TableMgr.h"
+
 #include "GUI/GameControl.h"
+#include "Logging/Logging.h"
 #include "Scriptable/Actor.h"
 
+#include <tuple>
+#include <utility>
+
 using namespace GemRB;
 
 TLKImporter::TLKImporter(void)
 {
 	if (core->HasFeature(GFFlags::CHARNAMEISGABBER)) {
-		charname=-1;
+		charname = -1;
 	}
 
-	AutoTable tm = gamedata->LoadTable("gender");
+	AutoTable tm = gamedata->LoadTable("gender", true);
 	TableMgr::index_t gtcount = 0;
 	if (tm) {
 		gtcount = tm->GetRowCount();
@@ -51,13 +52,13 @@ TLKImporter::TLKImporter(void)
 
 		auto& entry =
 			gtmap.emplace(
-					std::piecewise_construct,
-					std::forward_as_tuple(key),
-					std::forward_as_tuple()
-			).first->second;
-		entry.type = tm->QueryFieldSigned<int>(i,0);
-		entry.male = tm->QueryFieldAsStrRef(i,1);
-		entry.female = tm->QueryFieldAsStrRef(i,2);
+				     std::piecewise_construct,
+				     std::forward_as_tuple(key),
+				     std::forward_as_tuple())
+				.first->second;
+		entry.type = tm->QueryFieldSigned<int>(i, 0);
+		entry.male = tm->QueryFieldAsStrRef(i, 1);
+		entry.female = tm->QueryFieldAsStrRef(i, 2);
 	}
 }
 
@@ -94,8 +95,8 @@ bool TLKImporter::Open(DataStream* stream)
 	delete str;
 	str = stream;
 	char Signature[8];
-	str->Read( Signature, 8 );
-	if (strncmp( Signature, "TLK\x20V1\x20\x20", 8 ) != 0) {
+	str->Read(Signature, 8);
+	if (strncmp(Signature, "TLK\x20V1\x20\x20", 8) != 0) {
 		Log(ERROR, "TLKImporter", "Not a valid TLK File.");
 		return false;
 	}
@@ -106,6 +107,11 @@ bool TLKImporter::Open(DataStream* stream)
 		Log(ERROR, "TLKImporter", "Too many strings ({}), increase OVERRIDE_START.", StrRefCount);
 		return false;
 	}
+
+	if (GetString(ieStrRef(1)).back() == u'\n') {
+		hasEndingNewline = true;
+	}
+
 	return true;
 }
 
@@ -113,20 +119,21 @@ bool TLKImporter::Open(DataStream* stream)
 		0	 - PROTAGONIST
 		1-9 - PLAYERx
 */
-static inline Actor *GetActorFromSlot(int slot)
+static inline const Actor* GetActorFromSlot(int slot)
 {
-	if (slot==-1) {
-		const GameControl *gc = core->GetGameControl();
+	if (slot == -1) {
+		const GameControl* gc = core->GetGameControl();
+		const Actor* act = nullptr;
 		if (gc) {
-			return gc->dialoghandler->GetSpeaker();
+			act = gc->dialoghandler->GetSpeaker();
 		}
-		return NULL;
+		return act;
 	}
-	const Game *game = core->GetGame();
+	const Game* game = core->GetGame();
 	if (!game) {
 		return NULL;
 	}
-	if (slot==0) {
+	if (slot == 0) {
 		return game->GetPC(0, false); //protagonist
 	}
 	return game->FindPC(slot);
@@ -134,26 +141,30 @@ static inline Actor *GetActorFromSlot(int slot)
 
 String TLKImporter::Gabber() const
 {
-	const Actor *act = core->GetGameControl()->dialoghandler->GetSpeaker();
+	const Actor* act = core->GetGameControl()->dialoghandler->GetSpeaker();
 	if (act) {
 		return act->GetName();
 	}
-	return L"?";
+	return u"?";
 }
 
 String TLKImporter::CharName(int slot) const
 {
-	const Actor *act = GetActorFromSlot(slot);
+	const Actor* act = GetActorFromSlot(slot);
 	if (act) {
 		return act->GetName();
 	}
-	return L"?";
+	if (!act) {
+		act = core->GetFirstSelectedActor();
+		if (act) return act->GetName();
+	}
+	return u"?";
 }
 
 ieStrRef TLKImporter::ClassStrRef(int slot) const
 {
 	int clss = 0;
-	const Actor *act = GetActorFromSlot(slot);
+	const Actor* act = GetActorFromSlot(slot);
 	if (act) {
 		clss = act->GetActiveClass();
 	}
@@ -169,9 +180,9 @@ ieStrRef TLKImporter::ClassStrRef(int slot) const
 ieStrRef TLKImporter::RaceStrRef(int slot) const
 {
 	int race = 0;
-	const Actor *act = GetActorFromSlot(slot);
+	const Actor* act = GetActorFromSlot(slot);
 	if (act) {
-		race=act->GetStat(IE_RACE);
+		race = act->GetStat(IE_RACE);
 	}
 
 	AutoTable tab = gamedata->LoadTable("races");
@@ -179,13 +190,13 @@ ieStrRef TLKImporter::RaceStrRef(int slot) const
 		return ieStrRef::INVALID;
 	}
 	TableMgr::index_t row = tab->FindTableValue(3, race, 0);
-	return tab->QueryFieldAsStrRef(row,0);
+	return tab->QueryFieldAsStrRef(row, 0);
 }
 
 ieStrRef TLKImporter::GenderStrRef(int slot, ieStrRef malestrref, ieStrRef femalestrref) const
 {
-	const Actor *act = GetActorFromSlot(slot);
-	if (act && (act->GetStat(IE_SEX)==SEX_FEMALE) ) {
+	const Actor* act = GetActorFromSlot(slot);
+	if (act && (act->GetStat(IE_SEX) == SEX_FEMALE)) {
 		return femalestrref;
 	}
 	return malestrref;
@@ -203,7 +214,7 @@ String TLKImporter::BuiltinToken(const ieVariable& Token)
 
 	//these are hardcoded, all engines are the same or don't use them
 	if (Token == "DAYANDMONTH") {
-		ieDword dayandmonth = core->GetVariable("DAYANDMONTH", 0);
+		ieDword dayandmonth = core->GetDictionary().Get("DAYANDMONTH", 0);
 		//preparing sub-tokens
 		core->GetCalendar()->GetMonthName((int) dayandmonth);
 		return GetString(ieStrRef::DAYANDMONTH, STRING_FLAGS::RESOLVE_TAGS);
@@ -244,7 +255,7 @@ String TLKImporter::BuiltinToken(const ieVariable& Token)
 	}
 	if (Token == "MAGESCHOOL") {
 		//this is subject to change, the row number in magesch.2da, default value is 0 (generalist)
-		ieDword row = core->GetVariable("MAGESCHOOL", 0);
+		ieDword row = core->GetDictionary().Get("MAGESCHOOL", 0);
 		AutoTable tm = gamedata->LoadTable("magesch");
 		if (tm) {
 			ieStrRef value = tm->QueryFieldAsStrRef(row, 2);
@@ -252,38 +263,36 @@ String TLKImporter::BuiltinToken(const ieVariable& Token)
 		}
 	}
 	if (Token == "TM") {
-		return L"\x99";
+		return u"\x99";
 	}
 
-	return L"";
+	return u"";
 }
 
 String TLKImporter::ResolveTags(const String& source)
 {
 	const size_t strLen = source.length();
-	auto mystrncpy = [&source, &strLen](ieVariable& tok, size_t idx, wchar_t delim)
-	{
+	auto mystrncpy = [&source, &strLen](ieVariable& tok, size_t idx, wchar_t delim) {
 		char* dest = tok.begin();
 		auto maxlength = std::min(sizeof(ieVariable) - 1, strLen);
 		while (idx < source.length() && (source[idx] != delim) && maxlength--) {
 			char chr = source[idx++];
-			if (chr != ' ') *dest++ = chr;
+			if (chr != u' ') *dest++ = chr;
 		}
 		*dest = '\0';
 		return idx;
 	};
-	
+
 	ieVariable Token;
 	String dest;
 	for (size_t i = 0; source[i]; i++) {
 		auto srcch = source[i];
-		if (srcch == L'<') {
-			i = mystrncpy(Token, i + 1, L'>');
+		if (srcch == u'<') {
+			i = mystrncpy(Token, i + 1, u'>');
 			String resolvedToken = BuiltinToken(Token);
 			if (resolvedToken.empty()) {
-
 				auto& tokens = core->GetTokenDictionary();
-				auto lookup = tokens.find(Token.c_str());
+				auto lookup = tokens.find(Token);
 				if (lookup != tokens.cend()) {
 					dest.append(lookup->second);
 				}
@@ -291,21 +300,21 @@ String TLKImporter::ResolveTags(const String& source)
 			} else {
 				dest.append(resolvedToken);
 			}
-		} else if (srcch == L'%' && i + 1 < strLen - 1) {
+		} else if (srcch == u'%' && i + 1 <= strLen - 1) {
 			// also resolve format strings
 			// we assume they are % followed by a single character
 			auto nextch = source[i + 1];
 			// we are going to only work with %d
 			// the originals dont seem to use anything else so we will play it safe
-			if (nextch != L'd') {
+			if (nextch != u'd') {
 				dest.push_back(srcch);
 			} else {
-				dest.append(L"{}");
+				dest.append(u"{}");
 				++i;
 			}
-		} else if (srcch == L'[') {
+		} else if (srcch == u'[') {
 			// voice actor directives
-			i = source.find_first_of(L']', i + 1);
+			i = source.find_first_of(u']', i + 1);
 			if (i == String::npos) break;
 		} else {
 			dest.push_back(srcch);
@@ -335,47 +344,51 @@ String TLKImporter::GetString(ieStrRef strref, STRING_FLAGS flags)
 		if (OverrideTLK) {
 			size_t Length;
 			char* cstr = OverrideTLK->ResolveAuxString(strref, Length);
-			String* tmp = StringFromCString(cstr);
-			std::swap(string, *tmp);
+			string = StringFromTLK(StringView(cstr, Length));
 			free(cstr);
-			delete tmp;
 		}
 		type = 0;
 		SoundResRef.Reset();
 	} else {
 		ieDword Volume, Pitch, StrOffset;
 		ieDword l;
-		if (str->Seek( 18 + (ieDword(strref) * 0x1A), GEM_STREAM_START ) == GEM_ERROR) {
-			return L"";
+		if (str->Seek(18 + (ieDword(strref) * 0x1A), GEM_STREAM_START) == GEM_ERROR) {
+			return u"";
 		}
 		str->ReadWord(type);
-		str->ReadResRef( SoundResRef );
+		str->ReadResRef(SoundResRef);
 		// volume and pitch variance fields are known to be unused at minimum in bg1
 		str->ReadDword(Volume);
 		str->ReadDword(Pitch);
 		str->ReadDword(StrOffset);
 		str->ReadDword(l);
-				
+
 		if (type & 1) {
-			str->Seek( StrOffset + Offset, GEM_STREAM_START );
+			if (str->Seek(StrOffset + Offset, GEM_STREAM_START) == GEM_ERROR) {
+				return u"";
+			}
 			std::string mbstr(l, '\0');
 			str->Read(&mbstr[0], l);
-			String* tmp = StringFromCString(mbstr.c_str());
-			std::swap(string, *tmp);
-			delete tmp;
+			string = StringFromTLK(mbstr);
 		}
 	}
 
 	if (bool(flags & STRING_FLAGS::RESOLVE_TAGS) || (type & 4)) {
 		string = ResolveTags(string);
 	}
-	if (type & 2 && bool(flags & STRING_FLAGS::SOUND) && !SoundResRef.IsEmpty()) {
+	if ((type & 2) && bool(flags & STRING_FLAGS::SOUND) && !SoundResRef.IsEmpty()) {
 		// GEM_SND_SPEECH will stop the previous sound source
-		unsigned int flag = GEM_SND_RELATIVE | (uint32_t(flags) & (GEM_SND_SPEECH | GEM_SND_QUEUE));
-		core->GetAudioDrv()->Play(SoundResRef, SFX_CHAN_DIALOG, Point(), flag);
+		unsigned int flag = (uint32_t(flags) & (GEM_SND_SPEECH | GEM_SND_QUEUE));
+
+		// Narrator's error announcements (ambush, incomplete party)
+		SFXChannel channel = SoundResRef.BeginsWith("ERROR") ? SFXChannel::Narrator : SFXChannel::Dialog;
+		core->strrefHandle = core->GetAudioDrv()->Play(SoundResRef, channel, Point(), flag);
 	}
 	if (bool(flags & STRING_FLAGS::STRREFON)) {
-		string = fmt::to_wstring(ieDword(strref)) + L": " + string;
+		string = fmt::format(u"{}: {}", ieDword(strref), string);
+	}
+	if (hasEndingNewline) {
+		RTrim(string, u"\n");
 	}
 	return string;
 }
@@ -393,11 +406,13 @@ StringBlock TLKImporter::GetStringBlock(ieStrRef strref, STRING_FLAGS flags)
 		return StringBlock();
 	}
 	ieWord type;
-	str->Seek( 18 + (ieDword(strref) * 0x1A), GEM_STREAM_START );
+	if (str->Seek(18 + (ieDword(strref) * 0x1A), GEM_STREAM_START) == GEM_ERROR) {
+		return StringBlock();
+	}
 	str->ReadWord(type);
 	ResRef soundRef;
-	str->ReadResRef( soundRef );
-	return StringBlock(GetString( strref, flags ), soundRef);
+	str->ReadResRef(soundRef);
+	return StringBlock(GetString(strref, flags), soundRef);
 }
 
 #include "plugindef.h"
