@@ -23,11 +23,12 @@
 #include "TlkOverride.h"
 
 #include "Interface.h"
+
 #include "Logging/Logging.h"
 
 #include <algorithm>
-#include <cstdio>
 #include <cassert>
+#include <cstdio>
 
 using namespace GemRB;
 
@@ -41,23 +42,23 @@ bool CTlkOverride::Init()
 	CloseResources();
 	//Creation of the headers should be game specific, some games don't have these
 	toh_str = GetAuxHdr(true);
-	if (toh_str == NULL) {
+	if (!toh_str) {
 		return false;
 	}
 	tot_str = GetAuxTlk(true);
-	if (tot_str == NULL) {
+	if (!tot_str) {
 		return false;
 	}
 
 	char Signature[8];
 
-	memset(Signature,0,8);
-	toh_str->Read( Signature, 4 );
-	if (strncmp( Signature, "TLK ", 4 ) != 0) {
+	memset(Signature, 0, 8);
+	toh_str->Read(Signature, 4);
+	if (strncmp(Signature, "TLK ", 4) != 0) {
 		Log(ERROR, "TLKImporter", "Not a valid TOH file.");
 		return false;
 	}
-	toh_str->Seek( 8, GEM_CURRENT_POS );
+	toh_str->Seek(8, GEM_CURRENT_POS);
 	toh_str->ReadDword(AuxCount);
 	if (tot_str->ReadScalar<strpos_t, int32_t>(FreeOffset) != 4) {
 		FreeOffset = DataStream::InvalidPos;
@@ -71,15 +72,12 @@ void CTlkOverride::CloseResources()
 {
 	if (toh_str) {
 		delete toh_str;
-		toh_str=NULL;
+		toh_str = nullptr;
 	}
 	if (tot_str) {
 		delete tot_str;
-		tot_str=NULL;
+		tot_str = nullptr;
 	}
-#ifdef CACHE_TLK_OVERRIDE
-	stringmap.clear();
-#endif
 }
 
 //gets the length of a stored string which might span more than one segment
@@ -88,17 +86,16 @@ strret_t CTlkOverride::GetLength(strpos_t offset)
 	strpos_t tmp = offset;
 	char buffer[SEGMENT_SIZE];
 
-	if (tot_str->Seek(offset+8, GEM_STREAM_START) != GEM_OK) {
+	if (tot_str->Seek(offset + 8, GEM_STREAM_START) != GEM_OK) {
 		return 0;
 	}
 
 	strret_t length = 0;
-	do
-	{
-		if (tot_str->Seek(tmp+8, GEM_STREAM_START) != GEM_OK) {
+	do {
+		if (tot_str->Seek(tmp + 8, GEM_STREAM_START) != GEM_OK) {
 			return 0;
 		}
-		memset(buffer,0,sizeof(buffer));
+		memset(buffer, 0, sizeof(buffer));
 		tot_str->Read(buffer, SEGMENT_SIZE);
 		tot_str->ReadScalar<strpos_t, int32_t>(tmp);
 		if (tmp != DataStream::InvalidPos) {
@@ -114,26 +111,26 @@ strret_t CTlkOverride::GetLength(strpos_t offset)
 char* CTlkOverride::GetString(strpos_t offset)
 {
 	if (!tot_str) {
-		return NULL;
+		return nullptr;
 	}
 
 	strret_t length = GetLength(offset);
 	if (length == 0) {
-		return NULL;
+		return nullptr;
 	}
 
 	//assuming char is one byte
-	char *ret = (char *) malloc(length+1);
-	char *pos = ret;
-	ret[length]=0;
-	while(length) {
-		tot_str->Seek(offset+8, GEM_STREAM_START);
+	char* ret = (char*) malloc(length + 1);
+	char* pos = ret;
+	ret[length] = 0;
+	while (length) {
+		tot_str->Seek(offset + 8, GEM_STREAM_START);
 		strret_t tmp = std::min<strret_t>(length, SEGMENT_SIZE);
 		tot_str->Read(pos, tmp);
-		tot_str->Seek(SEGMENT_SIZE-tmp, GEM_CURRENT_POS);
+		tot_str->Seek(SEGMENT_SIZE - tmp, GEM_CURRENT_POS);
 		tot_str->ReadScalar<strpos_t, int32_t>(offset);
-		length-=tmp;
-		pos+=tmp;
+		length -= tmp;
+		pos += tmp;
 	}
 	return ret;
 }
@@ -149,15 +146,13 @@ ieStrRef CTlkOverride::UpdateString(ieStrRef strref, const String& string)
 		assert(strref != ieStrRef::INVALID);
 	}
 
-	// FIXME: newvalue could be a multibyte string in an encoding incompatible with ASCII
-	std::string newvalue = MBStringFromString(string);
+	std::string newvalue = TLKStringFromString(string);
 	size_t length = std::min<size_t>(newvalue.length(), std::numeric_limits<uint16_t>::max());
 
 	//set the backpointer of the first string segment
 	strpos_t backp = DataStream::InvalidPos;
 
-	do
-	{
+	do {
 		//fill the backpointer
 		tot_str->Seek(offset + 4, GEM_STREAM_START);
 		tot_str->WriteScalar<strpos_t, int32_t>(backp);
@@ -174,7 +169,7 @@ ieStrRef CTlkOverride::UpdateString(ieStrRef strref, const String& string)
 			if (offset != DataStream::InvalidPos) {
 				strpos_t freep = offset;
 				offset = DataStream::InvalidPos;
-				tot_str->Seek(-4,GEM_CURRENT_POS);
+				tot_str->Seek(-4, GEM_CURRENT_POS);
 				tot_str->WriteScalar<strpos_t, int32_t>(offset);
 				ReleaseSegment(freep);
 			}
@@ -184,10 +179,10 @@ ieStrRef CTlkOverride::UpdateString(ieStrRef strref, const String& string)
 		if (offset == DataStream::InvalidPos) {
 			//no more space, but we need some
 			offset = ClaimFreeSegment();
-			tot_str->Seek(-4,GEM_CURRENT_POS);
+			tot_str->Seek(-4, GEM_CURRENT_POS);
 			tot_str->WriteScalar<strpos_t, int32_t>(offset);
 		}
-	} while(length);
+	} while (length);
 
 	return strref;
 }
@@ -196,7 +191,7 @@ strpos_t CTlkOverride::ClaimFreeSegment()
 {
 	strpos_t offset = FreeOffset;
 	strpos_t pos = tot_str->GetPos();
-	
+
 	if (offset == DataStream::InvalidPos) {
 		offset = tot_str->Size();
 	} else {
@@ -206,13 +201,11 @@ strpos_t CTlkOverride::ClaimFreeSegment()
 		}
 	}
 	ieDword tmp = 0;
-	char buffer[SEGMENT_SIZE];
-	memset(buffer, 0, sizeof(buffer));
 	tot_str->Seek(offset, GEM_STREAM_START);
 	tot_str->WriteDword(tmp);
 	tmp = 0xffffffff;
 	tot_str->WriteDword(tmp);
-	tot_str->Write(buffer, SEGMENT_SIZE);
+	tot_str->WriteFilling(SEGMENT_SIZE);
 	tot_str->WriteDword(tmp);
 
 	//update free segment pointer
@@ -262,8 +255,6 @@ ieStrRef CTlkOverride::GetNewStrRef(ieStrRef strref)
 {
 	EntryType entry;
 
-	memset(&entry,0,sizeof(entry));
-
 	if (strref >= ieStrRef::BIO_START && strref <= ieStrRef::BIO_END) {
 		entry.strref = strref;
 	} else {
@@ -273,10 +264,13 @@ ieStrRef CTlkOverride::GetNewStrRef(ieStrRef strref)
 
 	toh_str->Seek(TOH_HEADER_SIZE + AuxCount * EntryType::FileSize, GEM_STREAM_START);
 	toh_str->WriteStrRef(entry.strref);
-	toh_str->Write(entry.dummy, 20);
+	toh_str->WriteDword(entry.flags);
+	toh_str->WriteResRef(entry.soundRef);
+	toh_str->WriteDword(entry.volumeVariance);
+	toh_str->WriteDword(entry.pitchVariance);
 	toh_str->WriteScalar<strpos_t, int32_t>(entry.offset);
 	AuxCount++;
-	toh_str->Seek(12,GEM_STREAM_START);
+	toh_str->Seek(12, GEM_STREAM_START);
 	toh_str->WriteDword(AuxCount);
 	return entry.strref;
 }
@@ -287,33 +281,21 @@ strpos_t CTlkOverride::LocateString(ieStrRef strref)
 	ieDword offset;
 
 	if (!toh_str) return DataStream::InvalidPos;
-	toh_str->Seek(TOH_HEADER_SIZE,GEM_STREAM_START);
-	for(ieDword i=0;i<AuxCount;i++) {
+	toh_str->Seek(TOH_HEADER_SIZE, GEM_STREAM_START);
+	for (ieDword i = 0; i < AuxCount; i++) {
 		toh_str->ReadStrRef(strref2);
-		toh_str->Seek(20,GEM_CURRENT_POS);
+		toh_str->Seek(20, GEM_CURRENT_POS);
 		toh_str->ReadDword(offset);
-		if (strref2==strref) {
+		if (strref2 == strref) {
 			return offset;
 		}
 	}
 	return DataStream::InvalidPos;
 }
 
-//this function handles all of the .tlk override mechanism with caching
-//strings it once found
-//it is possible to turn off caching
-char* CTlkOverride::ResolveAuxString(ieStrRef strref, size_t &Length)
+char* CTlkOverride::ResolveAuxString(ieStrRef strref, size_t& Length)
 {
-	char *string;
-
-#ifdef CACHE_TLK_OVERRIDE
-	StringMapType::iterator tmp = stringmap.find(strref);
-	if (tmp!=stringmap.end()) {
-		return CS((*tmp).second);
-	}
-#endif
-
-	string = NULL;
+	char* string = nullptr;
 	strpos_t offset = LocateString(strref);
 	if (offset != DataStream::InvalidPos) {
 		string = GetString(offset);
@@ -322,21 +304,18 @@ char* CTlkOverride::ResolveAuxString(ieStrRef strref, size_t &Length)
 		Length = strlen(string);
 	} else {
 		Length = 0;
-		string = ( char* ) malloc( 1 );
+		string = (char*) malloc(1);
 		string[0] = 0;
 	}
-#ifdef CACHE_TLK_OVERRIDE
-	stringmap[strref]=CS(string);
-#endif
+
 	return string;
 }
 
 DataStream* CTlkOverride::GetAuxHdr(bool create)
 {
-	char nPath[_MAX_PATH];
 	char Signature[] = "TLK ";
 
-	PathJoin(nPath, core->config.CachePath, "default.toh", nullptr);
+	path_t nPath = PathJoin(core->config.CachePath, "default.toh");
 	FileStream* fs = new FileStream();
 
 	while (true) {
@@ -357,8 +336,7 @@ DataStream* CTlkOverride::GetAuxHdr(bool create)
 
 DataStream* CTlkOverride::GetAuxTlk(bool create)
 {
-	char nPath[_MAX_PATH];
-	PathJoin(nPath, core->config.CachePath, "default.tot", nullptr);
+	path_t nPath = PathJoin(core->config.CachePath, "default.tot");
 	FileStream* fs = new FileStream();
 
 	while (true) {
@@ -385,4 +363,3 @@ DataStream* CTlkOverride::GetAuxTlk(bool create)
 		return nullptr;
 	}
 }
-
