@@ -29,32 +29,27 @@
 #include "Streams/FileStream.h"
 #include "Strings/String.h"
 
-#ifdef CACHE_TLK_OVERRIDE
-#include <map>
-
-using StringMapType = std::map<ieStrRef, char *>;
-#endif
-
 namespace GemRB {
 
 constexpr strret_t SEGMENT_SIZE = 512;
 #define TOH_HEADER_SIZE 20
 
-struct EntryType
-{
-	ieStrRef strref;
-	ieByte dummy[20];
-	strpos_t offset;
-	
+// this mimics normal TLK entries with a bunch of unused / not useful fields
+// the originals passed it around whole, but since custom entries were never
+// used outside the UI, the flags and sound fields don't matter
+struct EntryType {
+	ieStrRef strref = ieStrRef::INVALID;
+	ieDword flags = 0;
+	ResRef soundRef;
+	ieDword volumeVariance = 0;
+	ieDword pitchVariance = 0;
+	strpos_t offset = 0;
+
 	static constexpr strpos_t FileSize = 28; // size in bytes for this structure in the TLK file
 };
 
-class CTlkOverride  
-{
+class CTlkOverride {
 private:
-#ifdef CACHE_TLK_OVERRIDE
-	StringMapType stringmap;
-#endif
 	DataStream* tot_str = nullptr;
 	DataStream* toh_str = nullptr;
 	ieDword AuxCount = 0;
@@ -62,15 +57,15 @@ private:
 	strpos_t NextStrRef = DataStream::InvalidPos;
 
 	void CloseResources();
-	DataStream *GetAuxHdr(bool create);
-	DataStream *GetAuxTlk(bool create);
+	DataStream* GetAuxHdr(bool create);
+	DataStream* GetAuxTlk(bool create);
 	ieStrRef GetNewStrRef(ieStrRef strref);
 	strpos_t LocateString(ieStrRef strref);
-	ieStrRef GetNextStrRef();
 	strpos_t ClaimFreeSegment();
 	void ReleaseSegment(strpos_t offset);
-	char *GetString(strpos_t offset);
+	char* GetString(strpos_t offset);
 	strret_t GetLength(strpos_t offset);
+
 public:
 	CTlkOverride() noexcept = default;
 	CTlkOverride(const CTlkOverride&) = delete;
@@ -78,11 +73,11 @@ public:
 	CTlkOverride& operator=(const CTlkOverride&) = delete;
 
 	bool Init();
-	char *ResolveAuxString(ieStrRef strref, size_t &Length);
+	char* ResolveAuxString(ieStrRef strref, size_t& Length);
 	ieStrRef UpdateString(ieStrRef strref, const String& newvalue);
+	ieStrRef GetNextStrRef();
 };
 
-#endif //TLKOVERRIDE_H
 }
 
-
+#endif //TLKOVERRIDE_H
