@@ -19,37 +19,39 @@
  */
 
 #include "TTFFont.h"
+
 #include "Interface.h"
-#include "Logging/Logging.h"
 #include "Sprite2D.h"
+
+#include "Logging/Logging.h"
+#include "Strings/Iconv.h"
 #include "Video/Video.h"
 
+#include <cerrno>
 #include <cstdint>
 #include <utility>
-#include <iconv.h>
-#include <cerrno>
 
 namespace GemRB {
 
 const Glyph& TTFFont::AliasBlank(ieWord chr) const
 {
-	((TTFFont*)this)->CreateAliasForChar(0, chr);
+	((TTFFont*) this)->CreateAliasForChar(0, chr);
 	return Font::GetGlyph(chr);
 }
 
 const Glyph& TTFFont::GetGlyph(ieWord chr) const
 {
 	if (!core->TLKEncoding.multibyte) {
-		char* oldchar = (char*)&chr;
+		char* oldchar = (char*) &chr;
 		ieWord unicodeChr = 0;
-		char* newchar = (char*)&unicodeChr;
+		char* newchar = (char*) &unicodeChr;
 		size_t in = (core->TLKEncoding.widechar) ? 2 : 1;
 		size_t out = 2;
 
 		// TODO: make this work on BE systems
 		// TODO: maybe we want to work with non-unicode fonts?
 		iconv_t cd = iconv_open("UTF-16LE", core->TLKEncoding.encoding.c_str());
-		size_t ret = iconv(cd, &oldchar, &in, &newchar, &out);
+		size_t ret = portableIconv(cd, &oldchar, &in, &newchar, &out);
 
 		if (ret != GEM_OK) {
 			Log(ERROR, "FONT", "iconv error: {}", errno);
@@ -90,8 +92,8 @@ const Glyph& TTFFont::GetGlyph(ieWord chr) const
 		return AliasBlank(chr);
 	}
 
-	error = FT_Load_Glyph( face, index, FT_LOAD_DEFAULT | FT_LOAD_TARGET_MONO);
-	if( error ) {
+	error = FT_Load_Glyph(face, index, FT_LOAD_DEFAULT | FT_LOAD_TARGET_MONO);
+	if (error) {
 		LogFTError(error);
 		return AliasBlank(chr);
 	}
@@ -118,7 +120,7 @@ const Glyph& TTFFont::GetGlyph(ieWord chr) const
 	// TODO: handle styles for fonts that dont do it themselves
 
 	 FIXME: maxx is currently unused.
-	 glyph spacing is non existant right now
+	 glyph spacing is non-existent right now
 	 font styles are non functional too
 	 */
 
@@ -127,7 +129,7 @@ const Glyph& TTFFont::GetGlyph(ieWord chr) const
 
 	/* Render the glyph */
 	error = FT_Render_Glyph(glyph, FT_RENDER_MODE_NORMAL);
-	if( error ) {
+	if (error) {
 		LogFTError(error);
 		return AliasBlank(chr);
 	}
@@ -147,11 +149,11 @@ const Glyph& TTFFont::GetGlyph(ieWord chr) const
 		return AliasBlank(chr);
 	}
 
-	pixels = (uint8_t*)malloc(sprSize.w * sprSize.h);
+	pixels = (uint8_t*) malloc(sprSize.w * sprSize.h);
 	uint8_t* dest = pixels;
 	const uint8_t* src = bitmap->buffer;
 
-	for( int row = 0; row < sprSize.h; row++ ) {
+	for (int row = 0; row < sprSize.h; row++) {
 		// TODO: handle italics. we will need to offset the row by font->glyph_italics * row i think.
 		memcpy(dest, src, sprSize.w);
 		dest += sprSize.w;
@@ -164,9 +166,9 @@ const Glyph& TTFFont::GetGlyph(ieWord chr) const
 
 	Region r(glyph->bitmap_left, glyph->bitmap_top, sprSize.w, sprSize.h);
 	PixelFormat fmt = PixelFormat::Paletted8Bit(palette, true, 0);
-	Holder<Sprite2D> spr = core->GetVideoDriver()->CreateSprite(r, pixels, fmt);
+	Holder<Sprite2D> spr = VideoDriver->CreateSprite(r, pixels, fmt);
 	// FIXME: casting away const
-	const Glyph& ret = ((TTFFont*)this)->CreateGlyphForCharSprite(chr, spr);
+	const Glyph& ret = ((TTFFont*) this)->CreateGlyphForCharSprite(chr, spr);
 	return ret;
 }
 
@@ -174,7 +176,7 @@ int TTFFont::GetKerningOffset(ieWord leftChr, ieWord rightChr) const
 {
 	FT_UInt leftIndex = FT_Get_Char_Index(face, leftChr);
 	FT_UInt rightIndex = FT_Get_Char_Index(face, rightChr);
-	FT_Vector kerning = {0,0};
+	FT_Vector kerning = { 0, 0 };
 	// FT_KERNING_DEFAULT is "grid fitted". we will end up with a scaled multiple of 64
 	FT_Error error = FT_Get_Kerning(face, leftIndex, rightIndex, FT_KERNING_DEFAULT, &kerning);
 	if (error) {
@@ -182,16 +184,16 @@ int TTFFont::GetKerningOffset(ieWord leftChr, ieWord rightChr) const
 		return 0;
 	}
 	// kerning is in 26.6 format. basically divide by 64 to get the number of pixels.
-	return (int)(-kerning.x / 64);
+	return (int) (-kerning.x / 64);
 }
 
-TTFFont::TTFFont(PaletteHolder pal, FT_Face face, int lineheight, int baseline)
-: Font(std::move(pal), lineheight, baseline, false), face(face)
+TTFFont::TTFFont(Holder<Palette> pal, FT_Face face, int lineheight, int baseline)
+	: Font(std::move(pal), lineheight, baseline, false), face(face)
 {
 	FT_Reference_Face(face); // retain the face or the font manager will destroy it
 	// ttf fonts dont produce glyphs for whitespace
 	PixelFormat fmt = PixelFormat::Paletted8Bit(palette);
-	Holder<Sprite2D> blank = core->GetVideoDriver()->CreateSprite(Region(), nullptr, fmt);
+	Holder<Sprite2D> blank = VideoDriver->CreateSprite(Region(), nullptr, fmt);
 	// blank for returning when there is an error
 	// TODO: ttf fonts have a "box" glyph they use for this
 	CreateGlyphForCharSprite(0, blank);
