@@ -22,21 +22,20 @@
 #define __GemRB__TTFFont__
 
 #include "Freetype.h"
+#include "Holder.h"
 
 #include "GUI/TextSystem/Font.h"
-#include "Holder.h"
 
 namespace GemRB {
 
-class TTFFont : public Font
-{
+class TTFFont : public Font {
 private:
-	FT_Face face;
+	FT_Face face = nullptr;
 
 	const Glyph& AliasBlank(ieWord chr) const;
 
 public:
-	TTFFont(PaletteHolder pal, FT_Face face, int lineheight, int baseline);
+	TTFFont(Holder<Palette> pal, FT_Face face, int lineheight, int baseline);
 	~TTFFont(void) override;
 
 	const Glyph& GetGlyph(ieWord chr) const override;
