@@ -18,19 +18,21 @@
  *
  */
 
-#include "Interface.h"
-#include "Palette.h"
-#include "TTFFont.h"
 #include "TTFFontManager.h"
 
-using namespace GemRB;
+#include "Palette.h"
+#include "TTFFont.h"
+
+namespace GemRB {
+
+struct CoreSettings;
 
 FT_Library library = NULL;
 
-static void loadFT()
+static void loadFT(const CoreSettings&)
 {
-	FT_Error error = FT_Init_FreeType( &library );
-	if ( error ) {
+	FT_Error error = FT_Init_FreeType(&library);
+	if (error) {
 		LogFTError(error);
 	}
 }
@@ -38,7 +40,7 @@ static void loadFT()
 static void destroyFT()
 {
 	if (library) {
-		FT_Done_FreeType( library );
+		FT_Done_FreeType(library);
 		library = NULL;
 	}
 }
@@ -53,29 +55,30 @@ bool TTFFontManager::Import(DataStream* stream)
 	Close();
 	if (stream) {
 		FT_Error error;
-
-		ftStream = new std::remove_pointer<FT_Stream>::type{};
-		ftStream->read = [](FT_Stream TTFStream, unsigned long	offset, unsigned char* buffer, unsigned long count)
-		-> unsigned long {
+		ftStream = new std::remove_pointer_t<FT_Stream> {};
+		ftStream->read = [](FT_Stream TTFStream, unsigned long offset, unsigned char* buffer, unsigned long count)
+			-> unsigned long {
 			DataStream* dstream = static_cast<DataStream*>(TTFStream->descriptor.pointer);
 			dstream->Seek(offset, GEM_STREAM_START);
 			return dstream->Read(buffer, count);
 		};
 
-		ftStream->close = [](FT_Stream TTFStream){
+		ftStream->close = [](FT_Stream TTFStream) {
 			delete static_cast<DataStream*>(TTFStream->descriptor.pointer);
 			delete TTFStream;
 		};
-		ftStream->descriptor.pointer = stream->Clone();
-		ftStream->pos = stream->GetPos();
-		ftStream->size = stream->Size();
+
+		DataStream* clone = stream->Clone();
+		ftStream->descriptor.pointer = clone;
+		ftStream->pos = clone->GetPos();
+		ftStream->size = clone->Size();
 
 		FT_Open_Args args = FT_Open_Args();
 		args.flags = FT_OPEN_STREAM;
 		args.stream = ftStream;
 
-		error = FT_Open_Face( library, &args, 0, &face );
-		if( error ) {
+		error = FT_Open_Face(library, &args, 0, &face);
+		if (error) {
 			LogFTError(error);
 			Close();
 			return false;
@@ -93,17 +96,19 @@ void TTFFontManager::Close()
 {
 	if (face) {
 		FT_Done_Face(face);
+		face = nullptr;
 	}
 }
 
-Font* TTFFontManager::GetFont(unsigned short pxSize, FontStyle /*style*/, bool /*background*/)
+Holder<Font> TTFFontManager::GetFont(unsigned short pxSize, FontStyle /*style*/, bool /*background*/)
 {
-	PaletteHolder pal = MakeHolder<Palette>(ColorWhite, ColorBlack);
-	
+	Holder<Palette> pal = MakeHolder<Palette>(ColorWhite, ColorBlack);
+
+	Palette::Colors buffer;
 	// FIXME: we probably dont need to do this
 	// Font already can do blending between fg and bg colors
 	for (int i = 1; i < 256; ++i) {
-		Color& c = pal->col[i];
+		auto c = pal->GetColorAt(i);
 		unsigned int m = (c.r + c.g + c.b) / 3;
 		if (m > 2) {
 			int tmp = m * MUL;
@@ -111,16 +116,19 @@ Font* TTFFontManager::GetFont(unsigned short pxSize, FontStyle /*style*/, bool /
 		} else {
 			c.a = 0;
 		}
+		buffer[i] = c;
 	}
 
+	pal->CopyColors(1, buffer.cbegin() + 1, buffer.cend());
+
 	FT_Error error = 0;
 	ieWord lineHeight = 0, baseline = 0;
 	/* Make sure that our font face is scalable (global metrics) */
-	if ( FT_IS_SCALABLE(face) ) {
+	if (FT_IS_SCALABLE(face)) {
 		FT_Fixed scale;
 		/* Set the character size and use default DPI (72) */
-		error = FT_Set_Pixel_Sizes( face, 0, pxSize );
-		if( error ) {
+		error = FT_Set_Pixel_Sizes(face, 0, pxSize);
+		if (error) {
 			LogFTError(error);
 		} else {
 			/* Get the scalable font metrics for this font */
@@ -137,12 +145,12 @@ Font* TTFFontManager::GetFont(unsigned short pxSize, FontStyle /*style*/, bool /
 		 * or series of fonts to grab from the non-scalable format.
 		 * It is not the point size of the font.
 		 * */
-		if ( pxSize >= face->num_fixed_sizes )
+		if (pxSize >= face->num_fixed_sizes)
 			pxSize = face->num_fixed_sizes - 1;
 
-		error = FT_Set_Pixel_Sizes( face,
-								   face->available_sizes[pxSize].height,
-								   face->available_sizes[pxSize].width );
+		error = FT_Set_Pixel_Sizes(face,
+					   face->available_sizes[pxSize].height,
+					   face->available_sizes[pxSize].width);
 
 		if (error) {
 			LogFTError(error);
@@ -159,13 +167,15 @@ Font* TTFFontManager::GetFont(unsigned short pxSize, FontStyle /*style*/, bool /
 		//font->underline_height = FT_FLOOR(face->underline_thickness);
 	}
 
-	return new TTFFont(pal, face, lineHeight, baseline);
+	return MakeHolder<TTFFont>(pal, face, lineHeight, baseline);
+}
+
 }
 
 #include "plugindef.h"
 
 GEMRB_PLUGIN(0x3AD6427C, "TTF Font Importer")
-PLUGIN_RESOURCE(TTFFontManager, "ttf")
+PLUGIN_IE_RESOURCE(TTFFontManager, "ttf", (ieWord) IE_TTF_CLASS_ID)
 PLUGIN_INITIALIZER(loadFT)
 PLUGIN_CLEANUP(destroyFT)
 END_PLUGIN()
