@@ -21,9 +21,8 @@
 #ifndef GemRB_TTFFont_h
 #define GemRB_TTFFont_h
 
-#include "Freetype.h"
-
 #include "FontManager.h"
+#include "Freetype.h"
 
 namespace GemRB {
 
@@ -41,7 +40,7 @@ public:
 	bool Import(DataStream* stream) override;
 	void Close();
 
-	Font* GetFont(unsigned short pxSize, FontStyle style, bool background) override;
+	Holder<Font> GetFont(unsigned short pxSize, FontStyle style, bool background) override;
 };
 
 }
