@@ -20,27 +20,27 @@
 
 // GemRB.cpp : Defines the entry point for the application.
 
-#include <clocale> //language encoding
-#include <SDL.h>
-
 #include "AndroidLogger.h"
 #include "Interface.h"
 
+#include <SDL.h>
+#include <clocale> //language encoding
+
 // if/when android moves to SDL 1.3 remove these special functions.
 // SDL 1.3 fires window events for these conditions that are handled in SDLVideo.cpp.
 // see SDL_WINDOWEVENT_MINIMIZED and SDL_WINDOWEVENT_RESTORED
-#if SDL_COMPILEDVERSION < SDL_VERSIONNUM(1,3,0)
-#include "Audio.h"
+#if SDL_COMPILEDVERSION < SDL_VERSIONNUM(1, 3, 0)
+	#include "Audio.h"
 
 // pause audio playing if app goes in background
 static void appPutToBackground()
 {
-  GemRB::core->GetAudioDrv()->Pause();
+	GemRB::core->GetAudioDrv()->Pause();
 }
 // resume audio playing if app return to foreground
 static void appPutToForeground()
 {
-  GemRB::core->GetAudioDrv()->Resume();
+	GemRB::core->GetAudioDrv()->Resume();
 }
 
 #endif
@@ -53,40 +53,35 @@ int main(int argc, char* argv[])
 	setenv("SDL_VIDEO_X11_WMCLASS", argv[0], 0);
 	setenv("GEMRB_DATA", SDL_AndroidGetExternalStoragePath(), 1);
 
-	// Prevent fragmentation of the heap by malloc (glibc).
-	// The default threshold is 128*1024, which can result in a large memory usage
-	// due to fragmentation since we use a lot of small objects. On the other hand
-	// if the threshold is too low, free() starts to permanently ask the kernel
-	// about shrinking the heap.
-	#if defined(HAVE_UNISTD_H)
-		int pagesize = sysconf(_SC_PAGESIZE);
-	#else
-		int pagesize = 4*1024;
-	#endif
+// Prevent fragmentation of the heap by malloc (glibc).
+// The default threshold is 128*1024, which can result in a large memory usage
+// due to fragmentation since we use a lot of small objects. On the other hand
+// if the threshold is too low, free() starts to permanently ask the kernel
+// about shrinking the heap.
+#if defined(HAVE_UNISTD_H)
+	int pagesize = sysconf(_SC_PAGESIZE);
+#else
+	int pagesize = 4 * 1024;
+#endif
 	setenv("MALLOC_TRIM_THRESHOLD_", fmt::format("{}", 5 * pagesize), 1);
-	
+
 	AddLogWriter(createAndroidLogger());
 	ToggleLogging(true);
 
-	Interface::SanityCheck(VERSION_GEMRB);
+	SanityCheck();
 
-	core = new Interface();
-	CFGConfig* config = new CFGConfig(argc, argv);
-	
-	if (core->Init( config ) == GEM_ERROR) {
-		delete config;
-		delete( core );
-		Log(MESSAGE, "Main", "Aborting due to fatal error...");
-
-		return -1;
-	}
-	delete config;
-
-#if SDL_COMPILEDVERSION < SDL_VERSIONNUM(1,3,0)
-    SDL_ANDROID_SetApplicationPutToBackgroundCallback(&appPutToBackground, &appPutToForeground);
+	try {
+		Interface gemrb(LoadFromArgs(argc, argv));
+#if SDL_COMPILEDVERSION < SDL_VERSIONNUM(1, 3, 0)
+		SDL_ANDROID_SetApplicationPutToBackgroundCallback(&appPutToBackground, &appPutToForeground);
 #endif
+		gemrb.Main();
+	} catch (CoreInitializationException& cie) {
+		Log(FATAL, "Main", "Aborting due to fatal error... {}", cie);
+		return GEM_ERROR;
+	}
 
-	core->Main();
-	delete( core );
-	return 0;
+	VideoDriver.reset();
+
+	return GEM_OK;
 }
