@@ -106,23 +106,19 @@ using namespace GemRB;
 		[[NSFileManager defaultManager] changeCurrentDirectoryPath:NSHomeDirectory()];
 		setenv("PYTHONHOME", "Documents/python", 1);
 		setenv("PYTHONPATH", "Documents/python/lib/python27", 1);
-		core = new Interface();
-		CFGConfig* config = new CFGConfig(argc, argv);
-		free(argv);
-		if ((ret = core->Init(config)) == GEM_ERROR) {
-			delete config;
-			delete( core );
-			Log(MESSAGE, "Cocoa Wrapper", "Unable to initialize core. Relaunching wraper.");
+		
+		try {
+			Interface gemrb(LoadFromArgs(argc, argv));
+			free(argv);
+			gemrb.Main(); // pass control to GemRB
+		} catch (CoreInitializationException& cie) {
+			Log(FATAL, "Main", "Aborting due to fatal error... {}", cie);
 			// reload the wrapper interface so we can try again instead of dying
 			[self setupWrapper];
-		} else {
-			// pass control to GemRB
-			delete config;
-			core->Main();
-			delete( core );
-			// We must exit since the application runloop never returns.
-			exit(ret);
 		}
+
+		// We must exit since the application runloop never returns.
+		exit(GEM_OK);
 	}
 }
 
