@@ -23,6 +23,7 @@
 #import "AppleLogger.h"
 #import "Interface.h"
 #import "Logging/Logging.h"
+#import "PluginMgr.h"
 #import "Streams/FileStream.h"
 
 using namespace GemRB;
@@ -81,8 +82,6 @@ using namespace GemRB;
 // always called before openFile when launched via CLI/DragDrop
 - (void)applicationWillFinishLaunching:(NSNotification *) __unused aNotification
 {
-	AddLogWriter(Logger::WriterPtr(new AppleLogger()));
-
 	// Load default defaults
 	NSString* defaultsPath = [[NSBundle mainBundle] pathForResource:@"defaults" ofType:@"plist"];
 	NSMutableDictionary* defaultDict = [NSMutableDictionary dictionaryWithContentsOfFile:defaultsPath];
@@ -162,11 +161,6 @@ using namespace GemRB;
 		[[NSRunLoop mainRunLoop] performSelector:@selector(launchGame:) target:self argument:nil order:0 modes:modes];
 		return;
 	}
-	
-	ToggleLogging(true);
-
-	core = new Interface();
-	InterfaceConfig* config = new InterfaceConfig();
 
 	// load NSUserDefaults into config
 	NSUserDefaults* defaults = [NSUserDefaults standardUserDefaults];
@@ -185,6 +179,8 @@ using namespace GemRB;
 		}
 	}
 
+	InterfaceConfig config;
+
 	for ( NSString* key in dict ) {
 		NSString* value = nil;
 		id obj = [dict objectForKey:key];
@@ -194,27 +190,34 @@ using namespace GemRB;
 			value = (NSString*)obj;
 		}
 		if (value && ![value isEqualToString:@""]) {
-			config->SetKeyValuePair([key cStringUsingEncoding:NSASCIIStringEncoding],
-								[value cStringUsingEncoding:NSASCIIStringEncoding]);
+			std::string ckey = [key cStringUsingEncoding:NSASCIIStringEncoding];
+			config.Set(ckey, [value cStringUsingEncoding:NSASCIIStringEncoding]);
 		}
 	}
 	
-	if (core->Init(config) == GEM_ERROR) {
-		delete config;
-		delete( core );
-		core = NULL;
-		Log(MESSAGE, "Cocoa Wrapper", "Unable to initialize core. Terminating.");
-	} else {
+	try {
+		CoreSettings settings = LoadFromDictionary(std::move(config));
+		ToggleLogging(settings.Logging);
+
+		if (getenv("TERM") && isatty(STDOUT_FILENO)) {
+			AddLogWriter(createStdioLogWriter());
+		} else {
+			AddLogWriter(std::make_shared<AppleLogger>());
+		}
+
+		Interface gemrb(std::move(settings));
 		[_configWindow close];
 		// pass control to GemRB
-		delete config;
-		core->Main();
-		delete( core );
-		core = NULL;
+		gemrb.Main();
+		VideoDriver.reset();
+	} catch (std::exception& e) {
+		Log(FATAL, "Cocoa Wrapper", "Unable to initialize core: {}. Terminating.", e);
+	}
 
-		if ([defaults boolForKey:@"TerminateOnClose"]) {
-			[NSApp terminate:self];
-		}
+	PluginMgr::Get()->RunCleanup();
+
+	if ([defaults boolForKey:@"TerminateOnClose"]) {
+		[NSApp terminate:self];
 	}
 }
 
