@@ -16,22 +16,22 @@
  *
  */
 
-#include <algorithm>
-
 #include "CodepageToIconv.h"
 
+#include <algorithm>
+
 namespace GemRB {
 
-const char* GetIconvNameForCodepage(uint32_t codepage) {
-	const CodepageIconvMapEntry searchItem{codepage, ""};
+const char* GetIconvNameForCodepage(uint32_t codepage)
+{
+	const CodepageIconvMapEntry searchItem { codepage, "" };
 
 	auto entry =
 		std::lower_bound(
 			codepageIconvMap.cbegin(),
 			codepageIconvMap.cend(),
 			searchItem,
-			[](const CodepageIconvMapEntry& a, const CodepageIconvMapEntry& b) { return a.first < b.first; }
-		);
+			[](const CodepageIconvMapEntry& a, const CodepageIconvMapEntry& b) { return a.first < b.first; });
 
 	if (entry != codepageIconvMap.cend() && entry->first == codepage) {
 		return entry->second;
