@@ -20,40 +20,58 @@
 
 // GemRB.cpp : Defines the entry point for the application.
 
-#include "win32def.h" // logging
-#include <clocale> //language encoding
+#include "win32def.h"
 
 #include "Interface.h"
+#include "PluginMgr.h"
+
+#include "Logging/Loggers/Stdio.h"
 #include "Logging/Logging.h"
-#include "Win32Console.h"
+
+#include <clocale> //language encoding
 
 using namespace GemRB;
 
+void SetupLogging(const CoreSettings& cfg)
+{
+	if (cfg.Logging) {
+		ToggleLogging(cfg.Logging);
+	}
+
+	if (cfg.LogColor >= 0 && cfg.LogColor < int(ANSIColor::count)) {
+		AddLogWriter(createStdioLogWriter(ANSIColor(cfg.LogColor)));
+	} else {
+		AddLogWriter(createStdioLogWriter());
+	}
+}
+
 int main(int argc, char* argv[])
 {
-	AddLogWriter(createWin32ConsoleLogger());
-	ToggleLogging(true);
-
 	setlocale(LC_ALL, "");
 
-	Interface::SanityCheck(VERSION_GEMRB);
+	auto hConsole = GetStdHandle(STD_OUTPUT_HANDLE);
+	DWORD dwMode = 0;
+	GetConsoleMode(hConsole, &dwMode);
+	SetConsoleMode(hConsole, dwMode | ENABLE_VIRTUAL_TERMINAL_PROCESSING);
 
-	core = new Interface();
-	CFGConfig* config = new CFGConfig(argc, argv);
+	int ret = GEM_OK;
+	try {
+		auto cfg = LoadFromArgs(argc, argv);
+		SetupLogging(cfg);
 
-	if (core->Init( config ) == GEM_ERROR) {
-		delete config;
-		delete( core );
-		Log(MESSAGE, "Main", "Aborting due to fatal error...");
+		SanityCheck();
 
-		ToggleLogging(false); // Windows build will hang if we leave the logging thread running
-		return -1;
+		Interface gemrb(std::move(cfg));
+		gemrb.Main();
+	} catch (CoreInitializationException& cie) {
+		Log(FATAL, "Main", "Aborting due to fatal error... {}", cie);
+		ret = GEM_ERROR;
 	}
-	delete config;
 
-	core->Main();
-	delete( core );
+	VideoDriver.reset();
+	PluginMgr::Get()->RunCleanup();
 
 	ToggleLogging(false); // Windows build will hang if we leave the logging thread running
-	return 0;
+	SetConsoleMode(hConsole, dwMode);
+	return ret;
 }
