@@ -3,7 +3,7 @@
 import os
 
 class Base:
-    SIGN = ""
+    SIGN = b""
     def __init__(self, io=None):
         if io:
             self.load(io)
@@ -30,4 +30,4 @@ def BaseFactory(io, class_list):
         sign = io.read(len(c.SIGN))
         io.seek(pos, os.SEEK_SET)
         if sign == c.SIGN:
-            return c(io)
\ No newline at end of file
+            return c(io)
